(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   6546956,     120671]
NotebookOptionsPosition[   6528400,     120444]
NotebookOutlinePosition[   6528853,     120462]
CellTagsIndexPosition[   6528810,     120459]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SeedRandom", "[", "1", "]"}], " ", 
   RowBox[{"(*", 
    RowBox[{
    "Set", " ", "a", " ", "random", " ", "seed", " ", "to", " ", "ensure", 
     " ", "results", " ", "are", " ", "consistent", " ", "when", " ", "the", 
     " ", "notebook", " ", "is", " ", "run", " ", "on", " ", "different", " ", 
     RowBox[{"occasions", "."}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Load", " ", "in", " ", "the", " ", "CSV", " ", "file", " ", 
      "containing", " ", "protein", " ", "descriptors"}], ",", " ", 
     RowBox[{"NP", " ", "descriptors"}], ",", " ", 
     RowBox[{"and", " ", "the", " ", "binding", " ", "energy"}], ",", " ", 
     RowBox[{"then", " ", "plot", " ", "the", " ", "correlations"}]}], "*)"}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"rawData", "=", " ", 
    RowBox[{
    "Import", "[", 
     "\"\<C:\\\\Users\\\\ianro\\\\Documents\\\\UCD\\\\NanomaterialsAugust\\\\\
Si\\ProteinPredictorSet.csv\>\"", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Dimensions", "[", "rawData", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"startNum", " ", "=", " ", "2"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"predictorLabels", "=", " ", 
    RowBox[{"rawData", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", 
       RowBox[{"startNum", ";;"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticks", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"predictorLabels", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "@", "predictorLabels"}]}], "}"}]}], "]"}], 
         ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"None", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Rotate", "[", 
              RowBox[{
               RowBox[{"predictorLabels", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", 
               RowBox[{"90", " ", "Degree"}]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "@", "predictorLabels"}]}], "}"}]}], "]"}]}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"MatrixPlot", "[", 
    RowBox[{
     RowBox[{"Correlation", "[", 
      RowBox[{"rawData", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"2", ";;"}], ",", 
         RowBox[{"startNum", ";;"}]}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", "ticks"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numProteins", " ", "=", " ", "59"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"auHamaker", " ", "=", " ", "72.08829"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tiO2Hamaker", " ", "=", " ", "8.775015"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Prepare", " ", "the", " ", 
     RowBox[{"data", ":", " ", 
      RowBox[{
      "convert", " ", "the", " ", "boolean", " ", "material", " ", "index", 
       " ", "to", " ", "a", " ", "float", " ", "and", " ", "rescale", " ", 
       "energies", " ", "by", " ", "the", " ", "average", " ", "Hamaker", " ",
        "constant"}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"rawData", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"2", ";;"}], ",", 
        RowBox[{"-", "3"}]}], "]"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"rawData", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"2", ";;"}], ",", 
         RowBox[{"-", "3"}]}], "]"}], "]"}], "*", "1.0"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"rawData", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"2", ";;", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"numProteins", "*", "4"}], "+", "1"}], ")"}]}], ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}], " ", "=", 
     RowBox[{
      RowBox[{"rawData", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"2", ";;", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"numProteins", "*", "4"}], "+", "1"}], ")"}]}], ",", 
         RowBox[{"-", "1"}]}], "]"}], "]"}], " ", "/", "auHamaker"}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"rawData", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"numProteins", "*", "4"}], "+", "2"}], ")"}], ";;"}], ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"rawData", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"numProteins", "*", "4"}], "+", "2"}], ")"}], ";;"}], ",", 
         RowBox[{"-", "1"}]}], "]"}], "]"}], "/", "tiO2Hamaker"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8045848270178194`*^9, 3.8045848596931076`*^9}, {
   3.8045959025624833`*^9, 3.8045959052560205`*^9}, {3.805172195195793*^9, 
   3.8051722052353096`*^9}, {3.805172363664761*^9, 3.8051723640815935`*^9}, {
   3.8051723979559717`*^9, 3.8051723980943594`*^9}, {3.805702582860469*^9, 
   3.8057026347929688`*^9}, {3.8057027018665843`*^9, 3.805702703388138*^9}, 
   3.807794341042885*^9, {3.8077947547490406`*^9, 3.8077947806194897`*^9}, {
   3.807795023631029*^9, 3.8077950325402665`*^9}, {3.807812844737937*^9, 
   3.807812845923723*^9}, {3.8079472301291776`*^9, 3.8079472784775476`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"a55fe3f7-2029-40ee-abb6-d052e0c9017a"],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   FrameBox[GridBox[{
      {
       ItemBox[
        TagBox[
         RowBox[{"{", 
          TemplateBox[{"1"},
           "OutputSizeLimit`Skeleton"], "}"}],
         Short[#, 5]& ],
        BaseStyle->{Deployed -> False},
        StripOnInput->False]},
      {GridBox[{
         {
          PaneBox[
           TagBox[
            TooltipBox[
             StyleBox[
              StyleBox[
               DynamicBox[ToBoxes[
                 FEPrivate`FrontEndResource[
                 "FEStrings", "sizeBriefExplanation"], StandardForm],
                ImageSizeCache->{65., {2., 8.}}],
               StripOnInput->False,
               DynamicUpdating->True,
               LineSpacing->{1, 2},
               LineIndent->0,
               LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLText",
              StripOnInput->False],
             StyleBox[
              DynamicBox[
               ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
                StandardForm]], DynamicUpdating -> True, LineIndent -> 0, 
              LinebreakAdjustments -> {1., 100, 0, 0, 0}, 
              LineSpacing -> {1, 2}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Dynamic[
               FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"]], 
              DynamicUpdating -> True, LineIndent -> 0, 
              LinebreakAdjustments -> {1., 100, 0, 0, 0}, 
              LineSpacing -> {1, 2}], "Tooltip"]& ],
           Alignment->Center,
           BaselinePosition->Baseline,
           ImageSize->{Automatic, {25, Full}}], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{50., {1., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, {25, Full}}],
           Appearance->None,
           BaselinePosition->Baseline,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 2, 33816624755361754876, 5/2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{58., {1., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, {25, Full}}],
           Appearance->None,
           BaselinePosition->Baseline,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 2, 33816624755361754876, 5 2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{43., {1., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{43., {1., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, {25, Full}}],
           Appearance->None,
           BaselinePosition->Baseline,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 2, 33816624755361754876, Infinity],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{72., {1., 8.}}],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, {25, Full}}],
           Appearance->None,
           BaselinePosition->Baseline,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetOptions[
              FrontEnd`$FrontEnd, 
               FrontEnd`PreferencesSettings -> {"Page" -> "Advanced"}], 
              FrontEnd`FrontEndToken["PreferencesDialog"]}],
           Evaluator->None,
           Method->"Preemptive"]}
        },
        AutoDelete->False,
        FrameStyle->GrayLevel[0.85],
        GridBoxDividers->{"Columns" -> {False, {True}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{2}}}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
     GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], 
         Offset[1.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    BaseStyle->"OutputSizeLimit",
    FrameMargins->{{12, 12}, {0, 15}},
    FrameStyle->GrayLevel[0.85],
    RoundingRadius->5,
    StripOnInput->False],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  If[33816624755361754876 === $SessionID, 
   Out[2], Message[
     MessageName[Syntax, "noinfoker"]]; Missing["NotAvailable"]; 
   Null]]], "Output",
 CellChangeTimes->{3.809748064969385*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"bd6bc1e8-c6f2-42dc-9020-4047684b94db"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"473", ",", "181"}], "}"}]], "Output",
 CellChangeTimes->{3.809748065037197*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"658d6a5b-21d1-46be-859f-5b2ab43482d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"MolecularWeight\"\>", ",", "\<\"Residues\"\>", 
   ",", "\<\"AverageResidueWeight\"\>", ",", "\<\"Charge\"\>", 
   ",", "\<\"IsoelectricPoint\"\>", 
   ",", "\<\"MolarExtinctionCoefficientsReduced\"\>", 
   ",", "\<\"MolarExtinctionCoefficientsCB\"\>", 
   ",", "\<\"ExtinctionCoefficientsReduced\"\>", 
   ",", "\<\"ExtinctionCoefficientsCB\"\>", 
   ",", "\<\"ProbabilityOfExpressionInInclusionBodies\"\>", 
   ",", "\<\"AlaNumber\"\>", ",", "\<\"AlaMole\"\>", 
   ",", "\<\"AlaDayhoffStat\"\>", ",", "\<\"CysNumber\"\>", 
   ",", "\<\"CyseMole\"\>", ",", "\<\"CysteineDayhoffStat\"\>", 
   ",", "\<\"AspNumber\"\>", ",", "\<\"AspMole\"\>", 
   ",", "\<\"AspDayhoffStat\"\>", ",", "\<\"GluNumber\"\>", 
   ",", "\<\"GluMole\"\>", ",", "\<\"GluDayhoffStat\"\>", 
   ",", "\<\"PheNumber\"\>", ",", "\<\"PheMole\"\>", 
   ",", "\<\"PheDayhoffStat\"\>", ",", "\<\"GlyNumber\"\>", 
   ",", "\<\"GlyMole\"\>", ",", "\<\"GlyDayhoffStat\"\>", 
   ",", "\<\"HisNumber\"\>", ",", "\<\"HisMole\"\>", 
   ",", "\<\"HisDayhoffStat\"\>", ",", "\<\"IleNumber\"\>", 
   ",", "\<\"IleMole\"\>", ",", "\<\"IleDayhoffStat\"\>", 
   ",", "\<\"LysNumber\"\>", ",", "\<\"LysMole\"\>", 
   ",", "\<\"LysDayhoffStat\"\>", ",", "\<\"LeuNumber\"\>", 
   ",", "\<\"LeuMole\"\>", ",", "\<\"LeuDayhoffStat\"\>", 
   ",", "\<\"MetNumber\"\>", ",", "\<\"MetMole\"\>", 
   ",", "\<\"MetDayhoffStat\"\>", ",", "\<\"AsnNumber\"\>", 
   ",", "\<\"AsnMole\"\>", ",", "\<\"AsnDayhoffStat\"\>", 
   ",", "\<\"ProNumber\"\>", ",", "\<\"ProMole\"\>", 
   ",", "\<\"ProDayhoffStat\"\>", ",", "\<\"GlnNumber\"\>", 
   ",", "\<\"GlnMole\"\>", ",", "\<\"GlnDayhoffStat\"\>", 
   ",", "\<\"ArgNumber\"\>", ",", "\<\"ArgMole\"\>", 
   ",", "\<\"ArgDayhoffStat\"\>", ",", "\<\"SerNumber\"\>", 
   ",", "\<\"SerMole\"\>", ",", "\<\"SerDayhoffStat\"\>", 
   ",", "\<\"ThrNumber\"\>", ",", "\<\"ThrMole\"\>", 
   ",", "\<\"ThrDayhoffStat\"\>", ",", "\<\"ValNumber\"\>", 
   ",", "\<\"ValMole\"\>", ",", "\<\"ValDayhoffStat\"\>", 
   ",", "\<\"TrpNumber\"\>", ",", "\<\"TrpMole\"\>", 
   ",", "\<\"TrpDayhoffStat\"\>", ",", "\<\"TyrNumber\"\>", 
   ",", "\<\"TyrMole\"\>", ",", "\<\"TyrDayhoffStat\"\>", 
   ",", "\<\"TinyNumber\"\>", ",", "\<\"TinyMole\"\>", 
   ",", "\<\"SmallNumber\"\>", ",", "\<\"SmallMole\"\>", 
   ",", "\<\"AliphaticNumber\"\>", ",", "\<\"AliphaticMole\"\>", 
   ",", "\<\"AromaticNumber\"\>", ",", "\<\"AromaticMole\"\>", 
   ",", "\<\"NonPolarNumber\"\>", ",", "\<\"NonPolarMole\"\>", 
   ",", "\<\"PolarNumber\"\>", ",", "\<\"PolarMole\"\>", 
   ",", "\<\"ChargedNumber\"\>", ",", "\<\"ChargedMole\"\>", 
   ",", "\<\"BasicNumber\"\>", ",", "\<\"BasicMole\"\>", 
   ",", "\<\"AcidicNumber\"\>", ",", "\<\"AcidicMole\"\>", 
   ",", "\<\"Surface Area (A2)\"\>", ",", "\<\"Volume (A3)\"\>", 
   ",", "\<\"Sphericity\"\>", 
   ",", "\<\"First Principle Moment Of Inertia (Da A2)\"\>", 
   ",", "\<\"Second Principle Moment Of Inertia (Da A2)\"\>", 
   ",", "\<\"Third Principle Moment Of Inertia (Da A2)\"\>", 
   ",", "\<\"First Dipole Moment (Z A)\"\>", 
   ",", "\<\"Second Dipole Moment (Z A)\"\>", 
   ",", "\<\"Third Dipole Moment (Z A)\"\>", 
   ",", "\<\"Surface Amino Acids\"\>", ",", "\<\"Surface Amino Acids %\"\>", 
   ",", "\<\"Surface ALA\"\>", ",", "\<\"Surface ALA %\"\>", 
   ",", "\<\"Surface ALA Dayhoff %\"\>", ",", "\<\"Surface ARG\"\>", 
   ",", "\<\"Surface ARG %\"\>", ",", "\<\"Surface ARG Dayhoff %\"\>", 
   ",", "\<\"Surface ASN\"\>", ",", "\<\"Surface ASN %\"\>", 
   ",", "\<\"Surface ASN Dayhoff %\"\>", ",", "\<\"Surface ASP\"\>", 
   ",", "\<\"Surface ASP %\"\>", ",", "\<\"Surface ASP Dayhoff %\"\>", 
   ",", "\<\"Surface CYS\"\>", ",", "\<\"Surface CYS %\"\>", 
   ",", "\<\"Surface CYS Dayhoff %\"\>", ",", "\<\"Surface GLN\"\>", 
   ",", "\<\"Surface GLN %\"\>", ",", "\<\"Surface GLN Dayhoff %\"\>", 
   ",", "\<\"Surface GLU\"\>", ",", "\<\"Surface GLU %\"\>", 
   ",", "\<\"Surface GLU Dayhoff %\"\>", ",", "\<\"Surface GLY\"\>", 
   ",", "\<\"Surface GLY %\"\>", ",", "\<\"Surface GLY Dayhoff %\"\>", 
   ",", "\<\"Surface HIS\"\>", ",", "\<\"Surface HIS %\"\>", 
   ",", "\<\"Surface HIS Dayhoff %\"\>", ",", "\<\"Surface ILE\"\>", 
   ",", "\<\"Surface ILE %\"\>", ",", "\<\"Surface ILE Dayhoff %\"\>", 
   ",", "\<\"Surface LEU\"\>", ",", "\<\"Surface LEU %\"\>", 
   ",", "\<\"Surface LEU Dayhoff %\"\>", ",", "\<\"Surface LYS\"\>", 
   ",", "\<\"Surface LYS %\"\>", ",", "\<\"Surface LYS Dayhoff %\"\>", 
   ",", "\<\"Surface MET\"\>", ",", "\<\"Surface MET %\"\>", 
   ",", "\<\"Surface MET Dayhoff %\"\>", ",", "\<\"Surface PHE\"\>", 
   ",", "\<\"Surface PHE %\"\>", ",", "\<\"Surface PHE Dayhoff %\"\>", 
   ",", "\<\"Surface PRO\"\>", ",", "\<\"Surface PRO %\"\>", 
   ",", "\<\"Surface PRO Dayhoff %\"\>", ",", "\<\"Surface SER\"\>", 
   ",", "\<\"Surface SER %\"\>", ",", "\<\"Surface SER Dayhoff %\"\>", 
   ",", "\<\"Surface THR\"\>", ",", "\<\"Surface THR %\"\>", 
   ",", "\<\"Surface THR Dayhoff %\"\>", ",", "\<\"Surface TRP\"\>", 
   ",", "\<\"Surface TRP %\"\>", ",", "\<\"Surface TRP Dayhoff %\"\>", 
   ",", "\<\"Surface TYR\"\>", ",", "\<\"Surface TYR %\"\>", 
   ",", "\<\"Surface TYR Dayhoff %\"\>", ",", "\<\"Surface VAL\"\>", 
   ",", "\<\"Surface VAL %\"\>", ",", "\<\"Surface VAL Dayhoff %\"\>", 
   ",", "\<\"Surface Tiny\"\>", ",", "\<\"Surface Tiny %\"\>", 
   ",", "\<\"Surface Small\"\>", ",", "\<\"Surface Small %\"\>", 
   ",", "\<\"Surface Aliphatic\"\>", ",", "\<\"Surface Aliphatic %\"\>", 
   ",", "\<\"Surface Aromatic\"\>", ",", "\<\"Surface Aromatic %\"\>", 
   ",", "\<\"Surface Non-Polar\"\>", ",", "\<\"Surface Non-Polar %\"\>", 
   ",", "\<\"Surface Polar\"\>", ",", "\<\"Surface Polar %\"\>", 
   ",", "\<\"Surface Charged\"\>", ",", "\<\"Surface Charged %\"\>", 
   ",", "\<\"Surface Basic\"\>", ",", "\<\"Surface Basic %\"\>", 
   ",", "\<\"Surface Acidic\"\>", ",", "\<\"Surface Acidic %\"\>", 
   ",", "\<\"np-material\"\>", ",", "\<\"NP-radius\"\>", 
   ",", "\<\"Eads/kbt\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.8097480651117325`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"797e7b4c-8bdf-4782-8fd9-df63b9e0144e"],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzs3Gk0le8fP3oNGlQ0KGMlTZIomSp5k4hQSkQo0aCUpBQhQgMqkiFS5lKk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   "], {{0, 0}, {180, 180}}, {0, 1}],
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{{{179.5, 
       FormBox["\"MolecularWeight\"", TraditionalForm]}, {178.5, 
       FormBox["\"Residues\"", TraditionalForm]}, {177.5, 
       FormBox["\"AverageResidueWeight\"", TraditionalForm]}, {176.5, 
       FormBox["\"Charge\"", TraditionalForm]}, {175.5, 
       FormBox["\"IsoelectricPoint\"", TraditionalForm]}, {174.5, 
       FormBox["\"MolarExtinctionCoefficientsReduced\"", TraditionalForm]}, {
      173.5, 
       FormBox["\"MolarExtinctionCoefficientsCB\"", TraditionalForm]}, {172.5, 
       FormBox["\"ExtinctionCoefficientsReduced\"", TraditionalForm]}, {171.5, 
       FormBox["\"ExtinctionCoefficientsCB\"", TraditionalForm]}, {170.5, 
       FormBox[
       "\"ProbabilityOfExpressionInInclusionBodies\"", TraditionalForm]}, {
      169.5, 
       FormBox["\"AlaNumber\"", TraditionalForm]}, {168.5, 
       FormBox["\"AlaMole\"", TraditionalForm]}, {167.5, 
       FormBox["\"AlaDayhoffStat\"", TraditionalForm]}, {166.5, 
       FormBox["\"CysNumber\"", TraditionalForm]}, {165.5, 
       FormBox["\"CyseMole\"", TraditionalForm]}, {164.5, 
       FormBox["\"CysteineDayhoffStat\"", TraditionalForm]}, {163.5, 
       FormBox["\"AspNumber\"", TraditionalForm]}, {162.5, 
       FormBox["\"AspMole\"", TraditionalForm]}, {161.5, 
       FormBox["\"AspDayhoffStat\"", TraditionalForm]}, {160.5, 
       FormBox["\"GluNumber\"", TraditionalForm]}, {159.5, 
       FormBox["\"GluMole\"", TraditionalForm]}, {158.5, 
       FormBox["\"GluDayhoffStat\"", TraditionalForm]}, {157.5, 
       FormBox["\"PheNumber\"", TraditionalForm]}, {156.5, 
       FormBox["\"PheMole\"", TraditionalForm]}, {155.5, 
       FormBox["\"PheDayhoffStat\"", TraditionalForm]}, {154.5, 
       FormBox["\"GlyNumber\"", TraditionalForm]}, {153.5, 
       FormBox["\"GlyMole\"", TraditionalForm]}, {152.5, 
       FormBox["\"GlyDayhoffStat\"", TraditionalForm]}, {151.5, 
       FormBox["\"HisNumber\"", TraditionalForm]}, {150.5, 
       FormBox["\"HisMole\"", TraditionalForm]}, {149.5, 
       FormBox["\"HisDayhoffStat\"", TraditionalForm]}, {148.5, 
       FormBox["\"IleNumber\"", TraditionalForm]}, {147.5, 
       FormBox["\"IleMole\"", TraditionalForm]}, {146.5, 
       FormBox["\"IleDayhoffStat\"", TraditionalForm]}, {145.5, 
       FormBox["\"LysNumber\"", TraditionalForm]}, {144.5, 
       FormBox["\"LysMole\"", TraditionalForm]}, {143.5, 
       FormBox["\"LysDayhoffStat\"", TraditionalForm]}, {142.5, 
       FormBox["\"LeuNumber\"", TraditionalForm]}, {141.5, 
       FormBox["\"LeuMole\"", TraditionalForm]}, {140.5, 
       FormBox["\"LeuDayhoffStat\"", TraditionalForm]}, {139.5, 
       FormBox["\"MetNumber\"", TraditionalForm]}, {138.5, 
       FormBox["\"MetMole\"", TraditionalForm]}, {137.5, 
       FormBox["\"MetDayhoffStat\"", TraditionalForm]}, {136.5, 
       FormBox["\"AsnNumber\"", TraditionalForm]}, {135.5, 
       FormBox["\"AsnMole\"", TraditionalForm]}, {134.5, 
       FormBox["\"AsnDayhoffStat\"", TraditionalForm]}, {133.5, 
       FormBox["\"ProNumber\"", TraditionalForm]}, {132.5, 
       FormBox["\"ProMole\"", TraditionalForm]}, {131.5, 
       FormBox["\"ProDayhoffStat\"", TraditionalForm]}, {130.5, 
       FormBox["\"GlnNumber\"", TraditionalForm]}, {129.5, 
       FormBox["\"GlnMole\"", TraditionalForm]}, {128.5, 
       FormBox["\"GlnDayhoffStat\"", TraditionalForm]}, {127.5, 
       FormBox["\"ArgNumber\"", TraditionalForm]}, {126.5, 
       FormBox["\"ArgMole\"", TraditionalForm]}, {125.5, 
       FormBox["\"ArgDayhoffStat\"", TraditionalForm]}, {124.5, 
       FormBox["\"SerNumber\"", TraditionalForm]}, {123.5, 
       FormBox["\"SerMole\"", TraditionalForm]}, {122.5, 
       FormBox["\"SerDayhoffStat\"", TraditionalForm]}, {121.5, 
       FormBox["\"ThrNumber\"", TraditionalForm]}, {120.5, 
       FormBox["\"ThrMole\"", TraditionalForm]}, {119.5, 
       FormBox["\"ThrDayhoffStat\"", TraditionalForm]}, {118.5, 
       FormBox["\"ValNumber\"", TraditionalForm]}, {117.5, 
       FormBox["\"ValMole\"", TraditionalForm]}, {116.5, 
       FormBox["\"ValDayhoffStat\"", TraditionalForm]}, {115.5, 
       FormBox["\"TrpNumber\"", TraditionalForm]}, {114.5, 
       FormBox["\"TrpMole\"", TraditionalForm]}, {113.5, 
       FormBox["\"TrpDayhoffStat\"", TraditionalForm]}, {112.5, 
       FormBox["\"TyrNumber\"", TraditionalForm]}, {111.5, 
       FormBox["\"TyrMole\"", TraditionalForm]}, {110.5, 
       FormBox["\"TyrDayhoffStat\"", TraditionalForm]}, {109.5, 
       FormBox["\"TinyNumber\"", TraditionalForm]}, {108.5, 
       FormBox["\"TinyMole\"", TraditionalForm]}, {107.5, 
       FormBox["\"SmallNumber\"", TraditionalForm]}, {106.5, 
       FormBox["\"SmallMole\"", TraditionalForm]}, {105.5, 
       FormBox["\"AliphaticNumber\"", TraditionalForm]}, {104.5, 
       FormBox["\"AliphaticMole\"", TraditionalForm]}, {103.5, 
       FormBox["\"AromaticNumber\"", TraditionalForm]}, {102.5, 
       FormBox["\"AromaticMole\"", TraditionalForm]}, {101.5, 
       FormBox["\"NonPolarNumber\"", TraditionalForm]}, {100.5, 
       FormBox["\"NonPolarMole\"", TraditionalForm]}, {99.5, 
       FormBox["\"PolarNumber\"", TraditionalForm]}, {98.5, 
       FormBox["\"PolarMole\"", TraditionalForm]}, {97.5, 
       FormBox["\"ChargedNumber\"", TraditionalForm]}, {96.5, 
       FormBox["\"ChargedMole\"", TraditionalForm]}, {95.5, 
       FormBox["\"BasicNumber\"", TraditionalForm]}, {94.5, 
       FormBox["\"BasicMole\"", TraditionalForm]}, {93.5, 
       FormBox["\"AcidicNumber\"", TraditionalForm]}, {92.5, 
       FormBox["\"AcidicMole\"", TraditionalForm]}, {91.5, 
       FormBox["\"Surface Area (A2)\"", TraditionalForm]}, {90.5, 
       FormBox["\"Volume (A3)\"", TraditionalForm]}, {89.5, 
       FormBox["\"Sphericity\"", TraditionalForm]}, {88.5, 
       FormBox[
       "\"First Principle Moment Of Inertia (Da A2)\"", TraditionalForm]}, {
      87.5, 
       FormBox[
       "\"Second Principle Moment Of Inertia (Da A2)\"", TraditionalForm]}, {
      86.5, 
       FormBox[
       "\"Third Principle Moment Of Inertia (Da A2)\"", TraditionalForm]}, {
      85.5, 
       FormBox["\"First Dipole Moment (Z A)\"", TraditionalForm]}, {84.5, 
       FormBox["\"Second Dipole Moment (Z A)\"", TraditionalForm]}, {83.5, 
       FormBox["\"Third Dipole Moment (Z A)\"", TraditionalForm]}, {82.5, 
       FormBox["\"Surface Amino Acids\"", TraditionalForm]}, {81.5, 
       FormBox["\"Surface Amino Acids %\"", TraditionalForm]}, {80.5, 
       FormBox["\"Surface ALA\"", TraditionalForm]}, {79.5, 
       FormBox["\"Surface ALA %\"", TraditionalForm]}, {78.5, 
       FormBox["\"Surface ALA Dayhoff %\"", TraditionalForm]}, {77.5, 
       FormBox["\"Surface ARG\"", TraditionalForm]}, {76.5, 
       FormBox["\"Surface ARG %\"", TraditionalForm]}, {75.5, 
       FormBox["\"Surface ARG Dayhoff %\"", TraditionalForm]}, {74.5, 
       FormBox["\"Surface ASN\"", TraditionalForm]}, {73.5, 
       FormBox["\"Surface ASN %\"", TraditionalForm]}, {72.5, 
       FormBox["\"Surface ASN Dayhoff %\"", TraditionalForm]}, {71.5, 
       FormBox["\"Surface ASP\"", TraditionalForm]}, {70.5, 
       FormBox["\"Surface ASP %\"", TraditionalForm]}, {69.5, 
       FormBox["\"Surface ASP Dayhoff %\"", TraditionalForm]}, {68.5, 
       FormBox["\"Surface CYS\"", TraditionalForm]}, {67.5, 
       FormBox["\"Surface CYS %\"", TraditionalForm]}, {66.5, 
       FormBox["\"Surface CYS Dayhoff %\"", TraditionalForm]}, {65.5, 
       FormBox["\"Surface GLN\"", TraditionalForm]}, {64.5, 
       FormBox["\"Surface GLN %\"", TraditionalForm]}, {63.5, 
       FormBox["\"Surface GLN Dayhoff %\"", TraditionalForm]}, {62.5, 
       FormBox["\"Surface GLU\"", TraditionalForm]}, {61.5, 
       FormBox["\"Surface GLU %\"", TraditionalForm]}, {60.5, 
       FormBox["\"Surface GLU Dayhoff %\"", TraditionalForm]}, {59.5, 
       FormBox["\"Surface GLY\"", TraditionalForm]}, {58.5, 
       FormBox["\"Surface GLY %\"", TraditionalForm]}, {57.5, 
       FormBox["\"Surface GLY Dayhoff %\"", TraditionalForm]}, {56.5, 
       FormBox["\"Surface HIS\"", TraditionalForm]}, {55.5, 
       FormBox["\"Surface HIS %\"", TraditionalForm]}, {54.5, 
       FormBox["\"Surface HIS Dayhoff %\"", TraditionalForm]}, {53.5, 
       FormBox["\"Surface ILE\"", TraditionalForm]}, {52.5, 
       FormBox["\"Surface ILE %\"", TraditionalForm]}, {51.5, 
       FormBox["\"Surface ILE Dayhoff %\"", TraditionalForm]}, {50.5, 
       FormBox["\"Surface LEU\"", TraditionalForm]}, {49.5, 
       FormBox["\"Surface LEU %\"", TraditionalForm]}, {48.5, 
       FormBox["\"Surface LEU Dayhoff %\"", TraditionalForm]}, {47.5, 
       FormBox["\"Surface LYS\"", TraditionalForm]}, {46.5, 
       FormBox["\"Surface LYS %\"", TraditionalForm]}, {45.5, 
       FormBox["\"Surface LYS Dayhoff %\"", TraditionalForm]}, {44.5, 
       FormBox["\"Surface MET\"", TraditionalForm]}, {43.5, 
       FormBox["\"Surface MET %\"", TraditionalForm]}, {42.5, 
       FormBox["\"Surface MET Dayhoff %\"", TraditionalForm]}, {41.5, 
       FormBox["\"Surface PHE\"", TraditionalForm]}, {40.5, 
       FormBox["\"Surface PHE %\"", TraditionalForm]}, {39.5, 
       FormBox["\"Surface PHE Dayhoff %\"", TraditionalForm]}, {38.5, 
       FormBox["\"Surface PRO\"", TraditionalForm]}, {37.5, 
       FormBox["\"Surface PRO %\"", TraditionalForm]}, {36.5, 
       FormBox["\"Surface PRO Dayhoff %\"", TraditionalForm]}, {35.5, 
       FormBox["\"Surface SER\"", TraditionalForm]}, {34.5, 
       FormBox["\"Surface SER %\"", TraditionalForm]}, {33.5, 
       FormBox["\"Surface SER Dayhoff %\"", TraditionalForm]}, {32.5, 
       FormBox["\"Surface THR\"", TraditionalForm]}, {31.5, 
       FormBox["\"Surface THR %\"", TraditionalForm]}, {30.5, 
       FormBox["\"Surface THR Dayhoff %\"", TraditionalForm]}, {29.5, 
       FormBox["\"Surface TRP\"", TraditionalForm]}, {28.5, 
       FormBox["\"Surface TRP %\"", TraditionalForm]}, {27.5, 
       FormBox["\"Surface TRP Dayhoff %\"", TraditionalForm]}, {26.5, 
       FormBox["\"Surface TYR\"", TraditionalForm]}, {25.5, 
       FormBox["\"Surface TYR %\"", TraditionalForm]}, {24.5, 
       FormBox["\"Surface TYR Dayhoff %\"", TraditionalForm]}, {23.5, 
       FormBox["\"Surface VAL\"", TraditionalForm]}, {22.5, 
       FormBox["\"Surface VAL %\"", TraditionalForm]}, {21.5, 
       FormBox["\"Surface VAL Dayhoff %\"", TraditionalForm]}, {20.5, 
       FormBox["\"Surface Tiny\"", TraditionalForm]}, {19.5, 
       FormBox["\"Surface Tiny %\"", TraditionalForm]}, {18.5, 
       FormBox["\"Surface Small\"", TraditionalForm]}, {17.5, 
       FormBox["\"Surface Small %\"", TraditionalForm]}, {16.5, 
       FormBox["\"Surface Aliphatic\"", TraditionalForm]}, {15.5, 
       FormBox["\"Surface Aliphatic %\"", TraditionalForm]}, {14.5, 
       FormBox["\"Surface Aromatic\"", TraditionalForm]}, {13.5, 
       FormBox["\"Surface Aromatic %\"", TraditionalForm]}, {12.5, 
       FormBox["\"Surface Non-Polar\"", TraditionalForm]}, {11.5, 
       FormBox["\"Surface Non-Polar %\"", TraditionalForm]}, {10.5, 
       FormBox["\"Surface Polar\"", TraditionalForm]}, {9.5, 
       FormBox["\"Surface Polar %\"", TraditionalForm]}, {8.5, 
       FormBox["\"Surface Charged\"", TraditionalForm]}, {7.5, 
       FormBox["\"Surface Charged %\"", TraditionalForm]}, {6.5, 
       FormBox["\"Surface Basic\"", TraditionalForm]}, {5.5, 
       FormBox["\"Surface Basic %\"", TraditionalForm]}, {4.5, 
       FormBox["\"Surface Acidic\"", TraditionalForm]}, {3.5, 
       FormBox["\"Surface Acidic %\"", TraditionalForm]}, {2.5, 
       FormBox["\"np-material\"", TraditionalForm]}, {1.5, 
       FormBox["\"NP-radius\"", TraditionalForm]}, {0.5, 
       FormBox["\"Eads/kbt\"", TraditionalForm]}}, None}, {None, {{0.5, 
       FormBox[
        RotationBox[
        "\"MolecularWeight\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {1.5, 
       FormBox[
        RotationBox["\"Residues\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {2.5, 
       FormBox[
        RotationBox[
        "\"AverageResidueWeight\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {3.5, 
       FormBox[
        RotationBox["\"Charge\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {4.5, 
       FormBox[
        RotationBox[
        "\"IsoelectricPoint\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {5.5, 
       FormBox[
        RotationBox[
        "\"MolarExtinctionCoefficientsReduced\"", BoxRotation -> 
         1.5707963267948966`], TraditionalForm]}, {6.5, 
       FormBox[
        RotationBox[
        "\"MolarExtinctionCoefficientsCB\"", BoxRotation -> 
         1.5707963267948966`], TraditionalForm]}, {7.5, 
       FormBox[
        RotationBox[
        "\"ExtinctionCoefficientsReduced\"", BoxRotation -> 
         1.5707963267948966`], TraditionalForm]}, {8.5, 
       FormBox[
        RotationBox[
        "\"ExtinctionCoefficientsCB\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {9.5, 
       FormBox[
        RotationBox[
        "\"ProbabilityOfExpressionInInclusionBodies\"", BoxRotation -> 
         1.5707963267948966`], TraditionalForm]}, {10.5, 
       FormBox[
        RotationBox["\"AlaNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {11.5, 
       FormBox[
        RotationBox["\"AlaMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {12.5, 
       FormBox[
        RotationBox["\"AlaDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {13.5, 
       FormBox[
        RotationBox["\"CysNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {14.5, 
       FormBox[
        RotationBox["\"CyseMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {15.5, 
       FormBox[
        RotationBox[
        "\"CysteineDayhoffStat\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {16.5, 
       FormBox[
        RotationBox["\"AspNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {17.5, 
       FormBox[
        RotationBox["\"AspMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {18.5, 
       FormBox[
        RotationBox["\"AspDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {19.5, 
       FormBox[
        RotationBox["\"GluNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {20.5, 
       FormBox[
        RotationBox["\"GluMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {21.5, 
       FormBox[
        RotationBox["\"GluDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {22.5, 
       FormBox[
        RotationBox["\"PheNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {23.5, 
       FormBox[
        RotationBox["\"PheMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {24.5, 
       FormBox[
        RotationBox["\"PheDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {25.5, 
       FormBox[
        RotationBox["\"GlyNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {26.5, 
       FormBox[
        RotationBox["\"GlyMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {27.5, 
       FormBox[
        RotationBox["\"GlyDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {28.5, 
       FormBox[
        RotationBox["\"HisNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {29.5, 
       FormBox[
        RotationBox["\"HisMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {30.5, 
       FormBox[
        RotationBox["\"HisDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {31.5, 
       FormBox[
        RotationBox["\"IleNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {32.5, 
       FormBox[
        RotationBox["\"IleMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {33.5, 
       FormBox[
        RotationBox["\"IleDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {34.5, 
       FormBox[
        RotationBox["\"LysNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {35.5, 
       FormBox[
        RotationBox["\"LysMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {36.5, 
       FormBox[
        RotationBox["\"LysDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {37.5, 
       FormBox[
        RotationBox["\"LeuNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {38.5, 
       FormBox[
        RotationBox["\"LeuMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {39.5, 
       FormBox[
        RotationBox["\"LeuDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {40.5, 
       FormBox[
        RotationBox["\"MetNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {41.5, 
       FormBox[
        RotationBox["\"MetMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {42.5, 
       FormBox[
        RotationBox["\"MetDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {43.5, 
       FormBox[
        RotationBox["\"AsnNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {44.5, 
       FormBox[
        RotationBox["\"AsnMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {45.5, 
       FormBox[
        RotationBox["\"AsnDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {46.5, 
       FormBox[
        RotationBox["\"ProNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {47.5, 
       FormBox[
        RotationBox["\"ProMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {48.5, 
       FormBox[
        RotationBox["\"ProDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {49.5, 
       FormBox[
        RotationBox["\"GlnNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {50.5, 
       FormBox[
        RotationBox["\"GlnMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {51.5, 
       FormBox[
        RotationBox["\"GlnDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {52.5, 
       FormBox[
        RotationBox["\"ArgNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {53.5, 
       FormBox[
        RotationBox["\"ArgMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {54.5, 
       FormBox[
        RotationBox["\"ArgDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {55.5, 
       FormBox[
        RotationBox["\"SerNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {56.5, 
       FormBox[
        RotationBox["\"SerMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {57.5, 
       FormBox[
        RotationBox["\"SerDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {58.5, 
       FormBox[
        RotationBox["\"ThrNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {59.5, 
       FormBox[
        RotationBox["\"ThrMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {60.5, 
       FormBox[
        RotationBox["\"ThrDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {61.5, 
       FormBox[
        RotationBox["\"ValNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {62.5, 
       FormBox[
        RotationBox["\"ValMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {63.5, 
       FormBox[
        RotationBox["\"ValDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {64.5, 
       FormBox[
        RotationBox["\"TrpNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {65.5, 
       FormBox[
        RotationBox["\"TrpMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {66.5, 
       FormBox[
        RotationBox["\"TrpDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {67.5, 
       FormBox[
        RotationBox["\"TyrNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {68.5, 
       FormBox[
        RotationBox["\"TyrMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {69.5, 
       FormBox[
        RotationBox["\"TyrDayhoffStat\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {70.5, 
       FormBox[
        RotationBox["\"TinyNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {71.5, 
       FormBox[
        RotationBox["\"TinyMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {72.5, 
       FormBox[
        RotationBox["\"SmallNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {73.5, 
       FormBox[
        RotationBox["\"SmallMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {74.5, 
       FormBox[
        RotationBox[
        "\"AliphaticNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {75.5, 
       FormBox[
        RotationBox["\"AliphaticMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {76.5, 
       FormBox[
        RotationBox["\"AromaticNumber\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {77.5, 
       FormBox[
        RotationBox["\"AromaticMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {78.5, 
       FormBox[
        RotationBox["\"NonPolarNumber\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {79.5, 
       FormBox[
        RotationBox["\"NonPolarMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {80.5, 
       FormBox[
        RotationBox["\"PolarNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {81.5, 
       FormBox[
        RotationBox["\"PolarMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {82.5, 
       FormBox[
        RotationBox["\"ChargedNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {83.5, 
       FormBox[
        RotationBox["\"ChargedMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {84.5, 
       FormBox[
        RotationBox["\"BasicNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {85.5, 
       FormBox[
        RotationBox["\"BasicMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {86.5, 
       FormBox[
        RotationBox["\"AcidicNumber\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {87.5, 
       FormBox[
        RotationBox["\"AcidicMole\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {88.5, 
       FormBox[
        RotationBox[
        "\"Surface Area (A2)\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {89.5, 
       FormBox[
        RotationBox["\"Volume (A3)\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {90.5, 
       FormBox[
        RotationBox["\"Sphericity\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {91.5, 
       FormBox[
        RotationBox[
        "\"First Principle Moment Of Inertia (Da A2)\"", BoxRotation -> 
         1.5707963267948966`], TraditionalForm]}, {92.5, 
       FormBox[
        RotationBox[
        "\"Second Principle Moment Of Inertia (Da A2)\"", BoxRotation -> 
         1.5707963267948966`], TraditionalForm]}, {93.5, 
       FormBox[
        RotationBox[
        "\"Third Principle Moment Of Inertia (Da A2)\"", BoxRotation -> 
         1.5707963267948966`], TraditionalForm]}, {94.5, 
       FormBox[
        RotationBox[
        "\"First Dipole Moment (Z A)\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {95.5, 
       FormBox[
        RotationBox[
        "\"Second Dipole Moment (Z A)\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {96.5, 
       FormBox[
        RotationBox[
        "\"Third Dipole Moment (Z A)\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {97.5, 
       FormBox[
        RotationBox[
        "\"Surface Amino Acids\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {98.5, 
       FormBox[
        RotationBox[
        "\"Surface Amino Acids %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {99.5, 
       FormBox[
        RotationBox["\"Surface ALA\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {100.5, 
       FormBox[
        RotationBox["\"Surface ALA %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {101.5, 
       FormBox[
        RotationBox[
        "\"Surface ALA Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {102.5, 
       FormBox[
        RotationBox["\"Surface ARG\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {103.5, 
       FormBox[
        RotationBox["\"Surface ARG %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {104.5, 
       FormBox[
        RotationBox[
        "\"Surface ARG Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {105.5, 
       FormBox[
        RotationBox["\"Surface ASN\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {106.5, 
       FormBox[
        RotationBox["\"Surface ASN %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {107.5, 
       FormBox[
        RotationBox[
        "\"Surface ASN Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {108.5, 
       FormBox[
        RotationBox["\"Surface ASP\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {109.5, 
       FormBox[
        RotationBox["\"Surface ASP %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {110.5, 
       FormBox[
        RotationBox[
        "\"Surface ASP Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {111.5, 
       FormBox[
        RotationBox["\"Surface CYS\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {112.5, 
       FormBox[
        RotationBox["\"Surface CYS %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {113.5, 
       FormBox[
        RotationBox[
        "\"Surface CYS Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {114.5, 
       FormBox[
        RotationBox["\"Surface GLN\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {115.5, 
       FormBox[
        RotationBox["\"Surface GLN %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {116.5, 
       FormBox[
        RotationBox[
        "\"Surface GLN Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {117.5, 
       FormBox[
        RotationBox["\"Surface GLU\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {118.5, 
       FormBox[
        RotationBox["\"Surface GLU %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {119.5, 
       FormBox[
        RotationBox[
        "\"Surface GLU Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {120.5, 
       FormBox[
        RotationBox["\"Surface GLY\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {121.5, 
       FormBox[
        RotationBox["\"Surface GLY %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {122.5, 
       FormBox[
        RotationBox[
        "\"Surface GLY Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {123.5, 
       FormBox[
        RotationBox["\"Surface HIS\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {124.5, 
       FormBox[
        RotationBox["\"Surface HIS %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {125.5, 
       FormBox[
        RotationBox[
        "\"Surface HIS Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {126.5, 
       FormBox[
        RotationBox["\"Surface ILE\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {127.5, 
       FormBox[
        RotationBox["\"Surface ILE %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {128.5, 
       FormBox[
        RotationBox[
        "\"Surface ILE Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {129.5, 
       FormBox[
        RotationBox["\"Surface LEU\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {130.5, 
       FormBox[
        RotationBox["\"Surface LEU %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {131.5, 
       FormBox[
        RotationBox[
        "\"Surface LEU Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {132.5, 
       FormBox[
        RotationBox["\"Surface LYS\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {133.5, 
       FormBox[
        RotationBox["\"Surface LYS %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {134.5, 
       FormBox[
        RotationBox[
        "\"Surface LYS Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {135.5, 
       FormBox[
        RotationBox["\"Surface MET\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {136.5, 
       FormBox[
        RotationBox["\"Surface MET %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {137.5, 
       FormBox[
        RotationBox[
        "\"Surface MET Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {138.5, 
       FormBox[
        RotationBox["\"Surface PHE\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {139.5, 
       FormBox[
        RotationBox["\"Surface PHE %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {140.5, 
       FormBox[
        RotationBox[
        "\"Surface PHE Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {141.5, 
       FormBox[
        RotationBox["\"Surface PRO\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {142.5, 
       FormBox[
        RotationBox["\"Surface PRO %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {143.5, 
       FormBox[
        RotationBox[
        "\"Surface PRO Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {144.5, 
       FormBox[
        RotationBox["\"Surface SER\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {145.5, 
       FormBox[
        RotationBox["\"Surface SER %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {146.5, 
       FormBox[
        RotationBox[
        "\"Surface SER Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {147.5, 
       FormBox[
        RotationBox["\"Surface THR\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {148.5, 
       FormBox[
        RotationBox["\"Surface THR %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {149.5, 
       FormBox[
        RotationBox[
        "\"Surface THR Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {150.5, 
       FormBox[
        RotationBox["\"Surface TRP\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {151.5, 
       FormBox[
        RotationBox["\"Surface TRP %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {152.5, 
       FormBox[
        RotationBox[
        "\"Surface TRP Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {153.5, 
       FormBox[
        RotationBox["\"Surface TYR\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {154.5, 
       FormBox[
        RotationBox["\"Surface TYR %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {155.5, 
       FormBox[
        RotationBox[
        "\"Surface TYR Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {156.5, 
       FormBox[
        RotationBox["\"Surface VAL\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {157.5, 
       FormBox[
        RotationBox["\"Surface VAL %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {158.5, 
       FormBox[
        RotationBox[
        "\"Surface VAL Dayhoff %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {159.5, 
       FormBox[
        RotationBox["\"Surface Tiny\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {160.5, 
       FormBox[
        RotationBox["\"Surface Tiny %\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {161.5, 
       FormBox[
        RotationBox["\"Surface Small\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {162.5, 
       FormBox[
        RotationBox[
        "\"Surface Small %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {163.5, 
       FormBox[
        RotationBox[
        "\"Surface Aliphatic\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {164.5, 
       FormBox[
        RotationBox[
        "\"Surface Aliphatic %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {165.5, 
       FormBox[
        RotationBox[
        "\"Surface Aromatic\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {166.5, 
       FormBox[
        RotationBox[
        "\"Surface Aromatic %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {167.5, 
       FormBox[
        RotationBox[
        "\"Surface Non-Polar\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {168.5, 
       FormBox[
        RotationBox[
        "\"Surface Non-Polar %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {169.5, 
       FormBox[
        RotationBox["\"Surface Polar\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {170.5, 
       FormBox[
        RotationBox[
        "\"Surface Polar %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {171.5, 
       FormBox[
        RotationBox[
        "\"Surface Charged\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {172.5, 
       FormBox[
        RotationBox[
        "\"Surface Charged %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {173.5, 
       FormBox[
        RotationBox["\"Surface Basic\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {174.5, 
       FormBox[
        RotationBox[
        "\"Surface Basic %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {175.5, 
       FormBox[
        RotationBox["\"Surface Acidic\"", BoxRotation -> 1.5707963267948966`],
         TraditionalForm]}, {176.5, 
       FormBox[
        RotationBox[
        "\"Surface Acidic %\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {177.5, 
       FormBox[
        RotationBox["\"np-material\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {178.5, 
       FormBox[
        RotationBox["\"NP-radius\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}, {179.5, 
       FormBox[
        RotationBox["\"Eads/kbt\"", BoxRotation -> 1.5707963267948966`], 
        TraditionalForm]}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic, "DomainPadding" -> Scaled[0.02], "RangePadding" -> 
    Scaled[0.05]}]], "Output",
 CellChangeTimes->{3.809748065780682*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"fe39fe13-f10a-47c1-9bbb-02b7c1ffab5b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.8045848270178194`*^9, 3.8045848596931076`*^9}, {
  3.8045959025624833`*^9, 3.8045959052560205`*^9}, {3.805172195195793*^9, 
  3.8051722052353096`*^9}, {3.805172363664761*^9, 3.8051723640815935`*^9}, {
  3.8051723979559717`*^9, 3.8051723980943594`*^9}, {3.805702582860469*^9, 
  3.805702699734916*^9}},ExpressionUUID->"aa6c0a0c-b477-41ce-aedc-\
d10d7c9bb961"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Perform", " ", "and", " ", "save", " ", "the", " ", "PCA", " ", "results",
     " ", "to", " ", "a", " ", "file"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"trialDataSet", " ", "=", " ", 
     RowBox[{"rawData", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"2", ";;", 
         RowBox[{"(", 
          RowBox[{"numProteins", "+", "1"}], ")"}]}], ",", 
        RowBox[{"startNum", ";;", 
         RowBox[{"-", "4"}]}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dimensions", "[", "trialDataSet", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"meanCenteredData", "=", 
     RowBox[{
      RowBox[{"Thread", "[", 
       RowBox[{"f", "[", "trialDataSet", "]"}], "]"}], " ", "/.", " ", 
      RowBox[{
       RowBox[{"f", "[", "x_", "]"}], "\[RuleDelayed]", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{"Mean", " ", "[", "trialDataSet", "]"}]}], ")"}], "/", 
        RowBox[{"StandardDeviation", "[", "trialDataSet", "]"}]}]}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"covarMatrix", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"Transpose", "[", "meanCenteredData", "]"}], ".", 
       "meanCenteredData"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Length", "[", "meanCenteredData", "]"}], "-", "1"}], 
       ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"datasetEigenSystem", "=", 
     RowBox[{"Eigensystem", "[", "covarMatrix", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"datasetEigenVectors", " ", "=", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"datasetEigenSystem", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"principleComponentSets", "=", 
     RowBox[{"meanCenteredData", ".", "datasetEigenVectors"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"varianceProportions", "=", 
     RowBox[{"100", "*", 
      RowBox[{
       RowBox[{"datasetEigenSystem", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "/", 
       RowBox[{"Tr", "[", "covarMatrix", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"targetPercentage", " ", "=", " ", "80"}], "\[IndentingNewLine]", 
   RowBox[{"varsToInclude", "=", 
    RowBox[{
     RowBox[{"FirstPosition", "[", " ", 
      RowBox[{
       RowBox[{"Accumulate", "[", "varianceProportions", "]"}], ",", " ", 
       RowBox[{"x_", " ", "/;", " ", 
        RowBox[{"x", ">", "targetPercentage"}]}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"formattedData", "=", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "\"\<  \>\"", "}"}], ",", 
         RowBox[{"predictorLabels", "[", 
          RowBox[{"[", 
           RowBox[{";;", 
            RowBox[{"-", "4"}]}], "]"}], "]"}]}], "]"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Join", "[", " ", 
         RowBox[{
          RowBox[{"{", "\"\<mean\>\"", "}"}], ",", " ", 
          RowBox[{"Mean", "[", "trialDataSet", "]"}]}], "]"}], "//", "N"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Join", "[", " ", 
         RowBox[{
          RowBox[{"{", "\"\<sdev\>\"", "}"}], ",", " ", 
          RowBox[{"StandardDeviation", "[", "trialDataSet", "]"}]}], "]"}], "//",
         "N"}], "}"}], ",", "\[IndentingNewLine]", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<x\>\"", "<>", 
            RowBox[{"ToString", "[", "i", "]"}], "<>", "\"\< [\>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"varianceProportions", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], "<>", "\"\< %]\>\""}], 
           " ", "}"}], ",", " ", 
          RowBox[{"datasetEigenVectors", "[", 
           RowBox[{"[", 
            RowBox[{";;", ",", "i"}], "]"}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "varsToInclude"}], "}"}]}], "]"}]}], 
     "  ", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{"\"\<descriptor_pca_59-2d.csv\>\"", ",", 
     RowBox[{"Transpose", "[", "formattedData", "]"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.804584875614585*^9, 3.804584895500905*^9}, {
  3.807794887131542*^9, 3.8077948999220614`*^9}, {3.8078128617984467`*^9, 
  3.807812865122681*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"8de9aeb2-890e-4bc2-840f-abd23110d055"],

Cell[BoxData["80"], "Output",
 CellChangeTimes->{3.809748075083166*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"6c77e2f8-a859-42e1-9316-9ee3485753eb"],

Cell[BoxData["10"], "Output",
 CellChangeTimes->{3.8097480751071014`*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"17bd84da-37c5-4069-9e3b-5c5fd411b564"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"  \"\>", ",", "\<\"MolecularWeight\"\>", 
     ",", "\<\"Residues\"\>", ",", "\<\"AverageResidueWeight\"\>", 
     ",", "\<\"Charge\"\>", ",", "\<\"IsoelectricPoint\"\>", 
     ",", "\<\"MolarExtinctionCoefficientsReduced\"\>", 
     ",", "\<\"MolarExtinctionCoefficientsCB\"\>", 
     ",", "\<\"ExtinctionCoefficientsReduced\"\>", 
     ",", "\<\"ExtinctionCoefficientsCB\"\>", 
     ",", "\<\"ProbabilityOfExpressionInInclusionBodies\"\>", 
     ",", "\<\"AlaNumber\"\>", ",", "\<\"AlaMole\"\>", 
     ",", "\<\"AlaDayhoffStat\"\>", ",", "\<\"CysNumber\"\>", 
     ",", "\<\"CyseMole\"\>", ",", "\<\"CysteineDayhoffStat\"\>", 
     ",", "\<\"AspNumber\"\>", ",", "\<\"AspMole\"\>", 
     ",", "\<\"AspDayhoffStat\"\>", ",", "\<\"GluNumber\"\>", 
     ",", "\<\"GluMole\"\>", ",", "\<\"GluDayhoffStat\"\>", 
     ",", "\<\"PheNumber\"\>", ",", "\<\"PheMole\"\>", 
     ",", "\<\"PheDayhoffStat\"\>", ",", "\<\"GlyNumber\"\>", 
     ",", "\<\"GlyMole\"\>", ",", "\<\"GlyDayhoffStat\"\>", 
     ",", "\<\"HisNumber\"\>", ",", "\<\"HisMole\"\>", 
     ",", "\<\"HisDayhoffStat\"\>", ",", "\<\"IleNumber\"\>", 
     ",", "\<\"IleMole\"\>", ",", "\<\"IleDayhoffStat\"\>", 
     ",", "\<\"LysNumber\"\>", ",", "\<\"LysMole\"\>", 
     ",", "\<\"LysDayhoffStat\"\>", ",", "\<\"LeuNumber\"\>", 
     ",", "\<\"LeuMole\"\>", ",", "\<\"LeuDayhoffStat\"\>", 
     ",", "\<\"MetNumber\"\>", ",", "\<\"MetMole\"\>", 
     ",", "\<\"MetDayhoffStat\"\>", ",", "\<\"AsnNumber\"\>", 
     ",", "\<\"AsnMole\"\>", ",", "\<\"AsnDayhoffStat\"\>", 
     ",", "\<\"ProNumber\"\>", ",", "\<\"ProMole\"\>", 
     ",", "\<\"ProDayhoffStat\"\>", ",", "\<\"GlnNumber\"\>", 
     ",", "\<\"GlnMole\"\>", ",", "\<\"GlnDayhoffStat\"\>", 
     ",", "\<\"ArgNumber\"\>", ",", "\<\"ArgMole\"\>", 
     ",", "\<\"ArgDayhoffStat\"\>", ",", "\<\"SerNumber\"\>", 
     ",", "\<\"SerMole\"\>", ",", "\<\"SerDayhoffStat\"\>", 
     ",", "\<\"ThrNumber\"\>", ",", "\<\"ThrMole\"\>", 
     ",", "\<\"ThrDayhoffStat\"\>", ",", "\<\"ValNumber\"\>", 
     ",", "\<\"ValMole\"\>", ",", "\<\"ValDayhoffStat\"\>", 
     ",", "\<\"TrpNumber\"\>", ",", "\<\"TrpMole\"\>", 
     ",", "\<\"TrpDayhoffStat\"\>", ",", "\<\"TyrNumber\"\>", 
     ",", "\<\"TyrMole\"\>", ",", "\<\"TyrDayhoffStat\"\>", 
     ",", "\<\"TinyNumber\"\>", ",", "\<\"TinyMole\"\>", 
     ",", "\<\"SmallNumber\"\>", ",", "\<\"SmallMole\"\>", 
     ",", "\<\"AliphaticNumber\"\>", ",", "\<\"AliphaticMole\"\>", 
     ",", "\<\"AromaticNumber\"\>", ",", "\<\"AromaticMole\"\>", 
     ",", "\<\"NonPolarNumber\"\>", ",", "\<\"NonPolarMole\"\>", 
     ",", "\<\"PolarNumber\"\>", ",", "\<\"PolarMole\"\>", 
     ",", "\<\"ChargedNumber\"\>", ",", "\<\"ChargedMole\"\>", 
     ",", "\<\"BasicNumber\"\>", ",", "\<\"BasicMole\"\>", 
     ",", "\<\"AcidicNumber\"\>", ",", "\<\"AcidicMole\"\>", 
     ",", "\<\"Surface Area (A2)\"\>", ",", "\<\"Volume (A3)\"\>", 
     ",", "\<\"Sphericity\"\>", 
     ",", "\<\"First Principle Moment Of Inertia (Da A2)\"\>", 
     ",", "\<\"Second Principle Moment Of Inertia (Da A2)\"\>", 
     ",", "\<\"Third Principle Moment Of Inertia (Da A2)\"\>", 
     ",", "\<\"First Dipole Moment (Z A)\"\>", 
     ",", "\<\"Second Dipole Moment (Z A)\"\>", 
     ",", "\<\"Third Dipole Moment (Z A)\"\>", 
     ",", "\<\"Surface Amino Acids\"\>", ",", "\<\"Surface Amino Acids %\"\>",
      ",", "\<\"Surface ALA\"\>", ",", "\<\"Surface ALA %\"\>", 
     ",", "\<\"Surface ALA Dayhoff %\"\>", ",", "\<\"Surface ARG\"\>", 
     ",", "\<\"Surface ARG %\"\>", ",", "\<\"Surface ARG Dayhoff %\"\>", 
     ",", "\<\"Surface ASN\"\>", ",", "\<\"Surface ASN %\"\>", 
     ",", "\<\"Surface ASN Dayhoff %\"\>", ",", "\<\"Surface ASP\"\>", 
     ",", "\<\"Surface ASP %\"\>", ",", "\<\"Surface ASP Dayhoff %\"\>", 
     ",", "\<\"Surface CYS\"\>", ",", "\<\"Surface CYS %\"\>", 
     ",", "\<\"Surface CYS Dayhoff %\"\>", ",", "\<\"Surface GLN\"\>", 
     ",", "\<\"Surface GLN %\"\>", ",", "\<\"Surface GLN Dayhoff %\"\>", 
     ",", "\<\"Surface GLU\"\>", ",", "\<\"Surface GLU %\"\>", 
     ",", "\<\"Surface GLU Dayhoff %\"\>", ",", "\<\"Surface GLY\"\>", 
     ",", "\<\"Surface GLY %\"\>", ",", "\<\"Surface GLY Dayhoff %\"\>", 
     ",", "\<\"Surface HIS\"\>", ",", "\<\"Surface HIS %\"\>", 
     ",", "\<\"Surface HIS Dayhoff %\"\>", ",", "\<\"Surface ILE\"\>", 
     ",", "\<\"Surface ILE %\"\>", ",", "\<\"Surface ILE Dayhoff %\"\>", 
     ",", "\<\"Surface LEU\"\>", ",", "\<\"Surface LEU %\"\>", 
     ",", "\<\"Surface LEU Dayhoff %\"\>", ",", "\<\"Surface LYS\"\>", 
     ",", "\<\"Surface LYS %\"\>", ",", "\<\"Surface LYS Dayhoff %\"\>", 
     ",", "\<\"Surface MET\"\>", ",", "\<\"Surface MET %\"\>", 
     ",", "\<\"Surface MET Dayhoff %\"\>", ",", "\<\"Surface PHE\"\>", 
     ",", "\<\"Surface PHE %\"\>", ",", "\<\"Surface PHE Dayhoff %\"\>", 
     ",", "\<\"Surface PRO\"\>", ",", "\<\"Surface PRO %\"\>", 
     ",", "\<\"Surface PRO Dayhoff %\"\>", ",", "\<\"Surface SER\"\>", 
     ",", "\<\"Surface SER %\"\>", ",", "\<\"Surface SER Dayhoff %\"\>", 
     ",", "\<\"Surface THR\"\>", ",", "\<\"Surface THR %\"\>", 
     ",", "\<\"Surface THR Dayhoff %\"\>", ",", "\<\"Surface TRP\"\>", 
     ",", "\<\"Surface TRP %\"\>", ",", "\<\"Surface TRP Dayhoff %\"\>", 
     ",", "\<\"Surface TYR\"\>", ",", "\<\"Surface TYR %\"\>", 
     ",", "\<\"Surface TYR Dayhoff %\"\>", ",", "\<\"Surface VAL\"\>", 
     ",", "\<\"Surface VAL %\"\>", ",", "\<\"Surface VAL Dayhoff %\"\>", 
     ",", "\<\"Surface Tiny\"\>", ",", "\<\"Surface Tiny %\"\>", 
     ",", "\<\"Surface Small\"\>", ",", "\<\"Surface Small %\"\>", 
     ",", "\<\"Surface Aliphatic\"\>", ",", "\<\"Surface Aliphatic %\"\>", 
     ",", "\<\"Surface Aromatic\"\>", ",", "\<\"Surface Aromatic %\"\>", 
     ",", "\<\"Surface Non-Polar\"\>", ",", "\<\"Surface Non-Polar %\"\>", 
     ",", "\<\"Surface Polar\"\>", ",", "\<\"Surface Polar %\"\>", 
     ",", "\<\"Surface Charged\"\>", ",", "\<\"Surface Charged %\"\>", 
     ",", "\<\"Surface Basic\"\>", ",", "\<\"Surface Basic %\"\>", 
     ",", "\<\"Surface Acidic\"\>", ",", "\<\"Surface Acidic %\"\>"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"mean\"\>", ",", "26515.34338983051`", ",", 
     "236.38983050847457`", ",", "112.14740677966103`", ",", 
     RowBox[{"-", "0.09322033898305085`"}], ",", "6.68218813559322`", ",", 
     "32993.72881355932`", ",", "33315.76271186441`", ",", 
     "1.2937966101694915`", ",", "1.307627118644068`", ",", 
     "0.3622372881355932`", ",", "16.28813559322034`", ",", 
     "6.673661016949152`", ",", "0.7760847457627119`", ",", 
     "10.813559322033898`", ",", "4.554372881355932`", ",", 
     "0.9294745762711865`", ",", "11.440677966101696`", ",", 
     "4.618135593220339`", ",", "1.0739491525423728`", ",", 
     "13.983050847457626`", ",", "5.569203389830509`", ",", 
     "1.0125084745762711`", ",", "5.508474576271187`", ",", 
     "2.6447457627118647`", ",", "0.9120169491525423`", ",", 
     "10.322033898305085`", ",", "4.50064406779661`", ",", 
     "1.1540508474576272`", ",", "15.372881355932204`", ",", 
     "6.6271525423728805`", ",", "1.1045254237288136`", ",", 
     "16.64406779661017`", ",", "7.151169491525424`", ",", 
     "0.8513050847457628`", ",", "7.406779661016949`", ",", 
     "3.0448474576271183`", ",", "1.5224237288135594`", ",", 
     "9.915254237288135`", ",", "4.23235593220339`", ",", 
     "0.9405084745762711`", ",", "20.593220338983052`", ",", 
     "8.334542372881357`", ",", "1.1263389830508475`", ",", 
     "14.745762711864407`", ",", "6.525898305084746`", ",", 
     "0.9888135593220339`", ",", "4.6440677966101696`", ",", 
     "1.8991525423728812`", ",", "1.117135593220339`", ",", 
     "9.779661016949152`", ",", "3.902050847457627`", ",", 
     "1.083915254237288`", ",", "12.169491525423728`", ",", 
     "5.211661016949153`", ",", "1.0021864406779661`", ",", 
     "15.525423728813559`", ",", "6.85528813559322`", ",", 
     "0.979271186440678`", ",", "13.186440677966102`", ",", 
     "5.835067796610169`", ",", "0.9565593220338983`", ",", 
     "3.76271186440678`", ",", "1.7023898305084746`", ",", 
     "1.3095593220338986`", ",", "8.254237288135593`", ",", 
     "3.512508474576271`", ",", "1.0331016949152543`", ",", 
     "16.033898305084747`", ",", "6.605203389830509`", ",", 
     "1.000779661016949`", ",", "67.15254237288136`", ",", 
     "29.159881355932203`", ",", "120.77966101694915`", ",", 
     "51.16410169491525`", ",", "62.83050847457627`", ",", 
     "25.845796610169494`", ",", "29.203389830508474`", ",", 
     "12.16179661016949`", ",", "123.59322033898304`", ",", 
     "51.869423728813565`", ",", "112.79661016949153`", ",", 
     "48.130576271186435`", ",", "62.32203389830509`", ",", 
     "26.321338983050847`", ",", "32.96610169491525`", ",", 
     "14.12515254237288`", ",", "29.35593220338983`", ",", 
     "12.196220338983052`", ",", "12504.934521389829`", ",", 
     "29797.97617976271`", ",", "0.3885425593220339`", ",", 
     "5.90124569349661`*^6", ",", "8.374057906193221`*^6", ",", 
     "8.280165616467796`*^6", ",", 
     RowBox[{"-", "14.276556745762711`"}], ",", "13.100479779661015`", ",", 
     "23.675330101694918`", ",", "71.98906779661017`", ",", 
     "30.947269271186443`", ",", "4.494305084745762`", ",", 
     "6.04840527118644`", ",", "0.7033029322033898`", ",", 
     "3.564881355932203`", ",", "4.9632105762711864`", ",", 
     "1.0129000847457625`", ",", "3.831135593220339`", ",", 
     "5.106034966101696`", ",", "1.1874500169491524`", ",", 
     "4.622627118644068`", ",", "6.121299033898306`", ",", 
     "1.1129635254237287`", ",", "1.2329830508474577`", ",", 
     "1.865721406779661`", ",", "0.643352186440678`", ",", 
     "3.493169491525424`", ",", "4.979198457627118`", ",", 
     "1.2767175084745763`", ",", "5.400084745762711`", ",", 
     "7.560318288135593`", ",", "1.2600530847457627`", ",", 
     "4.80586440677966`", ",", "6.943071610169492`", ",", 
     "0.8265561186440679`", ",", "2.405779661016949`", ",", 
     "3.258434338983051`", ",", "1.6292171864406781`", ",", 
     "2.643881355932203`", ",", "3.6446170847457626`", ",", 
     "0.8099148813559321`", ",", "5.648186440677966`", ",", "7.528699`", ",", 
     "1.0173917627118645`", ",", "5.1492881355932205`", ",", 
     "7.3551286101694915`", ",", "1.1144134576271187`", ",", 
     "1.3799661016949154`", ",", "1.9353023728813559`", ",", 
     "1.138413186440678`", ",", "2.6695762711864406`", ",", 
     "3.4822026440677964`", ",", "0.9672785254237288`", ",", 
     "4.199559322033898`", ",", "5.9220521016949155`", ",", 
     "1.1388561525423728`", ",", "4.812101694915254`", ",", 
     "7.031751016949152`", ",", "1.0045358983050847`", ",", 
     "4.073813559322034`", ",", "5.886624593220338`", ",", 
     "0.9650204915254236`", ",", "1.0806101694915253`", ",", 
     "1.5453132711864408`", ",", "1.1887025084745761`", ",", 
     "2.240033898305085`", ",", "3.0823523728813558`", ",", 
     "0.9065742542372882`", ",", "4.241220338983051`", ",", 
     "5.74026286440678`", ",", "0.8697368305084747`", ",", 
     "19.419067796610168`", ",", "27.775573915254235`", ",", 
     "36.31361016949152`", ",", "50.66522288135593`", ",", 
     "17.027593220338982`", ",", "22.961984118644068`", ",", 
     "8.395999999999999`", ",", "11.368302711864407`", ",", 
     "34.63618644067796`", ",", "47.7379999661017`", ",", 
     "37.352881355932205`", ",", "52.2620000338983`", ",", 
     "21.142661016949152`", ",", "29.25839093220339`", ",", 
     "11.119949152542373`", ",", "15.576773593220338`", ",", 
     "10.022711864406778`", ",", "13.681617389830508`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"sdev\"\>", ",", "16188.08945410905`", ",", 
     "144.1703992944786`", ",", "3.1461169998118264`", ",", 
     "10.396648405678791`", ",", "1.407235128882255`", ",", 
     "22609.66774438308`", ",", "22742.380323315097`", ",", 
     "0.6545577021971036`", ",", "0.6562293254097699`", ",", 
     "0.21171730818622847`", ",", "12.483162242296796`", ",", 
     "2.410830595245415`", ",", "0.2802868166555154`", ",", 
     "7.724735407300339`", ",", "1.919949648211039`", ",", 
     "0.39189743362316215`", ",", "10.033171167201735`", ",", 
     "2.3433499117467913`", ",", "0.54491759654569`", ",", 
     "13.627421044532094`", ",", "2.05696761059157`", ",", 
     "0.3740141235062063`", ",", "6.4843920868815035`", ",", 
     "2.3795168778934963`", ",", "0.8205455185324183`", ",", 
     "6.9392454075653855`", ",", "1.9338255257989134`", ",", 
     "0.4958464523080818`", ",", "11.141562920581075`", ",", 
     "2.783754781446488`", ",", "0.4639595834037109`", ",", 
     "11.814314391747347`", ",", "2.2437863869111223`", ",", 
     "0.2671390735719356`", ",", "5.592848401639108`", ",", 
     "1.5234928879971534`", ",", "0.7617376279992961`", ",", 
     "7.428482314929107`", ",", "1.8883890029070836`", ",", 
     "0.41964115922195977`", ",", "15.204489631942765`", ",", 
     "2.9594763535069317`", ",", "0.3999243294877037`", ",", 
     "10.462730606100255`", ",", "2.9912024320463226`", ",", 
     "0.4532102151577342`", ",", "3.781819995462898`", ",", 
     "1.0946626438843334`", ",", "0.6439099170671988`", ",", 
     "7.933055672116666`", ",", "1.6176973782864292`", ",", 
     "0.4494016822450441`", ",", "8.183567518093977`", ",", 
     "1.9518057122269383`", ",", "0.3753466202461616`", ",", 
     "9.42731894494782`", ",", "2.797281063207798`", ",", 
     "0.39963810484627194`", ",", "7.966469767787699`", ",", 
     "1.8265898966371148`", ",", "0.2993753422681185`", ",", 
     "2.812159454024044`", ",", "1.115226341909077`", ",", 
     "0.85781308291103`", ",", "7.319301880076342`", ",", 
     "1.905612349522085`", ",", "0.5604730666547265`", ",", 
     "10.857964027250507`", ",", "2.203865927611038`", ",", 
     "0.3339090867285332`", ",", "39.56435767957457`", ",", 
     "4.488673692769797`", ",", "76.71511737829688`", ",", 
     "6.1716571314437525`", ",", "41.98487106104838`", ",", 
     "5.160897538819697`", ",", "20.617016457801892`", ",", 
     "3.479319740189319`", ",", "77.37996681046423`", ",", 
     "3.939659525825453`", ",", "68.09242695777985`", ",", 
     "3.939659525825453`", ",", "40.378997903043654`", ",", 
     "4.9870011568358095`", ",", "20.03270266141127`", ",", 
     "3.029163568479836`", ",", "21.632321532648223`", ",", 
     "3.0846067656817358`", ",", "7361.7237428828075`", ",", 
     "18814.639808310025`", ",", "0.05763344578312958`", ",", 
     "6.824870997330254`*^6", ",", "1.0642176205654135`*^7", ",", 
     "1.0793943582539707`*^7", ",", "93.54694850857055`", ",", 
     "106.06707764994006`", ",", "116.0631317534289`", ",", 
     "42.162486874923346`", ",", "1.545645057246704`", ",", 
     "3.5418640098032017`", ",", "2.5083372700097213`", ",", 
     "0.29166710875336466`", ",", "2.480446317491421`", ",", 
     "2.190790182858508`", ",", "0.4471000328987288`", ",", 
     "3.324390856608829`", ",", "2.6564885069316206`", ",", 
     "0.617788087218299`", ",", "4.0361277785482885`", ",", 
     "2.1325611553999146`", ",", "0.3877383984760484`", ",", 
     "1.498226060143789`", ",", "1.685572675214857`", ",", 
     "0.5812319526118482`", ",", "2.3204405582928485`", ",", 
     "2.309509012317959`", ",", "0.592181833937399`", ",", 
     "3.9984017422833253`", ",", "3.3104717631812925`", ",", 
     "0.5517453219613034`", ",", "3.1276685569265714`", ",", 
     "2.3420060096427653`", ",", "0.278810238120908`", ",", 
     "1.9198719431774307`", ",", "1.9848884337692427`", ",", 
     "0.9924441574141933`", ",", "2.00080936282559`", ",", 
     "1.5991190988556931`", ",", "0.3553598752202542`", ",", 
     "4.01210672785197`", ",", "2.6643664368248974`", ",", 
     "0.3600495811998454`", ",", "3.6828203540729554`", ",", 
     "3.3464170768635473`", ",", "0.5070328167242106`", ",", 
     "1.0285178818639236`", ",", "1.2145672721372387`", ",", 
     "0.7144513498405968`", ",", "2.102135303590054`", ",", 
     "1.3267455197354652`", ",", "0.36854038468748374`", ",", 
     "2.7556188132312522`", ",", "2.260955379486137`", ",", 
     "0.43479914721646595`", ",", "2.877002011762719`", ",", 
     "3.0517221237694367`", ",", "0.4359603017377842`", ",", 
     "2.5598768590707794`", ",", "1.9226568445130827`", ",", 
     "0.3151896156981443`", ",", "0.8524389758105887`", ",", 
     "0.9214504424219166`", ",", "0.70880807533092`", ",", 
     "2.0233745708601525`", ",", "1.8696587498675268`", ",", 
     "0.5498996683547919`", ",", "2.867711697791143`", ",", 
     "2.0451729725666445`", ",", "0.3098746460100718`", ",", 
     "10.978959291902646`", ",", "4.935356555289769`", ",", 
     "22.08558499847179`", ",", "6.367783717085283`", ",", 
     "11.150392880226306`", ",", "4.676106473818319`", ",", 
     "5.8577843669475556`", ",", "3.389521667081309`", ",", 
     "20.949026252141564`", ",", "4.557068780934082`", ",", 
     "21.7245018871389`", ",", "4.557068780934082`", ",", 
     "13.307274762596856`", ",", "5.915641962251553`", ",", 
     "6.598851345770479`", ",", "3.7014587420495593`", ",", 
     "7.126905219080254`", ",", "3.6158088786452653`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"x1 [30.4344 %]\"\>", ",", 
     RowBox[{"-", "0.1358598006009037`"}], ",", 
     RowBox[{"-", "0.13581776956427716`"}], ",", 
     RowBox[{"-", "0.005438360326841662`"}], ",", "0.04761020487504133`", ",",
      "0.01587535182176719`", ",", 
     RowBox[{"-", "0.10000010295778423`"}], ",", 
     RowBox[{"-", "0.1006640516843187`"}], ",", "0.019567589875217308`", ",", 
     "0.02010797228267947`", ",", 
     RowBox[{"-", "0.03547982589700482`"}], ",", 
     RowBox[{"-", "0.11319236723561461`"}], ",", 
     RowBox[{"-", "0.02020050743044346`"}], ",", 
     RowBox[{"-", "0.020220480978771913`"}], ",", 
     RowBox[{"-", "0.11270717608492321`"}], ",", "0.000429121286591797`", ",",
      "0.0004436487576903157`", ",", 
     RowBox[{"-", "0.11475060052676099`"}], ",", 
     RowBox[{"-", "0.021457868341704718`"}], ",", 
     RowBox[{"-", "0.021448329142630108`"}], ",", 
     RowBox[{"-", "0.11375076504735941`"}], ",", 
     RowBox[{"-", "0.0430165272773288`"}], ",", 
     RowBox[{"-", "0.043037978431260455`"}], ",", 
     RowBox[{"-", "0.07320784486413034`"}], ",", "0.031613320248935144`", ",",
      "0.03161005905357741`", ",", 
     RowBox[{"-", "0.11035960101166091`"}], ",", "0.017223653266374796`", ",",
      "0.017226495336262086`", ",", 
     RowBox[{"-", "0.10816197137882164`"}], ",", "0.0075515656299197`", ",", 
     "0.007568788919575881`", ",", 
     RowBox[{"-", "0.11394220002936234`"}], ",", "0.014442166177966098`", ",",
      "0.014453234995072827`", ",", 
     RowBox[{"-", "0.1112346526435597`"}], ",", 
     RowBox[{"-", "0.01845819746482307`"}], ",", 
     RowBox[{"-", "0.01847836856814588`"}], ",", 
     RowBox[{"-", "0.10790311285711174`"}], ",", "0.00497259632665054`", ",", 
     "0.004952576139144801`", ",", 
     RowBox[{"-", "0.11608671239669215`"}], ",", 
     RowBox[{"-", "0.026868237681046774`"}], ",", 
     RowBox[{"-", "0.026858522711141943`"}], ",", 
     RowBox[{"-", "0.1030843735525423`"}], ",", "0.018155142907563374`", ",", 
     "0.01816956504028373`", ",", 
     RowBox[{"-", "0.1038480375627874`"}], ",", 
     RowBox[{"-", "0.01603806208980781`"}], ",", 
     RowBox[{"-", "0.016032580884885753`"}], ",", 
     RowBox[{"-", "0.12475146341243099`"}], ",", 
     RowBox[{"-", "0.03566800311847921`"}], ",", 
     RowBox[{"-", "0.03568014249343761`"}], ",", 
     RowBox[{"-", "0.11164769983760793`"}], ",", "0.009618878353481937`", ",",
      "0.009603521598838571`", ",", 
     RowBox[{"-", "0.10691912560765712`"}], ",", "0.026674787781445167`", ",",
      "0.026678083873147036`", ",", 
     RowBox[{"-", "0.1189231095550999`"}], ",", "0.033564966834531425`", ",", 
     "0.03361723746989713`", ",", 
     RowBox[{"-", "0.0799189173156465`"}], ",", "0.022555542924215726`", ",", 
     "0.02256373324410687`", ",", 
     RowBox[{"-", "0.09397539071886168`"}], ",", "0.002257370492626581`", ",",
      "0.002250162539831854`", ",", 
     RowBox[{"-", "0.12643241274222955`"}], ",", 
     RowBox[{"-", "0.01827053994911161`"}], ",", 
     RowBox[{"-", "0.01827129842812031`"}], ",", 
     RowBox[{"-", "0.13115881030516482`"}], ",", "0.043417342449083726`", ",", 
     RowBox[{"-", "0.13266135146365485`"}], ",", "0.005608967777851021`", ",", 
     RowBox[{"-", "0.12748384643290753`"}], ",", 
     RowBox[{"-", "0.0308241741088329`"}], ",", 
     RowBox[{"-", "0.12244050208205666`"}], ",", 
     RowBox[{"-", "0.01620104919064071`"}], ",", 
     RowBox[{"-", "0.134167808522572`"}], ",", 
     RowBox[{"-", "0.01991889379495343`"}], ",", 
     RowBox[{"-", "0.13509580888579203`"}], ",", "0.01991889379495343`", ",", 
     RowBox[{"-", "0.13191309712891747`"}], ",", 
     RowBox[{"-", "0.008119103506154022`"}], ",", 
     RowBox[{"-", "0.1283549073054612`"}], ",", "0.008911852044315766`", ",", 
     RowBox[{"-", "0.127366033045088`"}], ",", 
     RowBox[{"-", "0.021877399541571037`"}], ",", 
     RowBox[{"-", "0.13577431304425022`"}], ",", 
     RowBox[{"-", "0.13582541366278006`"}], ",", "0.12772958691068953`", ",", 
     RowBox[{"-", "0.12252042788016745`"}], ",", 
     RowBox[{"-", "0.1201601974939322`"}], ",", 
     RowBox[{"-", "0.11996984636540026`"}], ",", "0.0070463979276961545`", 
     ",", 
     RowBox[{"-", "0.04043450464953655`"}], ",", 
     RowBox[{"-", "0.05159134969772615`"}], ",", 
     RowBox[{"-", "0.13569611519928274`"}], ",", "0.07057456050977558`", ",", 
     RowBox[{"-", "0.10764535881032677`"}], ",", 
     RowBox[{"-", "0.018177359709740496`"}], ",", 
     RowBox[{"-", "0.01817737219692806`"}], ",", 
     RowBox[{"-", "0.10972647885327647`"}], ",", "0.002387061327428615`", ",",
      "0.0023870499069473983`", ",", 
     RowBox[{"-", "0.1110217601727086`"}], ",", 
     RowBox[{"-", "0.019553736489722626`"}], ",", 
     RowBox[{"-", "0.019553734717525337`"}], ",", 
     RowBox[{"-", "0.11782687138738675`"}], ",", 
     RowBox[{"-", "0.03542070682333008`"}], ",", 
     RowBox[{"-", "0.035420708644796975`"}], ",", 
     RowBox[{"-", "0.0760809054493704`"}], ",", "0.025412793141285375`", ",", 
     "0.02541280041064715`", ",", 
     RowBox[{"-", "0.10657711224905081`"}], ",", "0.013373633306880876`", ",",
      "0.013373653155762742`", ",", 
     RowBox[{"-", "0.10571790425795057`"}], ",", "0.0010076572699841489`", 
     ",", "0.0010076548726594575`", ",", 
     RowBox[{"-", "0.10853000492476234`"}], ",", "0.02882061050414024`", ",", 
     "0.028820639263027283`", ",", 
     RowBox[{"-", "0.09628935409423675`"}], ",", 
     RowBox[{"-", "0.013579339112217937`"}], ",", 
     RowBox[{"-", "0.013579337383185654`"}], ",", 
     RowBox[{"-", "0.11135492774970421`"}], ",", 
     RowBox[{"-", "0.0054366495951193245`"}], ",", 
     RowBox[{"-", "0.005436682775300059`"}], ",", 
     RowBox[{"-", "0.118107279286383`"}], ",", 
     RowBox[{"-", "0.027332751340893476`"}], ",", 
     RowBox[{"-", "0.027332722669981317`"}], ",", 
     RowBox[{"-", "0.10170588768110896`"}], ",", "0.011114340321503087`", ",",
      "0.011114336007120475`", ",", 
     RowBox[{"-", "0.09463195746617929`"}], ",", 
     RowBox[{"-", "0.00044910461689517565`"}], ",", 
     RowBox[{"-", "0.0004491156925407143`"}], ",", 
     RowBox[{"-", "0.1254060560203866`"}], ",", 
     RowBox[{"-", "0.042986586860694564`"}], ",", 
     RowBox[{"-", "0.042986562071834586`"}], ",", 
     RowBox[{"-", "0.1056629140041544`"}], ",", "0.013847748885292475`", ",", 
     "0.013847736806739246`", ",", 
     RowBox[{"-", "0.09533981897648278`"}], ",", "0.03284819827185239`", ",", 
     "0.032848190858364525`", ",", 
     RowBox[{"-", "0.11640084688126105`"}], ",", "0.02963368195399614`", ",", 
     "0.02963369377986786`", ",", 
     RowBox[{"-", "0.0857069071459583`"}], ",", "0.01112139114225976`", ",", 
     "0.011121391833941965`", ",", 
     RowBox[{"-", "0.09519587219267392`"}], ",", 
     RowBox[{"-", "0.0069526613837860895`"}], ",", 
     RowBox[{"-", "0.006952652699382638`"}], ",", 
     RowBox[{"-", "0.12331047376743104`"}], ",", 
     RowBox[{"-", "0.016443385364293624`"}], ",", 
     RowBox[{"-", "0.016443353793911316`"}], ",", 
     RowBox[{"-", "0.12815077906739245`"}], ",", "0.04497287551474616`", ",", 
     RowBox[{"-", "0.13114399377012104`"}], ",", "0.01447217172430677`", ",", 
     RowBox[{"-", "0.12838499212757676`"}], ",", 
     RowBox[{"-", "0.0343753592576803`"}], ",", 
     RowBox[{"-", "0.12191649563257917`"}], ",", 
     RowBox[{"-", "0.025589748153359796`"}], ",", 
     RowBox[{"-", "0.1337899926469544`"}], ",", 
     RowBox[{"-", "0.017429963883985947`"}], ",", 
     RowBox[{"-", "0.13434211854407388`"}], ",", "0.017429963883985947`", ",", 
     RowBox[{"-", "0.12999396008113845`"}], ",", 
     RowBox[{"-", "0.009590115764444226`"}], ",", 
     RowBox[{"-", "0.12602168763343474`"}], ",", "0.004179242334177435`", ",", 
     RowBox[{"-", "0.1260388532790846`"}], ",", 
     RowBox[{"-", "0.019968147251646202`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"x2 [11.3791 %]\"\>", ",", "0.0017858558603715813`", ",", 
     "0.009389740809781772`", ",", 
     RowBox[{"-", "0.1853507477581475`"}], ",", "0.006944329007145341`", ",", 
     RowBox[{"-", "0.004068764308175995`"}], ",", 
     RowBox[{"-", "0.029686845049571954`"}], ",", 
     RowBox[{"-", "0.029615122441443677`"}], ",", 
     RowBox[{"-", "0.050493525676137366`"}], ",", 
     RowBox[{"-", "0.050436983372048355`"}], ",", 
     RowBox[{"-", "0.09551376835057179`"}], ",", "0.043927498871696856`", ",",
      "0.06703830209275617`", ",", "0.06697032812060927`", ",", 
     "0.03333844983073019`", ",", "0.039077262812972836`", ",", 
     "0.03905859308954875`", ",", 
     RowBox[{"-", "0.007246538375264425`"}], ",", 
     RowBox[{"-", "0.03166944232361462`"}], ",", 
     RowBox[{"-", "0.031637824073833996`"}], ",", 
     RowBox[{"-", "0.007955346613440335`"}], ",", 
     RowBox[{"-", "0.03939281481935169`"}], ",", 
     RowBox[{"-", "0.03941671920756988`"}], ",", 
     RowBox[{"-", "0.0034499559910261403`"}], ",", 
     RowBox[{"-", "0.006039078143025038`"}], ",", 
     RowBox[{"-", "0.006038536004241946`"}], ",", "0.011164700194700462`", 
     ",", "0.03124194015991089`", ",", "0.031249691869910647`", ",", 
     RowBox[{"-", "0.050165517121262534`"}], ",", 
     RowBox[{"-", "0.12293578058591836`"}], ",", 
     RowBox[{"-", "0.12290138731502334`"}], ",", "0.04565335269164612`", ",", 
     "0.08310597385746217`", ",", "0.08308739943948315`", ",", 
     RowBox[{"-", "0.03576706278274203`"}], ",", 
     RowBox[{"-", "0.05547124021383146`"}], ",", 
     RowBox[{"-", "0.05548794022011183`"}], ",", 
     RowBox[{"-", "0.006437042234567188`"}], ",", 
     RowBox[{"-", "0.029469420142349694`"}], ",", 
     RowBox[{"-", "0.02946012285155545`"}], ",", "0.038912212418909554`", ",",
      "0.07447982382737438`", ",", "0.07447714153251268`", ",", 
     RowBox[{"-", "0.07193592460854906`"}], ",", 
     RowBox[{"-", "0.1524573653011087`"}], ",", 
     RowBox[{"-", "0.15247596800541083`"}], ",", "0.018101687278982172`", ",",
      "0.006911873810214316`", ",", "0.006931206127630001`", ",", 
     RowBox[{"-", "0.031060908418422625`"}], ",", 
     RowBox[{"-", "0.0939564150166574`"}], ",", 
     RowBox[{"-", "0.09397679961049814`"}], ",", "0.06804961631378979`", ",", 
     "0.1179391204316453`", ",", "0.11794033044292004`", ",", 
     "0.059680823762426886`", ",", "0.09496940822801363`", ",", 
     "0.09495663156138771`", ",", "0.004468449574054136`", ",", 
     "0.011562119781231336`", ",", "0.011529177123047853`", ",", 
     RowBox[{"-", "0.008761725619841157`"}], ",", 
     RowBox[{"-", "0.02934504378096767`"}], ",", 
     RowBox[{"-", "0.029358872416533063`"}], ",", 
     RowBox[{"-", "0.04912020622722398`"}], ",", 
     RowBox[{"-", "0.0936477708588279`"}], ",", 
     RowBox[{"-", "0.09363769601303863`"}], ",", "0.04690309170715253`", ",", 
     "0.11014272138037172`", ",", "0.11013095830224308`", ",", 
     "0.04204729499568934`", ",", "0.13823585142248165`", ",", 
     "0.0332218524878536`", ",", "0.15201662994619858`", ",", 
     "0.03814347914484547`", ",", "0.11027541199583156`", ",", 
     RowBox[{"-", "0.040287723718403806`"}], ",", 
     RowBox[{"-", "0.12868098222491156`"}], ",", "0.027309578755106426`", ",",
      "0.1563068865164414`", ",", 
     RowBox[{"-", "0.011153833837218295`"}], ",", 
     RowBox[{"-", "0.1563068865164414`"}], ",", 
     RowBox[{"-", "0.03374250105814788`"}], ",", 
     RowBox[{"-", "0.17822338604352247`"}], ",", 
     RowBox[{"-", "0.03470102201950471`"}], ",", 
     RowBox[{"-", "0.1536831607740317`"}], ",", 
     RowBox[{"-", "0.0308488907350705`"}], ",", 
     RowBox[{"-", "0.13721812018597282`"}], ",", "0.006330363281859931`", ",",
      "0.006284539977542955`", ",", 
     RowBox[{"-", "0.011952937156598226`"}], ",", "0.00025284879231237127`", 
     ",", "0.0008104277992067852`", ",", "0.00025318771903443186`", ",", 
     "0.046896187944896715`", ",", 
     RowBox[{"-", "0.02122759417739282`"}], ",", 
     RowBox[{"-", "0.006342767186158135`"}], ",", "0.010113100754910889`", 
     ",", "0.00914370367817284`", ",", "0.049734096581018336`", ",", 
     "0.07632882578968377`", ",", "0.0763287857348851`", ",", 
     "0.030637388696875646`", ",", "0.0234437260529063`", ",", 
     "0.02344375144703911`", ",", 
     RowBox[{"-", "0.008215765798912238`"}], ",", 
     RowBox[{"-", "0.031200066789947294`"}], ",", 
     RowBox[{"-", "0.03120005213470367`"}], ",", 
     RowBox[{"-", "0.009718591803780844`"}], ",", 
     RowBox[{"-", "0.04235696171348464`"}], ",", 
     RowBox[{"-", "0.04235692397399516`"}], ",", 
     RowBox[{"-", "0.0015710050536652548`"}], ",", 
     RowBox[{"-", "0.0035979421168833665`"}], ",", 
     RowBox[{"-", "0.003597931824709625`"}], ",", "0.014821948366413493`", 
     ",", "0.031078026718223115`", ",", "0.031078012616017267`", ",", 
     RowBox[{"-", "0.05220244882014685`"}], ",", 
     RowBox[{"-", "0.1188610735297187`"}], ",", 
     RowBox[{"-", "0.1188610882824488`"}], ",", "0.05357340951916288`", ",", 
     "0.080183630292066`", ",", "0.08018355964659657`", ",", 
     RowBox[{"-", "0.04632232802008369`"}], ",", 
     RowBox[{"-", "0.062717377107718`"}], ",", 
     RowBox[{"-", "0.0627173643698746`"}], ",", 
     RowBox[{"-", "0.00673493954228863`"}], ",", 
     RowBox[{"-", "0.034269296346548336`"}], ",", 
     RowBox[{"-", "0.03426929692280089`"}], ",", "0.0433161066472226`", ",", 
     "0.08671590999951412`", ",", "0.08671591639242193`", ",", 
     RowBox[{"-", "0.07261940075342814`"}], ",", 
     RowBox[{"-", "0.1535410671870623`"}], ",", 
     RowBox[{"-", "0.15354109656487186`"}], ",", "0.01703409064247903`", ",", 
     "0.007254712764475089`", ",", "0.00725472072558644`", ",", 
     RowBox[{"-", "0.02242365103470299`"}], ",", 
     RowBox[{"-", "0.07931351932566268`"}], ",", 
     RowBox[{"-", "0.07931352835551536`"}], ",", "0.0743148336280154`", ",", 
     "0.12353919602195297`", ",", "0.12353920176612816`", ",", 
     "0.0653223474251564`", ",", "0.08644175282360063`", ",", 
     "0.08644177519290053`", ",", "0.005937498773575131`", ",", 
     "0.009295448813770615`", ",", "0.009295416472371655`", ",", 
     "0.01292229947875027`", ",", "0.005382698823089945`", ",", 
     "0.005382690384285577`", ",", 
     RowBox[{"-", "0.044282741086286756`"}], ",", 
     RowBox[{"-", "0.076285859536021`"}], ",", 
     RowBox[{"-", "0.07628584831651082`"}], ",", "0.05100359386749807`", ",", 
     "0.10049839114729783`", ",", "0.10049837121610848`", ",", 
     "0.049593894162341626`", ",", "0.13268596435624022`", ",", 
     "0.037535723258125486`", ",", "0.15177876086612183`", ",", 
     "0.043292512425194496`", ",", "0.12258858512248456`", ",", 
     RowBox[{"-", "0.036644501307394745`"}], ",", 
     RowBox[{"-", "0.10838829313494759`"}], ",", "0.03553937221570241`", ",", 
     "0.17559394503893835`", ",", 
     RowBox[{"-", "0.014643454903608293`"}], ",", 
     RowBox[{"-", "0.17559394503893833`"}], ",", 
     RowBox[{"-", "0.03970268873380117`"}], ",", 
     RowBox[{"-", "0.1810038937348657`"}], ",", 
     RowBox[{"-", "0.04248962924626559`"}], ",", 
     RowBox[{"-", "0.15856969329972842`"}], ",", 
     RowBox[{"-", "0.03479095526592968`"}], ",", 
     RowBox[{"-", "0.13380548181810123`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"x3 [9.77878 %]\"\>", ",", "0.003634600564123674`", ",", 
     "0.0013635620454865622`", ",", "0.04873483723577306`", ",", 
     RowBox[{"-", "0.014451905610566095`"}], ",", "0.03993945272894068`", ",",
      "0.11804102832031925`", ",", "0.11834236122452291`", ",", 
     "0.1454441975049941`", ",", "0.14692479010223164`", ",", 
     RowBox[{"-", "0.10273010471946968`"}], ",", 
     RowBox[{"-", "0.07747101407550414`"}], ",", 
     RowBox[{"-", "0.1444602442943322`"}], ",", 
     RowBox[{"-", "0.1444802185128131`"}], ",", "0.0014037564561273981`", ",",
      "0.026208019333290995`", ",", "0.026197179921487013`", ",", 
     "0.08636988263431683`", ",", "0.13373526163060231`", ",", 
     "0.13373714575239312`", ",", "0.047208284241987836`", ",", 
     "0.05440494347944991`", ",", "0.0543587371159012`", ",", 
     "0.051176496305491335`", ",", "0.08845435543992099`", ",", 
     "0.08844577281376545`", ",", "0.0017275214543487265`", ",", 
     RowBox[{"-", "0.003263612266533678`"}], ",", 
     RowBox[{"-", "0.0032815713477850296`"}], ",", 
     RowBox[{"-", "0.09798352441688014`"}], ",", 
     RowBox[{"-", "0.1459850691142063`"}], ",", 
     RowBox[{"-", "0.14600017590677195`"}], ",", "0.05061947393398293`", ",", 
     "0.06366258629903766`", ",", "0.06365861564071591`", ",", 
     "0.043560435621519594`", ",", "0.03307114341422915`", ",", 
     "0.033076377875097165`", ",", "0.00637038286999917`", ",", 
     RowBox[{"-", "0.014734745553449852`"}], ",", 
     RowBox[{"-", "0.014722673925352049`"}], ",", 
     RowBox[{"-", "0.07812258824940237`"}], ",", 
     RowBox[{"-", "0.14841806397502125`"}], ",", 
     RowBox[{"-", "0.14844159385852046`"}], ",", 
     RowBox[{"-", "0.06989293224125692`"}], ",", 
     RowBox[{"-", "0.0900108103384194`"}], ",", 
     RowBox[{"-", "0.08997730357823347`"}], ",", 
     RowBox[{"-", "0.03208580995581192`"}], ",", 
     RowBox[{"-", "0.06622439403718951`"}], ",", 
     RowBox[{"-", "0.06620554335122976`"}], ",", "0.01940354550292062`", ",", 
     "0.024182300117317406`", ",", "0.02417842301840903`", ",", 
     "0.017534435266678798`", ",", "0.04856047209411145`", ",", 
     "0.048556035698053765`", ",", "0.02865648634405912`", ",", 
     "0.06550931226737139`", ",", "0.06550094070949895`", ",", 
     "0.0189201140661049`", ",", "0.03365482599986873`", ",", 
     "0.03361174657258471`", ",", "0.10100399293093452`", ",", 
     "0.10601038250318569`", ",", "0.10600505828950044`", ",", 
     "0.10147409403904553`", ",", "0.15166488679194481`", ",", 
     "0.15165945664129984`", ",", 
     RowBox[{"-", "0.018680420160861886`"}], ",", 
     RowBox[{"-", "0.043274535020348566`"}], ",", 
     RowBox[{"-", "0.043321857328281387`"}], ",", "0.009697616367839855`", 
     ",", "0.055637149396329626`", ",", "0.023909679244369122`", ",", 
     "0.10928041886322117`", ",", 
     RowBox[{"-", "0.055029497913911325`"}], ",", 
     RowBox[{"-", "0.17645956577893504`"}], ",", "0.06908444697906731`", ",", 
     "0.14276599777044321`", ",", 
     RowBox[{"-", "0.0022962504363226383`"}], ",", 
     RowBox[{"-", "0.02252379460110433`"}], ",", "0.005496485935856174`", ",",
      "0.02252379460110433`", ",", 
     RowBox[{"-", "0.022911980131532835`"}], ",", 
     RowBox[{"-", "0.09284926305356554`"}], ",", 
     RowBox[{"-", "0.023801100102621278`"}], ",", 
     RowBox[{"-", "0.05564409939864137`"}], ",", 
     RowBox[{"-", "0.020726505735353496`"}], ",", 
     RowBox[{"-", "0.09546806150876855`"}], ",", "0.0008145610570807427`", 
     ",", "0.0009822293421517872`", ",", "0.007475474244315008`", ",", 
     RowBox[{"-", "0.014032601809481569`"}], ",", "0.02394377708271229`", ",",
      "0.012713315696534201`", ",", "0.07097677822608528`", ",", 
     "0.006565930944437223`", ",", "0.053044525474851584`", ",", 
     "0.002282527411488611`", ",", "0.02083025110629997`", ",", 
     RowBox[{"-", "0.0816304572243448`"}], ",", 
     RowBox[{"-", "0.13902809330675892`"}], ",", 
     RowBox[{"-", "0.13902810031460922`"}], ",", "0.004054035092669189`", ",",
      "0.02693533928670358`", ",", "0.026935316967081405`", ",", 
     "0.09055917833640652`", ",", "0.13201195340221797`", ",", 
     "0.1320119873917418`", ",", "0.037335187419988994`", ",", 
     "0.04699093652705505`", ",", "0.04699092254492347`", ",", 
     "0.04726692462153527`", ",", "0.07719034559005404`", ",", 
     "0.07719032749279549`", ",", "0.002952570357233656`", ",", 
     RowBox[{"-", "0.0006010571043471624`"}], ",", 
     RowBox[{"-", "0.0006010562607779505`"}], ",", 
     RowBox[{"-", "0.09784500373001236`"}], ",", 
     RowBox[{"-", "0.14561273316692727`"}], ",", 
     RowBox[{"-", "0.14561272142378814`"}], ",", "0.0448333128175969`", ",", 
     "0.0409024325196657`", ",", "0.040902395069716456`", ",", 
     "0.044516260155723734`", ",", "0.028496361372184455`", ",", 
     "0.02849635970691048`", ",", "0.031360176661538695`", ",", 
     "0.017564894000518524`", ",", "0.01756487564957117`", ",", 
     RowBox[{"-", "0.0729661723949365`"}], ",", 
     RowBox[{"-", "0.13596373863715092`"}], ",", 
     RowBox[{"-", "0.1359637462629301`"}], ",", 
     RowBox[{"-", "0.06540101207958161`"}], ",", 
     RowBox[{"-", "0.08407199344676484`"}], ",", 
     RowBox[{"-", "0.0840719615157672`"}], ",", 
     RowBox[{"-", "0.021423561104613856`"}], ",", 
     RowBox[{"-", "0.04056689275812354`"}], ",", 
     RowBox[{"-", "0.04056689773603553`"}], ",", "0.020313174757881875`", ",",
      "0.029859358495629807`", ",", "0.029859326620620123`", ",", 
     "0.020484827599593098`", ",", "0.043711063829523694`", ",", 
     "0.04371108463291638`", ",", "0.030590957217304`", ",", 
     "0.06564488009715994`", ",", "0.06564489532800884`", ",", 
     "0.030850654329224018`", ",", "0.048465915512287926`", ",", 
     "0.04846589951385423`", ",", "0.09026374329195383`", ",", 
     "0.09527894336878057`", ",", "0.09527894898626878`", ",", 
     "0.10226039422916901`", ",", "0.14214495369013333`", ",", 
     "0.14214495803972052`", ",", 
     RowBox[{"-", "0.015923445702483836`"}], ",", 
     RowBox[{"-", "0.03957881497304323`"}], ",", 
     RowBox[{"-", "0.03957881610053365`"}], ",", "0.008097345267749603`", ",",
      "0.03458465177556691`", ",", "0.02496780775428971`", ",", 
     "0.10042270898238186`", ",", 
     RowBox[{"-", "0.05065204178997854`"}], ",", 
     RowBox[{"-", "0.16335037280772938`"}], ",", "0.07033751142728704`", ",", 
     "0.1326839900245715`", ",", "0.0003446666882276116`", ",", 
     RowBox[{"-", "0.0208926771121911`"}], ",", "0.0040975209001832685`", ",",
      "0.02089267711219106`", ",", 
     RowBox[{"-", "0.028997138510144738`"}], ",", 
     RowBox[{"-", "0.09256881607348116`"}], ",", 
     RowBox[{"-", "0.02202487001803058`"}], ",", 
     RowBox[{"-", "0.044784548917899424`"}], ",", 
     RowBox[{"-", "0.03375013963714768`"}], ",", 
     RowBox[{"-", "0.10560176774363662`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"x4 [6.45533 %]\"\>", ",", 
     RowBox[{"-", "0.006544467890998492`"}], ",", 
     RowBox[{"-", "0.0009547170298691567`"}], ",", 
     RowBox[{"-", "0.12385348404665333`"}], ",", 
     RowBox[{"-", "0.11002978155384548`"}], ",", 
     RowBox[{"-", "0.10301960148489173`"}], ",", 
     RowBox[{"-", "0.05414707501094931`"}], ",", 
     RowBox[{"-", "0.05245944810230551`"}], ",", 
     RowBox[{"-", "0.05915634553547785`"}], ",", 
     RowBox[{"-", "0.057295934145120755`"}], ",", "0.015403812351950964`", 
     ",", "0.017369209859734235`", ",", "0.044912806633142184`", ",", 
     "0.044862647163274164`", ",", 
     RowBox[{"-", "0.09348084019778659`"}], ",", 
     RowBox[{"-", "0.17962538182756732`"}], ",", 
     RowBox[{"-", "0.17961933263189428`"}], ",", "0.033436742223948615`", ",",
      "0.05194266363906072`", ",", "0.051940471713749346`", ",", 
     "0.060601128322529944`", ",", "0.12824871893109413`", ",", 
     "0.12828107573881842`", ",", "0.07774535325407642`", ",", 
     "0.08254160334921062`", ",", "0.08255151956649885`", ",", 
     RowBox[{"-", "0.09933386889358346`"}], ",", 
     RowBox[{"-", "0.16498926749178583`"}], ",", 
     RowBox[{"-", "0.16497810686667752`"}], ",", 
     RowBox[{"-", "0.008336059521916631`"}], ",", "0.0013456505616366511`", 
     ",", "0.0013500969764122033`", ",", "0.028515027283558095`", ",", 
     "0.08861192396124226`", ",", "0.08864346260430221`", ",", 
     RowBox[{"-", "0.0819249644293835`"}], ",", 
     RowBox[{"-", "0.1559167097023285`"}], ",", 
     RowBox[{"-", "0.15590125375743144`"}], ",", 
     RowBox[{"-", "0.01543144052118998`"}], ",", 
     RowBox[{"-", "0.013746078551661963`"}], ",", 
     RowBox[{"-", "0.013720124351227827`"}], ",", 
     RowBox[{"-", "0.04408077376615908`"}], ",", 
     RowBox[{"-", "0.09988658941709506`"}], ",", 
     RowBox[{"-", "0.09987593796160511`"}], ",", "0.05163385510751607`", ",", 
     "0.11633784216489727`", ",", "0.11634432288694851`", ",", 
     RowBox[{"-", "0.02446689244443117`"}], ",", 
     RowBox[{"-", "0.012710276229901857`"}], ",", 
     RowBox[{"-", "0.01270829060478829`"}], ",", "0.03720004117473419`", ",", 
     "0.1140347070309249`", ",", "0.1140489932128242`", ",", 
     RowBox[{"-", "0.030905821681586135`"}], ",", 
     RowBox[{"-", "0.0796348334235463`"}], ",", 
     RowBox[{"-", "0.07963009700541497`"}], ",", "0.01425939068458968`", ",", 
     "0.04138962482052187`", ",", "0.04139548177960447`", ",", 
     RowBox[{"-", "0.009055962272199881`"}], ",", 
     RowBox[{"-", "0.024922294417437547`"}], ",", 
     RowBox[{"-", "0.024917739885832017`"}], ",", 
     RowBox[{"-", "0.06456760636090592`"}], ",", 
     RowBox[{"-", "0.064515941285428`"}], ",", 
     RowBox[{"-", "0.06450331674749081`"}], ",", 
     RowBox[{"-", "0.0206852299935298`"}], ",", 
     RowBox[{"-", "0.02907666358658413`"}], ",", 
     RowBox[{"-", "0.029109523641132277`"}], ",", "0.015781085542315`", ",", 
     "0.011018319948370279`", ",", "0.01100839987973751`", ",", 
     "0.02831142359761153`", ",", "0.1278214170113727`", ",", 
     "0.028675802044506885`", ",", "0.13418030246731844`", ",", 
     RowBox[{"-", "0.009448277840256633`"}], ",", 
     RowBox[{"-", "0.03662585560211069`"}], ",", 
     RowBox[{"-", "0.02406069555055723`"}], ",", 
     RowBox[{"-", "0.05185478749025226`"}], ",", "0.0007885375892143432`", 
     ",", "0.02385488966632243`", ",", 
     RowBox[{"-", "0.002917489605927266`"}], ",", 
     RowBox[{"-", "0.02385488966632243`"}], ",", "0.0023002753455107533`", 
     ",", "0.006631440540429256`", ",", 
     RowBox[{"-", "0.031951632149558276`"}], ",", 
     RowBox[{"-", "0.07739367870386833`"}], ",", "0.033882649101969135`", ",",
      "0.08672405291655146`", ",", "0.00011036478335811727`", ",", 
     RowBox[{"-", "0.003522162439322766`"}], ",", "0.031312081431407596`", 
     ",", "0.014895135653477665`", ",", "0.029511091688391923`", ",", 
     "0.04906027257544486`", ",", "0.023011922428488586`", ",", 
     "0.025350822427122045`", ",", "0.04662450185573031`", ",", 
     "0.003979586515586101`", ",", "0.0718506216483019`", ",", 
     "0.02923612402586638`", ",", "0.05740324381834115`", ",", 
     "0.057403309635876316`", ",", 
     RowBox[{"-", "0.09754867403697562`"}], ",", 
     RowBox[{"-", "0.1659709195477313`"}], ",", 
     RowBox[{"-", "0.16597092653853845`"}], ",", "0.04766553455781032`", ",", 
     "0.0656754961933158`", ",", "0.06567551111678896`", ",", 
     "0.06568656515079231`", ",", "0.13594379052057529`", ",", 
     "0.13594380365366623`", ",", "0.07738595468457916`", ",", 
     "0.09093697971378324`", ",", "0.09093697601547385`", ",", 
     RowBox[{"-", "0.1062006427942943`"}], ",", 
     RowBox[{"-", "0.17551625761258796`"}], ",", 
     RowBox[{"-", "0.17551626462733155`"}], ",", 
     RowBox[{"-", "0.005209555879826374`"}], ",", 
     RowBox[{"-", "0.004437488920723323`"}], ",", 
     RowBox[{"-", "0.004437460535360887`"}], ",", "0.041170262646165814`", 
     ",", "0.09938869124609667`", ",", "0.09938871489524266`", ",", 
     RowBox[{"-", "0.0939473024236208`"}], ",", 
     RowBox[{"-", "0.14905092015387034`"}], ",", 
     RowBox[{"-", "0.14905091706732806`"}], ",", "0.0033210553662153803`", 
     ",", 
     RowBox[{"-", "0.0034919219310507368`"}], ",", 
     RowBox[{"-", "0.0034918943841925325`"}], ",", 
     RowBox[{"-", "0.036413446607628026`"}], ",", 
     RowBox[{"-", "0.09311758886678238`"}], ",", 
     RowBox[{"-", "0.09311754965865492`"}], ",", "0.052745965015347146`", ",",
      "0.10524583319229565`", ",", "0.10524582768725546`", ",", 
     RowBox[{"-", "0.020185476817722415`"}], ",", 
     RowBox[{"-", "0.0003842962203742131`"}], ",", 
     RowBox[{"-", "0.0003843018147793089`"}], ",", "0.04747646776668144`", 
     ",", "0.12534975025106404`", ",", "0.12534978939535563`", ",", 
     RowBox[{"-", "0.02712560452259064`"}], ",", 
     RowBox[{"-", "0.08297693139564029`"}], ",", 
     RowBox[{"-", "0.08297688044727834`"}], ",", "0.018224085685234225`", ",",
      "0.045472379580380085`", ",", "0.04547237246647807`", ",", 
     "0.0022063345238353786`", ",", 
     RowBox[{"-", "0.009109673493415935`"}], ",", 
     RowBox[{"-", "0.009109673919103835`"}], ",", 
     RowBox[{"-", "0.06554442418898647`"}], ",", 
     RowBox[{"-", "0.10512834137419104`"}], ",", 
     RowBox[{"-", "0.10512832436359094`"}], ",", 
     RowBox[{"-", "0.015757293221628624`"}], ",", 
     RowBox[{"-", "0.02579061928908395`"}], ",", 
     RowBox[{"-", "0.02579063313866405`"}], ",", "0.01957136838362177`", ",", 
     "0.015735516945700984`", ",", "0.015735457945362602`", ",", 
     "0.037010579099177585`", ",", "0.13196427543504247`", ",", 
     "0.03673405503229425`", ",", "0.15079660094785605`", ",", 
     "0.001813889635867566`", ",", 
     RowBox[{"-", "0.01657678764505092`"}], ",", 
     RowBox[{"-", "0.028734475147966843`"}], ",", 
     RowBox[{"-", "0.0810239471290325`"}], ",", "0.008662534028831964`", ",", 
     "0.031089737323607203`", ",", 
     RowBox[{"-", "0.0006298136831921486`"}], ",", 
     RowBox[{"-", "0.031089737323607314`"}], ",", "0.0012183070889858205`", 
     ",", 
     RowBox[{"-", "0.005416518297496065`"}], ",", 
     RowBox[{"-", "0.034563155592821`"}], ",", 
     RowBox[{"-", "0.08301063510259285`"}], ",", "0.034277076159522774`", ",",
      "0.07611527341546324`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"x5 [4.88772 %]\"\>", ",", 
     RowBox[{"-", "0.0009920764743412665`"}], ",", 
     RowBox[{"-", "0.00042225939050857467`"}], ",", 
     RowBox[{"-", "0.023645763807773057`"}], ",", "0.19665530587154872`", ",",
      "0.1755390568839767`", ",", "0.03903982632117388`", ",", 
     "0.03598091693292878`", ",", "0.013544153583189975`", ",", 
     "0.010277477724375228`", ",", 
     RowBox[{"-", "0.1496002528563964`"}], ",", "0.026781419459918354`", ",", 
     "0.11071165878563474`", ",", "0.11066039293163524`", ",", 
     RowBox[{"-", "0.012570788553522623`"}], ",", 
     RowBox[{"-", "0.056520772068562354`"}], ",", 
     RowBox[{"-", "0.05646370100597328`"}], ",", "0.02193607728389354`", ",", 
     "0.03256700845215919`", ",", "0.032598575770212225`", ",", 
     RowBox[{"-", "0.08570370104750874`"}], ",", 
     RowBox[{"-", "0.07369045287893941`"}], ",", 
     RowBox[{"-", "0.07370797705403613`"}], ",", 
     RowBox[{"-", "0.15886825079514966`"}], ",", 
     RowBox[{"-", "0.16430869595497896`"}], ",", 
     RowBox[{"-", "0.1643074617143962`"}], ",", 
     RowBox[{"-", "0.042596599922293546`"}], ",", 
     RowBox[{"-", "0.07369969847084672`"}], ",", 
     RowBox[{"-", "0.07369973892230154`"}], ",", 
     RowBox[{"-", "0.046741937550009355`"}], ",", 
     RowBox[{"-", "0.08316482503813746`"}], ",", 
     RowBox[{"-", "0.08318475223210135`"}], ",", "0.044357313243867685`", ",",
      "0.05495436095160841`", ",", "0.05490745415372047`", ",", 
     "0.04070156591321019`", ",", "0.09679499219561236`", ",", 
     "0.09681420853921807`", ",", "0.06102567384362033`", ",", 
     "0.040245506888907503`", ",", "0.04018381054516836`", ",", 
     RowBox[{"-", "0.007476483213110538`"}], ",", 
     RowBox[{"-", "0.040397384772321174`"}], ",", 
     RowBox[{"-", "0.040363629428507596`"}], ",", "0.03241453871264684`", ",",
      "0.06410171091825206`", ",", "0.0641005534152877`", ",", 
     "0.14238077345445657`", ",", "0.2051115488063124`", ",", 
     "0.2050984253084851`", ",", "0.03551691923059419`", ",", 
     "0.101868489831164`", ",", "0.10184980200385148`", ",", 
     RowBox[{"-", "0.06822428657862202`"}], ",", 
     RowBox[{"-", "0.11224671098965845`"}], ",", 
     RowBox[{"-", "0.11228378956700298`"}], ",", "0.05919639020812051`", ",", 
     "0.07299169089533815`", ",", "0.07298451720017539`", ",", 
     RowBox[{"-", "0.013025862139779087`"}], ",", 
     RowBox[{"-", "0.06810541461138776`"}], ",", 
     RowBox[{"-", "0.06806353924960128`"}], ",", "0.037146374636698856`", ",",
      "0.009006458366105273`", ",", "0.008995497119680642`", ",", 
     "0.028254711284566154`", ",", "0.012646313933256464`", ",", 
     "0.01261187620053324`", ",", "0.00353025544405618`", ",", 
     RowBox[{"-", "0.009631270320986995`"}], ",", 
     RowBox[{"-", "0.00959690661071771`"}], ",", "0.007140192603508943`", ",",
      "0.01759428337294777`", ",", 
     RowBox[{"-", "0.015450951214516092`"}], ",", 
     RowBox[{"-", "0.03832951564971408`"}], ",", "0.01696564024662209`", ",", 
     "0.03916832429466111`", ",", "0.03980506476984347`", ",", 
     "0.09956472018306882`", ",", "0.010071751828046576`", ",", 
     "0.03523711723961415`", ",", 
     RowBox[{"-", "0.01233953854565818`"}], ",", 
     RowBox[{"-", "0.03523711723961416`"}], ",", 
     RowBox[{"-", "0.03018951588950327`"}], ",", 
     RowBox[{"-", "0.030554259243842894`"}], ",", "0.02344547646089643`", ",",
      "0.07617043260959826`", ",", 
     RowBox[{"-", "0.07806368146589203`"}], ",", 
     RowBox[{"-", "0.12420040121904512`"}], ",", 
     RowBox[{"-", "0.010334800970209862`"}], ",", 
     RowBox[{"-", "0.0020934118835889835`"}], ",", 
     RowBox[{"-", "0.01915780763819808`"}], ",", "0.00046137627242583823`", 
     ",", 
     RowBox[{"-", "0.08743786116428776`"}], ",", 
     RowBox[{"-", "0.09184852583917166`"}], ",", 
     RowBox[{"-", "0.007799287416353336`"}], ",", 
     RowBox[{"-", "0.06315474990775075`"}], ",", 
     RowBox[{"-", "0.061689689237822025`"}], ",", 
     RowBox[{"-", "0.009020331092044425`"}], ",", 
     RowBox[{"-", "0.07203299969590254`"}], ",", "0.015640361030236402`", ",",
      "0.10778323300344066`", ",", "0.10778321609772737`", ",", 
     RowBox[{"-", "0.021803328713863614`"}], ",", 
     RowBox[{"-", "0.056078313180899626`"}], ",", 
     RowBox[{"-", "0.05607833264149058`"}], ",", "0.016374463552729583`", ",",
      "0.04260683558385866`", ",", "0.0426068232225766`", ",", 
     RowBox[{"-", "0.08043548827979649`"}], ",", 
     RowBox[{"-", "0.0734221095896105`"}], ",", 
     RowBox[{"-", "0.07342212227067382`"}], ",", 
     RowBox[{"-", "0.15982925362023842`"}], ",", 
     RowBox[{"-", "0.17045598203945944`"}], ",", 
     RowBox[{"-", "0.17045598385808947`"}], ",", 
     RowBox[{"-", "0.04889827040656243`"}], ",", 
     RowBox[{"-", "0.06940648460355163`"}], ",", 
     RowBox[{"-", "0.06940647708153501`"}], ",", 
     RowBox[{"-", "0.058584038389317625`"}], ",", 
     RowBox[{"-", "0.08745338820479201`"}], ",", 
     RowBox[{"-", "0.08745337905368566`"}], ",", "0.06300489137798991`", ",", 
     "0.08269938762601714`", ",", "0.08269947802680645`", ",", 
     "0.03911384519777678`", ",", "0.07806276113531196`", ",", 
     "0.07806273811134053`", ",", "0.03717071541939564`", ",", 
     "0.03243047375990305`", ",", "0.032430449643802844`", ",", 
     RowBox[{"-", "0.02262460337852249`"}], ",", 
     RowBox[{"-", "0.06113427100750926`"}], ",", 
     RowBox[{"-", "0.06113423019405139`"}], ",", "0.022626804755827453`", ",",
      "0.05693520856610153`", ",", "0.05693518380079106`", ",", 
     "0.1532075199686371`", ",", "0.18956052443999596`", ",", 
     "0.18956051949729946`", ",", "0.026114616781151085`", ",", 
     "0.10161524155672726`", ",", "0.10161525541155293`", ",", 
     RowBox[{"-", "0.07523527870068682`"}], ",", 
     RowBox[{"-", "0.09995592058870821`"}], ",", 
     RowBox[{"-", "0.09995588803814683`"}], ",", "0.07180566829763223`", ",", 
     "0.0823568789029754`", ",", "0.08235686896934033`", ",", 
     RowBox[{"-", "0.03410831603995804`"}], ",", 
     RowBox[{"-", "0.07061892478634471`"}], ",", 
     RowBox[{"-", "0.07061891190375255`"}], ",", "0.025254004647440525`", ",",
      "0.008048139826208748`", ",", "0.008048149648384278`", ",", 
     "0.0207816548938538`", ",", "0.005402709330224727`", ",", 
     "0.005402714242501124`", ",", 
     RowBox[{"-", "0.017901380159951654`"}], ",", 
     RowBox[{"-", "0.03288037883521882`"}], ",", 
     RowBox[{"-", "0.032880296860471496`"}], ",", "0.012047231097296003`", 
     ",", "0.059221165370325166`", ",", 
     RowBox[{"-", "0.01795752653318025`"}], ",", 
     RowBox[{"-", "0.006965836304691896`"}], ",", 
     RowBox[{"-", "0.0011067568278927825`"}], ",", "0.019693028084028855`", 
     ",", "0.03304433718352137`", ",", "0.09065604143179606`", ",", 
     "0.000667679892532913`", ",", "0.03401881964390463`", ",", 
     RowBox[{"-", "0.018150327999277016`"}], ",", 
     RowBox[{"-", "0.034018819643904796`"}], ",", 
     RowBox[{"-", "0.03415788681245252`"}], ",", 
     RowBox[{"-", "0.037776142000603447`"}], ",", "0.015812152631217047`", 
     ",", "0.060143589146738174`", ",", 
     RowBox[{"-", "0.078419792688803`"}], ",", 
     RowBox[{"-", "0.123371873418559`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"x6 [4.51465 %]\"\>", ",", 
     RowBox[{"-", "0.005534036262251468`"}], ",", 
     RowBox[{"-", "0.004070124514859927`"}], ",", 
     RowBox[{"-", "0.018527113533657776`"}], ",", "0.01091613979182977`", ",",
      "0.002534125693214823`", ",", "0.06535063307328516`", ",", 
     "0.06500007297047719`", ",", "0.16359849885246205`", ",", 
     "0.16260536784889`", ",", 
     RowBox[{"-", "0.04533482677473993`"}], ",", "0.004065488748507071`", ",",
      "0.01628610998001231`", ",", "0.016279702456687098`", ",", 
     "0.0011751236310280967`", ",", 
     RowBox[{"-", "0.014203500658391183`"}], ",", 
     RowBox[{"-", "0.014217625066292832`"}], ",", 
     RowBox[{"-", "0.06530163068755707`"}], ",", 
     RowBox[{"-", "0.16388423089815266`"}], ",", 
     RowBox[{"-", "0.16392572652239576`"}], ",", "0.012079950033924067`", ",",
      "0.05269128631875125`", ",", "0.05262386071930562`", ",", 
     "0.002620445176614436`", ",", 
     RowBox[{"-", "0.030235361215558514`"}], ",", 
     RowBox[{"-", "0.030233895169505875`"}], ",", 
     RowBox[{"-", "0.05885689932447872`"}], ",", 
     RowBox[{"-", "0.14379138328891888`"}], ",", 
     RowBox[{"-", "0.1438004642638648`"}], ",", "0.007993241349283513`", ",", 
     "0.04685971887330002`", ",", "0.04689240965048397`", ",", 
     "0.024621347623697224`", ",", "0.08500104395676651`", ",", 
     "0.08504622550571367`", ",", "0.022289054706515234`", ",", 
     "0.06449811366532363`", ",", "0.0644578838485858`", ",", 
     RowBox[{"-", "0.08099600177518831`"}], ",", 
     RowBox[{"-", "0.17159691722772322`"}], ",", 
     RowBox[{"-", "0.17157691231777106`"}], ",", 
     RowBox[{"-", "0.0008612346267248983`"}], ",", 
     RowBox[{"-", "0.0026087955092807154`"}], ",", 
     RowBox[{"-", "0.0026745897126658645`"}], ",", "0.0282679421007772`", ",",
      "0.06379216702962424`", ",", "0.06379364705263742`", ",", 
     RowBox[{"-", "0.05314635505284556`"}], ",", 
     RowBox[{"-", "0.08258957288480027`"}], ",", 
     RowBox[{"-", "0.08259303384480082`"}], ",", 
     RowBox[{"-", "0.03945302142897923`"}], ",", 
     RowBox[{"-", "0.0725984906382923`"}], ",", 
     RowBox[{"-", "0.07260845501541913`"}], ",", "0.05221271001908014`", ",", 
     "0.09299441871383562`", ",", "0.09302314103911417`", ",", 
     "0.03346746790482668`", ",", "0.08910723461685333`", ",", 
     "0.08909823197059084`", ",", 
     RowBox[{"-", "0.08060027248396119`"}], ",", 
     RowBox[{"-", "0.1864898795636849`"}], ",", 
     RowBox[{"-", "0.18643308857495738`"}], ",", "0.10188306961389829`", ",", 
     "0.17868847062782964`", ",", "0.1786859912114148`", ",", 
     RowBox[{"-", "0.009009624907062327`"}], ",", "0.03353010376017015`", ",",
      "0.03352147710024002`", ",", "0.022333568055587946`", ",", 
     "0.08610773397157323`", ",", "0.08604284726066373`", ",", 
     "0.0008097022993063409`", ",", "0.01484279696811115`", ",", 
     "0.0027537570431791407`", ",", "0.026291205023750246`", ",", 
     RowBox[{"-", "0.007658110109772014`"}], ",", 
     RowBox[{"-", "0.01990799241447176`"}], ",", "0.001563929559097007`", ",",
      "0.07012352811409758`", ",", "0.0015537886866113873`", ",", 
     "0.06418853906951874`", ",", 
     RowBox[{"-", "0.010383292607920296`"}], ",", 
     RowBox[{"-", "0.06418853906951874`"}], ",", "0.01691900463902651`", ",", 
     "0.10038590155769014`", ",", "0.0214397774158823`", ",", 
     "0.08642226170966558`", ",", "0.011726701008894025`", ",", 
     "0.07741272428528245`", ",", 
     RowBox[{"-", "0.00182367031832671`"}], ",", 
     RowBox[{"-", "0.004888232908381209`"}], ",", 
     RowBox[{"-", "0.02221552200522249`"}], ",", 
     RowBox[{"-", "0.012004269219224142`"}], ",", 
     RowBox[{"-", "0.009542017798617405`"}], ",", 
     RowBox[{"-", "0.009939938440769902`"}], ",", "0.03891926847360561`", ",", 
     RowBox[{"-", "0.07118887503426771`"}], ",", 
     RowBox[{"-", "0.047773414878695866`"}], ",", 
     RowBox[{"-", "0.0003769033532928511`"}], ",", "0.014676591941749067`", 
     ",", "0.00463415919719685`", ",", "0.00023272385048817075`", ",", 
     "0.00023274965078787767`", ",", 
     RowBox[{"-", "0.00688246922335601`"}], ",", 
     RowBox[{"-", "0.033636259851190765`"}], ",", 
     RowBox[{"-", "0.033636295971839536`"}], ",", 
     RowBox[{"-", "0.07006619046046829`"}], ",", 
     RowBox[{"-", "0.16730969655516317`"}], ",", 
     RowBox[{"-", "0.16730968316450412`"}], ",", "0.02434752997606421`", ",", 
     "0.07952524177957683`", ",", "0.07952527030088474`", ",", 
     RowBox[{"-", "0.0017918388654467004`"}], ",", 
     RowBox[{"-", "0.03742273427328206`"}], ",", 
     RowBox[{"-", "0.03742271857620473`"}], ",", 
     RowBox[{"-", "0.05984290316051984`"}], ",", 
     RowBox[{"-", "0.13304952319333363`"}], ",", 
     RowBox[{"-", "0.13304956158402215`"}], ",", "0.008727683531591628`", ",",
      "0.046587323935243355`", ",", "0.04658730737533928`", ",", 
     "0.01900739422279452`", ",", "0.04161850296925148`", ",", 
     "0.041618567033059696`", ",", "0.03186862760821928`", ",", 
     "0.06320033432506016`", ",", "0.06320031255308349`", ",", 
     RowBox[{"-", "0.06645428139996937`"}], ",", 
     RowBox[{"-", "0.13794815335354524`"}], ",", 
     RowBox[{"-", "0.13794814176212966`"}], ",", "0.006574348001582094`", ",",
      "0.012569096645347059`", ",", "0.012569072392834274`", ",", 
     "0.035384561959441965`", ",", "0.07390171465430045`", ",", 
     "0.07390172214627079`", ",", 
     RowBox[{"-", "0.059333281575140825`"}], ",", 
     RowBox[{"-", "0.08040730867961221`"}], ",", 
     RowBox[{"-", "0.08040728630192119`"}], ",", 
     RowBox[{"-", "0.02786108777172293`"}], ",", 
     RowBox[{"-", "0.055187336226140256`"}], ",", 
     RowBox[{"-", "0.05518732598396975`"}], ",", "0.0511777133371668`", ",", 
     "0.07248688919613142`", ",", "0.07248691353193691`", ",", 
     "0.032955240391275065`", ",", "0.06516309241583015`", ",", 
     "0.06516310447869489`", ",", 
     RowBox[{"-", "0.07671902688683278`"}], ",", 
     RowBox[{"-", "0.1779701748112865`"}], ",", 
     RowBox[{"-", "0.17797013763764313`"}], ",", "0.08155683822895803`", ",", 
     "0.16654280079349826`", ",", "0.16654278592180824`", ",", 
     RowBox[{"-", "0.006670022021595581`"}], ",", "0.01631529856113409`", ",",
      "0.016315308179523726`", ",", "0.03690455081074189`", ",", 
     "0.12093222152949336`", ",", "0.12093225833230084`", ",", 
     RowBox[{"-", "0.002586871548285528`"}], ",", 
     RowBox[{"-", "0.02195182718007145`"}], ",", "0.003794287698821272`", ",",
      "0.004399174346993218`", ",", "0.0014044178828169496`", ",", 
     "0.013003170288278021`", ",", "0.010010983478119573`", ",", 
     "0.06968270312341551`", ",", "0.00715467564158101`", ",", 
     "0.059725073678799825`", ",", 
     RowBox[{"-", "0.007630769689845218`"}], ",", 
     RowBox[{"-", "0.05972507367879979`"}], ",", "0.023114695245886302`", ",",
      "0.10529374089019153`", ",", "0.026432944831869143`", ",", 
     "0.08079558326000354`", ",", "0.01868504252837938`", ",", 
     "0.08955631403667196`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"x7 [3.91623 %]\"\>", ",", "0.011899079402319636`", ",", 
     "0.011825700567991074`", ",", "0.023926512132527177`", ",", 
     "0.0012320599458839061`", ",", 
     RowBox[{"-", "0.05759084598295303`"}], ",", "0.10315747667095428`", ",", 
     "0.10121923623324301`", ",", "0.16704241525159721`", ",", 
     "0.16613048100516514`", ",", "0.0005152692302428088`", ",", 
     "0.025206288917667644`", ",", "0.013967974982752858`", ",", 
     "0.013975993061578578`", ",", "0.027034845732789598`", ",", 
     "0.012768846522126707`", ",", "0.012775682884038105`", ",", 
     "0.03740532481650777`", ",", "0.03414836245780887`", ",", 
     "0.03412318818357681`", ",", 
     RowBox[{"-", "0.046763624122196173`"}], ",", 
     RowBox[{"-", "0.1254498047356858`"}], ",", 
     RowBox[{"-", "0.12546645892344785`"}], ",", 
     RowBox[{"-", "0.07106154163497165`"}], ",", 
     RowBox[{"-", "0.020517383266112292`"}], ",", 
     RowBox[{"-", "0.02055061405906024`"}], ",", 
     RowBox[{"-", "0.018123308987828334`"}], ",", 
     RowBox[{"-", "0.058966052568992906`"}], ",", 
     RowBox[{"-", "0.05897969527849824`"}], ",", "0.0482077709156774`", ",", 
     "0.125423771069803`", ",", "0.12549434686402539`", ",", 
     "0.05576993271378687`", ",", "0.10837109571106805`", ",", 
     "0.10844930297909512`", ",", 
     RowBox[{"-", "0.08955448746501292`"}], ",", 
     RowBox[{"-", "0.19487154668905418`"}], ",", 
     RowBox[{"-", "0.19485782248184175`"}], ",", "0.09987138929894908`", ",", 
     "0.14190008546055088`", ",", "0.14193069781727707`", ",", 
     "0.022896003099024113`", ",", "0.0360941625314186`", ",", 
     "0.03599550868491535`", ",", 
     RowBox[{"-", "0.004372958096474838`"}], ",", 
     RowBox[{"-", "0.0018660327354281456`"}], ",", 
     RowBox[{"-", "0.00184120262269543`"}], ",", "0.022138667456238877`", ",", 
     RowBox[{"-", "0.08119743066464644`"}], ",", 
     RowBox[{"-", "0.08119898143378851`"}], ",", 
     RowBox[{"-", "0.00181660739910639`"}], ",", 
     RowBox[{"-", "0.06354146747900154`"}], ",", 
     RowBox[{"-", "0.06354975281561855`"}], ",", 
     RowBox[{"-", "0.041303170309163244`"}], ",", 
     RowBox[{"-", "0.09655965964056426`"}], ",", 
     RowBox[{"-", "0.09655039307591576`"}], ",", 
     RowBox[{"-", "0.0012179254173316882`"}], ",", 
     RowBox[{"-", "0.06486948233372855`"}], ",", 
     RowBox[{"-", "0.06486961445379014`"}], ",", "0.014908691485177324`", ",",
      "0.007600745845334744`", ",", "0.007597309709774297`", ",", 
     "0.1334362844519309`", ",", "0.177976909326618`", ",", 
     "0.1779670155063652`", ",", "0.024621271621489076`", ",", 
     "0.05900678995851151`", ",", "0.05905248290952569`", ",", 
     RowBox[{"-", "0.009531039599345524`"}], ",", 
     RowBox[{"-", "0.06589623757853344`"}], ",", 
     RowBox[{"-", "0.06590764701137135`"}], ",", "0.01567154680403185`", ",", 
     "0.013469725488857913`", ",", 
     RowBox[{"-", "0.0010875803464215393`"}], ",", 
     RowBox[{"-", "0.07311220782895879`"}], ",", "0.03099167311930418`", ",", 
     "0.05100289051762788`", ",", "0.0019488129561720394`", ",", 
     RowBox[{"-", "0.025506640822744734`"}], ",", "0.023081356158683442`", 
     ",", "0.09857732128161001`", ",", 
     RowBox[{"-", "0.001191301357572564`"}], ",", 
     RowBox[{"-", "0.09857732128161002`"}], ",", 
     RowBox[{"-", "0.010845697759649485`"}], ",", 
     RowBox[{"-", "0.03745838930518837`"}], ",", 
     RowBox[{"-", "0.01686146548668977`"}], ",", 
     RowBox[{"-", "0.09174853344320985`"}], ",", 
     RowBox[{"-", "0.004630001565586293`"}], ",", "0.029544352199101204`", 
     ",", "0.0010129363806513011`", ",", "0.01176847801575056`", ",", 
     "0.042516831536829704`", ",", 
     RowBox[{"-", "0.016288408734750175`"}], ",", 
     RowBox[{"-", "0.018182758808210353`"}], ",", 
     RowBox[{"-", "0.011418674098840557`"}], ",", 
     RowBox[{"-", "0.05704593955343035`"}], ",", 
     RowBox[{"-", "0.005509041908147166`"}], ",", 
     RowBox[{"-", "0.01732342215624455`"}], ",", 
     RowBox[{"-", "0.0015867175242092963`"}], ",", 
     RowBox[{"-", "0.16344839771186884`"}], ",", "0.00995963028331294`", ",", 
     RowBox[{"-", "0.00038962826474966223`"}], ",", 
     RowBox[{"-", "0.0003896617882943581`"}], ",", "0.01563787114402559`", 
     ",", "0.01303372268649395`", ",", "0.01303375035813054`", ",", 
     "0.030370583334725188`", ",", "0.04248147139150006`", ",", 
     "0.04248146554150833`", ",", 
     RowBox[{"-", "0.05508786641895835`"}], ",", 
     RowBox[{"-", "0.12324867411808214`"}], ",", 
     RowBox[{"-", "0.12324863284952413`"}], ",", 
     RowBox[{"-", "0.08759166919674362`"}], ",", 
     RowBox[{"-", "0.03882362688116486`"}], ",", 
     RowBox[{"-", "0.03882363232920236`"}], ",", 
     RowBox[{"-", "0.0224355980700326`"}], ",", 
     RowBox[{"-", "0.04452777396962918`"}], ",", 
     RowBox[{"-", "0.04452777040583578`"}], ",", "0.040223732978352085`", ",",
      "0.12696121683219433`", ",", "0.12696123290691694`", ",", 
     "0.06186908822383731`", ",", "0.10357441803199133`", ",", 
     "0.10357449779589656`", ",", 
     RowBox[{"-", "0.12438479791784153`"}], ",", 
     RowBox[{"-", "0.19523208137182974`"}], ",", 
     RowBox[{"-", "0.19523208608672088`"}], ",", "0.09510952569478914`", ",", 
     "0.18122726541433265`", ",", "0.1812273079564584`", ",", 
     "0.013308639522865087`", ",", "0.04045456040346832`", ",", 
     "0.04045453752024776`", ",", 
     RowBox[{"-", "0.014835568576111515`"}], ",", "0.0014995364798676427`", 
     ",", "0.0014995670573282045`", ",", 
     RowBox[{"-", "0.022754906819497104`"}], ",", 
     RowBox[{"-", "0.11461916262180391`"}], ",", 
     RowBox[{"-", "0.11461913513599706`"}], ",", 
     RowBox[{"-", "0.009019556340621755`"}], ",", 
     RowBox[{"-", "0.05889420514126358`"}], ",", 
     RowBox[{"-", "0.05889417793343868`"}], ",", 
     RowBox[{"-", "0.05958547108755401`"}], ",", 
     RowBox[{"-", "0.10572697369712952`"}], ",", 
     RowBox[{"-", "0.10572699281410111`"}], ",", 
     RowBox[{"-", "0.004945187159160869`"}], ",", 
     RowBox[{"-", "0.05530856263552457`"}], ",", 
     RowBox[{"-", "0.05530859009620077`"}], ",", "0.0035419162747262253`", 
     ",", "0.03922656862110592`", ",", "0.039226671417049344`", ",", 
     "0.09627012638830286`", ",", "0.14230645163724875`", ",", 
     "0.14230648267772572`", ",", "0.018010532064423206`", ",", 
     "0.051477151620614704`", ",", "0.051477157793264325`", ",", 
     RowBox[{"-", "0.016622904026665792`"}], ",", 
     RowBox[{"-", "0.03173067376874045`"}], ",", 
     RowBox[{"-", "0.03173072194196888`"}], ",", "0.008415104759874475`", ",",
      "0.01677434661619895`", ",", 
     RowBox[{"-", "0.010905458344899088`"}], ",", 
     RowBox[{"-", "0.05828324480129454`"}], ",", "0.02074345486115886`", ",", 
     "0.0709388704863762`", ",", 
     RowBox[{"-", "0.023772939090407064`"}], ",", 
     RowBox[{"-", "0.07029856008088367`"}], ",", "0.009810432637530009`", ",",
      "0.061405329895859326`", ",", 
     RowBox[{"-", "0.01253971064894454`"}], ",", 
     RowBox[{"-", "0.0614053298958593`"}], ",", 
     RowBox[{"-", "0.02375856418666432`"}], ",", 
     RowBox[{"-", "0.033212867065316724`"}], ",", 
     RowBox[{"-", "0.03859015825037808`"}], ",", 
     RowBox[{"-", "0.09562219307602823`"}], ",", 
     RowBox[{"-", "0.008630818286744536`"}], ",", "0.04354938080148281`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"x8 [3.5715 %]\"\>", ",", "0.0069354523303293055`", ",", 
     "0.007399390011616779`", ",", "0.02938846324623545`", ",", 
     "0.1194167427129551`", ",", "0.15657462724626203`", ",", 
     RowBox[{"-", "0.028965609927249072`"}], ",", 
     RowBox[{"-", "0.026443876692400545`"}], ",", 
     RowBox[{"-", "0.005107063738520481`"}], ",", 
     RowBox[{"-", "0.0007980249459539944`"}], ",", 
     RowBox[{"-", "0.12250770742341427`"}], ",", "0.09876679501678623`", ",", 
     "0.1287036477198115`", ",", "0.12876600904596963`", ",", 
     "0.0819703610627263`", ",", "0.13116347615270152`", ",", 
     "0.13117237264701942`", ",", "0.013300503727435917`", ",", 
     "0.10883902277174698`", ",", "0.10881410452848901`", ",", 
     RowBox[{"-", "0.05495631161824182`"}], ",", 
     RowBox[{"-", "0.12895077715073694`"}], ",", 
     RowBox[{"-", "0.12889255397128674`"}], ",", "0.13247484698683953`", ",", 
     "0.21011266096646347`", ",", "0.21013686582137872`", ",", 
     "0.02589174074326862`", ",", "0.03110049653477569`", ",", 
     "0.031084073824205735`", ",", "0.03717450053127467`", ",", 
     "0.0049752669780255485`", ",", "0.004974535444205501`", ",", 
     RowBox[{"-", "0.017623201940587394`"}], ",", 
     RowBox[{"-", "0.006008578665245427`"}], ",", 
     RowBox[{"-", "0.005997501893266257`"}], ",", 
     RowBox[{"-", "0.03870258127771718`"}], ",", 
     RowBox[{"-", "0.0675929899236118`"}], ",", 
     RowBox[{"-", "0.06760645501855386`"}], ",", 
     RowBox[{"-", "0.07374858658917446`"}], ",", 
     RowBox[{"-", "0.11558372782315984`"}], ",", 
     RowBox[{"-", "0.11562127745659806`"}], ",", "0.024166320440419567`", ",", 
     RowBox[{"-", "0.035739067173182204`"}], ",", 
     RowBox[{"-", "0.03579420296367942`"}], ",", "0.03649454676948399`", ",", 
     "0.040778448942089214`", ",", "0.04077525618271132`", ",", 
     RowBox[{"-", "0.0145030966578635`"}], ",", 
     RowBox[{"-", "0.04454879678122143`"}], ",", 
     RowBox[{"-", "0.04452955196431439`"}], ",", "0.025481159371932564`", ",",
      "0.07500959424015329`", ",", "0.07498398210887507`", ",", 
     "0.021871192426000604`", ",", "0.022178848677797115`", ",", 
     "0.022199347828215088`", ",", 
     RowBox[{"-", "0.036919437896083956`"}], ",", 
     RowBox[{"-", "0.08306606579375311`"}], ",", 
     RowBox[{"-", "0.08301793021488452`"}], ",", 
     RowBox[{"-", "0.09030554641518548`"}], ",", 
     RowBox[{"-", "0.19766217141005815`"}], ",", 
     RowBox[{"-", "0.19769998119352178`"}], ",", 
     RowBox[{"-", "0.006071886229788761`"}], ",", "0.006539283336419684`", 
     ",", "0.006551625877554163`", ",", 
     RowBox[{"-", "0.05143976295390294`"}], ",", 
     RowBox[{"-", "0.02435574284235538`"}], ",", 
     RowBox[{"-", "0.024350215546787398`"}], ",", 
     RowBox[{"-", "0.02567248000964473`"}], ",", 
     RowBox[{"-", "0.13195592034054576`"}], ",", 
     RowBox[{"-", "0.13204500168167693`"}], ",", "0.02063137262227984`", ",", 
     "0.045312621073040446`", ",", "0.0013170018871989978`", ",", 
     RowBox[{"-", "0.008813218756855623`"}], ",", "0.018429675730954248`", 
     ",", 
     RowBox[{"-", "0.059021280191215914`"}], ",", 
     RowBox[{"-", "0.019784263195873664`"}], ",", 
     RowBox[{"-", "0.005937853704496582`"}], ",", "0.017540480893312924`", 
     ",", "0.06568023615677741`", ",", 
     RowBox[{"-", "0.004266389521317758`"}], ",", 
     RowBox[{"-", "0.06568023615677744`"}], ",", "0.011487247216999343`", ",",
      "0.003905929618381423`", ",", "0.03986353242247065`", ",", 
     "0.08941773463002815`", ",", 
     RowBox[{"-", "0.01547364023138865`"}], ",", 
     RowBox[{"-", "0.081509338982147`"}], ",", "0.00986250505091768`", ",", 
     "0.008850099616050065`", ",", 
     RowBox[{"-", "0.00038047804008126476`"}], ",", "0.034678774332552516`", 
     ",", "0.00609133308947611`", ",", "0.007713536192929235`", ",", 
     "0.019830452101455343`", ",", 
     RowBox[{"-", "0.05807099106946002`"}], ",", 
     RowBox[{"-", "0.09764600211456581`"}], ",", "0.009044531655515699`", ",",
      "0.040456220047996296`", ",", "0.11200633669289228`", ",", 
     "0.1261708107572744`", ",", "0.12617086789035353`", ",", 
     "0.08058557935330672`", ",", "0.1396757908940749`", ",", 
     "0.13967578760561034`", ",", "0.008256642305899743`", ",", 
     "0.09859550480234944`", ",", "0.09859548884645701`", ",", 
     RowBox[{"-", "0.0467677317481383`"}], ",", 
     RowBox[{"-", "0.12431437780750659`"}], ",", 
     RowBox[{"-", "0.12431438582949245`"}], ",", "0.11356414990378827`", ",", 
     "0.19185383676489107`", ",", "0.19185382517886546`", ",", 
     "0.03873773779839513`", ",", "0.05526359018718333`", ",", 
     "0.05526356262728278`", ",", "0.02843970799125325`", ",", 
     RowBox[{"-", "0.01565208998684253`"}], ",", 
     RowBox[{"-", "0.01565207131827468`"}], ",", 
     RowBox[{"-", "0.00665688375455133`"}], ",", "0.005986477563356005`", ",",
      "0.005986501890850935`", ",", 
     RowBox[{"-", "0.039349776068872605`"}], ",", 
     RowBox[{"-", "0.0697941715250393`"}], ",", 
     RowBox[{"-", "0.069794189485851`"}], ",", 
     RowBox[{"-", "0.07631140840044266`"}], ",", 
     RowBox[{"-", "0.10604846649912127`"}], ",", 
     RowBox[{"-", "0.10604850996498172`"}], ",", "0.01846555666440626`", ",", 
     RowBox[{"-", "0.049947954636629315`"}], ",", 
     RowBox[{"-", "0.04994797491413486`"}], ",", "0.03931534599767184`", ",", 
     "0.04649351199390798`", ",", "0.046493487051193556`", ",", 
     RowBox[{"-", "0.02099347571356312`"}], ",", 
     RowBox[{"-", "0.035470977753779005`"}], ",", 
     RowBox[{"-", "0.03547100657788195`"}], ",", "0.024518777418502072`", ",",
      "0.06344615641295301`", ",", "0.06344621679792142`", ",", 
     "0.012934860388146889`", ",", 
     RowBox[{"-", "0.00044991222074773586`"}], ",", 
     RowBox[{"-", "0.0004499300572867815`"}], ",", 
     RowBox[{"-", "0.027883330586462564`"}], ",", 
     RowBox[{"-", "0.0545718141174157`"}], ",", 
     RowBox[{"-", "0.054571817867224474`"}], ",", 
     RowBox[{"-", "0.0809003370493146`"}], ",", 
     RowBox[{"-", "0.17068204946075358`"}], ",", 
     RowBox[{"-", "0.17068204725473796`"}], ",", "0.0010962410974364313`", 
     ",", "0.0034344401285716954`", ",", "0.003434461128687215`", ",", 
     RowBox[{"-", "0.04485275498316357`"}], ",", 
     RowBox[{"-", "0.022627046967678737`"}], ",", 
     RowBox[{"-", "0.022627043028796232`"}], ",", 
     RowBox[{"-", "0.029981369816727443`"}], ",", 
     RowBox[{"-", "0.12377183884625333`"}], ",", 
     RowBox[{"-", "0.12377189177648837`"}], ",", "0.023565089359199164`", ",",
      "0.03225335958381659`", ",", "0.002131414740451032`", ",", 
     RowBox[{"-", "0.015415164630410538`"}], ",", "0.02081850335369488`", ",", 
     RowBox[{"-", "0.051179272347213645`"}], ",", 
     RowBox[{"-", "0.019431269833438736`"}], ",", 
     RowBox[{"-", "0.027584090143091086`"}], ",", "0.017052461149887677`", 
     ",", "0.021729279202692242`", ",", "0.0011096913083732257`", ",", 
     RowBox[{"-", "0.021729279202692076`"}], ",", "0.014584944638848803`", 
     ",", "0.0010361682478821355`", ",", "0.040784829793904354`", ",", 
     "0.08727732996235249`", ",", 
     RowBox[{"-", "0.01053011945004989`"}], ",", 
     RowBox[{"-", "0.08764948789174525`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"x9 [3.15005 %]\"\>", ",", 
     RowBox[{"-", "0.003106317508623881`"}], ",", 
     RowBox[{"-", "0.002259996173480504`"}], ",", 
     RowBox[{"-", "0.023245293687593083`"}], ",", 
     RowBox[{"-", "0.09145741636900287`"}], ",", 
     RowBox[{"-", "0.03291845272682044`"}], ",", "0.012572731744960082`", ",",
      "0.011956575882313856`", ",", 
     RowBox[{"-", "0.021117783460093607`"}], ",", 
     RowBox[{"-", "0.02239499194131514`"}], ",", "0.07003768717999924`", ",", 
     "0.013353552566192469`", ",", "0.07989549933876998`", ",", 
     "0.0799689593595261`", ",", "0.08149975296814994`", ",", 
     "0.18446618810062598`", ",", "0.18453053116001428`", ",", 
     RowBox[{"-", "0.022101330316878`"}], ",", 
     RowBox[{"-", "0.09034019803375024`"}], ",", 
     RowBox[{"-", "0.09031398383970969`"}], ",", "0.06798292380624774`", ",", 
     "0.13521924603313673`", ",", "0.13524656623974593`", ",", 
     RowBox[{"-", "0.032915381021596746`"}], ",", 
     RowBox[{"-", "0.07092920296338157`"}], ",", 
     RowBox[{"-", "0.07090448587869`"}], ",", "0.034739611492846476`", ",", 
     "0.00835568022624188`", ",", "0.008351540994905069`", ",", 
     RowBox[{"-", "0.02272706413258934`"}], ",", "0.01367297643483954`", ",", 
     "0.01373342878475716`", ",", "0.09910776182041821`", ",", 
     "0.21288800668516328`", ",", "0.21293793452056434`", ",", 
     "0.0006494860354362723`", ",", 
     RowBox[{"-", "0.02348968701130235`"}], ",", 
     RowBox[{"-", "0.023501537675755066`"}], ",", 
     RowBox[{"-", "0.06176040979036911`"}], ",", 
     RowBox[{"-", "0.09578780529589531`"}], ",", 
     RowBox[{"-", "0.09577223013556443`"}], ",", 
     RowBox[{"-", "0.023544126622444195`"}], ",", 
     RowBox[{"-", "0.015302264992774232`"}], ",", 
     RowBox[{"-", "0.015278332509556304`"}], ",", 
     RowBox[{"-", "0.08688113941731689`"}], ",", 
     RowBox[{"-", "0.07397056580095786`"}], ",", 
     RowBox[{"-", "0.07399765638723747`"}], ",", "0.0370939621927148`", ",", 
     "0.10069721048310393`", ",", "0.10071078355270775`", ",", 
     RowBox[{"-", "0.02834013598254446`"}], ",", 
     RowBox[{"-", "0.06883678542343377`"}], ",", 
     RowBox[{"-", "0.06884040389098989`"}], ",", 
     RowBox[{"-", "0.03811388536503435`"}], ",", 
     RowBox[{"-", "0.11117787502038681`"}], ",", 
     RowBox[{"-", "0.11117855761224098`"}], ",", 
     RowBox[{"-", "0.08486539895507872`"}], ",", 
     RowBox[{"-", "0.09365360263777445`"}], ",", 
     RowBox[{"-", "0.09369089686445572`"}], ",", 
     RowBox[{"-", "0.006598081738623047`"}], ",", "0.02324881587697655`", ",",
      "0.023258673028396026`", ",", 
     RowBox[{"-", "0.02779487293228853`"}], ",", 
     RowBox[{"-", "0.06791100196365434`"}], ",", 
     RowBox[{"-", "0.06792940488166195`"}], ",", "0.06548513640483826`", ",", 
     "0.09142985129108278`", ",", "0.09143673684899817`", ",", 
     RowBox[{"-", "0.01860448554264993`"}], ",", 
     RowBox[{"-", "0.0699400303397816`"}], ",", 
     RowBox[{"-", "0.06993552020739296`"}], ",", "0.006863045368604641`", ",",
      "0.06282191642221385`", ",", "0.006026231920882711`", ",", 
     RowBox[{"-", "0.0036650419971660355`"}], ",", 
     RowBox[{"-", "0.020294805987338647`"}], ",", 
     RowBox[{"-", "0.03635886877026472`"}], ",", "0.008728249701583429`", ",", 
     RowBox[{"-", "0.013990453069209804`"}], ",", "0.0014224913372964695`", 
     ",", "0.0004084409858680395`", ",", 
     RowBox[{"-", "0.006401547171657288`"}], ",", 
     RowBox[{"-", "0.00040844098586804295`"}], ",", "0.009841736547475183`", 
     ",", "0.08290078027639179`", ",", 
     RowBox[{"-", "0.013768359505043334`"}], ",", "0.03207743781878309`", ",",
      "0.03112088133937522`", ",", "0.10253013061255654`", ",", 
     RowBox[{"-", "0.011949526897270968`"}], ",", 
     RowBox[{"-", "0.006706497247951101`"}], ",", "0.04531883907814813`", ",", 
     RowBox[{"-", "0.01833427016288939`"}], ",", "0.020808655627504072`", ",",
      "0.013862254202592732`", ",", "0.10486105700047244`", ",", 
     "0.06357279212315757`", ",", "0.11644973458713996`", ",", 
     RowBox[{"-", "0.009285324278699261`"}], ",", 
     RowBox[{"-", "0.051174632727980576`"}], ",", "0.019513015543327357`", 
     ",", "0.101013122837693`", ",", "0.10101314682078098`", ",", 
     "0.0874754687782264`", ",", "0.1924998121959839`", ",", 
     "0.192499760055434`", ",", 
     RowBox[{"-", "0.019521097508389228`"}], ",", 
     RowBox[{"-", "0.08063423964474276`"}], ",", 
     RowBox[{"-", "0.08063418913440355`"}], ",", "0.048335967428206034`", ",",
      "0.12405050047539898`", ",", "0.12405052180325868`", ",", 
     RowBox[{"-", "0.0185723796488527`"}], ",", 
     RowBox[{"-", "0.04745879569200346`"}], ",", 
     RowBox[{"-", "0.04745878756285835`"}], ",", "0.031066231648123853`", ",",
      "0.006237199495686786`", ",", "0.006237197226020577`", ",", 
     RowBox[{"-", "0.025982346017845534`"}], ",", "0.0065790777265820255`", 
     ",", "0.0065790830873906836`", ",", "0.10181128663881217`", ",", 
     "0.20210573069620966`", ",", "0.20210567345049701`", ",", 
     RowBox[{"-", "0.0003224971207723259`"}], ",", 
     RowBox[{"-", "0.006346675508473548`"}], ",", 
     RowBox[{"-", "0.006346675110259725`"}], ",", 
     RowBox[{"-", "0.06288214006186246`"}], ",", 
     RowBox[{"-", "0.12168853087521317`"}], ",", 
     RowBox[{"-", "0.12168848347291192`"}], ",", 
     RowBox[{"-", "0.037479065291032614`"}], ",", 
     RowBox[{"-", "0.03291971944748881`"}], ",", 
     RowBox[{"-", "0.0329197007727372`"}], ",", 
     RowBox[{"-", "0.10003385794669992`"}], ",", 
     RowBox[{"-", "0.09200927262430143`"}], ",", 
     RowBox[{"-", "0.09200929475360096`"}], ",", "0.051479167735017484`", ",",
      "0.09172281486313585`", ",", "0.09172284194988002`", ",", 
     RowBox[{"-", "0.03948816893634295`"}], ",", 
     RowBox[{"-", "0.0918218114355334`"}], ",", 
     RowBox[{"-", "0.09182174639344051`"}], ",", 
     RowBox[{"-", "0.040924727687227165`"}], ",", 
     RowBox[{"-", "0.10322781402571249`"}], ",", 
     RowBox[{"-", "0.10322777957691046`"}], ",", 
     RowBox[{"-", "0.09533662971563468`"}], ",", 
     RowBox[{"-", "0.07919643690035984`"}], ",", 
     RowBox[{"-", "0.07919644727677724`"}], ",", "0.0011434683659869507`", 
     ",", "0.026982260737270995`", ",", "0.026982268199452736`", ",", 
     RowBox[{"-", "0.025653862390928733`"}], ",", 
     RowBox[{"-", "0.0821692538728041`"}], ",", 
     RowBox[{"-", "0.08216922775878199`"}], ",", "0.07282666912114164`", ",", 
     "0.10943123220364985`", ",", "0.10943129451731595`", ",", 
     RowBox[{"-", "0.04626257127078681`"}], ",", 
     RowBox[{"-", "0.120979502808216`"}], ",", 
     RowBox[{"-", "0.1209795112625009`"}], ",", "0.008048326314050457`", ",", 
     "0.09257784721589057`", ",", 
     RowBox[{"-", "0.0012172662215759744`"}], ",", "0.004150349777519227`", 
     ",", 
     RowBox[{"-", "0.030468922268022752`"}], ",", 
     RowBox[{"-", "0.05909909659514573`"}], ",", "0.007145816303020858`", ",", 
     RowBox[{"-", "0.001633707818685104`"}], ",", 
     RowBox[{"-", "0.0031735135148149296`"}], ",", "0.00045071810139399315`", 
     ",", 
     RowBox[{"-", "0.01496054302120009`"}], ",", 
     RowBox[{"-", "0.0004507181013939099`"}], ",", 
     RowBox[{"-", "0.004572340674296602`"}], ",", "0.06551327034776905`", ",", 
     RowBox[{"-", "0.02304153692023117`"}], ",", "0.027348105480192897`", ",",
      "0.012796898576602031`", ",", "0.0791870259331217`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"x10 [2.82711 %]\"\>", ",", "0.008454021648489286`", ",", 
     "0.0063850643144097`", ",", "0.023800930671829125`", ",", 
     RowBox[{"-", "0.03196010007555278`"}], ",", 
     RowBox[{"-", "0.10915102667273612`"}], ",", "0.014093776503711835`", ",",
      "0.013838316424421846`", ",", "0.07070359939965543`", ",", 
     "0.0695019243055022`", ",", "0.06074424058207741`", ",", 
     "0.0443374620550646`", ",", "0.053365425527172536`", ",", 
     "0.053371104084017074`", ",", "0.02133292545261529`", ",", 
     "0.026911618042160846`", ",", "0.0269210048446285`", ",", 
     RowBox[{"-", "0.01776644832312046`"}], ",", "0.005450375022477458`", ",",
      "0.0054503046527053164`", ",", 
     RowBox[{"-", "0.04158370321185111`"}], ",", 
     RowBox[{"-", "0.05657700701019284`"}], ",", 
     RowBox[{"-", "0.056533392418419315`"}], ",", 
     RowBox[{"-", "0.012988461060120318`"}], ",", 
     RowBox[{"-", "0.05971834817456474`"}], ",", 
     RowBox[{"-", "0.05973398885646945`"}], ",", "0.041305122251607984`", ",",
      "0.06103242471953345`", ",", "0.061091250394585024`", ",", 
     "0.07902198364457177`", ",", "0.06910770426123966`", ",", 
     "0.06905345994868867`", ",", 
     RowBox[{"-", "0.0708900978359012`"}], ",", 
     RowBox[{"-", "0.10998189046835992`"}], ",", 
     RowBox[{"-", "0.109830163836919`"}], ",", 
     RowBox[{"-", "0.06466457078960247`"}], ",", 
     RowBox[{"-", "0.1104465337062361`"}], ",", 
     RowBox[{"-", "0.11044824849092215`"}], ",", 
     RowBox[{"-", "0.09367743892838107`"}], ",", 
     RowBox[{"-", "0.22639213448974044`"}], ",", 
     RowBox[{"-", "0.22640855424606432`"}], ",", "0.046639451500955616`", ",",
      "0.03209697435648148`", ",", "0.03205873155846868`", ",", 
     RowBox[{"-", "0.0002379672053748911`"}], ",", 
     RowBox[{"-", "0.0717298503780993`"}], ",", 
     RowBox[{"-", "0.07176116221455509`"}], ",", 
     RowBox[{"-", "0.007680607040300819`"}], ",", "0.006851428561433955`", 
     ",", "0.0068335875641597`", ",", "0.036135517854013456`", ",", 
     "0.06475749625913582`", ",", "0.06469741229988367`", ",", 
     RowBox[{"-", "0.06589683462372661`"}], ",", 
     RowBox[{"-", "0.12163681475826843`"}], ",", 
     RowBox[{"-", "0.12158936226193323`"}], ",", "0.11495458060225275`", ",", 
     "0.22230725274062055`", ",", "0.22233046564680858`", ",", 
     "0.04784872143966752`", ",", "0.07056621210138238`", ",", 
     "0.07058031114776779`", ",", "0.018721808342329796`", ",", 
     "0.06969162608230833`", ",", "0.06965782132935655`", ",", 
     "0.0026671866745420925`", ",", "0.024871088023485102`", ",", 
     "0.024900000497817223`", ",", 
     RowBox[{"-", "0.018661279442243814`"}], ",", 
     RowBox[{"-", "0.015243601865021807`"}], ",", 
     RowBox[{"-", "0.015125939950905526`"}], ",", "0.02771763545888858`", ",",
      "0.10927754144235732`", ",", 
     RowBox[{"-", "0.005086307830626111`"}], ",", "0.018777376123217827`", 
     ",", "0.008672078311916916`", ",", 
     RowBox[{"-", "0.04600279519578496`"}], ",", 
     RowBox[{"-", "0.0001369456994242159`"}], ",", "0.01770700141252591`", 
     ",", 
     RowBox[{"-", "0.00991375750193499`"}], ",", 
     RowBox[{"-", "0.15897123727880302`"}], ",", "0.02478489273473121`", ",", 
     "0.15897123727880302`", ",", "0.0028329590382586796`", ",", 
     RowBox[{"-", "0.051172745644858256`"}], ",", 
     RowBox[{"-", "0.00995161396495613`"}], ",", 
     RowBox[{"-", "0.10931349755882992`"}], ",", "0.014503749408164388`", ",",
      "0.024623693609847844`", ",", "0.009374716108556778`", ",", 
     "0.00745840572820463`", ",", 
     RowBox[{"-", "0.02676197495022989`"}], ",", "0.002702993540865768`", ",",
      "0.0010603239792985261`", ",", "0.009516701830414902`", ",", 
     RowBox[{"-", "0.0819399163973497`"}], ",", "0.035549993727269524`", ",", 
     RowBox[{"-", "0.04126993155537621`"}], ",", "0.00861563471094657`", ",", 
     "0.017693612274056678`", ",", "0.05115494429781615`", ",", 
     "0.04996495017786693`", ",", "0.04996492907083211`", ",", 
     "0.0032819460483853088`", ",", 
     RowBox[{"-", "0.006439941310715708`"}], ",", 
     RowBox[{"-", "0.006439949190551832`"}], ",", 
     RowBox[{"-", "0.017466799836503483`"}], ",", "0.005796080940418384`", 
     ",", "0.0057961060486234894`", ",", 
     RowBox[{"-", "0.03910795999395617`"}], ",", 
     RowBox[{"-", "0.06738525079968238`"}], ",", 
     RowBox[{"-", "0.06738519931365557`"}], ",", 
     RowBox[{"-", "0.020714541213647627`"}], ",", 
     RowBox[{"-", "0.06797135821550532`"}], ",", 
     RowBox[{"-", "0.06797134656655328`"}], ",", "0.0512188686972915`", ",", 
     "0.06853446455386067`", ",", "0.06853443562877082`", ",", 
     "0.09036907227296286`", ",", "0.08195768688272431`", ",", 
     "0.08195764458293742`", ",", 
     RowBox[{"-", "0.06631493155792606`"}], ",", 
     RowBox[{"-", "0.10569794847460007`"}], ",", 
     RowBox[{"-", "0.10569792629299354`"}], ",", 
     RowBox[{"-", "0.05397736276364398`"}], ",", 
     RowBox[{"-", "0.07557829768274404`"}], ",", 
     RowBox[{"-", "0.07557828113134785`"}], ",", 
     RowBox[{"-", "0.09127538540367397`"}], ",", 
     RowBox[{"-", "0.20885476617881718`"}], ",", 
     RowBox[{"-", "0.2088547225668041`"}], ",", "0.032265323636651744`", ",", 
     RowBox[{"-", "0.007185841996904391`"}], ",", 
     RowBox[{"-", "0.0071859259825299004`"}], ",", 
     RowBox[{"-", "0.0029085389235447567`"}], ",", 
     RowBox[{"-", "0.07274427135394321`"}], ",", 
     RowBox[{"-", "0.07274427404538517`"}], ",", "0.005343943037199386`", ",",
      "0.02861000979759755`", ",", "0.028610007309541538`", ",", 
     "0.021905094489495305`", ",", "0.029723502868095025`", ",", 
     "0.02972344164009704`", ",", 
     RowBox[{"-", "0.0670554608398714`"}], ",", 
     RowBox[{"-", "0.11325607409262868`"}], ",", 
     RowBox[{"-", "0.11325614260399937`"}], ",", "0.13719978404739736`", ",", 
     "0.2318973965714875`", ",", "0.23189737401118404`", ",", 
     "0.03776029634989493`", ",", "0.03971128130927977`", ",", 
     "0.03971128238335588`", ",", "0.004230366010692297`", ",", 
     "0.05629870973366363`", ",", "0.05629869796395934`", ",", 
     "0.0022797168625104114`", ",", "0.03867811791106904`", ",", 
     "0.03867814219548961`", ",", 
     RowBox[{"-", "0.01769631727702985`"}], ",", 
     RowBox[{"-", "0.014750800614620294`"}], ",", 
     RowBox[{"-", "0.01475083535718865`"}], ",", "0.0395414006342982`", ",", 
     "0.11088370743134712`", ",", 
     RowBox[{"-", "0.0007839951235376966`"}], ",", "0.020840815146141334`", 
     ",", "0.006929190498168397`", ",", 
     RowBox[{"-", "0.05516734042160626`"}], ",", 
     RowBox[{"-", "0.008426957837931737`"}], ",", "0.004016018265488166`", 
     ",", 
     RowBox[{"-", "0.013661714769537758`"}], ",", 
     RowBox[{"-", "0.14873058502705383`"}], ",", "0.029895102320399713`", ",",
      "0.14873058502705383`", ",", "0.007310781085641677`", ",", 
     RowBox[{"-", "0.04732203687237188`"}], ",", 
     RowBox[{"-", "0.016093794833402453`"}], ",", 
     RowBox[{"-", "0.1101067907512457`"}], ",", "0.02855196274899266`", ",", 
     "0.03529375943479488`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.809748075257698*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"83ecb88e-e40a-4202-a8a8-391db0575edf"],

Cell[BoxData["\<\"descriptor_pca_59-2d.csv\"\>"], "Output",
 CellChangeTimes->{3.809748075621249*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"b24dfb73-1a00-4667-93e1-708a5f208318"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Scan", " ", "over", " ", "the", " ", "number", " ", "of", " ", "PCA", " ",
     "variables", " ", "and", " ", "NN", " ", "layers", " ", "to", " ", 
    "include"}], "*)"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.804584928337494*^9, 3.804584947218421*^9}, {
   3.80458504988518*^9, 3.804585066087655*^9}, 3.804585096446577*^9, {
   3.8045946373730955`*^9, 3.8045946444959526`*^9}, 3.805183157625868*^9, {
   3.8057027377383423`*^9, 3.805702745771078*^9}, {3.807794929568647*^9, 
   3.8077949532285423`*^9}, {3.8077949975712976`*^9, 3.8077950005079927`*^9}, 
   3.80794730262958*^9},ExpressionUUID->"56f838f2-39c9-4c79-8475-\
a3c9fa2813ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"rescaleEnergies", " ", "=", " ", 
     RowBox[{"Flatten", "[", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{"auHamaker", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"numProteins", "*", "4"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", " ", 
         RowBox[{"tiO2Hamaker", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"numProteins", "*", "4"}]}], "}"}]}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"bindingNPDescriptors", "=", " ", 
    RowBox[{"rawData", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;"}], ",", 
       RowBox[{
        RowBox[{"-", "3"}], ";;"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Dimensions", "[", "bindingNPDescriptors", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"pcaVarScan", " ", "=", " ", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"repeatedComponents", " ", "=", " ", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"principleComponentSets", "[", 
             RowBox[{"[", 
              RowBox[{";;", ",", " ", 
               RowBox[{"1", ";;", "PCAMax"}]}], "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "8"}], "}"}]}], "]"}], ",", "1"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"proteinPCAWithEnergy", "=", 
        RowBox[{"Table", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Join", "[", " ", 
           RowBox[{
            RowBox[{"repeatedComponents", "[", 
             RowBox[{"[", "i", "]"}], "]"}], " ", ",", "  ", 
            RowBox[{"bindingNPDescriptors", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], " ", "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", " ", 
            RowBox[{"Length", "[", "bindingNPDescriptors", "]"}]}], "}"}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"proteinPCAWithEnergy", "[", 
         RowBox[{"[", 
          RowBox[{";;", ",", 
           RowBox[{"-", "2"}]}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"Log", "[", 
          RowBox[{"proteinPCAWithEnergy", "[", 
           RowBox[{"[", 
            RowBox[{";;", ",", 
             RowBox[{"-", "2"}]}], "]"}], "]"}], "]"}], "//", "N"}]}], ";", 
       " ", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "replaces", " ", "the", " ", "radius", " ", "by", " ", "log", " ", 
          RowBox[{"radius", ".", " ", "note"}], " ", "that", " ", 
          "consequently", " ", 
          RowBox[{"R", "^", "n"}]}], " ", "\[Rule]", " ", 
         RowBox[{
          RowBox[{"Log", "[", " ", 
           RowBox[{"R", "^", "n"}], "]"}], " ", "\[Rule]", " ", 
          RowBox[{"n", " ", 
           RowBox[{"Log", "[", "R", "]"}], " ", "and", " ", "so", " ", 
           RowBox[{
            RowBox[{"radius", "/", "SA"}], "/", "volume"}], " ", "are", " ", 
           "all", " ", "encoded", " ", "here"}]}]}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"PCAEnergyRules", "=", 
        RowBox[{
         RowBox[{"Thread", "[", 
          RowBox[{"f", "[", "proteinPCAWithEnergy", "  ", "]"}], " ", "]"}], 
         " ", "/.", " ", 
         RowBox[{
          RowBox[{"f", "[", "x_", "]"}], " ", "\[RuleDelayed]", " ", 
          RowBox[{
           RowBox[{"x", "[", 
            RowBox[{"[", 
             RowBox[{";;", 
              RowBox[{"-", "2"}]}], "]"}], "]"}], " ", "\[Rule]", " ", 
           RowBox[{"x", "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}]}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"BindingEnergyPredictorPCANN", " ", "=", " ", 
        RowBox[{"Predict", "[", 
         RowBox[{"PCAEnergyRules", ",", 
          RowBox[{"Method", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<NeuralNetwork\>\"", ",", 
             RowBox[{"\"\<NetworkDepth\>\"", "\[Rule]", "networkDepth"}]}], 
            "}"}]}], ",", 
          RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"targetEnergies", "=", 
        RowBox[{"rawData", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"2", ";;"}], ",", 
           RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"predictedEnergiesPCANN", "=", " ", 
        RowBox[{"BindingEnergyPredictorPCANN", "[", "    ", 
         RowBox[{"proteinPCAWithEnergy", " ", "[", 
          RowBox[{"[", 
           RowBox[{";;", " ", ",", 
            RowBox[{";;", 
             RowBox[{"-", "2"}]}]}], "]"}], "]"}], "     ", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"estRSq", "=", 
        RowBox[{"1", "-", " ", 
         RowBox[{
          RowBox[{"Total", "[", "    ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"predictedEnergiesPCANN", " ", "-", "targetEnergies"}], 
             ")"}], "^", "2"}], "]"}], "/", 
          RowBox[{"Total", "[", "  ", 
           RowBox[{
            RowBox[{"(", "  ", 
             RowBox[{"targetEnergies", " ", "-", " ", 
              RowBox[{"Mean", "[", "targetEnergies", "]"}]}], "  ", ")"}], 
            "^", "2"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"estRSqAdjust", " ", "=", " ", 
        RowBox[{"1", "-", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Total", "[", "    ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"predictedEnergiesPCANN", " ", "-", "targetEnergies"}], 
              ")"}], "^", "2"}], "]"}], "/", 
           RowBox[{"Total", "[", "  ", 
            RowBox[{
             RowBox[{"(", "  ", 
              RowBox[{"targetEnergies", " ", "-", " ", 
               RowBox[{"Mean", "[", "targetEnergies", "]"}]}], "  ", ")"}], 
             "^", "2"}], "]"}]}], " ", "*", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"numProteins", "*", "8"}], " ", "-", " ", "1"}], ")"}], 
           "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"numProteins", "*", "8"}], " ", "-", " ", "1", " ", "-", 
             " ", "PCAMax"}], ")"}]}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"{", 
         RowBox[{
         "PCAMax", ",", "networkDepth", ",", "estRSq", ",", "estRSqAdjust"}], 
         " ", "}"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"PCAMax", ",", "networkDepth", ",", "estRSq", ",", 
         RowBox[{"ListPlot", "[", " ", 
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"targetEnergies", "*", "rescaleEnergies"}], ",", 
              RowBox[{"predictedEnergiesPCANN", "*", "rescaleEnergies"}]}], 
             "}"}], "]"}], ",", 
           RowBox[{"Frame", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"True", ",", "False"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<\!\(\*SubscriptBox[\(E\), \(ads\)]\)\>\"", ",", 
              "\"\< \!\(\*SubscriptBox[\(E\), \(ads\)]\) (predicted)\>\""}], 
             "}"}]}], ",", " ", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"\"\<ANN layers: \>\"", "<>", 
             RowBox[{"ToString", "[", "networkDepth", "]"}], "<>", 
             "\"\< PCA vars 1 -\>\"", "<>", 
             RowBox[{"ToString", "[", "PCAMax", "]"}]}]}], " ", ",", " ", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "350"}], ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "350"}], ",", "0"}], "}"}]}], "}"}]}]}], "]"}]}],
         " ", "}"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"PCAMax", ",", "1", ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"networkDepth", ",", "1", ",", "6"}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.804584928337494*^9, 3.804584947218421*^9}, {
   3.80458504988518*^9, 3.804585066087655*^9}, 3.804585096446577*^9, {
   3.8045946373730955`*^9, 3.8045946444959526`*^9}, 3.805183157625868*^9, {
   3.8057027377383423`*^9, 3.805702745771078*^9}, {3.807794929568647*^9, 
   3.8077949532285423`*^9}, 3.8077949975712976`*^9, {3.8079473061593184`*^9, 
   3.807947307077737*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"86763866-1c74-49e0-86ec-ef492dbb4215"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.326469350292537`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.149064046324306`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.2256876851982477`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.373856981487562`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.7573567288112952`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.9555440876736012`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.1492796721908647`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.2021013593192458`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.9680176586238904`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.946087580937209`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.541556933865403`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.3894430010754864`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.0640299998793146`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.15668959272026`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.3788359385414743`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.2639078704738314`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.814221232047535`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.885479715221432`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.322667853544591`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.1729315829242166`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.1048395446750088`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.660280407539144`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.9480229493583494`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.6108665485060056`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.280579857005902`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.7704540681988712`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.4505125964286294`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.9258480579855617`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.524949497345547`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.7340162389758447`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.781842790278421`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.7634724030768383`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.9805869302767483`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.0900891975659293`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.9033378208860272`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.1913375931097825`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.767035725219727`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.1854593041394104`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.189142117256492`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.6006949797255556`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.3241736834096076`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.8443055980381835`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.8912756801416706`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.3454925702912357`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.1771036904884276`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.6839668370549503`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.093574484843516`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.3658444415868374`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.30413350906229`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.1774433212384423`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.285132624175161`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.1815620553629445`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.2746710762594033`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.1115059602606747`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.7886601610330888`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.0466615257484952`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.9139589467304607`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "2.6235617865259395`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "5", ",", 
     RowBox[{"-", "1.846313272238806`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.434478054618857`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.4648958353707653`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.069331154893534`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.4972092249656637`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.781964757382926`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.269466511135165`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.4352519764305685`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.5285461133840186`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.273624233561373`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.8081821610694333`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.747995148726652`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.1611530901898215`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.199949270540333`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.7902686081192933`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.0699541104387413`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.80130141525066`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.523297317775189`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.273198516707776`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.6810611473791375`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.6401872356800253`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.8038588500295956`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.9220991994677634`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.246348327862958`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.852304512979847`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.678875983880322`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.165398781133524`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.730671244941446`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "1.9753887101497345`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.17220565642492`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.306435752602815`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.624489521113623`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.1786172622488342`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.9739974411932923`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.780124495947955`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.757314862094801`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.4082673996012387`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.735815338385749`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.288768471273212`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.4256362122058936`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.4700771664857077`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.8458631630740583`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.6964798041401727`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.4097921826138475`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.363480310047582`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.942539460985966`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "1.8348597920688643`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.653769904931855`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.6858987971555437`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.7074864766524493`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "4.0409861296474086`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.1577727048318107`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.753081229975076`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.9904159038867477`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.739411173437461`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.174828481851907`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.643278585190466`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "4.456279653741267`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "3.262772304628116`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "50", ",", 
     RowBox[{"-", "2.5109357192409476`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.4565529297476747`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.509934467858788`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.1605888820500527`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.46785008355726`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.8874403679155103`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.2732135829550124`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.520279859599943`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.586328195605694`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.327160275268008`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.6835333866290907`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.7791701384510574`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.236988921501675`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.2390861317420625`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.8671045228011374`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.2136542370473764`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.815489919375255`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.6504938804901603`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.2987538947032866`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.6829933308169744`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.6720561661262874`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.7491024769764967`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.855308136730667`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.3594362232756527`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.9277226661916935`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.709713025513575`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.2166786949725124`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.722152833698788`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.0131599376264857`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.185391254252251`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.356259062324824`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.7155400065669473`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.082516994091551`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.945753880415252`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.7507233699120897`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.803027891215064`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.404735977230144`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.7519792104931327`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.3848314213029607`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.479864682599629`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.5365501539847872`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.85178634144325`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.697600909939742`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.420200839831268`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.462347218944991`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.986252610514135`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "1.8950443463147757`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.69770557881176`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.7030520379939653`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.7294918467340534`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "4.036813052438891`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.209726352227248`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.8221759428611772`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.011362880157096`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.7713482314534024`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.1919461593554237`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.6715654720066184`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "4.318758428033179`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "3.301390829217894`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "100", ",", 
     RowBox[{"-", "2.591682722672434`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.4973717645403988`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.544200737734242`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.1989999901509663`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.4824047830791938`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.974241031379715`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.1820708952868766`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.573546270829839`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.658610141813601`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.3293621335725954`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.627146439456394`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.7549373955187453`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.2250624158237073`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.2381502044229378`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.863516272892588`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.3157393773662824`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.8252364815422863`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.6805822901333904`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.3080582130606784`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.695578843665178`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.737632397716744`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.7182683359530375`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.8164885933623895`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.4025682895238605`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.958119834719342`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.7024278908543953`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.2331523039317482`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.7357170797087846`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.0124220646654263`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.1203808968141704`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.3737334343760965`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.795636943253891`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.2101803288717212`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.950197320535693`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.663864916202063`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.8047962852219133`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.401298724106231`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.7889058805528606`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.452443432907064`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.508708820808484`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.580553238258253`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.856474115282801`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.626646345751855`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.449383637758643`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.5080363648520447`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.971189932511924`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "1.916321435839302`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.714259705702549`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.709697050658297`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.7205621675864418`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.9923977944268065`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.2335413657336023`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.813942007779627`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.0514135943576965`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.7608620706636264`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.2276095507328586`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.6878525222335004`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "4.1380548574532705`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "3.3241077961483065`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "200", ",", 
     RowBox[{"-", "2.619205957028527`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.0617495125649359`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.843904164266386`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "0.48783133282393254`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "0.8200751257975059`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.306017406238052`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.6867485320537914`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.75530593508957`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.8424869028713913`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.3998935329455278`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "0.6685967058745769`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.930420293298644`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.8934600123190675`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.5411808264715219`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.4249411448299518`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.3037787661901432`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "0.9200999178918784`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.543758257963092`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.1292019965777838`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.602267783018035`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.1516118433985585`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.831127223144348`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.5150160176364371`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.5443463800346782`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "2.2439049334958403`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.7291155080646587`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.2888892862291406`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.701786937116347`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.4582893658871239`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.9240505651557291`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.2949453146233938`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.452082574217822`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "2.0277404984492904`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.5913808238504437`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.650537371161189`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.2925435717203901`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "0.5816901316977806`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.1409551391080244`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "2.0014263713509326`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.2469034206779133`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "0.6377205409905283`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.1911764743422093`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "0.8593984988059851`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "0.8967016011938442`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.733976815994047`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.6818596982455303`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.2211347274050246`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "0.7522319959567022`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.2865664548721572`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.8299567168831052`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.6542883220142646`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.2177377930408098`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.4118205473153038`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.8824981005730477`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "0.9535947635417147`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "2.012262315221114`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.8383060838072642`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.536805537084552`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.5964012768069344`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "5", ",", 
     RowBox[{"-", "1.8100517264073053`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.304245851431593`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.1626891748902994`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.0426924604687287`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.1077317153304014`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.613259001836464`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.173650745896161`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.1661277148813993`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.2659874142665286`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.9169094525764343`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.7228955699790829`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.7741431587296432`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.1691503513099413`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.560634835382048`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.436144007731041`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.5387762505249283`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.1658466088092159`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.6798693324170957`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.568301697489976`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.3877360141264714`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.9916709817590055`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "3.114429987868967`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.37704131673849`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.6867640887223556`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "3.2733648386925838`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.761936197260062`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.8667485844753542`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.8979337642157876`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.937261921489593`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.6168823494888613`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.0374515770058514`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.3739411032345816`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.9824046146929666`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.513299540798506`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.268105494976362`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.175054634094643`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.0128701193103373`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.488449453362758`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.878408679643283`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.874490976938501`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.1919709459186112`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.8932088070504725`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.683276549384816`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.3187466938802954`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.6224079218098204`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.344308473546769`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.755728283085556`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.2074982527095397`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.7734745159979786`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "3.0316044303058174`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.9978934440567908`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.957317162420805`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.0149769601533443`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "3.071216609886137`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "1.3140264854248112`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.952689176029899`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.574630988095177`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "3.0282195152942757`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.052872440673891`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "50", ",", 
     RowBox[{"-", "2.8677164551855467`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.339727337218227`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.1661442128588955`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.0772015129318868`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.1365945418896721`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.6364423764517784`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.177235930650831`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.125810067561138`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.295095284737405`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.9694279930005818`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.7620022450104076`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.8459768763928044`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.3110503514808807`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.6085759944569897`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.420434980453025`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.5258205928992714`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.188719338941301`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.7641983517976894`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.5994648681512227`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.5001603587002417`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.070954613752797`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.8799593071920673`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.2717636619424586`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.665478071547456`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "3.211672198850942`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.814063583936894`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.9113824523376886`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.918638329393169`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.9726148832794022`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.5839395681944706`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.098081263678752`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.49861134824271`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "3.006640828534197`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.5296524689701387`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.3339358439843125`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.2207232682793134`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.0343643294057048`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.525901725524116`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.95440885286236`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.91798835671506`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.2697372505915945`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.9673116239687343`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.7014678903682787`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.3596933372763467`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.666644507160387`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.3482123232837777`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.815887852043558`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.2383973907736912`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.7932977835365527`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "3.0885067501309114`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.0401040579417815`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.059140888078254`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.0793450244814395`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "3.077858418475638`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "1.3608718081963393`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.963215221854322`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.6158587261674198`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "3.0565671181188865`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.0903710124712043`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "100", ",", 
     RowBox[{"-", "2.85844938042841`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.3675884064015846`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.1894689410787334`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.0816353117345099`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.1503777452232276`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.6653432216355186`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.1792090429475053`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.183818400310427`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.360409687048968`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.9907976385225554`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.8539575168817375`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.873256267938004`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.34597155332498`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.6772607818904013`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.431963538523866`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.521293293515738`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.2023459834541594`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.7819712615875871`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.5770296996643312`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.5150595469067576`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.1457496061260297`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.9994340385742935`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.304008257535742`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.6638146270975036`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "3.0954929706672867`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.81203870876574`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.9382787710334402`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.9311712014167497`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.995968577831491`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.7440363372598227`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.1183514729034654`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.5005975989784637`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "3.069245888468567`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.4780402814126243`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.370571290191527`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.2026265938006944`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.0500562195050378`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.542890841782037`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.9929101067063706`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.9390361178869782`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.2785860696534423`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.8637353132729688`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.7774824384915584`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.368515122766172`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.7235728987357857`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.360237316973248`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.7888545558041782`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.2454386026690554`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.8229064258009817`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "3.076658731637496`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.0425445255649137`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.0834595120350223`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.0907303486090907`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "3.016415919516947`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "1.3753427076762832`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.96002115893819`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.6510665052994216`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "3.0865766007237596`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.110221254322642`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "200", ",", 
     RowBox[{"-", "2.956397958294089`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8097480852529235`*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"4f5eb2d1-3181-49c2-99b6-fcf2bdc5a014"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"472", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.8097480853293715`*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"754d18a5-5459-44a2-b5d4-e07d1fd94884"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "0.6403092298089`", ",", "0.6395439302978552`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097481339056845`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"032ea2be-6533-4067-9072-0687e8c20082"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "0.6565977737004371`", ",", "0.6558671306657573`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809748163897134*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"0c58243c-ec91-403e-90a1-966d8b68141c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "3", ",", "0.6581937100184343`", ",", "0.6574664625929415`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097481958528986`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"5cfa4030-fd74-427b-9fd3-083b874290e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "4", ",", "0.6534112129977361`", ",", "0.6526737900466674`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097482307013907`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"a0658a94-34fb-4020-a2bc-66bc24d93990"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "5", ",", "0.6481175420837904`", ",", "0.6473688560031174`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097482536890173`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"0d3efe86-a09f-45c3-af48-fc825e510f25"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "6", ",", "0.6457387408491473`", ",", "0.6449849934892518`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097482913017235`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"dae92b97-9255-4ccd-ad89-f0d3532ad1e3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "1", ",", "0.6919070665305316`", ",", "0.6905932373899367`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097483201110916`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"da82ebd9-662a-48e8-a0da-405380684762"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "2", ",", "0.7133420896767138`", ",", "0.7121196678842903`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097483518258696`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"ced5428a-6a10-4219-9566-e87469e094c4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "3", ",", "0.7431977711614035`", ",", "0.7421026657079339`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809748390060462*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"86fd0064-f196-4f1b-96ba-39f7dcc14ca8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "4", ",", "0.7696008423267332`", ",", "0.7686183299272735`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097484253176036`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"8be5755e-674d-4d03-ab7f-a75d8a063018"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "5", ",", "0.7354570562104323`", ",", "0.7343289413115429`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097484595043473`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"3aca4e12-37f6-4dff-9295-767fcb435552"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "6", ",", "0.7721237483884196`", ",", "0.7711519946502039`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097484950693254`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"3a2f1513-b9c0-42ad-9d72-7e4f41a3e86a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3", ",", "1", ",", "0.7084121899192959`", ",", "0.7065430372905734`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.80974852288873*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"3691316b-3364-46b4-aea7-e1eda8465420"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3", ",", "2", ",", "0.8123814156534783`", ",", "0.8111787324204878`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097485549499116`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"52710a37-150f-4a65-b2c1-734239f344cb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3", ",", "3", ",", "0.8521741294998301`", ",", "0.8512265277658546`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097485919122705`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"07c65707-5635-41e8-b391-2ea1b55b6ea3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3", ",", "4", ",", "0.9091330247014875`", ",", "0.9085505440905995`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.80974863534622*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"3ae1e1e1-67d3-4419-bee5-d64eed3b9fed"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3", ",", "5", ",", "0.8926376484200043`", ",", "0.8919494282175684`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809748682142575*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"9aaffe3e-e54c-4f70-a06f-b95e9466bf0c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3", ",", "6", ",", "0.8569973417932741`", ",", "0.8560806580868208`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809748722557049*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"ce4a7bc8-17d7-45b5-8cc9-0743a9a53dc4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "1", ",", "0.7238481322588395`", ",", "0.7214828057685512`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809748763070969*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"88b5cc8d-31ea-43f8-96a7-4a4d9061d8ce"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "2", ",", "0.8758784657628598`", ",", "0.8748153262833125`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809748799141432*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"c411caa0-59a1-4736-9433-cbca50f8e75d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "3", ",", "0.8977145135034594`", ",", "0.8968384065527396`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097488395287943`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"d460b92f-ab71-406c-ba25-1dce08290d43"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "4", ",", "0.9564264350834554`", ",", "0.9560532139706799`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097488868363914`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"fea3b115-074a-4a37-8175-b40aaea751fe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "5", ",", "0.9267270748524689`", ",", "0.9260994694978861`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809748937309149*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"ce35c671-049a-49fe-b1a0-8985bfd6bdda"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "6", ",", "0.9142814574585204`", ",", "0.9135472515266876`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809748989526677*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"8391edcb-d326-4def-86c2-7975524e0e57"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5", ",", "1", ",", "0.7485642223248876`", ",", "0.7458664135515494`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097490270518284`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"bb0583cd-7a6f-45f5-b193-fa25e2e8e9af"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5", ",", "2", ",", "0.8508231471340705`", ",", "0.8492225371247795`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809749069174116*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"f80116f3-7484-4313-a393-9116dee79161"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5", ",", "3", ",", "0.9219909464240725`", ",", "0.9211539394114553`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.80974910253661*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"8d8b947d-3f18-48a4-b7fa-41d5bf4dd889"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5", ",", "4", ",", "0.9334843654461809`", ",", "0.9327706783801527`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097491372149873`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"ec0f9b80-ee6a-4271-9824-b7d6089ced94"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5", ",", "5", ",", "0.940834097518711`", ",", "0.9401992702388688`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097491755476456`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"aa9b9460-1037-40d2-8e13-e0e44a160617"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5", ",", "6", ",", "0.9175420004880886`", ",", "0.9166572580040553`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097492134810867`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"8f2f9b31-3409-45c5-8958-6d640ac42f23"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6", ",", "1", ",", "0.8052951854535555`", ",", "0.8027828652658594`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097492456939807`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"ea4c487e-c547-4d41-bb3e-79a316d81ed0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6", ",", "2", ",", "0.8598850733542011`", ",", "0.8580771388168359`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809749275912286*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"5c32e5da-81ae-457d-b848-ee7cce192723"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6", ",", "3", ",", "0.9421450121752208`", ",", "0.9413984962032882`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809749317616065*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"85de8d30-a7d0-4d56-8a34-0c7de3f2fbad"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6", ",", "4", ",", "0.9235455708432486`", ",", "0.9225590620799358`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097493669311476`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"d6def51f-e39f-4236-8df1-a80ab15c9060"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6", ",", "5", ",", "0.9382224868143223`", ",", "0.9374253576119265`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809749421806281*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"8dc25c9c-b34d-47d1-aa5e-94bd2ecc9ec2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "6", ",", "6", ",", "0.9291054430029922`", ",", "0.9281906745256115`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809749487337954*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"41c6a09d-a9a9-4dd5-85b4-72a3a693b3b7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "7", ",", "1", ",", "0.8388356252070239`", ",", "0.8364042661045437`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809749527144825*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"186612aa-23d1-438e-a34d-8a042ff824f6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "7", ",", "2", ",", "0.9424314606917682`", ",", "0.9415629697970319`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097495611501207`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"0dc64aa6-d667-46c9-8dfa-b1123ff6330b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "7", ",", "3", ",", "0.9328518300003154`", ",", "0.9318388188149753`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097495971770973`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"3bfd3e34-ef32-437c-a17d-1e4d60a3a27e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "7", ",", "4", ",", "0.9364121279097545`", ",", "0.9354528281152896`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809749634824972*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"f0526cb0-4bf9-4d60-a602-d995d87affd5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "7", ",", "5", ",", "0.9350040277440093`", ",", "0.9340234850591128`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809749672091549*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"45d41984-e4aa-44e7-ba9e-b4c1252950d2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "7", ",", "6", ",", "0.9385291238678025`", ",", "0.9376017615123599`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097497120653543`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"d85d2bb7-6e6b-4a85-8299-2e9f0e18a474"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "8", ",", "1", ",", "0.8123593645883707`", ",", "0.8091171937821222`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809749741977764*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"e81b1171-1be9-4bb2-8cb0-4184d4f6a934"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "8", ",", "2", ",", "0.9002568151784128`", ",", "0.8985333908186446`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.80974977471622*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"47bfb5bb-c830-4cc4-b794-2306e3af3f81"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "8", ",", "3", ",", "0.9320350403133753`", ",", "0.9308606997572348`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809749809465073*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"357be996-5785-4d76-b24a-b35844d5f3c0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "8", ",", "4", ",", "0.9121549291883003`", ",", "0.9106370877919858`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097498467803874`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"a547f6a6-0741-4969-bf8f-3e4b77867a1f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "8", ",", "5", ",", "0.9534749226057275`", ",", "0.9526710335794766`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809749884779647*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"be256ec0-4765-4880-8601-8dd4afe96155"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "8", ",", "6", ",", "0.9415525071665831`", ",", "0.9405426152817724`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097499264577436`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"ffa5179b-a23f-4c57-a509-48d883af107b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "9", ",", "1", ",", "0.8561222338837666`", ",", "0.8533194202581257`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097499663254366`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"1ffd9207-0d57-4b8f-ba64-eeca58b5193a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "9", ",", "2", ",", "0.9513006563856048`", ",", "0.9503519678736361`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750012875492*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"2429eb20-d55f-4a8e-a9ce-b80d8bf74e1f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "9", ",", "3", ",", "0.9522264572625471`", ",", "0.9512958038325967`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750074426795*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"03e94afe-daa3-4d49-bb65-fd9c4b35ea64"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "9", ",", "4", ",", "0.9484464032993258`", ",", "0.9474421124545076`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750113721777*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"8b261a71-50cd-4fdb-a3cd-667212c66db5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "9", ",", "5", ",", "0.9668728559079804`", ",", "0.9662275219321619`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750161737113*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"450e02d1-2aa0-4ece-9bfa-a3135068c0c3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "9", ",", "6", ",", "0.9503338658841473`", ",", "0.9493663437909813`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097502154664793`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"d374e705-6e25-45b8-bd19-e64ec04ce590"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10", ",", "1", ",", "0.8450495335260632`", ",", "0.8416883520407283`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750246575468*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"13148da1-3740-4de4-90a7-a6b278289922"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10", ",", "2", ",", "0.9336536787092252`", ",", "0.9322144960348049`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097502816052055`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"e0cf6d8a-5559-454d-b2bd-101de68d8d3a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10", ",", "3", ",", "0.9478027802278418`", ",", "0.946670519495257`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097503301694965`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"1502457f-e5cb-43c9-a3fa-8ecec8f715e6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10", ",", "4", ",", "0.9452169748749134`", ",", "0.9440286229199224`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097503822660756`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"813e0003-480f-45eb-88b0-c1824b9ff6ad"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10", ",", "5", ",", "0.9500537384728138`", ",", "0.9489703054678856`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097504203470616`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"6c74531c-d795-4792-8eaf-a63cdff0b2fd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10", ",", "6", ",", "0.9574054085126542`", ",", "0.9564814477428636`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750463945999*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"49704739-e56f-43d1-b028-63b6164954fb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "11", ",", "1", ",", "0.8648625531778105`", ",", "0.8616310055364104`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750499418683*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"e34e154b-b570-49b9-8d7c-72f54e97fd58"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "11", ",", "2", ",", "0.9621985256297492`", ",", "0.961294577329591`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750535113296*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"c7523834-3826-4065-a14c-a324927b94c6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "11", ",", "3", ",", "0.9548432165196685`", ",", "0.9537633803929649`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097505770731096`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"66e50b8f-20d0-4b45-a6fc-72cd88ade3cc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "11", ",", "4", ",", "0.9518966461999228`", ",", "0.9507463486090513`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097506104451504`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"bfd3fce3-e584-4d14-85e0-7352d569a61b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "11", ",", "5", ",", "0.9592537248637591`", ",", "0.958279357414849`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097506437436266`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"ff4d11bb-e02a-4561-ba41-2c2a81fa1e2e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "11", ",", "6", ",", "0.9578203437282151`", ",", "0.9568116997738898`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750680633396*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"4fba3838-83e4-4ed6-92a1-dc310fcf22ec"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "12", ",", "1", ",", "0.8690411829610929`", ",", "0.8656174230385071`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750715331876*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"ed4247c7-2b5b-48fe-8b4b-e6da19ecd108"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "12", ",", "2", ",", "0.92106480298091`", ",", "0.9190011376993651`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750747628972*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"1fe78090-99f8-44bb-a59f-9d5c936c7830"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "12", ",", "3", ",", "0.9348292212442989`", ",", "0.9331254100349996`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750779299822*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"724ad1f8-4cec-4303-a927-d7e77e514c33"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "12", ",", "4", ",", "0.9525287370671338`", ",", "0.951287658297647`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097508126277823`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"706e0591-24ec-465a-9b96-39eb0bb8bdea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "12", ",", "5", ",", "0.9555738359818146`", ",", "0.9544123676414697`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097508458553867`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"6416dd86-0fe1-414d-8b6a-788be7174118"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "12", ",", "6", ",", "0.9498702491069828`", ",", "0.9485596673842897`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097508815662117`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"b674edc9-921f-4e88-8add-71a8c72eab69"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "13", ",", "1", ",", "0.8862459284362998`", ",", "0.8830171010775049`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750915434847*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"841dd508-2306-4571-a6ed-0b0bb061ce3d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "13", ",", "2", ",", "0.9601356829794756`", ",", "0.9590041630640459`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809750943729163*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"20c356cf-0443-4680-8208-f748020f50f6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "13", ",", "3", ",", "0.9677053704353017`", ",", "0.9667887106441639`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097509850383472`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"f7b253ce-7644-420a-9d27-f54d83d848b0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "13", ",", "4", ",", "0.9662282929853704`", ",", "0.9652697074150861`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809751033792178*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"daae1518-e889-466a-983f-fe66cb058fb2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "13", ",", "5", ",", "0.9525576557317469`", ",", "0.9512110389730409`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809751097599616*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"17cc60d0-f9c3-4985-acfe-de1e3cfa9ce0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "13", ",", "6", ",", "0.947234100623487`", ",", "0.9457363785887826`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097511543122253`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"666efec1-83fb-42ab-8bca-2842c00a9eca"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "14", ",", "1", ",", "0.8244087492611347`", ",", "0.8190295862188062`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809751183034487*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"f99989ed-9a52-46c5-b5c0-2e39d225dfd3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "14", ",", "2", ",", "0.9545815858880866`", ",", "0.9531902121516166`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809751215725503*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"61adff48-d54f-47e4-87d2-b46f4b4a500f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "14", ",", "3", ",", "0.9402593269503905`", ",", "0.9384291969226125`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097512562688875`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"98ab76ee-9ec5-4d50-8188-2d3e972aceba"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "14", ",", "4", ",", "0.9572201545080603`", ",", "0.9559096121953969`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809751303289976*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"9e461a10-f7a0-4c62-980c-2761466cb08c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "14", ",", "5", ",", "0.9369484677508325`", ",", "0.9350169109642059`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809751339205922*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"020626f9-7f43-480f-95b0-8a8d12d86e7a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "14", ",", "6", ",", "0.9508072313916506`", ",", "0.9493002319156836`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097513760678263`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"97537188-2fe4-43a5-a90a-6f232fb5e1c0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "15", ",", "1", ",", "0.899506368144467`", ",", "0.8962006565702719`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097514079105787`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"3cdb9852-d961-4fa1-af37-846e0ef19023"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "15", ",", "2", ",", "0.9452374566510664`", ",", "0.9434360571987989`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097514378233595`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"0bd4bac8-96a0-4180-8caa-23de4807d8a9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "15", ",", "3", ",", "0.9310855441674367`", ",", "0.9288186212782077`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.80975147243206*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"f9e7ff77-f871-436b-be87-3944127d9087"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "15", ",", "4", ",", "0.9561998739117458`", ",", "0.9547590802904217`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097515083097186`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"5bbfaa82-dd02-4a97-9aba-f7f788e65da6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "15", ",", "5", ",", "0.9673290067424358`", ",", "0.9662543030168581`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097515505874977`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"e8ae779f-9f7e-4ccf-8358-a44027f5d86e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "15", ",", "6", ",", "0.9552856018961551`", ",", "0.953814733537476`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097515878047132`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"cc0081dc-c00d-4a79-b56f-d97edf514f13"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "16", ",", "1", ",", "0.8610044597943005`", ",", "0.8561167045343199`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809751616348959*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"39a0efc8-3864-446b-a49e-b43c15647e83"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "16", ",", "2", ",", "0.9350360514264757`", ",", "0.932751604883231`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809751647173958*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"70357f64-59b4-4eec-8bcb-9286b2e8545c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "16", ",", "3", ",", "0.9428269058622111`", ",", "0.9408164234309921`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097516787063727`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"9805572e-5bb7-4109-bbd5-99a8955feb56"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "16", ",", "4", ",", "0.9573032471065274`", ",", "0.9558018228289547`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097517111415334`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"7a77a894-9574-44ab-8f14-bd3d2f7a5545"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "16", ",", "5", ",", "0.9449031732131647`", ",", "0.9429657023811001`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809751746685937*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"e4aea358-f85e-4f24-aa82-7040c1e6b65c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "16", ",", "6", ",", "0.9500296884243152`", ",", "0.9482724906546207`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809751786929281*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"3360cfa1-7649-47ea-aec7-fb258e523854"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "17", ",", "1", ",", "0.8652435667041007`", ",", "0.8601976209639459`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097518199832664`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"1493d286-c44d-4202-9d46-e493a7383f9f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "17", ",", "2", ",", "0.9239877545977335`", ",", "0.9211414810914813`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809751855185874*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"c97fe13e-cef5-42c6-a258-b51cfa25d1c8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "17", ",", "3", ",", "0.9491254414407375`", ",", "0.947220446957241`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809751890499696*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"e1a4d5c4-4e6d-4899-98bd-22cb34813670"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "17", ",", "4", ",", "0.9292434487086891`", ",", "0.926593974321129`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097519162535725`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"3cf92f18-6c5b-4ddd-9dfb-d9cc65956359"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "17", ",", "5", ",", "0.9283901457135768`", ",", "0.9257087194517504`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.80975195195413*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"b56417b1-7974-4a62-a72a-73978e5ef29a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "17", ",", "6", ",", "0.9447825226592863`", ",", "0.9427149078689953`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097519902615194`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"5c25d3b6-a68b-4755-a6cc-eb0559cbbd67"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "18", ",", "1", ",", "0.9027098451418023`", ",", "0.8988440111739269`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097520293133683`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"1de45725-2635-4f74-ac28-b2c49ab22238"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "18", ",", "2", ",", "0.9396688386790936`", ",", "0.9372715739908456`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809752059567527*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"613a7bac-369e-403e-b34b-6b0fe19aac87"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "18", ",", "3", ",", "0.9554976216250846`", ",", "0.9537293151995913`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097520957627316`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"0e1cc401-9a12-4ce4-903b-ae13674ac3ea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "18", ",", "4", ",", "0.9535498796985498`", ",", "0.9517041795541213`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809752119541416*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"ff9b3955-7592-4e88-8bbb-45b0a878cc42"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "18", ",", "5", ",", "0.9454252646989418`", ",", "0.943256732170423`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809752154369317*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"f8d28d6b-e5c5-4896-8dd2-3a07b9e4e694"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "18", ",", "6", ",", "0.9500747537763581`", ",", "0.9480909691582001`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809752195207201*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"2adfb314-3984-48e1-9f9f-48edc721dfdf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "19", ",", "1", ",", "0.884561486758107`", ",", "0.8797089828828947`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809752230177762*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"d8ca3dd9-197a-4348-b8d8-cb3a9102172d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "19", ",", "2", ",", "0.9228260491201051`", ",", "0.9195820113618794`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097522604218073`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"f7939c38-2bb9-4af8-8e2b-428cfe5201c0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "19", ",", "3", ",", "0.951470495289386`", ",", "0.9494305382329664`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097522995108995`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"1c34511c-f9b0-4d74-8386-ff789330f65a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "19", ",", "4", ",", "0.9555609398789197`", ",", "0.9536929262897592`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097523378987026`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"74e59342-cd00-4298-9c96-8840116f6309"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "19", ",", "5", ",", "0.9541378043775877`", ",", "0.9522099687208934`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097523712291093`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"16e4fb36-4bec-4411-85c8-049c4ea83364"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "19", ",", "6", ",", "0.9473959197925519`", ",", "0.9451846863325042`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097524112974405`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"9e7a2112-05e9-46f5-bdfd-2f6ee3719eb6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "20", ",", "1", ",", "0.8926833686165292`", ",", "0.8879243162270183`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097524381164193`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"7f60fd2f-0c90-4b51-a117-efcebc0800ce"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "20", ",", "2", ",", "0.9608586075379647`", ",", "0.9591228473400918`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809752474707642*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"8f23e978-ad32-4afc-a66d-591079cc886c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "20", ",", "3", ",", "0.9468767740537738`", ",", "0.9445209768942959`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097525140987277`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"71888764-d4eb-4322-843e-5bff628c2035"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "20", ",", "4", ",", "0.9461910372948156`", ",", "0.943804830522967`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809752559064106*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"4381ed52-c29e-44c5-addf-b67acd717f3c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "20", ",", "5", ",", "0.9445287244585885`", ",", "0.9420688009312531`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.809752616734984*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"cbd2f012-7f52-41db-aa70-a5860d52d5fe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "20", ",", "6", ",", "0.9435409574593739`", ",", "0.9410372305174393`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8097526559311223`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"e7f8ddd1-ec60-4bd8-bd82-77e0ba8c53b8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "0.6403092298089`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k4VX8XxYsGJUWozJmHe3FnYxOKjElFlHCvO3FNSTQoFEoalVJUhkop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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 1 PCA vars 1 -1\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "0.6565977737004371`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3dcjY8XToVQEiGk3W3XnWkh2mUVhZa6t+5q3JJSIVEqkpGQFhpfkpKi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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 2 PCA vars 1 -1\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "0.6581937100184343`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k41F8bxkVJi8reJvs6hhmzWCu7KEQqkW2G2WxDpURUilJaUMpWWULR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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 3 PCA vars 1 -1\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "0.6534112129977361`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3k4lG8btVQoEllSsmUfy+zWXxtll1ISss1gZiwzyJKkRUWLFkulQqFQ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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 4 PCA vars 1 -1\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "0.6481175420837904`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3kgVH8XhwtJRWWtZMm+m32sRVFEKiokhBmzWWaIpKRFobSjRciahBZE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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 5 PCA vars 1 -1\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6", ",", "0.6457387408491473`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8lf8bxjOShmSlIbI3Z5vfkk0oKkTkHMeZxjFD0VAoadIQyk4JEZpc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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 6 PCA vars 1 -1\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1", ",", "0.6919070665305316`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3cg1e8Xx0WkITslZc9r3Mk1KqtIRjQIibuHcTW0NcgoyooGGqikSUhR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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 1 PCA vars 1 -2\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "0.7133420896767138`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3cgle8bxgsJRZFKUvZeZzlmGVkZoYGscBxnODiaKBqKShoUysqqFKVE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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 2 PCA vars 1 -2\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "0.7431977711614035`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c8le8bLhr6okKpJHvPM+0ie4uWkDjnOM4wDkWoNCSVtCipKCspEUpU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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 3 PCA vars 1 -2\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "0.7696008423267332`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c4le8bL7sikUjD3vNsI5UiqwilROScwxnOwaFSGmahoSFSohK+EkoU
KvSJhkRFRKFEWdGW0fq9v7/e63qv53qe+7nvz3o0WWGeQWIzZszonDljxv+/
FgE5GnU/A5FvE5f99hgLZ5vqhhL82Ej9c+2KeyQL7lvtG9fMDYTTLqeRvitM
jLUm1isGBqFnx+2cxDoWAreGh7cVbYON9Yrrtp4shJyts1K9wMT90JPndJhs
rP6qulLcnw01tSfnzBewUbxU43t3Bxun42MkB3RY0CjZu/PtHSZOt/8ebi1i
QT1pSYXTISZqP5RwDa8zUc73TRgb4CDTbeT2oBMbv34dnSOdHITZFo/t1qUE
YeO3X06+Z1nITvwutqyIjcmyXP3FYWxMrZbc6R/NAntPneLxsCBw260DGc1s
OCytyxZxAjH7dILE4WssdNLyi0Z8+VjZxUkXX85Bi0/LwO4/AZinM5GhJsfC
epcJwz9jgXAsGAxlm7AgYeLfkprGxkNl9fxiov669UtsYyZYuLyhrWq5JBOr
Og03NU9y4bPt6ml5EQer3dxy76YwIbalWf3dATbmtX9e+jyRC+nPk6OVXWz4
zw1gDBwNxPqcilU9qUxkvMnNXTW0DVphRwT+rUysTTRNGlTiQEr3r7zpDzYy
xqbcz/gwUbXAptXvNhPNfcGzzoODkqB7PFYME2aLKGq6ttvwa23zimXE/Qs6
k4qsFPjQqRiSN4/hQMw4SfnVAA+kKz/GUmQC8WnfSvqbTiaOPwi4kZrMQspM
7ajd7Sz4XuxPcaEzYVE6Z/yKHhODL0h3banE/j5dYTJ3CXxUfdAxWsjCtRX1
tvs6t4ERFvN6xjkWog8nS0ddZ2PUtjFrpQax3ujM4MQtNlbE2VNy+1mor9ba
sCWMC8lPNTnb4ph4s2lPSOTXQHiVTVBtRlnIaj6bu/98AHbVm7s4NrOwTI51
vWM2E4bisRfnZrCQZvTTJk8rCCpywYNtKoEw8BHPp5xnQ/vvd8/NzmykFfbM
ttniDy3tOtbmRhbmFViWx/ewEOuheHZSnwVHp0/Tpz2CYFWu85efwMK/lL57
y+oDkd5aXVf1h+h/rpDxi9ivrnjehjq/QFw4b/qSkxEIY72ufz1SbHivUzi4
9zIb6lf2GXMvsCG71rXJPiYQt87I5XuuZcFhLHpBL7Hu1n4PTwt3Fm5kNARo
qAVg0OOT5kLDAHzTdGW6hLOgaDlrVdVpFvpr98T9XRUMpQHFFbNy2Cj0Wr9K
NY8Lyo19yZQ6NloP/rFTzw3Ar7s3fluEMNGbpZBf8y0UdrSjuR9bgyGVVx6/
gMFB/z+hKeVoMMJlSrX5lwVYNrKqX5zMwUiX5cKLsRwYftBkHDgVBMOCpLI4
Ag8pPnsfaRA4kP0/ICJDkEaJEqtWE8E7M/9q4o9QPPl4cPBvRQh4syhiIw0c
cFedkRqx5CFw2YHTr/cFImSj3K2b6wWI3jHSyDUIRxBTOTBOGAzR/bxZuvU8
bK2fTq79zcGfcpKX9T4hqrYs37vTQ4QIJY3ZA61szI1pbe2eGYwsmaSEQh0+
ksYLY+38uTA5ZSz1qlCA1I/vvt96FALx+aFDS1bwsXilrtVWP4JPr1zO59wN
w3KlS93aRL0xorNmb/cGwmHT4H8Pjwdi/ouD3jUGPHgtT02YlApG56Mpj1yO
CKXjxrnvbUMwPlFCFrfno4FUe7W9igO30Zz9TUXhCB/+Gf5IJMLZlLe6dcQ6
9+KWoyWqAqiXVo+v9Q2HVFWUoZeMCAuinAbLtHlIp1xfY/COgwfPL26mJLAx
q8g6YeZnNo6Rl+wwO8dD3/UXmceLuKBpN/N7m5jw8oiueaPPQUWRQ9CtdCFG
m7ut/lTxQVJZt/lIQyBsDoqkiq9wkW77mZK8UYTtM7pfle0U4XpvNBLyhDiS
/+SlKEOAz17G86ObiL4ZrB30fh+MseTzn1fL8bFNe0H65X4O7nO67ud18nD7
a9vB3u/B+CgnU7u9PAi/Cyp6Y/s4uPOpxEm2gIdHkW7je534SLOIXJl9KQR0
788LP5UL8OBAX+eBriAs2fjIY2SSg69RwZnd9mGAYrTX8jIBSDV/bg3l8XFF
PMXI0YoHi90LZE4WiDB7UbPgfo0AWW3vKJMVQYg8pHfywAEull5tV/vpForR
kQFHsQoBBgYT/xtNCEa9yhcdqjUP4j+uh5cnB8Bt90jwWjkunDorTzUMc5HI
H9BXVRNAdeUQbYDKw9raJSndp7mI2LoPZUE8tDiNnNqcx8PT/Koro7QIhOo6
R3QTcxbYk+aG7hDiTEKWcCFxf5LP6LnepzxUtohCxYl69jRL/fD7FgzhhsW7
Hr7kwdaW/WTzNR4WjIuaRib5CPV1WffwnBAnalXK/Y4E46HR5x9pLVxEWot7
Bb4MRpvT2g9j83dAKi7q778BPnTpW5zyOSG4Kb3QTovNh5y95HKXixxcntlZ
JP+HB7HKTwOFumFo8tIczr8QjLc61d+nsznAsZuOj2UEYETp6oztEaJ6/3tf
8kcO+AtXaA3YcNAt+9t4K8G7/Sdmy7RKBCNhTbKMYi0fg/d6ttyJDkGNOT9Z
31uE0zcvXymqCsMKHeeyz+mhyP1gK09348Lrb8I1V3E+jMVr9HwmA/Hdx2Dh
fBUBKhRvr710RgQDy9y44o0C/Ei6t1l+Dh8yMEq30+Hh2f43U0bGIQj3fSW8
d0QEo+sPaWamgVg2s6GxZHkwqvnDGGrnY54hqXCGBw/VmwZrNo0LEal47/16
QSjE80b7O/z5EIi+VOXXcgm9f3Q2MUIEs3r6sy5tEVT4yztaKwJRyvx+zbAj
ENGzGYEUU4KvhhnmF0eD4flqTkAQcW75nhA397lhGJ2XN1H2gIcPYXcEfk+5
eDb/2as6/3C0UzPb8x6J0PCA9SFnTShEkltIO1sF8E2+/92pLBxt7JuW6pdF
sAr0v9QezMOW8RMPK0q5cK6iH9s/xcaMvRLd870CoeDbPpaUxEN4kP8GchoP
F1OfLhYjfD1Nx/LBy1EOWMFrl+rcEOJU1JkVlVuCETrPc+ueZUGo/DiWfeEE
DwGNmJlSI0L/rzcv1VtFGNxImdH2UICftY0fG7lCbA5oGNlE4MjB1e5Ro5kA
nfYcM9FjHoQU/tuJJ1zEvFoetXA1H7t0pUkmBL+/ayxf41YUBD3WwvrV4VxQ
U+KeezXxcGFuccCOFh5qLs34yYgNxWHjf1scuoWQrz3ime3Ngf/w0o5N7oSe
ZQTPob0Jw/wuD6U3y4Vwby3LSy0j5nUiXvnFJh7uMZLmdRN9+aSaRLf0E4BV
Wz3j19MgqCpXXI48yEMn1/CGNDUM3v8mU3oUQ8DkDG+sHwrGBQP/xF16fIzf
rbQ/NJ/IgQ/eZk1HEPrO8i3SWs9Du26UR6SnAFS/szN3+/LwufBI4lYRD/S6
kz93nuEhpE11Wa8kH+6CzF1LSBGo9NbP0GsT4dW1Xm3HUSFGNMOGZaMFWOVy
ydU+lI93VWlnPY/yIHlHSqtUSwDZk2FzhVf5iHsmry0xRfgL38Nm4cNgHDiQ
sNCuXog8Dz77eaYAd+f4lrcr8nBUScdtxkIBIqjdset3bseFU8xpR2lifp4t
3nfuhoC0n+zclsUH+R/F8LgPF1ujs6x2KgbjVNJBnxcJYcj8lvmlmvC3e9Pv
m6XGOJh/RDpGEC9AzH/+lckvhGB8Gi+1InB7t5a8Lcqfg6t3WXqVrzgYPGow
JtccjNmb604VJfHh2KjsvLdYiIcxRn1tUWHYrSo/46GqCGt25XdJdIRC87rl
xLcfXHCy+iySCV8ujBvYHvonEBLxv7NP9gkQPJJYeWazCNyD+WoH/gmQPmlR
b/CCh57VxvtH/Ygcl5r0rEA+BGJxcqu9FhF8YJJiJI0D8SXaIGaFjQCTi8eq
cpr5sDtdF7lhLxeehQ0dbb0hkMidUf3nXCja75iVbdhJ6MSxzqfOy3i4xCSP
WKeLYB+6/NDJgjC8uiGz17mJyP8Xj+52JnKwlIfnHWsXYp5H/pqy+AJUNla5
yXSI4P4lK6/uZhh+vFb4fjKahxL/4FCdNC46fqVE/iaHY2xE7vxpAaFXqYcF
moWh2H6x4PcWkQC7KxzDvNvDUax6KeuBvgj+WZPB0j48fDeePax0lYudzxbM
iFYPxFqHd/qu02xkUkdXtf7HQ7ngjc72BB6OSKpuddNi4c9atxP3lXm4+uO1
0ERNiKyst6NNQQRuBYXNj9lBEPCl9pYJubDNsTv4WTUczpfcR7IJv783sMRm
w5gQ43KqjcPDQuwfip8+nR6MN3MODeUsFcB+3lEDxZk8pHQPyacQfn5a1/qJ
iQMf8W2CpxltApxn/+QF5Abhv28Nks1EXxTdbeoOaBL5ouNPuH4JH/5BDbLm
Swg8SZXFBT4QIl/ZRU//HAee7WmfHM9zQDNaMPVaUwQ3XU/zm+uF2PSq9S+r
ho/T3Odxurp8HNMSyEkS85/z5snwpREBCvkqL9YpEv6x6gK1uoMLNu2da0hW
GFJq0+U+NIXAuL5qsQTBi+GfvzpPEjnnZ9uaoPP2TLhwGfeLX3JQ9u9LoedO
gp/RMR+KZwvAe+VMbSL0sYoXN0tPxEXdm/snuom+Sr+qbf7vIB87S/8+e/c7
HC7PJ/ZG00SouTVLxkI7BKqcbzN7LxB8/7v/4Rri/VQfU5fVo8pD5OS8qfkx
Amg+XnCFdJiPx0L6iRe9PCy8vdLNnOCj+fM88eQFIVBXjn1cQhXCz9Vuikvk
ypqI5DjxYgFshhpi+/IiMNWw58guaQHOsc0btX6EwO5yaOZLTUIfBSc+yWZy
YX78clLE1WAMVvjH21zSwkkD0UTAVx34cYfs9c1IcNkfZLJXRwdjVRUTkeoK
ODEuXDzdqAORVBLpXcMSKOK1R91hdfR99vC/9lEP0j3kNc+1jdCesjzLJtMU
vRNhMcZzDbGTrhdv+9QMv587DCp5GyL/lPWySSMS7u5mNiVOG4L0I7ll+0kD
mASoq+hc1oNLZeQt7FKB5bbaUNYJbZgfdB6O/UJCxgHu0J14E6zktzyPyibh
V3uD7ClXE3TMWplrLWuMXHLrRe1pA1yVTDj6e6Yh8nTv39LI1kd0S/mpi+/0
4Hn2ocbxe4awvRf1u01XA9+vH5SLdtRA4Y12lWcqxnitcMLN56Ahltyjn3Ju
0Uam0jddB1c9gKq06aqaCea0//yq0KGLfLuvOybpOlCfdiyNy9CDmu/BhO0K
JLClZb/aFpiCE6j0o/i0EbzGw5TWPDFExJbexO2LjHHp+bbbhtrGYFKmIytL
qWBl1jNCbhrC2P6bb7q3GTpLbHO+qRqj5UXO+jvn9UBeKFykNqCHTW+GDZt7
TFEymzwYm2qAABp13fMMQxyJ6pHaxiPm09j1jNxHgt8ad5vNfFOsT06+8eWW
Hv6sbr3fe8gA35IiY8f2GkL4mmQ71mEI9R3L7qk/IWN46YcVtyeJOWg/y7w/
Zgz6/jT173wTrJ4qlzo6QfR5nFUbQ/zv3fDUQ++aHlwrkj5/09JFqPNisc5g
JazWKr7mPE8Hq3QVjqlI6WDLoY/hCft10bdxYrb4CTKKzi3aOtRojq63XgML
+3TRHuCgKHqjBw3Zipr1LGWs2+B/4GK7Hg6f3Trv9qAO9nTlqfWUGsJOaUGY
lZEaMv+Ki+yS9VCwQTE4OEod8Ten9uR/0Efx6fRLwlAzTEVZF+z2MQM5tKd4
zQFTVPLbOwMVDNFTXPrMM1QXL85fvWV9Sg9HlrVF2HMX4ZnB3I0fS7Vwva3o
2to0Pfxde16SammARncGs3UuCbvapL4dkDRBdoayBUfGFD5ZjxxvWxvjXY9u
k/w2XbyekaAubNfHL4WNj2Y9MsDsm2Zeh8MNcORLbuerAyRsvr0+/Li5EVxt
uQEe1RrwnbiW8MlZHxnNS1J9LpPR2JUWXxNhDi/N8rFTmiR02VhfXB2tC6UT
lltTJ42gk2Nm36driBw1xqinhAneLl2bvL/cCFnq9G7GfXNoN8W8pe8zxvFP
aU23+vXAn6EmeeuBGRQ7Xv5YM03Bza1PI2kZFLydWfI2e50WzPZzSzOFBG70
H2x+IdKGA3dbX4GKDhouXPwl726CxNWx+83TqBDb+vr2B0UqGi6OqdvtouHu
62b2v5lUPE+oqXrSSQUjfijPs4+KTvPrfgX1FKz9/XORfisJ8dM57eLDZPyq
9g/PtTHDjt/1AT9UyFh0xO5Q52ZLBEYt0gywosJQyj3/sQwVLoHmtdREGtx2
aLta7mbgk+nGWAsvOnYZXz3vQTPE9k0h9AYfU+wU2bxb6shAY+LnkZ/BNBh4
icpGd+rAZ/a9ou+tOkirsBdt3GsKhcwH7UoSNDR7T3+dn2iMwU8JM8QvmaE2
4A9avtNgfeKUslIyBd5+/h8X7iFjvQM3+ZgbBdykjij7jcsQOjyQupFmiQlj
yo4nXTS0n6sXrCijYnvivVg3Qr+kmd3buD+o2EO/n7Pulg3Srh9f/yycjiVS
u04IbSyh4bjTfLiDgdeDTy/sZpJAtT9rKXPGDLmbxdMSC0iopBgOW06TYWvy
l/32HwlhGtLP6oZMiHeCo/Kpnwy8cTjs3hNlgRBn76AvvWQ8Sb6q6SlGgsJE
fXpbGw08I5OojmIqEhT6uNeMrdGS3STdqGoN05Uv7vbJMTBy3mVOPp0Ou8rQ
m0qDVMjfF+u/fdEC9Ie35sspU1EkkDgtr0/CE5lNETkPNbFA2tv9RLYJzoU1
mHuoG0H1m763vYQ56hTb9ymstkLikx81dW8tIRj3WNoTQcLXlsG0ShsSLpxb
0L72ow5O9c2t3O9JQqPeOp/hLBKipg3i7eNoGPYIccw9bIq5nQ4R4x0ktP+a
VOjV0cfUzQmV7qtmeKjZcvu3mAXUI2pM4x9aQObOnt12qTRYPA8QqyJToFx+
wkHvuRm+/bxaV7uAhGVL15XPJesS+cfsF9eOhCWHn69+p24O51fP49z+mUGc
mk6jZ1pjUdPL8uUCBmIK1mycn0zGhh2+85qaaOg9Jnl31ISMAl3LxfI7qRDE
i9/cfpWM/qyPl9NLyUiSFPiQv1vDJG8f+WsiFWTTe0pF8vrwbH7/XuoQFQav
Qos+DVnhpLKcfdldC+zJXkktzGDg8qOq6Zc7KBj465qVmWoNieKLIUsM6MT8
urPTxClYGPLKV0GFDtfLi7JkjaxQVOLclT6fjk/8JTraCfp4ejg17L2dOVTX
5PXKiFERLWzviHhP7Jexvv7yoBa0Fc07Zh03QXmQuGnsN21Y6tItxtx1sb2B
ecSyygQkr74GxyQahMuHor8vomLq6bYHpeY0nPn86HBIAQVnN0lvWuRAgxhp
avqmNg3nj2hobjpLxepgTpimE3FvTUu/imoKnp3/sWHTqBn6j4v7H/chY7GK
+0XGlCVgW3Im3ZXgwdVZ/BRHGloevHXccoEOw3AJh5F+Bu5XdIU33WAg5efJ
2poxA0y3yl/5eNwU897pbhE3YqBj5ogfvYcGx/62iWvdOvhSZr264IEuErfL
UWk/CZ16mPdzixkN0vqSh5UVCT+94TrOJupQiKOV+H+h47OHYpRQlgorDs2V
akKBpnth6FE5KrxNqyxT1lih1oATeU/KEptTvoev+0zF6f/O5exdS0PAhC6t
2NoUmuumXGc60eDcuXNXhZkN5ud8Gw01pkPznNr3g9ctYXV1TnDqCga6C+l5
1Q9IWPOf5WDGenP42Nz3nvWS8O+cXVOPN1Gg1cTXc1lPhtNUQo2tvQlczvG2
pRYz0GDzUar5gQV8Ojc7avMp8IiXVpUwJGHvb9bb/lE6FpemOtwJp0FvsYq+
Jssaq9r6764rtMZWP9Nf5ykMyJ9ckpn3jgGVLdmsn3to8LaVvb5ygQUiNeqM
8vZRMfQs9snB2YSP1HCoVH0t/CZ5MrVbjTF36uOK9EdGmMey5cbNNUcc+9n5
J6NW2EBf9HbjNUss8ks7fqqNhBfbX7To7yahbNVoyDUnPQj9Hp5eQSN8JvuN
T4AdGdPVWacP+tFhxE6n+3ebgp361yuES8ZfV2lGRzfhqw+HVAujzRFdbuC4
lWOBY6sOPZZ8aYn5FdHRMudo4B8d2fBzmIJZR5o2hr0xR4/YCGkWwc/Brfzs
d3d0wWyLGqW3kyCvv8fo625zJPh6OXB0zKH+KfSYzKJlMHzBt3nQQuidU3jD
hwEyVNrvKReb0ZH96MbuQgVCp9v4mfZZVFy8ZLJDdiUFL1L/qSxZQoGV2vmP
S8SWIeVOyBH57TRMD9fnavXpo6h/42Q7iYZ7ci6/Ts2wRml8mEESgePauRpC
hx8MxKt+aHypRsWFgoN3nFqtifov1xnuY8DZv2RNy2YK5qqo33XqZiD8xja3
ZQusiDojZ5cNMXCAaf9k/QwDXL7ybJy63RxrWXkRoQwqNoyFDZpXk3G4t88r
7ZcWLjH8tF4vMsXoO0fZEJIOAq+JqdW46OB15OtFCgQe/1nIyv6ypuPxUS0y
S52KzIFz77/doiK5h/6l2pAKySuFDlSCz48WeHwLraAh6pmter8/Dbf+Rpdo
7SZDWkpix74qMqwrKmur7Un4Oc40aT1Hhpy+eng0wwpXzOYr/62i4HjF+bf/
0mk4OX5HJmGKjhjGkT30aAv0t/VNqf5hYEXApeBDmoZQepnJjPliDvHK4sYO
dQb2NcqkrpxJR39py4MhVV3oHZrOih0n8r2S/Bs5B3PsMX+9+VYLoYe+x5Nd
SozR0OYp9cDSFHvr979/qcDA7H/FWRduUnF5SmGrZRsFudXDvaRkKih39Uq+
eFjjelVy4h8mA5Fi5fl3LGioWDsnt4BGxwA9eppCNcX37k9dgfsJf1NWJN02
XIapmdk54+00UG29900VW2J6Tqzhiuc0sMWGDQzEyDj1obvpENFvh17LWtI3
Esr7d6ouX0jknbLOACSQofXcc/WShSYIzVh/i6FkCYnBHAuXZ4TfNCquLj5N
gdpup/c9oWTw5ner+3ylQ3aX2eOnLDo0NExl7n+yxrJQycQXWdZQS3btLaml
o8Sh753uPcKnXzQXr26mwb09iinYT4d0SILOnw1U1E8llT4+ZY7FJjl+5SFa
uGwjYxyrZILPkatChucbwyGW/7lmpznGJps+ONlZo8/Nlko7YIkIibrrXeJk
FHu+1u0VkvDBcmhKJNKDgUZrBt2FBHE9uXvlPiTYX2W4qB8j8ob/QrF+sjmK
Hf+7+usNCXG/ra9ESRjAMNYp2TeHhKeyrhdWDFggipnkZSBnBbLrl5Y5BJ4O
Mt9MVDpTYb8m7+50oDkufHaJf25JQn52gMaBLl0EfnCuMLlF5A0X06cTf8yh
d+eC3qEGEvbBa6bgnzWUJcrWFVZboNfy7QrmKBniRkNvf6nS0Rvsm+XiRPD1
Yuqu6isUwHv1xwveRK7qXjzX34HwWQmtc8q7rdHWatOQReD/9X+3d+tpG6Bt
Mt6n/CGh/6EeOtwpK9A3HhzixFhBceXNUj87C/zpct/6ZIiMMBeLk2ULluGD
heY6+ZcMyH4uruYdoOCcifi7PWoWuMlLSbD7aoXYlxFrmmgW+B/jqOLF
            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 4 PCA vars 1 -2\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5", ",", "0.7354570562104323`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8Vf8fx4syiqxoiezNXa5ZVJRI0kBIuPtel2skGkpKGlpIIipUigal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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 5 PCA vars 1 -2\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", "0.7721237483884196`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81d8fx0VDOyIpZe91B9c1KiIzpKFCcrnucq9ZoiRlFhqiaRRKimSk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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 6 PCA vars 1 -2\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "0.7084121899192959`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8Vf8fx0NJpbKi5GvvebfRUhQphdIg8+57XaMUGhoKJRGiYVSoZGWk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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 1 PCA vars 1 -3\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", "0.8123814156534783`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c4lf8fxkWkIpFKUvZeZ5ulUEZZDQkZ5xzOcA5HIUUaiIbKapP5laJB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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 2 PCA vars 1 -3\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "0.8521741294998301`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k8VG8bxi0p7agoKfu+zWZsLUIRIW1ki5kxG2ZGllBJCCUqpRUlVKIF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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 3 PCA vars 1 -3\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "0.9091330247014875`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c4VQ8ft5KKCtFS9na51x1mUchWKSNkXNzF5V4tSihCE4UWymgoLUqL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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 4 PCA vars 1 -3\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5", ",", "0.8926376484200043`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k8lG8XxkULlexE9n03C2OtZA+RLUIyDGaGYSjSQqQQaZU2tNAilIgo
ckmLylqJSoV+lkKEsrR4n/ev+/P88dyf+5zzPde5jlJQlHsILw8PT/ciHp7/
n8aBlxUf/WKAml89ysdh4Fzzo+GUbcEQtTotSJdiYLO/zQvbVQy4wbb76vIQ
jL1KbRRlhCChsWjztGQwGP7R0W+Kt2PU6ONkyfFAcM49MpW+SMeaqWMOHrZ0
WP2QXs8XEIxDN8tjpx7TUSKnONXTFYwdQQeeLB9gQLF0b+znB3T0fwhNcLpM
h0KabJXDYToWl9HmDY4GooLllzI2GArr53kCRcGh+P37yIpl6SH42IEZuZ0M
eE7+dvA7FwRL5/blI60hmC0v0FgTFQwa/7HNxbfpCN7zSPRYVAj22RhLKVDo
sJN7lMcNZcBxbezWGFYwug2vFn/zY0FBIO/FShITHb4dg/F/A8EnPp5anRUE
V8cZrb9jDEhL3Trx/zwt1g3oOJkdDOH48PyXusF45CpruX8mCK8Ox1iv6QrC
hm6tLS2zYVA+nCLX5MSElYtLQX0WHRopJep6h4Mg3Dku154ahq0Xc5vfVTEQ
sCqQNniEAdq8XvwBo2Cc+VRQsGF4O0bWv/SJOkGHU6pe2pB4KE610jYZWzNx
Zmxu81lfOtxFQhZuRQehpZ8tkI9QvBHTdDryiA59GYq8muV2hHtdiOguC8T1
7rRiUxEWXFwFottzwsCrkyb5bpCJ7sF78wFPmPi+b73Rp246Qu/eyLlECUbW
IpXd8Z1BSKR5l6fco8O4bMXPm+p0LDNa1ztwjbjf90MUf30wchZn1sbSGLi9
rtFyX/d2XK/KC+jsC0RiRvqy3XeC0Rvzs1PqazD0tc8OzdQEIznIm//cs2A0
1ip7bI0KQ/3v7yJ+qkx82rKHE/eDgbbS0PebrwYjt+VcQUI+8e4ux+YoCgPm
gkF3upbTkdD7qvBaQAiytX9ZFCqHoGFsoaAtOAiavnxXKfnBOCq0zM1QKgjZ
RR+XW2wNQHfm2tqo4kAIXzepOPAxCBmTK/rPERzaO3yfz3ELAVuaNd3pz8BC
Vn+DeSMDJt8vZpl0BOFMQQTtN3HfyExLZ2RrMC7m670NPcOA76q9qbYFDPg4
ixzaeyMYd5Y/zpD8FoSVTpuabfYz8Nq2z/GcMgN2Y4kSvUuDYeA6ohGWHIK7
Z5oCFeUDsU7GwWHcbRsmlTbRHYm6JSlsWLR2MBhfHu5J/reBjd7Zm4FJIywU
eblukC4Mw+TBxw2hO0Px6tBfa4WCQDDUjzAvPWSgN1fkat1kJHTaLTQUWVFY
WlhxQIIWitQtmx+VZ7ERzV+mwroRDl/JQ6H25Wx8+2Cy+lJSKEwHMsS4caHQ
up5WnkzwcNai31XuHBsr/w9EHAfXDIO6kl1j4HP+6q3U6Uhk1DfEp85FgilA
4f3WFIpfFaQV1nNhYJgfzHm/j4F7wq9u5BwNQeLOby/CNKMR11hxZX9QNLiP
CwXUGpl4rWnwekUFC38rSF5m+yLwY6nm2yO6HMSIKy4ffBWMr3/btrjxhCCX
Py2lSJUFcdnF83M1bOie0ln6rigcXeufNHuXRIBPLHJYdh0LUn8mF+vUsGD1
zjH/cn0UPpx9u/MXm4v93HP6n/cycMIlfc5yewjEXh/yqdNkwp67Us3xGMH5
szm3glAucrcFaulqc/FzppTMZ8NCbYZ7zrp5JlxGLyc0F0ej1Kjfn/4pGuey
Pqs9suTgzqIP6yS8OFAoq/3p5BcNpevFj+W+RENit8NQuQoTArKBM7cnw/Ck
/ZI3JSUYwzcioicOM3CULLtT/wITbWU/PL9IsWCo0sLqbaZDb9HkyneyIagq
tgupOR2Bv+I1kjIRYSBJOXtnNjGwtbpjSM6MhdOW45R0Ty7uXPa22dhLnL2J
SCmMgNxaJu953XCMe+mIJTaz0bWGNnf6XDjG0vPHrQRZOOG83i6tLAyPQz88
LuxmwodcGessGY4RQf6HOypC8OWGjXWyFxMPvpc6rLzOxB7+xcuFljCRbRy3
Pu8KB8ePFXP/G4vAk4P93Qc/hKAxMqTrbmgYfuxmn++xIfJtxnrCUxcFUt3f
muFCFs4/UzVbSnBrHC/Bf+I6FwMdhcoxMlHIfdNHma0KwX35DHaMTyjkbnXK
/3KJRFVL5fzHu+EYHEq9NprChs9zE+3h3WzwTd+JrkgPhGjrgWDe+3Q4dN87
1fQ1DLNCYpXqvkxIrx82HKQyoX2gLbqEl4kY/30oD2Gir/a16x6HMLRerb45
ahiDS9tYZhq60Qi3Ia2K3BmB5a1DesXqHJB8Ry/0thL/Xaj8YC9ExN2ydHrb
JBspd2KzD3qFw9Iy+KX3bSbqeL6toB9iItLP0fnphQjUSVHvn1kWgafa49PZ
HWEo2aL2I8CGiTcOTgNjYjvx+F3Dsed6EVAz2upwNZSDzvirX8cq2RC0WbLW
8VIoEjwNNIytQsF77/tgkVoUSouLJ++ci8Jn1dqp+bxQeEsf2SRSxQJtt5rq
2J4I2LE1LD4ciwBr9TrlQYtQ5OT0LJqNCUPC8eX8rxazUdEg6hC0i42hho9b
HyRyIDNudU3MPwY5lTduFldH4aalzap0CS4KBiyFjFzC4CgzcLTuHxM6fHXq
vrMMdP5mF7cS91aJ3ne6cpYL7nEjO/2t0ZhOa/AWWsHCv/6pmoowNtoSPs1p
63Agbd35Rc+OA+07Tw319RjQrN5UWrc2BLWsrxjuZKGppv5T6VY2arcM1W35
GQEn0D+sYHDAVzj6pSuABSPfF3u9V7AJvX92LjWGi50F3Rt380RDirW269X/
517zo9Z9OYR+LKcxKHpM7Mv4F143xoT7uxWBIZlcBNHtM8jzXIwKF86UE3Pq
rZ/flz3vWGgTa3v3KCAaapxMrf/EYtD0JGjgsm0kUuaEzP8RefZLfzzlUB6N
Gx3JN7UXx8CUEXClk83ElQGDI5VOLGysNjqaMBeMLULtQactGRDx6xxLS2Mi
aHnD01gDNi6dbF3DqxqE2zefyOfHMxDEdpJTvRsBiWK+Mc9TLEQKu/vvMSfm
kG7FHmYPE4EvsCirjgujwOU3hAj9G/Kk8Lx5Go7lI0qn7RbC4R3Y9G1LJhvL
3K7F8GlFoNsmVJ/7nImZzmElm41M7H+3dvdqKxYetJaUMQ6EY0pxra1LcQgE
t11bfaeJCWpWcrtXMxNf+lfUPATB6RWeX7SkSIR7ty9ifeZA6GGmex7RZ9N+
Tv+sbobB5Qx7heEngjeFjvyDgVxsflVeeLKcBa26LOuQV2w00NKEe25wMd6U
uDddMBpBD2t5fhO+qeTTWzkvYk50h2ndXUaNws+LHrSVbhzQQ796Ng4T/cJM
O5S/jo2f9fdsDovR4Xz14TP+Wjr+BvkVK7syUSFxIebUF+K9284tivdjQtDD
2b1dkQmjRyd+xZ5lQphx61TLNBObw8/vkiXFwLjEuV1iZzTe3e5VsR+NwNzN
sMANtRxscLyyySaSmIPWmmLDs0wsebBUuUw5HDKKt7b6i4UjuU1IZfEcE6OX
zie4LjBx8GDKauvGCFRTJYrO8nFQv8KvolOU8HGr7q+eHyL6ntqT5Bq7A1f+
Wqc/eh2OSPcOnwf1HIgWHi0tW8QBeYGidcw3DLH7F4kf4obhVNoh39cpUbi4
e/v+GaKvG+b/a1k6FormJs9uFx2iXtcC7qW/jsDuXN6NOZwI1D8kb98dEIr/
XpyYa68Lw9ARzTHBFjZ2Rie8HCpjwf6F5Ma9xBxzrKybEReOQby0EM9TaS7c
KjLvP3XnQumOyczkdBiMZoVH3JOIuJMHd0T+ZaCoSYkiphIG9rfUe2e9uciY
b1w4RfTP6VnjRs3XTOz9IvDnSx0bpJNpbdeFOAR3Hjk7pTloopP2L9FhYH3R
ju6EacIPrxmrvtzCgvm5H3U9+1hwL2rqetNL9LfrZMSRM4RuPdAv94hlobnX
ZTLvOwtX6ORvZqe56N77Lt5ZlqjPXf69G5sZ8NZtq2lXC8FSN/cHZo5MyH56
fcueyP+9F9Uu/F1c9F1LetdsT+jJe5GpE4lM8EsFHhZdS8yp31lxf8jRuH1a
UMmVn9CrkxnhSkWR8L/SS/2xjIv4Kvson85oROV2a2vmRCMgd5a9jND9WBoP
78HVbMS2SfAkKjCQv1TYQpmHgfPU0Q2vrjFx801qYPQZNjKXSPu7KAfhu8uX
kgwi7lvT7yN05SMg1dkd5EnU4WJ4Ucvz4BBU/zzmnLSKCcvL1ofGpaNBPlsq
setUNBoGZS08iLnnRK9sXSXAQcLwgfmc02zMOc4slbCLgI3wEU3RRQRHqh9b
vfYzkaNm9lLXjtDLxCWj0n3hyA/+xQwsCMF8zc5l5cuZEN1s8eigEgv7U9Z6
mmcxERDStNJANgoC0RsNwjiRuCrpqK5xIRR+4e4L2a9CYagtMfdeiYuHq4T1
AsO42PLu1b+gOhb4S6dvpZDCcVQ5XHAJUf8F/1sTQb+5KGJJvXYWJfaBC62G
oRGhCDbs28TJjYIppetLWCkHOo3VaxY/ZaM/hFJ9hNDpX29sQ/Jt6Eg3jm0b
66WjfGGiyD2WiZpPUw/2jzDBfLeR2kzo44u01q78n2F49Onx8Z4UwhfpX6rW
MiPyX/avre8PodvFnUuOikSjrkaA31iFgyvnysfd7Tmg/kt4akvsT+OPLzND
j7MQNys8J7Y/HCdWeyrX9bDxPMLo+OteJp6JKHxwtWDBoL2QL12Cg0hxF/3K
TA62bSJcpQkTDdp7XgdNMWEx3JTUXxiDgtWuzQ1+4bgQbPBCeZqDuv15hs1K
kZgKP/595fkwvM11NEz/TPRbVcABiyvKhP9KCLr7XAnbwoZtNPRJ0Br9bjCz
Qhtj1VUzcQoi0OuVIQu7SIK7NI3U1ySLCOmUgMxVKugfdwu4PaKOxbbyayfG
1dCZtTbX4rwemP7nE37/1kWskfoBy1Z9cGuhO1agg6unzMxntUk4Xqx4V7tG
F6Tp9I4dJzSRIDWwQuCDKhzvxdVglxTW3Xh9bq5aGQaHNn5NmiDhqD9zS2gK
CetZHe2780iAx+Pvz+/ooUtgfYHZSh2MReju8JjQwa0lKUf+LNLC1Kb4FQ1+
GkjsqDh1qU8dA3v9clZM68OyYfefN2qKEKVYvXw2IIuiu51SbVI6UHuv27vy
rAZkG4xObexQwdfc5Ep1CxWAKr7llrwu4g55nVi5QRVXrX/snDVSBbf1zqTt
pAbk/Q6l7BAhoaxkzZVkXxJCGeLTJTnaWKYr2iZdpomYrb2pO2R0oGTc/WRd
gTbolPm4e2VUhNiFHqu6R4GOzaTfaR99qMUJfg1ZoYeO15ddH+Sr48JLUUtK
vxq2fPqq1fJRD05B1tImmToINKQ6t5/RwruE3T/OntPA2IsPbeR+Ek40PQi0
S9ODa3r63YkadcT9ok8o2mtiMi0uaWyvFgZE9+4KrNWCwk7zBoWXZKSt0lqq
yWeAepW284/HdKA3G/E0aR0JVnMVS4/M6MJxVlDwCpGvXo9WN/Xb6hg5XtAS
/0kDkRvX8HazxUGZ28K/3FccG9REjkotVUUhPThfXIbgwXNmOd9xMj54tiVL
y5Hw4bPX4GoijqPCJI+7t1WguLKqzjVIEkdjX1cIUcSRcc5f+P6QKmKDasui
GlVhLS4RZaotj5I4emfSEiVc9xBls3crgJX+6rT3Eg2U5Jy+EhGpj119yrXU
i9ogR34ssT2oh93nandG7lPHx5KyNvdINfySD1f/pKuATPM3MTZhMrghv9aN
+1ABd94U33bKVid0/rS9c6smXmym0V+tIoHxLNC930sHeWckjUP59WB/9NRA
SYQe+j6qNQttV0Pqk9lbd0rU8VvE85nAM01MLZHP5SO+MycKut8dJMH67dN9
g3062GQZFuhWqwieTeUuXo1qONMie9L3BhnbtvWmvnElwUupYuyUEgkl+a93
L/bVg/hxE/+Ts9pY2H7A5+IXbVyWp426L9aF9YG+hGKC61wFox7aYwOcHBO5
VWWlj2Pfs5trvqijwLaqStJPF6Jdb6dt5ylQCf/q1Feqhc+LSj/nOStDz9Pn
76CyIko1nni/5qqgdvbNPbmtymi6eOm30GZdDGUUZ2U164LX//39AVEqfunm
F9k1UlD/viV4YREV2Xtlrn2rNwTtwHChez8V64ZPLtcepcDpzy8ZjVcE525H
k4JqdfG7NiC6wEIf5kcOXb3vqwOZTOvD3d4mSD7dISNdaAKtpZuvPuenQm3r
8emBOxS47FTZZBJPw2zvnw3NNWTs0rmV72aohY8/RlwEXAm94Fr0ydnT8C/C
PlZ5xAiaXtzy0VhVPD3+/ZjVDSVkV9lwPffqYXOmZBmfoT5afOZ/iKXqwNtS
NWGRkS4eBv5Fx5Qh5Hm3p1nTVeCzLWBk9R4yvEVZmUo5ZISlde228TTHRYXM
LQ5OppjRoex8+cEQTwfck+KiDbEjtSHJhdAv2Xep73fR9LHH6PFl5xoLtKUm
hkv0mUN26a7jERYmiJ6QlPT9YIz3Q60X4+kkPO8/nySioo8Cb77s1OskrCm3
OjBDI8FS91/w5wUS3PmvUkwJnvhhL3nqFw1aSSYmoq00cDb6hEz0khGUqn2L
zdaHyEzj6TdvDMF9sDdV2JWCFJH+sNs6ZnC33xZu9o0GvfWv6/sFaWBfl+Sd
WDCE9b3ISvEhKv7b+/LwRlsqjJ7WiAlKUjHgplEwGUjBS/4tMZefKkE69z17
IUMeF6KaDNwUtLFtMMxDY7sOHol27hOxMsW3FwF92gEmCP/pJvcxhoSImq/i
GYl6uHhBotNpRBU2XUmznC2KeKHu7Ps1l4TUiSW09DoDfHXj2Bdk6OHXpUPz
kzx6xJ40K9KrqgHLyrXXuvm18VSp4/4fXmN8b/EXvOdFA/+DPfHWJw3xYF2b
zXSIHiQrjtupt+tj978b92XNNGEu51yxiqyGKA8Lh2ozVchmtFv1KRggrPRq
QTxRXz7qaUOj82b4mv221yrZGPuv23qKpZNh7HRB7JQEFb1Hl9SP6pLhMTjw
9SOThPADfJU7bpHhLD/4fGsfCWlLwn3JU8T/D3vXpXoZgKzXIF4spIHB9e3J
d4+qQfNdZPH3YVOI/rxtMUPwsSdvPbXoDA3WGdPPOt9SMPhvU+75k2ZYtlFY
/T8PM6J+PXnZfBS8f7dLnkvoyKYbMrkrtU2xeUFciy/ZEN9ZsqoqKRrok/pM
l/isA2nbwl5+XiqSLj13+92lh8Ezro03hpRRqekpN1iuhIoQPr2kSRXYRTSu
WzuijB1N9EyTal1caSrrSRUg6rJ2OHFKhoozJlZZAnuoODv+LINznQKbEpOb
x/YYgZc0N1+pYojMvw2fcseosGKHRik5kPHk/Yv6Ijd9tOVPe2wZ1Udez9CA
YKk+1khtvkSbM8EzlyNaRvtM0XlLgJVlbwjfGSXZFiYVWtGL7b59oaHK8uCj
80RfZf068bBuTBPHLlh9k57Xg3Cf2lY+bRrUb40tvEyhwf7Lm5nbParQ1Hlo
fsFUBak7BKmGv/RR03RSqKeVhGUaSzIkRXXx8s2OSqcogvdkw9KACSMs3B4S
u/tHA6ahhpuouhQo7r26UiiAAh+9apMsW1OUkP/2z+WYwjtrKtp5nIrr29LS
8pONEDijZlhipofC/55veTOhj43dsbuq9C0w3Mrzp6TNHEoX5KcO3THBZlkh
z6Z6E/QUGRXWPiEhnW137O4LffhaPPYReEtC7MDi7qwREpSbWeqOrmSszWrL
1uYawPECc/vJEhpYbRvKe/tM4Nvtba/CohAcf74SIWiAvX+CPn8ZNUL6k5cb
Hz41hPoaKQ2lIDOMSMt9LPEyhf82vd/5FBoW+NfURLkZQWprXtCvPYZIac9f
JkCccYqPtAv3UZHcMJbmZE6Fd10olaqhjALx5fSAEkWsmhtZd/qZNvIVX450
u+siObgt/+WoKW5KVPk/jDWFzLbsY6fekPBbfLAn/KY+yjeMcm47qKPeT7bg
8XVlfMj75BtoTcbA8d64V1MkaAefNgroIXyTzzBn2MIA/zYto3X1aEA3wtR5
9RotJFZo2vuHGsOhR3tt8WFjiFUlJvJfMIRzgG1q3hoyBDKbPaM+GWCE9+Gr
+rdaGPJn5fU9UEN2qsfiyCk1CGns0f4Rb4AbLwquW+QYQOF75FF+GXMktyxb
cWcH0S8O0U0Dg2Rky1YvneuiIu/Z3fgiEQruFll3U7aScemK7s6V6ylwmLKd
CK4lw1Q+f0SW1xyWcgJ2O5sMMf+1sUC5XwNnvN+uklPWQoOg4+9TPGaIWN48
GvHHlNgDFCPspmkY0q/3VO6j4uL1Qw8cXpmhne8f9VaKOTYGlNp2eFNw+LBl
Wt9qMqLvbncxlzCFco3o0hu5JjhIt3npyqOJAvVfXlbXdQjfVRgTSaOiepLP
I+coCRm9/V7Zv5UxXTRzS7dTBaN99is5JFX8u7S/sipADe/j3suIEDy+3bF2
1k7HAM+PKJODFKiII5UcX19JRfpHo4laLSr0L6tVnn5mhGcSbpORVYY4p6GQ
a/nKEDX/EkuV48nQZZVO8iUZwKzq3sNaGxLIhiuO3RclQVBDITqRZooabpDy
9WpTHKvK/7xw2hB7daeNhh5TsZ+Wucco0RjJjc3t3q9pWBd4hX1YSQv7VO0c
21z0wXev5EWXAg1jb8ezMu7Q8KWs48mwtBouBQ2fj7ckfK240CdBOwNUjI+O
ZOdQoOl3LN2xVAfxt0M/phToY29jwn9vRWgQbpfR3qNGwo05EX+TNxTCV9/+
lz1GAaVevXTCzQxHLXIrEiJNEcdbcfWBsSGit2XJTcUaYdAocZ5C1cPiXxKW
NuIkpEiKku5rmeNy7c2j96XMQLX02TdXYgLLg5laPoqmCOb9qqnJS0bZ55oH
gt8MYNdr8pA0SYL+nep/hXMkfC7vDkQKGRPhE7LZxJ4Qeca1hiZuAlVBD3+h
CVPwvxC1KiHikI3/c1aOqw+mWI+C7w8jLFrU1/PytxEUFfX4H383Q8aOwCVT
BJ/y6Zt6Sx8aYZ+9RtQM0wifXreUWLUYIl5feHVijyGWcVJU/3pQ4dVswOvz
iIo1upe3VXCU0e7TlnVTRhnjcRs4X8WIPYd8gFZwXxdjs80DDtZm6LhZXCM/
b4qYxY/ufOAjI/bUFpd7a/QxYDI8x+Wq42dzbl+jrxr41AUbKog9ghReyFUe
I0E2YDXvF7IBji9IFdqt1UfyH7ObuxdrIr5usqRNSAutKzddXDdojJLGxY5v
rhiDvGmiYwXBk7jOer2hT2TY2BbWzzMMcHBM0JtZqY2reYGKBz+ogbaEcz5k
RAMijnqtM38N4EXf6PtrMxn74LUofMEM9Gqfu6Op5ug1+byOPkpGUofc+bHt
huhl++U6OlCgzeMhG3mIDPhYjVz0oeDYnrxPcQoUfFmsfEEy3gyFL+2utruZ
4v21+/HqKproK2kUNhUjY1mkm2rYnCkmjPXOXtxuBtH1lWXbrI2RJXzp+zjd
EFGOxifKJcxhLKj4w8vRHCvHS2qZByn4Yyf6s7qbjEpmVor1D1OEsCprxx3M
8D8FVOwM
            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 5 PCA vars 1 -3\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6", ",", "0.8569973417932741`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81e8bxouSpl1C9p5n2pXsbCVkxcEZxnGohIqkUNKSlGgYydcoFBVy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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 6 PCA vars 1 -3\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "1", ",", "0.7238481322588395`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl2cglm8bxhOFSqHQkL3ns80KCRmVdkh4Hs+0Q0hKFBX/BiqFBiptlE0H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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 1 PCA vars 1 -4\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "0.8758784657628598`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl2kglF8bxkWJIiFtZN/XWcxYK9kTolS2hBmzMWOoJJUshZRSlF3WSrRY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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 2 PCA vars 1 -4\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3", ",", "0.8977145135034594`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81e8bxkVJgxBJKXuvs81CRshI35LIPM7kOIdKpZJSZkNDEk0aQkJR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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 3 PCA vars 1 -4\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", "0.9564264350834554`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c81e0bzigUFYqGvbezbJWiSHbJTM5wBgfnIBklRYg0jJZRotQrKaSS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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 4 PCA vars 1 -4\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5", ",", "0.9267270748524689`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81d8fx0Wk0pCokL3HdZdrVrIykqgkRdx7Xfde7qAyKlIUDQ2RZJSQ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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 5 PCA vars 1 -4\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6", ",", "0.9142814574585204`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl2k4VW8XxkVJ4l+GSMk8czgDB4dKIZEhTUQJZz44phIqDRSJRpGkMiWh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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 6 PCA vars 1 -4\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", "0.7485642223248876`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3dYTu8fTokQKk0atNdb724iaWsQKpVUb72r3haSEGmSEkVE0SArJAqV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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 1 PCA vars 1 -5\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2", ",", "0.8508231471340705`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c81P8fl1EaKgoZIdtZt5xVSVQSSQlZccvdOedQ0pKi+BoNNJSRkJRS
lFTGU0PKiCJSWZVRJFJI43e/v96Pzx+f9+f9eb6e672CHrKVJS4mJtYxS0zs
/6u5f47Gw59M3CpW0e71YCC94eFgjC8D/N4qil4nA1t87J+vW8iE2p2p/CQV
BkZeHnskx2Shn3PTKpHKANMnNLT12k78TYo42DtNR3D6Q0ul7AAszmnQ1mXQ
sXZMyUbCj4HPYZti6+rYKFqu8f1dOwO/XH74rFjGhMb1/bu7HwRg+5OCNPUa
BtTjVMsc/gvAs6HrEQovGCjleseM9LORU9/JcxljYmYmaf6ceBZYX99lNQ8y
4TY+4+CdTodsB/GzvDcDUyW5eiohDBxy9VUoUWeAse+h3IkQFsz33Cl42M7C
+uUPM4VsJp5HZ28InkdHBzX/2mdvLrJ3tm6WvxiIFq+W/sg//gix+/ylLigA
Lo6TBn9GmPCQsp0r5DEgaeTXkpLGAD1t/u8wFh0PXVTXHJqkI9DpTUqpPgO2
HQbujVOBYG4ZW2uRy8PazZtzq5MDMBU56FDnw8TittHlzccCof467mufUSD8
FvrT+pOYGCPerA7xYOFsV26u7eBOyMzO07rtT8emY8ZxA0vZ8Dcfui+fx8TZ
kekt57wCoG1+fr11Nh2Nfby5WWDD16M/o28+CybKZDWdNTtRtVpcObKPjoKO
uGuWslxoH+FGzdrKgbhhnMKbfg5+NjoJjxM4+HrAxqyrIwCr5Hok3icykDxL
a29kGx3l6TdKEzUYML85/8dV3QBs3T5jcKkoACZeb0OkqxkoWulXQ4qio3j1
ozUHOnZi71f9p935AYhKiJ+z9xYDr0lDa1qfMGFCODcweY+BTyePJCp9pONR
hea2HSGBMH0fFXXfiYUu933BEaK5/n7yYTY1jImMxvTcg1n+aIzOiA+7w4C1
DP1W+7wASNlYbqn9j440ws+VeZosPJ2Xd9tCmQl9L4l8chYDPZIq14pOMZBW
+H7eyh1+eKqvv+hdJB2LCyxKj7ynI9OmlhEVzsAGh6+/zriyEFo/0fFRj45/
yX011o+YMFsY73Omh4GzuXzajGg/gY5//NlfTGRnGb9mn2XiHP6Z9+5jwdNJ
9uj+Kwx8vGou+bSAiQWbnBvsDzFR1VP7gSji4/qRKPme2SLeSf5d/0aSgdtn
6/w11PzB+85NEbsSgPEVzgGOoXR8qDp+Y5TBEK37Dv+15eFfjnVON4JRuN3F
VikvEL5eZQMRt5h4efSPnXquPyxTmSfqQ5noyZDNrxwXYOfMsYLgGh5m55Ue
kaexYeje+2xQn49Q6Zta3CtB2HVTI3RnAwef31osuxjNBuuye69iFAsGBXEl
h0V8SNTq8LmqxMWC/xMiIhjFLRFfvskFw/N8/o1jEwJ4jTQcfrBXAM5csvhn
kW41FbTzw4pEvLaOPdN5QIR7hnnBORoXUbs+Pw/UD8XNUw/UPRl8CB/nzdV5
xEFRuazHhBMHf0qJ260O8FHRnfXlvHIIwpZqzOt/ycBMdPTcc4EcZEjHxRRq
c+ErUUja58iBUarh7DeFQWA0MdRl7wsgsUQwqLqai+Wv0rY/TWZh7RvHrJzq
EBRsfSDBY4bgkDDdpHs/E83q1qvDh1lY8uqoZ6U+B1PFkvK0ei46nk675rKF
yHOafkI+FYQfk9dJEvZcTPgsF1SIfGXzcM7BhmuhEEvJV1dJDkV6crfOwzXB
+BtgnSf5mAv1mxU/NnmHYnew1fjxr0LI73UYKNHi4H12+Ud9DS6eNF/0IMcw
4HcsvfZPdSCOk1R3mVzgIKqguOWwFBdUrUZuT0MAmjYMSGWVslF2bT3r3mk+
blWPcRakBYGo6OSRWMfE1IZsdcksFk6vGSXHuwnhVrpn9/r7QtzqiUJMHh+r
m/4u+lIVjNHthkuiGnjQ1Wtw7fTkYyQ+a3StDBfdlvuaTs/i4DH77eO8Dg4i
NrIavu7m4YuMdFV4KQsW5Zpi71+x8ODrdYcFBRxsbTS/ed6NjTTzCJvMS8Ho
dtG+yXrCx5PYvo7Ytyy8bpXq6qrmYGwv7/w7+xA8k/SN3TJLdN7KP/cG87jo
1/5hlyDOh3mkvPSpAiEeMVflTj4LQkZrL3mqjIXBa+vpEaMsLL/RpvZzswBH
Qgm1wb+C0T9w7PJwDA+rl1uUBDRzITFxK7Q03h9pqouab6cw4dBxN7VuKBAH
3f+pkGfxoWQzSO2ncFAma7FycQIbYT4HUMLiIK+Ts1/Rk4um/PKrw9QwfFlO
ISjrChFkT1wo2MWHyljgszOngkH0Gr7Q08TBaQOy1R47DvY1zp7wHefhcm4P
nBfzsGYNo96jWLSfgH31LocLgbejU+0FPkzfKagojwShljA6kdYSCJ1XjxXH
eTy0Omz6NLJkF3rGz72duBIGHbMdDvnsYKhaDNfG1vMgYy+1yvEiG49lLLoO
7uBB/O7X/kKdEETMEx9hWwWhW7vi+69MNrK4OicOpPJB26ujPbKPj467w2uG
FLjgLlut2b+SjU2S4eouOmwcPDlP+qUkD/rpeTdoF7gYqHm/40FUMMyn4Fh3
R4Azd65cvVYegsdRUtGOskLkflqzyGxzIFbPf1+T1hgIQ4lKXa8pJlZLqehn
PRXhKHd/06VzQpzZ9MV/5xc+JuJqPBbNF+krcvLOcC0HLw52TRMMg/ErXVg8
LicE4VYt1cSYide7GM0J7RxUcIcw2MYF4fH31e7momf3gUr3H3xcbHaeLTAU
QiJv+EO7Hxdlu8yn99xni/z+afqxMCFmX331YMRWCEXuqvaXZUwoB92WWryA
jah5NCbZmIMuxV6XPjoPW9/M92clCnFOX44pHReM4cV5kyVPOFidsRjpH9h4
seTFm4d+oYg1qVVL6wxF3RP6p5x1AuitW/ejNJsL7/jH3x1KQqEvN3nhx+ZQ
WDL9LrXxRLln41udHc7FxnKz4wenGdjj3O0/pcOBrHfbSFwcBy2j7eIJQxxc
TGlSEdemw6budm+9aE503qbl2rf5SBILk5DtDoJg8VaffdYsVBecn8PaJcrl
55iVXClEd8Wqb2ZOoRhwI4u11gahRTtOfVaYAB7+dZ/dE3l49dXuUvEj0Zzt
2SbCZxxonZ49e77Ifw+9WbV32Voufp5t+qy0PQjfNVat23yNhaRvGslPM1ig
JB9u3i7y8WnN+8+3BbBReUnsJy1aAMLeeuUNLcFYVJW4NdOTjRvcz5vGxzjY
fJY3n9oVAscSW+OV8UHY8rIkL6WECyn5V8RuMh81tLjF764IIStc8tCQywe9
qkJspokFrvPxLeNn2egINLg9hxKCpKMxF7W2hCCAPeT2aJCHRaxjC6r0efhR
fdf+vyUBoB1/l3HIkok/dO9rmi4ifJPcmWEJfFB802dFenPgXUqobjjKhtnD
Uz93n+Ogao4sT7qPiy1B5/eoEsMw5jffb6RKiDfFPVobhkV+WHOTr2kggK3j
JWd7ARfMe19CAo5wIPVgtuZNTZFuBhxGJJfxcPjFIi3JaQ6yti5hVoxyEBsb
s8xOhGsnl6+i9F8wqud7l7bJcdB9Ym6rl04Qwijvol12h+N1mYtX3cYwCLa2
eD6oDsaB7PCWb0eCQPpHNjjhFYi/UQ42xxSCkBp31OtVTAjWJwZmpMzwUPPr
Y+PsETa6Vsnv2beOj0OX/e7Gv+LjgZOqdSyBi+oq0s69fmxQCtWTL+wJxECS
/ohMIw/zn320fi3Ow4bnChv3F/Gx00G/n+kYgkilRWK1SkLYvLcZaQgVYsUt
i8nxiUDEvNdtcc8PROHh/nDBHyZWmWnV/1HigPf52N1zHkI4Hd+du4nPx+kp
80f6rzigXr+upSPyfWJK3IuCRcEo+CSelDFXiLoA4iEpQyaCH+qqOZwW5aDK
SHlOIxcHNjaXG9QGYmthXXtrTzC4XTmlpSwh2h6YlGzbzYVN83H1d66BuBRA
+mx1WojmN+tkz24Qzee29P6NDUwsehVpxxL10NmuWx9YiXL6aopmY/sRHu4+
L98s3S7EKRrt5PdkASY6Zb+fiuIg+HqFu/q5QLTPJEf8JoXi2NumAzHVoTiT
khC0olCA6nbjhNBsDiLLNoR4toVCVjGe2EkJhV/GFG+OFwd/S7w9XqvysPuF
vFiUOhMDf6x9EnZwcJ4ybPvyMgezarM+3P3OQaKUks9mTTooOw2Xrb0g0sFE
J99IjY/u8dqTqwz5yA4qbHzGYOHKWWN3a5dArMmxOzqqFIr+BcyQl0GhqOlX
XblthI/Xf//7qzUqwMHBI7/OnOZh4Uy1x5lyPuwXJ+nLiXKV8T5Fcv4JHs7o
WNUbredCcdGkjm1cELIYPzn+uSwUpqaf1vNmQW7LyoexK7hIiadWTfqz4ceq
W2CqGoKT6048ljQSIF/BUVdPdM4Yudxdv/tEcyTIT3euEOHXMXQpfUsQ3N+8
/Euv5MK/tfxIZVIQjmsGyUiJ5v9l2ZsQ77EgFHIVXznJsWHrPVhoN8gGg9rr
HJwRgvsC32XpbiEwfFSuIlnLg6BeuWKhSK8/W9exsuwDANtIT/pHBkr+fSvc
upsD06zClUOr+eC82UhpEPmjCbtym7uIxw+7Hp98F8PBx7DbH7NJIvxv/n3R
+zsUuZW+ab6TQlTemyttrhUM1g7GrPprwaD8PVi7TnR/SrKROWRtwUXE1OLp
JYeCMKvUWPGNDQ/P+GYnX/WIcqXyUVd0oui7zXkS8fLB+Oi/QCX6qAC+znbT
gRYczMjHXh6cG4SVg3XRfXlhSBXzTdCuD8UFhulzzYlgTFRoP5fqEPlj0Mmv
C84HIvlkldyEqD8NlPkdWXlJEw1ePovcl2jCN3DQXs+EiPfR7jTxO3oYKS+b
jFCXBe1ccfXyUWUIZ8cRe+tUoTNg0LNJQwV9o65+xV90UTRvCUMrWwdtyasy
Vp43hvrMxzVlUvrYbaZ7ZE2TCUqPmkZz7AnIT7WyniIQMS9XZhvjjS6IE/Et
4af0kat75ZRMpCYc70bcwx5FdJ+8vdSyQgumRzcORX8jIiqqWDimRIQNt6V5
byYR1AyHHz6VRmifa5NrtcAQ3mMb6xdeIeCGVEzS71kGICuf150tpYeoltLU
i726YKs4hUlvMsSamr2/W3U08DFtcg+XLI/C222KLxQNRffUJrtJA0Oo1pil
bmzRgqPp7rhkpxUAZan7DTUjfFzjTU9I0EW+3diuKTNtHJ2ql21ZrQk176Mx
4bJEhH//FGQlRQSbuXSi6AwB+48WflPTMUTYjp5j4cqGeBb3LNYkUwsB5F8R
d29ScEbimL+XohEM7ce9T3ua4Kat3dCfBSZoeZXj8iBLF4H7z21y4+nCvWvI
oPG9MXJdtx0Q8zOBP5Xi1HzWAKGvmz6Pv9XCyPO3L0h9RHjqToVICU3gEh9/
+9s9XRgNx1x/7GmA8biI6JH9BhjOk1z4JZoA9V3WNer1JGxTGZpdc9MU1Vov
zj8eEZ3vQZzFjU59rJ0unZ00aYSqbeSdRb7G6NnW5KpbrAulPRpyUZr6EGxU
Ee/gLUUiFvO/0VVhqyN7XHG2NqanYk9ka2uhz21ynsRJEmZVXLvSLyTibff2
/mV9OsivpyU9XKAJjQVllS50BSjixQQlYwUS0n0W3x/QhmROjdt6aX3YLZUP
sSSoQTxaV8JWSwsF2+R4vL3qUPo37ykrXMSzM6cv8QUmqN0R2ZIrOh9J8L5o
XawxKi79QfMKAt4X3XyxVaCD7uGH3eq/NZFo3RpmH6iMd5JGam91NXCr9Vrx
pjRdzFnb7LDZUAvPt9ACXi4kIuyZmOb4A2NknlUwZ0sbo6alyfHCKkP0vtdp
WLRTB75f1Nax72hjRtbt6dyn+hg4lOGadcIAid9yO97EEsEZMctTvKIP5zWB
/q4VGvj53Mfro6kmzjaqpnhdIWHP0iIlDW8itq8oHUldQUR5n+SynDoDLD1p
4ZMyRYB28KGxV9NmyFGjDW+VNMKyR9viZOcYIEPd7B3tsSnuin/KvMI3womv
aQ33Puji+69uK6d0Y8i1v55Y94sMmSbPRY0NFHTPut6d6aSJpP3xq2rrtHBd
74nHK6EWnMKltTpKNFGXfXFm0RYjVBSd1DP+Ywpxn877n+QoSNGeKL7TQUF1
ZyPj3ywKBBHIndlLAe3IYN7WPgp8SOmmkwRTbPr9U1nvJRHLnCOXtUsZYKbC
LzR3pQlUNiY9uBJOhHKi3X8dHhZwry+KHPtJgcHsLfnPpCkoDPuzz285DZt3
aTlbRNKg9NmCc4BOwR7DG1muVAPkN+REGB8jYrdwZe/yDTQcdtG8J7WXCv3t
wpLh3dpoz/GuagjTQFqZvdBtvzE04t50nfKmoNHz19iSY4aYmKawmRYEVPn/
Qct3KshkAw36O5EufP2+LNtHwsanVeu6X5oiMK59r72bNfY9TZFknqZh0pC8
q/4tFSuCwn/cHaQg/FhN9GaRfw36pDR+WE3APrPHOU73VkJMNkzwaJQG1dl7
TvJXWsDxs4HkohQzdA40ZUcGEOGuXchu1iQi10Mi7VgBEYtehnZRuGSsMfrL
6P5HxPnUt89kM40hjQ0KqT9pmJJ1fBGmTUPwRk/Wtx4Str5U93EdIUJ28tHp
1lYqDMqbUuSuUhEj2xdYbGiFF5k+diN5NBjbvKruk6GBUXLGUviLAru7gjtL
Byg4/m+10i4/M5jV3lsio0DBhl1V8/jJZNRLu4fl1K7AR1UdE/KQNi6E1Jm6
qhNwrfr4flw3wEO5tgOyay1x/2N/h1osDUE/XJe/DyPiVaxyyU8LY2RfkG/b
9EUbLw/9usF9o4/nuk5eQxlEJBVcuDe6jIwh1+ANuQnG4NBaGX61JmibmZLt
0dbDf1e3/fO9bojaFS33f4ubw9HY0PzSdTNIP9gXaZdCRW2AkswtCgUKpSfX
6zaboDBj9Dsh3wDWy51KF5J0EHND+us8NWOoJjSv7VU3xdWt4v3dTQRIUE5T
zc5b4eyB6g8XK8xwqGCd25J4Ejbp0oMj5lLRc1yqetiIBDW9K2UHEokIOiJx
J/wGCU72zGskNTLipIK8SN+toG17zYAXSAbJuGbptUV6oG5u+z2ebQD9N4Jr
XwctYXtYyyM/zRz7Mm0ohWdpaKVcTu3RJKP/r3PG+RQrGP1sE5jutxbN711m
mgQZF6tHDu4bI8P5inLGAoIleKfKWyLTzfCVq6qtFaOHoNpEo2gjEyity+uR
FqdgkWFyt0sPBf1nXR5dGdDEJf0dt6dOaaGUJWEcPa6FN3YbzR3ytBFeF5Bo
US7SfUineFY0EfxVg1HflUW6kf0v4c4QFedGnyYEF5DhPytuNFVAhThx+tcd
LSq2/uvQ0bEhYS2PHbLCgQSX691tI2L6eJE1sc192ATqc5uc9OVJUFHccpE2
bYFAOcNLHaL3227M5SZvoGItUbm8V8RPg1DJ9Z8/0OAskL/yrI6K5J+nqipH
9CGvV6jXTyBhca/ODgkCDX2nsvz3W5lhw4fWyeJ32lhRZq6iwNTEsXAZCvWn
Ce6/DE8JiaRgjp5UgoKcEcLHxlzvUAwhe5h63e+bGYJ0FVySBkmwZFOdKUZk
VA4rW6u3iPRrXG6RvM4S7hZf2hpum8Mj+Xuo0ygFIZP/PC46UOE/qUMtsjLG
hgWnhzZXE7CxY/eeMpOVoCk9X9psZo4VF9S+H71lgXLWyLDKOnO8KzTLq3hC
hLX2kAvdlgivlY89574mguLRV7lRkgLNBq6uowsJEoapr0NGTeB4gbMzpYiG
ZbMvE7r0zeHV4bFBS6RrY9rVx40hJOz/Te/+MGwGT3erlzf+UaGroqi3gm4F
h618jvQec/j4Gs9kkWn43jNIzrxMheKOTPrPfVSo6eSkrAyhIULjISHvAAXF
kx8SPmtQ4FHJplD0NMFVsG2Yo6yLhdNfVp9+KsoHt+/OiwMIOMx4kVU/bIn/
Zs5l5liZQ9k37URqKxGdCe/l/6wwQYntcHCxgy7Sl/z2iXxEwNvMLi9/OxKe
8DdkKP8igcA4beb3zhhbBkp9O+eb4q/zHFr7Oz1c/TQeFadlhKhS/Q0+bHPU
aY1+c11Fw5KyqCjpC1T8yOqyHlKiYm5ig1tIlymc2Pmpu0X9ZsCHm9n7QAcX
JLcwv+0yxiK9fYSxSFN0JaUtdTAW9cCvguPSytZoL3+3i5NgjmCH0LpP/SQw
FCv7bR9Rkfn0dmShLBksInfJb5H/X7xktGuBDRlzq5IvfDlKgaVa1hdVcWtk
GZ29UalCwa+hR7mafXqgyc7LaSEQUCPjOJMqZgXVoCVhZXUWqFqowV8/QYM9
m9i9ZBcZ2QVHHzi8tEJR7imNOf1W2Oh3fV2LBxmXN/+5fzOVitDbOzdby1ti
sM13mL7QHLEB9vUuIp1wr86Lzl0pyjt6XpiARsHZNcbny8IoSOjp2542o4l/
W8Jp9tu0MNy7YUEwURs7SjU3K5N10RnRqSwr4qP88mdbWruIeJakSaKri/h6
/raXnaoZ4t+bfaswoOBf5aNzHSKdPZV3HReUUcFOzNL0tCTj3t+o65qRJISE
Bhm/WaULq7K7VRX2RLC0syyGokmQ0VMPjaJZojHo5MnX16g4UZbV/e80FXJj
aibMVyI/pCXuM4syh9ut7GTZDWZY7X+J998KA9zuLLbyrBXx+m7R83Z1Gn6r
3g6z9THDh5stTwaVdHBjOExdOKkN4dJFXTLrTeFaoVz1bxUF+t4n4h1FPr79
nPOqO45G2P/o4MfXsjR0Vf8pyOaQcWVa1seilYwn7YPDe/pIIFfrXv/maoVQ
UvdbRR9LRIiX5j8wp4Ly2/Wfs8iv+s2ifpEpxjgRpXZgupSAGAU54n0Da9y8
e1SMVkwDZY3ngekiC+yILXUk77QAQ3xIX1+chG/7i7iEOlOs77GoIo4T4dob
cNzphqjvlHT4I4aEhJdfLhYbEyE463KPttQCk9LzVrf1m0P6udzaojNkMKf5
N6tEvZez5J2615gZiGIKuqkRZtDQMJZ+/NUKMl7LJY3+mUMt3rnnepUZut0n
1HrdqOh61Vi0tpGKPeKqfnOGzTEnOEb7zzYKKouIj1fmUaBilONbGqyJuTJt
v0jndTEaYRs8tMQQnVfeVbm8JWBkquGTg50V5maMKkc4miNM8uGttxIkuAWc
6G7rM8Eni8FpoVAXA+1shlq4ISR0ZWpKvYj4bVwxvvg7Cap+y8Q/kExR82uB
noaLKQ7/trq6V1IfO7vfbtF4YISmBc7Zq0X/GWtxgtvcSQPJ+VvLfBGfZskM
NkWWUGG/Lq/6F1Okx9B7a66pGiE/018j9q0OCEfWZrQ0GEPW0bhpUtQDS7zT
Z92jmOAAts8K+ifyr3Plbt82WaDHont1wDAJ5Va33CxFOPTwvDMcHchYfiHl
Li2FCHiu/ZLtSYYB8YdmgqivfJDUvKAQaQV65jJqgw8FnZfvR+pq6UPcX5Zy
8CwBcwSu2oHTlrBJTy3muVhCzubOTV87c+zdLGWaTycjxNH8VIm8Na67ZQjO
nbLCgtGiCk4sGXX7IxTuLTTDHU5yjN2YJdoVI56vf2GO/wH2HtKN
            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 2 PCA vars 1 -5\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3", ",", "0.9219909464240725`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3k0lG8bFiUtKlRUsu/rbMZaJIRQlAgJs5hhZgwhqaQUSlpIK0pIWhUp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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 3 PCA vars 1 -5\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4", ",", "0.9334843654461809`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c4lf8bx0VKoTJaCNnjHM62GsoImU1RHM5xhnmoJIWi0PBVURokISmV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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 4 PCA vars 1 -5\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5", ",", "0.940834097518711`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k4VP8fxUVEpUIbyb4zzGasSShRWSolIsw+zJhRCUmiEC22UgkJlS9a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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 5 PCA vars 1 -5\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "6", ",", "0.9175420004880886`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k8lN0bxkWhokKUJfu+zmYwlLUshVRKSJjFzGAMQiQqirc9Um/WRIuo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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 6 PCA vars 1 -5\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "1", ",", "0.8052951854535555`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl2k4VW8bxQ0llQZDSinzPJ3RlDImKWOmKNMZnNlBJBWhoqSRilChJCpR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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 1 PCA vars 1 -6\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "2", ",", "0.8598850733542011`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k0VP8bx5OUioRURPZ9m81YS6FNIVFkNzPGzJhhJCKSsqRFKkkJJSSF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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 2 PCA vars 1 -6\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "3", ",", "0.9421450121752208`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3k0lVsfFpGSCkVJ5nk8ozmUIUlJkSJynPk456BSUmkgU2kkKkNCEhro
SkmeorguSRSl0IRCVDKk4Xu/v9619trvXmv/nnFrhYRtYEtKSEh0zpCQ+P/X
KjhX8+E4C5v7Jgwi2Uyca3o4EBvIhKvgopwalYH1W10aXeexQPdZa+7yjInh
Z/G1iiw2UudSO3zU2WBtjYhoL94GU8VXqu8jtkF07qHNkhwG+D/3zdcNZWDl
1yWOUkFMWL+ujNC5zUbJMs3vrzuYWOxEmbljbgg0S/dG9lQx8Ipll/toOBga
CWoV7kkMyPxJqg5NZ6CcHxA73MeBws4ZgzXrWJiePiY3K5GN3ykdVx5Ms+Dz
bdo94FwIpJ3DTo27hGCyLM9gaRgTu/de3zl7HhPM6IeKJ8LYuFu7ys9Wkg23
ZQ+zwjksLN+Qd5ypwkInraD4cwAf7c1lf+qXctHq39oX9TsYrU7GBW4XguHl
MWH0e5jYv6nPvv1JCGaaBrWeTmWCG+OzWcafi4deak4HJkJAZasUbrdiYUWn
0abmSS4ufhG37prNw8p16/JqUoh7aFhsKLkcggXPR5Y9jedCc+kD94+zuAia
F2zZd4yFp4qXissTmUjvzstbMbANhlePtbaAgTXxZgn9CznIyJVI7jNnIX14
an2GPwNurNU3XzUEo/mdYHY2OBhbkOrCcuDCXJWirue0Dfln2quMb25FYWdC
sY0CH2nUXFdXZy4kTRKUX/bxYLUrqXLQiIsv+xzp3Z0M+L+OtDt5lIGUGTp7
op6HoD0qIpiuFAKrG3I/ruoz8OJindzplQyY+3eFydYwEZ7Tom2kzcB1h1qn
fZ3bMNix5uBxAveY5MRZe24yYeoKLTaPDXPjjP6JO0wMHjivvsafidp72hu3
hHGx6kx+XPElDro3RYt2fWXhikGG9yGCd5nN5/L2ZwejTO6wW17yNtjJh9zs
mMPAVIpILVCBgVTjcft8bTYK637ciCtkwtBfqoCSzUT5v5ttlWyYSC16M8d+
SxAabwgXx6tuw4JC6/LDb0Lga2s7EvUoGKvcv/w8682G99/FPaPNTPxNeffA
rpaFgHP5uyavMpCeJ7ScJs7bP2LgcmopCznZZi846SxQXf7R+lrHxGZPhSN7
rzAhVq3y0ClkYe6atU0uB1iYL9gUuYrPhNtwzKJeGWI+QokP/eMhuJXeEKyp
HoysHX8c0pOC8U1rLcMjIgTnj17Wq/3EwPv70Yf+rBAghicbz/AVosjXa8WS
fC4YFz7/sN7AwbMjv5018oLR7taw9+36YPRmKhRUfxPDVe6QypbeUMjklx9e
ZMnBcEt13NsqLiJkb+jwr4Ti9sU7d9USQvG5y3rxxYMc3JZSqxGc5MKoMKHs
EMEHF8PvnotecDH3/4TYJUJt+5Z1Ex+F2Hy+4Fr8mBiBe0lqIoEYvNkUyc8N
HLy59etrMJ0Lll3c2Vf7WLjd4qSuMsBCzM7PjVzDCPh4ZMg1twgRXpc/W6+W
h/rX1w1nM3j4XU7ytd0nxMRh5x/rjETYvlBzTh/hI0nqreNXg7nIlE2ILdLl
ozfRqdjjMA+mZ0xkXhaFQnho0OG0rhhSSuIBNQc+LrevPvpTjtDTS4/s3Jow
vFAW1ZKdw3Ag/Jx5z14Wkmrr8idjWVBqO7K52pAH56SXnlZLeOisn/LO44Qj
afmoTvJhMX5MlJKlXPiI7mafbzTmY91Q7v6m4gg8iOStt1gSgXMpPXoPnUR4
drCUO+0WCo0b936sCYiAanNNtnV7OBbtce8v0+FBVzBnrFKdh0dPL/pRYpko
OHhypm4JG8fJajvNL/AwOE9Ftq6CB5pOM7+3iYEu1TOrjQjeVhS7se+kCaG+
Pm211pAQJBVPv6MNLGRcj5WqWs1EmtMIJdEnHBcXXUpb9CIcN3tjEJtP8EIm
wyNqUIgRXxOlmCYBtnwIfqOlJsBwYvbISnk+9OdGeyUN81DH6arL7+Rhg+Mn
lReyfAzKy97fUc5Gk7LDhYx0Nqq+lLrPLeRB0+Gr+UgVD6lWuxyzLonAOSU/
902DCI/i3nXGdbHR2a6Qtiidh697BOdfu4ThQ9y+5XSuCKTq33cG8vl4r1hm
xtojgFXUItlTheF4Pywfb7tCjMz2t5TJCjZuJlfe/7GZhWXXnquPrxPjdoGV
4PAfIfr64y8PxQrwLXKOZW6pAFJjNyPKE4Px37y1eje4IXDvvH2m4RMXj99p
ty59xcUSxwFaH5UHSt/LFxfXcrB96z6UsXmQedd7b+gKF08KKq8O0bZDWufW
rDerIhDqQpon3ilEHquUmdZAzNd/6ELvEx5u9UvqcTx5iG6WGQv8JkDQcEuT
oxUfTk7M//yu86Cet+tsoJ8A4gAPz8cXhFDV8Nr4kSbEY+ORsdRWLjqlx+Va
KTy0u6/5OKy0ExGk3MW6PTugR9/iXsARgXnRen+JbCjkXaSXe1zkwDdDoq1j
PweSt7/0FemFQU+2vzd0phA9uve+/8ziYDCwWtWpngfLPXq6w9FCxHQwN4+Y
CMFf7KDdZ0/44oMTNue/cLD/5BzZZzMFmM/1ul2xn4/+B2+2VMWIUB2cJrwy
S4yz/1y5WlwZhsrOuEr5oTDkfXSaT1/Hhcadsu5DLlyYSFXr+0+yUJHttiOW
0GuF4t01lzLCMa288epbexHGEh74zZfjI67rIMvnLA8t+7unjE1EMMKZvYkZ
YhjffEwzN2PhYU7jdGUzF/f4nzDwnI/vLu/T7s7n4d6m/upNP4T4oOSkWZsS
Bqn8ofcdQXw8Zs5/UyfDJ/y+/lz89nBYUYY/jqmHQ4W/vONZBQtkL01Wwijh
H3MsWRQzHg6Ws3zNHhG8fSkXzD4aDvJ5VwcqPRxDC/Inyoj1p9d8Ajtn89Gi
1PLyYVAEFO9nl9z/HIGGRyEfc13FKPwbUPjeUoSAxLrv7mURKKvL3HRIGAEb
VtCl5wIeNg51RLsX8bC6kn58/xQTdxdGrO4aYEMh4PlwQgKx7vurZz+h24un
nyyV1A3BVZdzJUaqbIQI1izTvSVES5dKhWeXCOIFG7ZG27FBik9W3jXERHAj
ZqRUh8N0ju/+JpsI9PtQJNofh2JPQfxXlSgR/IIbPm86KsD53t1HF9wWoNOF
Yx7+Lw/FpmkT3S94OPBy+Z7FK/nwrMlG/SwBvmsud11XTOiHM+lQsY0Dasqh
p75NPIzUT8w7q8VH9SWJccuDBC4+5jvrYsMw//7RDVmbOSifYNttIHx9XbpA
jtYdhsvc+MvsURHWPyvLP13Gh4XCTvnyKQEeWCYseH0lHGnsqUvB02KE3L8n
Mf2EuOfSxQ/3GxO65xrdmkUNw7OZi+f5W4nB4HzyqR0Q4O2eH7lo5eNHzW2X
JCUGPM0+SCbVh+B3SECxthcPx6teCF618kANPDcjKoCHYz2qDtmhHNAfnhqP
zCB0t5X2TwGTh/Wh53erkbYj4l8jxcZfEXh5vVdnFeGDj2OeH3YKEGGFx6W1
LmI+NhA55drDhXSVjPYN7VBc0G3vOF7Nx6GW+Tozp3jI+Wf9XokKAeLiYhc7
1woxadKRLU3ookYuoPy5Ig/bdPwneSQ+tlNfH/SK3AG/oC1XeAo7Id7Qurmq
RoTnkwyL5IuhIP+lGJ0gepzklYw2LQceziQc8W8j5hr3uVYrZZkQD35+aJYZ
5iCdu/WR3T0Cr8tBtxPbCD5Ey9ANFwhRc5+8bU8Qkb/Dv5pZNA76jxkOyzcL
0NHae2fwLR+rGpVX7y0RYtrx0MqhSBGilsyXeLwkHGMGducNfMOhddN64tsY
F1t6DC79IXK/6FDfDvFvok/UjavLEboVfI6/neEXDskk/wxxlhBpk1a1hm08
8AI1rx8hdEE6ndBSOF+EaMPXTRuNw9DAIB2QNmHBKrHLxbmHg8mlw5W5zXww
VyZ6u6hysaGooaO9V4TK3VVVGtLheF5lXrYxksB19Bv7BcGfSwzyZ9u0cPyc
PhaY6RyOl7dk965uYuGCvvekqicbMt4bqmw9eMh7Pbi7gODj7cbKdbId4RCZ
m72Z+YC41yuF76dieGiclyzOSuahYzpl1y9yBHaYLD64a/12nD2dHKpVJIZp
4YmlIdeJeVSsCtv8PAKurf6Cs44RCMqcFMzy58FWe/xouT4fkS2LJGI0WEg4
7CcvFcTGeerQimeXCb1a2G3Ne8fDUeklW9dpE/1Ozi78bAoL18ZeCU3VhZBq
TJW0yRQhJ7So+V8mG8wyVhXzHgtOuc5HRoict9s6Vte9hsj9PjX7jcNC5Oq7
irbLiLF/4PDPs2kCWJQvXOawNxQuC44ZKs7g4cOaGcN+Enyc1bP9z9SND9XA
m2fk1giQzRznBeexoen5nmJ/hwvF9fYP44i5HJSpmdYh/C+I3TDXQi0Mc/zM
nz2qD0OBsoe+wQUOGLMUrioTPKYZL5p6pUX0ir9FLKPtImx6+exPCMHztEfF
m1ufCHBcO1RemsB/wTz7kzOkxSjiq7R5KnLwgXIi6IkcB0za27WizDDU/j3h
cH+hGCa1lUtnPhaAY2f/x/caD+PtruxsFwZmna969q8EE2V/R4s2RBJ6Xfrg
/Cfi3cN7uZraRPijqWO5jNwEGw+7606+juXhS5RSUsw0F5E3/rS8JXR6YtXL
nOpXEai+M1vWSkeEtxEDrG6hCNQ/+x+7EueYrhaYcJq42DW5YErpQCh4U+lH
5W35+FdIP9nWy0NBw69Xsd2EDz3Nl0pcJIJh8iJN33ERAtc6T3GteRg1+vng
IdFj7AcaDr7L3w6vC/G9vJM7cIFp0ag9RvSTN5QFfY5CfA89+WXueS7m7aVP
5jgSeVgRdNj+kjbONd6TbK3QRCB3wMXAnIR0pc+h6QuNMVxZMbFLQwHKg+YB
ZYnyCJdJIL1tUENKvzTDx3Qp3o14B10f1Ed9nFpU8ksDPE9Znml/3gw5qcHs
4nF9RNL1Dzs9MYeV+59tO76YouCMrd2kMQkDfTeirXjGII0ltu44ZYjrm97W
SCkYwOP2rjvYrYIDlVOicyRtWBxZ/engKAm7fQtKvSJIcOS3Pt2TRcIvDWpM
c7UhOmY75tnONYH4dlFSLsMI16Rjj/2aYQSXir6dr+oMEdNafubiW33wIx9E
BIiN4fRgz692PU3oBH6JvntMC0W3nqu0qJjALfPxuPcGU6g9oJ9Z3aoDKcf+
b0IXLYC6cNM1dVNsuL5c+fQRExQ4f905SdfFzJufVL3aNaEecCR2hwIJdYPS
f4+bUcBhLRwrOWsMEw/nC2fLjLB9S2/8DlUTCGedVrWyMQCD8nPX7RtUHFoQ
e/6JFLHP5VtA2mZiPsvcfysaW6C1LderKlsf5/flbZExMsCm7k9GzW/MMBIp
/7qRY4ZgGtXzaboR4nUaT4kKDTHc2NVCfkcCyU/QUmtKgVdi4q3RO/ooTojX
3uSvh28Juw4O7zXCs2xE3uoygsZOuwca/5GRZKQUu/AXGTU6Lefrhk3AnK/6
5cl9I6ycKpc5NmGKuyEfJC2NTNG78Ym3/nV9vImrvOW+whDi1UslOwULcSYj
wLRMTwMr9BSOq8joQoUt+G8qTQ/vfCbmSJ0kY+DcqPaUMwVdPb59i9/pgatt
dUq1VweacyuqvUKUoal8y3rlTV0kn9u64G6/LuY3v/xoRdWD88JFYTbG6ojl
yOcwvA1QuFFRINijgTFS5Lm6IEOUnE27JBSbwzsza/7lTWYgi9+UuMaZoSF3
9YGtaSZ4U3KjZYNYDz41c5Xf9enjqF37dheuKvw/PDOnKy/Fzfbi62tS9XFF
7veNqyd10bjekvFsHgnrqayp947myEpXtuLImuFmP0VoamSEt2/0muZv0wPj
iD3X/Z0OphV86mfXG8JAmCEZRDbC0dG8zpdxJJz57NvmbmGOtU7cYO97mlhq
+mlmjlgL6c1qp/2vkHH82bHw3YfJ8NUqHz6jRQJF09/8iKUZFp603np60pjQ
Dy/vQzcVueqWQxtmmqLrojE5Z9IImRr015Z1FrB0UXs0RjfDiS+pTXfe62P6
5/7a4rnGUOx4Meb6k4Lpa/WPelZT0TOjtCfLUxuRM9J35xdqotTgkV9buA5C
VTr7ciN00JBzcXr+elMwruUv0RsxheTWV3c/KlKBYu1/sj1pqHnVzPw7gwrR
l9TPz67TYHl4IH/DOyqUegzCMlZSsebXuKrBMxJWpVrcbzKzwPS9oIg8e3OI
HLLvuvmZQfWoc1KnnzVuHk9YrTpGg5HM+oJ/ZakIua24rsKTinU7ddZaR1ki
6e9diTeFVOw2uZbtTTOCKX9p5iYCx8hw+7fLVlniqkXcrn4LOgx9w8uGInUx
e+1A+tvtekitcAn32WuGPvvkGU5LaGje/POrUrwJvgWGxs5cZ4T7wb/R+p0G
W61SqZhNNGwODBpcHE2G/j+kbkq0BbgJHXtcfOyQc9iJ9uK+DSZMKDv/66Kh
t23ITnsNDTviHxxcR/hXaNwKHsXNHNH0ulzPO/ZgP79apHzIGmoyu08K7a1x
YoGKw3uWFV71P8mJYpBgu/ycdL0JCXl+UqnxhSTIXQrKFTeQ4WT6h9nzl/C7
m0Z2VS4UyGKV8plxS9SXHTwQzreCaPVm9mgvGUdSX7BXhpKgMFGb1t5OQ4Kf
QObxMBWxCu+4101sifforcObNtrAzLGt5p28JV4unv3Z14sG59vifxb2U3Hl
jdUDuz9U0B/fUZJXpmKs7lt27CAF/8lu2p77WAtNaUbtzXJ6uBDWYOGtYYxS
27i65DlmeKj4fJ/CShu4ZdtwZmbbIPSH97I320kodz4RQbazQM6FRc/XDOpi
hYOlW0y0ARr1Pf0/ZZLg0S+ROu5Axidv0aq8ZDOsmXq+/WAsCc+nJxV6dQ3Q
2t2WyjMzwmOt1ru/JK0wacBVuPPeCrJV0VHOp2n4qGJae3YjDcrlJ930n5rj
b0v0h+gZFrBb5lk+j6yH9bmcfa8rjaCW/HTlWw0LWDnWfzqaYwEpahqNft4W
3SERMtE8GxwodPVRSiTjherAzAYOBb3HpWuGTMmwHmPdmvOLhNDDUv/suEbG
jWf7hv4uJyNBOtSf/N0WUT5K6mPTViCbPVhYPN8A7N7prsXxhjB8KS7+MkDM
OdQns63XBtFZjtSidIKv5HMVpZdp6PuzNvP8aVv03dtqqhJoR+D3OitVigKf
/Xtn5DaSsfaKauZcYxtILw3h8CSs8YWvpqsTa4BqhUblGXHGWOKa3ysrScWE
4WfTjnwq+tK9aq/0a+NsIv/z1iQtlLOlzA5+08Ex9WAb0gZd7GhgHLWuNEWE
8d+qoh9mEC4fiPmuSoVtcJiexSANGSP1yaJCCpLEeirRYjokSVM//9GhIS1X
QGUuoGOlgBOm5U6G8GFVLWubBVqyxzZuGjLH8awPTf5K5liqsv6i5ZQ1znR9
L5AmdPf82mx+yioa6ltLbglPU2EUMdPt83tLNC7mn5kdQ0fK+Kn71cNErt7a
2TFVaIoFb/W2SBlbQnvDI++JDjpWvW+fuP5aF13kf+vDlPUQv0OeShs3R8i2
sukfC2iYZSCdrKxoivXzpN2NIo2hcIhWGjRKnMsSO3gW0GHDoa2lEjlWs7K6
J8uejM1mldYprjbouBL+c3zaFn4p3yM8Rwi+9x9/+v0YDcETerQSWzNMp1mU
lFWbYXVn5O4Kc3sMSEo86Y+0gdYF9e9HblrjSqZUyjFzG7wuouffe0TCq7u1
nvNLSfC3r9s8+wUJ2t/0ly7pI0O7ia/v4UWGnm4mf58PBR4XeNtOl1jiY8XO
772/reDf6bdKh09BjFDfYqKajL2/QnreD9Gh22ZaPKpDh/5SFQOtEFs06Cj1
mEfYYmug2XQ2xZLo6d8YtsfpUNmSFTIeTQMj6foX1go6dmk+NM7fR0V66tmn
R09S4VfNoVINtPGf6fcxr3kGmDc16JBWb4y2jBFpO00LHGK2ZP83ZAO7cpUb
U+O2RI9OPXGmnQSpd4tkZm8joWzFkOi6uz5qPNY4Lk41QFdWt3+wMxnzVTIk
p26RYcxMowe9NsMMt7ZSfhsJf9bOsux4bYBj4wcPBowRuJYbrtrKscL+nHM9
QVo2UKqIiZG9QMNTcvSZG200zD7a5BPWbQEHr6bRe8dJ6N/Kz3pbpYcg9/2D
TnVGmG8Qbfw1ygImnLXxHvdI0PgiPi6raofRwEcBp3wJvbhHNHwk5py2QMLW
9zUFWfW3oooUKCjhXM4ZzSXj4iXTnXMdKRB3Xdxk9p0CG/XsQTVJO6iobJTS
tLPBz0+1edrvDBCZFNRx56YxHsh7TJ+RsMX2VVsOez+xxf15mkK3MUts6Fkg
aomnI6fwSJX7M1usEGTaN0zaYXVQqWurHwXr2qRaPC9SEXFr2zq7RTbovRt1
zeuYDeIYLv95SRgi4vMq76BZJlgTkr9dbEmFjIbc6SwNGpJ73/mmTmtjWdHO
rcVMbQy9XTVXRNKF/Y2jp4wI3r/a9UpVgeCjyoWDjDvDFvj3mDY5RIOK+0Gf
up0e05D4hj56z4jI0ZG6nw/D6Khf5P1NXEHDP16nnIOu0HHnT0ypdhQZ/MZO
2esB5rCtuH3/ngsJo9TnySFXzCFvoBERY2kDL6/fs+aoW+FERXbP3zQaVF+U
5Dnp03DA8mg0PcYKOzoEX51u0OEQfEmQpGUEvfgvxss1zSB1u6SxQ8MSztVn
I+KcLPH+RuujgSV6KO6I93oSqIfwhfO75d0sMPu6IPVbOBWGAScSPUpNEJz+
xz0g3Rh7a/d/eKFgCY1kZtJOL0tcmVLYat1OwUFv/6CjTAooNfqlo962aJqm
ZtjW2WGXZHlBlRWh+49vvj0cJfyOHvOTQjUDx3tebt4rU8QqK5LuGtkh86cJ
tbTFGlSnzfumSqxhvcOfv07FFkzJT4aGkmSIp/+6vDxEgluv9X3SNyJvl/lU
li2hoKesMxixZATdn7qqTvi8ON3rjuVCa9irHGOOeFpDtlFxZclZIge/l7oW
36CAp/Raw/8rHacag2+PtNKhqWkmW/fFFt9Ghr+PL7CDeuLa3tL7dIwVvDnL
6KKju625ZGUzDceL+FEKZEvMEsXq/t5Ixd5NnyhOblSi5+UGlou0cSJJ4rrv
E0OM7Foh+qRkAq1TKS9S+CQMTzZ9dHe2Re/VPKfdBP+2z3x4s0uKjEPs1P0f
r5Lw0XpgKjxcH7vjz1RmFBtCSl/+Qbk/CdVuyUGKRK6oBS2WfE+2wDyvGtOX
i4n/ftle3TPTELv6lznGXDTCk7lrcxz6rHB5TcfknGlrkNeOtsoRfIqWSxbM
3EiHi2t+zU+WBVLs07dkSZBRkBWsGdelh8ncFMvLxPtEwcPsycRvC+hd6tuy
+y0J++A7I/SvLdRuNrTNVrNDr3WPA2OIDKuzV2bElxL5KgjI9HCnID3p4umM
2WRg88rBnM0UVKRXf1ZXo+H9TO0LylG2sI/Ym6dabI1Xl+9G6esYoiWhjK9Z
ZoJZYm9d7pQNljbl5WXZ2kHR8Z8bgc5WqA9X+9psTEeYh9WpskV2KL78YveX
lfaYO1JyjxdHgerg46GgVkInvJRY56+Ej99LjN3daIP/AU2D1ME=
            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 3 PCA vars 1 -6\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "4", ",", "0.9235455708432486`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3k81G8XVUoqeyiyL2NnVnsphEQlKlFiFmYwY6yhUiKUtChJlhIloYUS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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 4 PCA vars 1 -6\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "5", ",", "0.9382224868143223`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl2kglG8bxUVKpUTRQvZ9nc0YS6UQKUsr2ZkxZoYZQ5JUFEql/BXSghaE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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 5 PCA vars 1 -6\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "6", ",", "0.9291054430029922`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c81P8fN0oyMopk7z1umw1RoVKKiLLujjvccVYapMxSKUrDqlCJEvqK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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 6 PCA vars 1 -6\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "1", ",", "0.8388356252070239`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81d8DxoVKQ2WX7L3dbZYyGkYhlSQZ13Xv5XKFkopQKGmSyihRMrJH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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 1 PCA vars 1 -7\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "2", ",", "0.9424314606917682`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3k41N8bLUqUJWsq2fd1xoyxVkKRslWilDD7GDNDCBWKkNKqRZYWJFGK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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 2 PCA vars 1 -7\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "3", ",", "0.9328518300003154`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81e8bxo1ERUJSkr3nWY5ZCZmJJtnOPofDoRIqhKKhaVRGZXwlFVEa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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 3 PCA vars 1 -7\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "4", ",", "0.9364121279097545`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3kg1F8bxZWSVhFKyW7szG4tRGVfskYxzDALMwalUlFZW7SjUipLUrRQ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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 4 PCA vars 1 -7\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "5", ",", "0.9350040277440093`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k8lG8XxouIUtlKyb7vZjMY2ixZSpZUEsKMMTPMmEGSCqUkpQVFhRIl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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 5 PCA vars 1 -7\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "6", ",", "0.9385291238678025`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k8lG8XxkMJvyQiJdn3dTa7SiFFslVkC7OYYTAjCYmKUFEKbaKFFiGF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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 6 PCA vars 1 -7\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"8", ",", "1", ",", "0.8123593645883707`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3cgle8bxosyQkKkUvZeZzlmRRTJiIiQcI6zOMehSCoqQqQhJWUkWl8a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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 1 PCA vars 1 -8\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "2", ",", "0.9002568151784128`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k4Vd8bxZUGioqKlDLP052NlUKkKGWIkOvO1zVHkjQoKmkQ+SY0UFEa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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 2 PCA vars 1 -8\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "3", ",", "0.9320350403133753`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl2kglF8bxotCSmVLQvZ9mzFjrJWyJImkEBJmH2axVKi0qChpExUh0R9Z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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 3 PCA vars 1 -8\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "4", ",", "0.9121549291883003`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3lYTd8bxTWgKKlUJM3zeMdmGpEGKSGlNNy5ut2iVKhoJPlKEkqiKAop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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 4 PCA vars 1 -8\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "5", ",", "0.9534749226057275`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k8lN8Xx0VJRbJWkn1fZ8xiLbJERLQgyjIzZjPDUISiRaJFK6lECyoV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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 5 PCA vars 1 -8\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "6", ",", "0.9415525071665831`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81e8bxouGSomSb5K955l2pahkZCRk5Qxn4BwHUUkoJSktSRES0lAK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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 6 PCA vars 1 -8\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"9", ",", "1", ",", "0.8561222338837666`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8Vv//xo0SlYqKhuw9721WlCLRFELCvW83bqsoIxFS2kuirK9EKkpk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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 1 PCA vars 1 -9\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "2", ",", "0.9513006563856048`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8le8fxosSoWyJ7D3PsiUiq5BEssLhLOdw0KCkoUJSESU7lHyjQSlJ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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 2 PCA vars 1 -9\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "3", ",", "0.9522264572625471`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k01G8bxkVFRYXQYt93sxkMZY8sWSqEhBljBjOWdpWUQkmbKELZflGS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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 3 PCA vars 1 -9\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "4", ",", "0.9484464032993258`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8lf8bxo2SVGRWKnvPs82KUCJEhewzHOeYByWpJCNS2lIZDRRtlFTK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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 4 PCA vars 1 -9\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "5", ",", "0.9668728559079804`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3dczP8fb1CZqZCS9r7Gra5J69JAlJBUqhvdXXd1JUkoRGUULb6UaCHK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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 5 PCA vars 1 -9\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "6", ",", "0.9503338658841473`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8Fd4bx62KUkIqkr3nXa5ZFLITZUQZd99r3Rsaigahob0QJVSKEiVl
fSizSYrsxtcopFRG63d/fz3/nNc5zznP87w/n6NOi/JmiomIiHSKioj8P5qH
5KjV/WRgyUYfHDRgIv1p3XDiVjrW9JtH7Y0KxYYtDi2OixhYK3btWI0sE2Nt
yY/kGEyEdGStSBLQwdgiELTfDMb3+1/X3v0ShIj0OkvFS6HwQqN73K1QrP2q
aCseRIeCran7zmE6CleqTfZ00PEmfvHkP0sa1Ip2x/ZXhKLz5X1TF0EIVFOU
y5wPhcKxImMybiIUpdzAxLFBFh7Tth6Zm0PDr19HF8xLZaKlQ/kTV46JTd9+
OQem08DjB4/YRdIwXZKruyKKjlq1zxaqPBrocXVyx6OYsBL41g/7MrFuZV0W
n8WAwsY3DX2HaOik5N/8FMhFlSZX4Vk9B60BrYM7/4Rgf0iZfqMwH0/XKf0/
YwxMOZVm+66kQ8IoqPXUGTq8ImJHjt+moc5T2W7vFA2b1AxoIfdpWNOp7/ts
mo36opsKSalsrF2/PrcmLRTlOnqNJn7BWPz6y8qXyWxU9nr0TRWwELQohDp4
lIHXUS/Np6wYON+Xm7tmOBiBl5TequwIhluyccrQEhakSVkKIuFsnB+b2XAh
IBQWd31dXI6H4Nl7nlQ2WDDLSDKXorNgokRS0bYLhm9yfHFlcDCudabctJTl
QpVi59H7mAUxw5Slbwc5uOBTaXLrAQfje2zN+jpD0X/zwIv67BCkiWru2vma
hpIfRRf7mTSYFy/4cUMnFJepB5yI8SEwCeiOkqyhw6OkgbM9MRS3Vz+y29MZ
jG2Jh8oNBYFIOJw6b9cdOuIXtmb08ekwMbgwNPWAjqzf6kd/M+h4VKmxcXMU
Gwrq/c9lTrPQ5xsXsf0rA9RCAWMkkIGLz9Jz44V5LH+SLFixNxjWC2l3OuaH
IuK8Vf0ZyxCcMfhpk6fBxPh0/5dMFyb0AsTzSdl0/D717pPWHzrOFPTOt9kc
hB7Tjd1KDwOx+JpF6YFeGmavDs7dokmDk/P47DkvJqTUah4ubqPhX9r7WutH
DByn3gpuFAjfPzec+ku4H0vlQeCr7zxcyjZ+wzrPgItL5mopGzr83WUP7r5O
h6JeRqVKMQ3Sbh5PHfYyMMMMmLOtjoZ1YwkKA3PpaJEJaDj4IRR3zzeFqKmE
gGylLmcjFopv6h6hrgIaJOZx7BTX0fChOm7/3zU8mA5/4JsGcFHg47lGMY8N
2seRucnr2Gg7+MdeNTcE01famt/PY2Hgomx+1bdInPdYWn9aNwpz80oPKFBZ
KNnQCYcVbAgkizW518Pgl6DUELcxHJ+6LZZf3sfCXWuJ4DkyLOhfSynZL+wH
u9ykypdiXEj/vyG2RyC3z1ls6gYf/hn5t5K/R2IgNVnlm04UOFIksU9NLNxY
81S+/BALDOukc117GGhOWlDLZTKQEPOpha0nwPuO+OmVKwXgP86T0n7EQfPx
OSQlLS7+lBJ8rPaEw63+j+H5u+HYtkRt/mAbHR0m0+5FfsJ6S6YkFgjXzR7K
U/+qzoXRacO5bwvCIF9B2+5nHw5x+chh5dVcjASbj8nLcLD2rWt2Tk0U5DoN
q/9djsJefrpJ/24Gikv/DRYTGJB/ddC/So8DjaLsvb0xbHQ2znjlsvhQZjIr
wj6G48dUEVHcgYs1yuP5GS08rB/NiX96UwDHQJltGWECpKf1a9fZRaB2/OFm
8WVhUC2u/OEWKEA97ZNOubkACruch0o0OcjRt3/Rwueg/uVlP1IiHX3mcvp3
hPw5RlSOMcnkQOvAZOQjFS4oms+4A09DcSinLSLanY6ym+uYD86GQ+2uU/0P
XR4Iy9z9jjQxIH1RSiPOnIGzdl9IqZv4EB0llPTw+LgzkIDEvHAs6irgzO4J
wxcfQ/mEpzwEHqszLXrKxVhq9pe1C7mY9G9KrGxg4zGr+3FeJwdLhpLen7vK
xeeFktXRpUysfKlh5RbDRMV4kbP0NQ7MyBsCug6wccZ8u23WlQg0V03orI8N
R33S+86kbiaiVrZEq0qy8HUXL6PHIQrpG8yG3bsiQaj682A4j4u9b6b8e1R4
MN+pIHnyGh8ueeZX6rZE4GL7O9J0GRMXIjbpmHOF5956rfJzfSR23GpmU7X5
GBxKvjqayMNljUPv9OTDIP79jqA0NQTve0jxKreD4Nx5/3TTCBsZ747luE6y
oWg7TBkkcxCdaHuhNoKDbVv2oITJQS3ltkhlNRvP88tvjFK2gf0reKuX4TaE
ORAWRcaEw1v3hFujRzgIAaOZA8+F66MCOrMpHMQ9m/t96zceftLsxWs/8WBn
R3/id5uDfxWmmrrRHEQGuro3ZIbD/01R8oWacDQYfPl+ppUN8/Mn94jsZKPd
2e2/MfkYnFxlEnP9OB/aZpud81kReHROql/EOwILHeascr3MQvC5tOfeNmyI
3R8fLNCOQsCpY3obHkehX6tycjaLhe/5Kqmz89mg7tLWGosLR1faO+0e3whw
l6/WGLRhIT2UethwLgvxJ+ZLtknwcL94/Pu8SB6Gans3VyREwPxuQ/yfDgHO
3bt+42Z5FCJbY39HifGR+5+djNl6Np4VFbWopbJgKF6lEzDNgNmPCy/SrJko
k3voduUCHw3X0iD2hY/vKbV+Mgu4UDlUWu5bw8WL+L4ZA8MIdGY6DcpVhcPg
TgPFxJiB6zPv5oU8ZKCSO4Lh11y4vkhQ31TGRaXvUJXvj3D4lUdNqoRHQDxv
9ENHEBdyG55bBfdxhLxvTE/exkdTTNzoFyofy7irOtrKGKDN+xQ93ibkx3wq
g2TMgaj7HDH6Jza83y4IYR7hQ6Y9bYdnKB+ji/OmSoS6rOWi0BBvGI4X8i/e
1gUJsKVXO7TkgABN9bT/chwj8Vdwa9GRhZEITH086VwigKVTg+fudGFkBF15
zeOgO2LR0HXhPLqUmx2Ln6Fj1YOC2Yl/NMgGvh5LSeGgq7W2KofIxeVTz1eI
adHw5PLfLos0Gmg8t5VaQm7ZPlnx0dY2DJGLvbfECd/xQl376ZO7hD6oBaJp
VXw8yfWbfTvMx9Amkkh7QxicDhyJ2f5ByOGQpk++R3hY/fLAaoZTGDodWCb8
ZuF9qcUThTs42Pt21a7la7lYNXTYNFGWh0m1VY7rbzLRo9Rw3Y/MBDlt/0uf
pxzIJhR0T9/goOqKyE/qvkjILAxoN1gsjNVHvLP8WThoH/rP+TwL68/zFlD6
oqCxNTVac0sUNrSV5J0qEXJAqtvkCpWHWmrK4p7rfLSmRM2/VMsHrbpS5Ndz
JlTMJS4ZDjDRyda/O48chcsGq6ev1vMRyhrZ9GiYh4PioqMOH3n4UXPf4ZB8
KMbWu9eoygfjDy3wpoYnB6p0vseCYg7IW9NFdwZycL/esVvxpJAzdSd/xl7g
IPvcZdKOAg42hGXsUCZsw72sqpBFsdvw9vaAptNoOHI+Pu0/2xmONa5XPBwi
uRBjrNfxecjBnIq5GsUaYRBsVphLdw7H/hcymhIzHBxLz9xoM8pBUlLicvtH
4aA0uq9bqB6BmgWBpa/lODAsyhCtcxHygtyzzzM2GoqBm9r/m+Ij0rvVv6Im
Al/OZ/2QexAB4j+S/vEANj7G+BzY2M7G6ZSDAa8So3B8lKHrOIeP2tmPz+aO
sTDclv1gKpeFvVeD7qe+CseJGadM4i3hedXE4F1BLEw/f2bxeDELQ0f1xhY+
44H+/K1t62UenFqWuuwuFHL1uNEH5lcBdirKiDQo8vFjiZiXkS0f6ncspr59
F3KgcNXWCFU2CvYPRkf+YcBk0d3E2WoWeJ+S71/w4+O/nx3aH9L5ODtt/kjv
FQc/7MalmHZC/TiV8uKaTARmfw8qHp4MR1MoYe8cQwZWuC/68klamNeKsfKc
Z1z8u6Hrv1moe94FTR3tAxFIE4/I0hfOy+sKk5KNsVxcj+E33XHk4koo8ZPV
WT7++S1sTV3Nx9u7krtdnjIw0aM2pMdmYa6Xd4WVq1Bfr//dF/6Ijfst5esl
O/joNB5J2WkpwPcu2cmTCUL9CWoJPmYWgY5fadt/EwWY2SX1zk9JyKtTh8PU
CyJh48isSNoTiZ1lTlH+rwV46HqDKtgrQNDFad68AGG/dB1/ZSTU59gXCiIJ
qgwcsS+ZmJtLRwZ5dE3bVQ4IbpM3twnn5sgcxS3rNWgIvdm94YssHbe+d4Ub
qYSjSMPcbvmKcFwKK3jWTGeiebNphrsuC3Y59ge/KAowcc9QxYssQO2gss3G
sXAMs1ect78YjvjhA7PnzvJQzFHNUB0Lg8Pio3pyohzsJIuYqe3l4Jy21ROj
dVx0nLVt+hbEQzb9Jyckl4nlxb/L5rCYQu7Z1CUJfcxxkWVDez9wEMRskjZV
jkJw907Ps7cikb/UVUc3k4WVBSvXjUqzQTFQmOlS50PkbXO/7r1I+L5t+0ur
4mLJ9wWLdwh5f0wjbOEcYf1vh8cnPeHwUcBd9spdjoV/5VPdC4X6TKe884i4
GIVYm9tiy0f5MHxUvkKigQcdTt9Ab55Q59odmdkOoWicI/tJJyEEJf8mCrxj
OTAeU89/z+eC89aF/FTIx9Tf4pmV5RzU9T0+0ZPIwWfljtUGdVzEFv998e63
AKE++sNXudtQ9UBK0lwzAhWWhL3nhJH8N77BUfh/8l7u4KYg5PT26cUz8nvD
8JbX7+G1LxzN4WYnXg1wsPF+l6uvcF5NX+aJpypEoK3nSNZduQhs9bCfYVtw
8Nuvs5SbwYHNcNO+93nb4Pue6GilI0Am3bRF43sE6nMNaUZ9EZgMOzEuncGG
9G+p2H4BB0NlQQdsrmiAHJxxpmSpFrayhx10TQj4feZC3fYuI4yVl01tV5WF
6v5Hq0SPy4M/N4XwrkkZDIJP8r1Xmnj/xSvo9mcdEK1Tve0ydfE6bdVFmwxj
xKuU1r9uN0Ssmc4Bu+cmiM29teEY0Qj5p62spw0IUFzJWLPFzBiE76mt0Sf1
8C17av8hLW243t/+ADuWoUYi3H06Wh2mB11G9k0QoOypt3HdNBG23NaXu7II
aG6znR9fYIoOKdtcK2lDmP0ivIn7YIRbcxKP/hbVh6KbQ+gYVxcJraWnL7/T
QbOcx+QXayLsanf9btdWw4s1nZs/71BBwd3Xy14sM8RzhVO2/13Th3Kt2WmX
Vk04lHfe2+ekAZCX+N5SMcLjtzKR2fkGyLf/GjNtpgX2pboJiwc6UAk8mBgt
S0Dy3owS3/emYDGWfC88Z4DnvvXl5A162LZ5IDlayRA3Jb8Wro7TQyhpdvv9
YjL4n/e8+UMiw9DhW+BZfxPoT94wdq0yRuurHM+KbB1UDlh7lBdqwrdvRP9Z
rzEEN72uXp0yRgiF7P7yvD7sHXyMj3vrYayl+wXxPQH7nbO0L641hWdq6t0J
YV7Bd6gaDjPCd03Zvm9stz703VeqXeolQjXGulb1CREXr749d+8NETWaLzIe
jxlCZ6v0uSYyGWtnSucenTKC4Ya3jUeE9xrY+NxL57YOdKtaJDjnDRHpskKs
k7cENr7KxKpgLazRlj22bK4W0hUtZmOs1fF+09R88RNE2LTZe88YEtHd7zO4
/L02pFmli126tKAmXVblSVsK+o6g9vBzS3E4fcvih0NayP7oHGPjowX7JQpR
lgYqyJz5U0w1XYFrG+V4vF2qWL4noVEpTAeF585eCY8U9tMnkSrJVBMQI3sL
HZOMYRubs7TB3gi9hcUvvCO14cdV5v0YUsUR6/ZtDmwlqOgeFu3TVMSd9pu3
3c7oQOI+6ZKTpx5aNlBD2xYRcMCk8VyjOgFZ55easySNMRVVo336iRHe9Wo/
lQnWRmVMs7GIpxZ+yW5qlGrUg5EB/fzpFF0cmcjtfJtEwOWzlrXqoqbwsGOH
eFWqYaKloKuKo4bzz5RPBVwnYmGcK7+tjAQf9dKx08JzqsMGex8eMcWSExZb
Tk0b4Hzp3tQBYd/kqFBHvSWM8CnH9kpvtyEuqpr1UB+bYvXVmQM+d0xwfPzM
0wcfdLDm3HjQgic6kOt4891xloQoxR82zYtI6Bct6s9y14DFxJ/ci8c0UaRb
7/eKr4mJuXuHxEc00HTp8i+ZDUa4ySe6/PY3gtiWrof/yZExtqzm6EdJEmq6
ntH/iZJRUSnTcyOBAuqB4Tzv92R0XBpuXp5Dhtvvn0q6bQR8al8r4rLbCL8q
gwS5NibwG0/JWL/IBEpH7A91+lmgeqf1bEWyJfTnbshvliTjo9rPGV9pCtbH
aHpY7KTCYe9+07fuVOwwvJXtRdHHGgpNbGSbPmL5Nu9WOlFRcjq0qrrSDHo+
/JLRWC2A+GdgwVVNnClz4G/abYxjf1qrxa4b4Zn/7Ff5ZEN8m1NjFXHUENUh
f9A6SQEtyCkxJZQE/61Bn5fHESETaTPvyQAB7JSOXQ6brHFouCjcXM8GU4ak
mCfdFLjJ77K8TacgOrl233ohv0TMZ5Enaow4s8c57g9sINcbk5MUbQPluTtO
hNtYQPRlxIaR/WboGnp+aWcoAWcOx8n8Om2KXD/xM8nXCIhd4t6457aQN0Z/
6f3/CDjycV3qDz8CJOG09PRPKvb1zj9V8dsMES7+zIkBIkSdT3vtNyBDdurR
2fZ2ChquL8hPZFKRKPuefdvQClZ9awotwyxhbPuq5v1CKtI95IPE/5nB/n7k
vSVDZNiU6yvaLKbArOGB/MKlZLx8pCyYq07GE0nfbTkN6hDfVLv0wVZ1ZEY1
mXqpGqDLc/cB2U5d1Mm93iO71hLNvMdjtZoWCPvhtbJ3GwFePuHqm+pMcSlT
4bXbZy2E7b8f9jpDGy067gEjFwlYHPD7IS+XgBGvCKfcw8a4IUGNCdhsjNe/
pmUHtHQhmfTy2KUjemhQb334W8wcmYXVeXXfqJCsiNtpf4qCb0XZfs/MyFha
emKdzksTSOXaV5ormsB6pXvpIqI27s72kT6paEP58Mu171RN0e5Ru/QbmwBx
8lmKWYYVZJ5P/Td71Qp7rzlukk8lou2C0tX4LiIGjs2pGTUi4kpaio4xnYiw
A+L3om8R0di7PIDnTETKnLAA4qQVqoKCL9StsgDRuHbJTRld1NarnmhM14Xe
28ib48OWaL9h/qH+nyXismzJBeepqOv9wyLZmGLwr8fFjFNWmPp+L/6DhpWw
fj1ZZ8RJGOdNrqpvIsLjutJFaQNLiHbn5dSmm2Ocq6ylmagLCsNEf+FaXSg6
5g1IipFRzW0bMrhGwuB5z0fXhzTwVdUhaYGQp6VMceN93zSx6TGjfzZWE9FN
oUcsyo0gLX10UeZqY4SvGk6YVCIju4KTKtAj48KXxsMRwn0OOVazrnDMIEaY
mb2nScHkhva9cRoUrOWxotSF9941WHpsfhQBL7K/b/QdNcGrpDMqvxYTsGLZ
hsvUGQscnT2ZuPmQFV7fkuKmOVEwkaQRtmSGAn2BxLpPH6g4l0kj6x8wR9rP
k9VVY3o4XNx6Ir1eH4vfaW8WN6BiSRP58dgCKpw+tE/d7tGCaCDzL3W9FpKj
F5IpP00weuNq27FfxpinO+fwUjkjmNcMmbOFeiK7n1IUNGGG9NVPN3B8KLBk
UTzIRiRcPhR2JVlHOL/G5RZpjpYwvZW+u6rLGn5pkwL3L2QICquUcjvJCJnS
phRaGcPH+IeCwZARXDpjd5SZ2GCtjsHJ5Dk2UM9UmTx4xwIk9U9y9Mfm6Ckw
y6usJ+DaDYqVfCIBATaP/aXeEODZmp68dIgIjadcHVdPItIk+ONWIUS4ZnKC
TxVS0Z//qFm0jIqATj8nTS4Jc/xSPGUEZOz+Tev/MGoGJQszP+8gKnRWLNNV
p1mhrWMsnq1sjS1bjX9lk6hIcj5BuLOGimWbs2g/4yjol/PN/NFLwXa1OoO8
PWRYdr9YtE7IV78qFpmsq4Ertp4Rq4vVsWjm8+qzjQZ4ahhz85+zPvbTX2Q/
GbXE9gX5WqeSLKG09czx0+0ElOk7HpNMJ6BkzWjEbWcdHGWW6N5W10V3Vl9A
iD0RIj3UUvVUAgzoZ82CeozR6U4XD9Y3xV+PedSOHl0YZTT4S6zTR0KpntMW
ljlq/T2CUhrMIV+WkCCZScEu/TBXqfsUSB15uimqzxRx4/G27c9MMLSFm/Wu
Qhsho75VQ8U6kNGNM/i60xRKsflOSpkEqI5HHpNUssbzeKO8BQ3WiHAWNP03
SMSW+dkHPPRJyGq8u7NAloQlNvYiWXRh3a8YxUjbknDw+LanZA8SLFWyPyuL
WYPy/kFc3GorzI48ytV4r4sRlRzdTKEO1y50/XVaxAqCFFJ5b6YVqhepha/7
TgWBObrv7ykhv64drHBus8KRP2mmvGEruAQVObb6kRBcefLnCScSBHeD11sr
WKKnQ//altuWSAp1eOIpoge7e7ckwor04EbL2xZJJaOpfERbRIKMwwPvfc78
0sBU9OZrfa1aGH3nJB1B0IJFRd9YMUULXdu7lGSF/Vgw9yN9vrsJmo9qEGmq
ZHyJrSG4MchI7TWbqNQnwyJZrJv5nxkaFby+RZZRUMm8mfkwm4IHfxOKNHYS
Ia9+7lgDhwirsvvVlQ4ETFaf1nSRE/oIXVVBAtUSCt/3zNeXsMbxsuz+f2cp
IObt957YYIa91CNxZgnmeD74OEfANsfqkCu8Q+r6YLv9svmcYADx+4UtHapU
5NzoUjuZS8WH4tb6YUVtxN55aCPXog3+Epm+hetM8SB683jzagL0Ao+nuhYZ
okvpc2x+lSF2P4r/+EaWil0rXGaCR8xwfUZ2i0U7CeW8fA/6LTJINTpFE15W
SN0TciL5nxW2i5XmV5hTUJOTm80Q6v+gWcIsiWwM5nSt3IX5xkhcKkd4qG+N
ZO7nr2eXWYNs579nptACz+pp+j/IlqCLjejpiRGheCv3s+9XAtYNWFQTvhEg
c/9N/9pzQr9T0hmCRCHfFj1V4ySQEHne8wF1iQUcM+tduOPmkGyRW1soXFf4
SDPk9TsyOPI9qgFfzTCx2W361R4q1NSMJR+PW0GZOjfGut4aKqkeA0XVZihs
KdvZq0lF36tnhWufCX3L+Ld9Dz3NMC8iUevPRjJ0tR7quF4mY4VRztbSCA1s
dCsvKW/UwJftayJG5A0xP4Efe/WEAcamn/7nbG+FGguNMnlNK2yTqLvTLU4E
WYsa4N1BwH8WwzN8vg6WZ0uJHfypC3GdhbWlAUIeZWSwUoQ+QjloudgHoine
H/BujhX6jP2/rW7sktCD1aazkXbZwn+GtMel1YPmULfe83P5LaGeeUy0LhD2
E6Fpj5yrpNBnOebVzDJMsatJz95JxBT5WSFqSd3aKJ26ktT5TxeyrsbPp/6Y
wvAvI3CFEwF74CMaJqxbpESIs1SONQYs+leHjhJxMvYAS+8KCQO8wIuuziSc
rXb7vaaBBPiv/XzJn4QzC+/Zp3SS8EFCI3PpTuEc6uranmu2QtfVhzt1NPVQ
E+Cwsq1dH/MivbTYM5ZY/VC0JvyBFeRs7xVvtTeHdvSAWXS1KaJczU+WKFij
pezo6CpDa0h/KazkJJHA8Pd5w1Yj4x4nLdH+qyW0dFkxP85a4X9L8NJJ
            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox["\"ANN layers: 6 PCA vars 1 -9\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"10", ",", "1", ",", "0.8450495335260632`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8lf8bxkWkIaFIKXuvsxyzhcoIWdnCOc7i4FBCpUSR0kBKhawkGiIl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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 1 PCA vars 1 -10\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "2", ",", "0.9336536787092252`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c4Vf8fD5GKhCiSveddLi4VISMpu5B1L3dwuZS+RokUStpGgzIaohSa
wquUJCUhI1mVrV1W6Xd/f53nOc8553mf92t+VIIiXIMFFyxY0CmwYMH/ryYB
+cqPfzNg+Gmn3oa7DJxpejySvIOOxEU9S3zyg7DV16bRdhkDDnm35QVa6Jh8
k1InxQhGllHd+OK4HWD4Rka2lfhjY4WjokCKP7hnHpvJXQjE1CHqu9qsIGz4
JrdeyI+OHbOhbOfDDJSuUf7R00GH+wbKv/nbDChfj4/uqwrE9tyltGC5ICil
KtyxP8R/35eZ3/ogEBVsn+TJoRCQTu6NUbgagrm5I0sXpQVjdv5o8nXxYLh/
n7P3OROENfHcwFVlgZguL9RaHcGfP6fiXZ89HfS4x1LHIoIR9NaruqCJgY1r
HufyQhgIZGzRqZRhoJNyqWTMh42jeqTJ3kdMtHi3DMX8DUBLyZ+s7oYAbHGc
0vk7yUDvdXbS1fXBWKjv13LyNB3hHdzsBZV0PN6iYLlvKghXjE64KP8OglWn
jufLaSZy5J/ikxgbG5ydC2szAnE0iiUlc4OO5e1f1rxOYeL3qPnfnWtZ8FsW
QB06wsClfKtGXh4d2b2FhVYj/iANXjh0ccAfm1IMUodXhGDJ7XXja9xDkD05
szXHOxCL73I5sR0BeDnIWZyHEEirbpJUc+PjKE9S1LD0h1DS82WqQf640pla
YibJhpBgqMI0iQVBvVTZriEWyOo7vg3psfF5z3rj3s5A+EQp7eJ1BCJDQC02
pj0II05Z0h/5eJjcXPrrmmYgvo65y1g8DoCh97sI0Vo6tB3WpJdM+KBsXZ3l
nk5/xNpKPM4IDkTC4bRFsbfoKDClTWn00GGomzM8dZ8O63o5BblldNQ9VHXb
HsHEe692/cUFQej1jOPu/sbAuX0VznnxDJx/eaZwb14AcqZvvh6qDIK5eNCt
jiWBqJ+xc4vVCMBp3d8WRarBmJJW3v+FEAxtb6FLJP7ehOY4VTcIDJwufr/E
YrsfLhlM/adB88fyK6YV+98HYfvW+EOEi4Gws/88m+USjFwT/dY8JTr+ZQw+
Mq9jICZBRO2DLgPZhWHUOf73DERu3vMcZuBCnsHbkGwGyorGNKNbGdjmJHkw
/iodhP8s634FMCC2aXOTzT4GVn98G5VdyOfXZIJMvwgd06kWNw4fDUJldkOA
smIALren9Kw77Y/vKpsDHSP5989K/5r6FYQPNXFJ81YcdBxeoz2TwkGxxxYr
uSImapZ57j+dzcKbg3+tlQoDcKVZ7u1Wh0D0n5e8VP09HDWvDv0qr+ZCpKhi
vww1BBvMuWXDb5mIFL2pxr4aimxFAsm0h42xd6arLiaGIMv0YXODfQh0rqSW
J/H5kFOpIV/dy4LY/wmxm4ukY/NhctXh2Hb20o2Un+E4pLZwkVtsOFiLSYJj
DSEIXDJxOIbDBMP8QFb3HgZgr3uF4xiMhF1jjUztSHRLZH6P3BUB3pOixRp1
LAi8UoyVF2LjbwXBg7YnDP2+q9a1/AhF1ArlJUNv6HiQtGXqySQd50VTk4vV
2ZDYohy9P4oN/VN6Il3FoVi9Ks1tRDsMQtLhIwrr2Nidbf5u4Wm+nroc8/Jr
IzCWpV1gspCHfbwzhn183lwUHAiZ5utZuvXgtmptFqTGPr/c+JqFzmczLoUh
PHwv74+858/Fr6nrRCEbNh6f/ui95BcTzhP5e5tKIlH3KFUlMTgSZzL6NB5b
clH2XvJybkYolG4+/LXJJxIqRxh2q47zIBNrP1yuxsL1DAkblhYLT19f9CIl
09FXZLyHs5OOo0SFXYbnWGD/9px2EmCDovaS3d/E18Wt86Z9gUG4U7Ix+H5m
GIhjpYJsIzYIK5280hsYyMvIWt/D96VMyy+kNHceOhKa5LNSebjVn4DkojDw
Ij0WnMsKwxcPPemEJg52xo+l55WHYTIt78sGcTYm5z6rueYw8STk3ZOiThZi
KLMffLksjIuL1uysCIbYiylrLf8AVH2+bi92hYWVKtcyQl+wcNpk9/rcAi7S
1Nf6yFpw8fTAYOeBd8E4buSw6YBTCL7Fcs722ETgarGw8agoF4Tqv/dHitgw
V3rDNBBlwyRGRvTEFR4SB/OuVi2OwPm2AdL0nWCocwNKOHQG1txoV/ztHA7O
obvJZ8bCMDSccnkimYOXtlShV/w5hX7eiqxIC8D8Omf5Uv1A2HfePdUwysTR
Hna6139syK0foQyRWQhcXmbbGc9ElO8elAez8P3ewk3j5SF4denetQlKFFwC
POtlwyMRakNYFr4rDEx6SyPZnb9f74lz/a9YyNr9pUZQgo24lyI/d3znwF/A
L7o5NBSWlvQXXmUs3NBW26TrwkK4j6NT/bkwdH/6KJyYwEG97pefp1v4e71U
9mDoDBNt9ps+TUrvQkW8rc7DA5HQMN5ufymEC2fyoazHZ7gQtxFe63gxBORs
scuNWSEQvPt5qFgjAiu7O5+VngtHn/rDH7O5ITh8+0th5gMWqLEa6pNxYajT
mKs9Vc0Be9U61SGLEDSo3He7c4qJvceXiL5ZyMHMRT3uwkk2hh+9316VwMXm
s+HCB+N5yLp99VrJvQjISVl3b+2KQOEnSwljZyZsM0bSmq4zoSdUrek9zcCO
XC3pe9EhuCP1YFNBDg+qklF2z9x4+Jn6yEtiKRutlgu5J+XYaN7bO6Orx0Vn
UeWi9m1c6N6qpxgaMKAhvONW8ms6HrJHMdLORu03lZZfHA4eeg5Xe/4Kww2b
jemLaVwIFU186PBjI80vvXhlC5vv98/OpETx8Hk4MaOMP+9K9tqON3cYiEqx
Xaspz0DCEiqDZMCC7rn9bn0NLLh2LQ0ITuchrDS/IPZUBCaWF02VP2XBaY7W
WJ7HQrN0c9djv0gIiSkLaw5FouFp0Kd823CMOq53SvwbBp+0Jz/syyOhu2j7
rQanSJgx/AraOSxs2TdW52XNgsM946N7Z+h4KSQcIRLNgKRP+2RqKgsjBS82
PuDz6uLJV6sF1YMQtz9ZapwQhCDOpjXqlWFYfjbg06wSB+HLXX3jzIPBlTh+
nf2TgYBGCGRU88A6mpZa856HYXfSgrb6UDyMsFSSTwuDV0DDmGc6B/3WxbXf
HoSj0ybEkPecBavc0sqNL5nY17U2dtUGvk/WUhTebmTjh/JaW+eSYGSe6D6y
KSMA5Iyk1x5NfD9JNlq6qomN6oIFv6mJ4ShlWX6bJYdDoibdNXdbCII5VSRW
VzCcszlLKb0R0NxtLzZ7Lxxb35QXnSzn50BSiOC6PDYeUVOX91zlgZlz9LKe
GA9BNQ8XzL0KxtWjm/KrPIPRydSpXESOwPQL+b3RLVwEhoy6141wEDrpek3/
Lgu/au/aHJIOxOiBhzJlMoH4G+RTorqFBW4b40L3Xg7IO84IxPiwYJdvVmNw
hAnjxyd+R+ewMJSWMhm/gYmtoWf/UyBEQZp+72KEdRS6yvrV7CbCIBBsovGC
GAorx4LNNuFsEIs9ejWz2RCuElG9qRqKD/H61XqfQpHULKG2cIaFgw2KPdp8
PR84kLzKui4MInt9nMw0w1C71KeiXYoFHN/Sk/OT7xfknsQt0TsxkKUdOC4f
hXDXlm1VtVyI/ZA57zHNBfEfSeeYNxO738memuHr5lTqQe/W5AhkFiz/KtkU
jkezH1+KTIZg/M0xSfsYNvZd9rub1hqG/57eSY2VDEVtDdE/1i8EKQDdjcbC
8BHtSfGXHDTKH44Q5ONq1yjrEF8ahuHj6jRaKw8xchIL6uV4uHkld5XwIh5U
bplOfefPSW7rZFg+ZKE4aWhn+F8G1reZfHg5FgLOWMrdHC8eouMKPAqFecic
NqnTbmUh8uBwzIpTLBBOpjZfkeBiiRXR8lpQOBoCCfuE9fi83Ez44MbvX9Or
J+/lv2Tj+pskesUUG67FDR1t/VzsifM82PyLi/Yqw3K3aDamzTSyViqyURBI
HKNl8jDw/FXAnzYeuipF4x34vdmi4f2BaXEGRFxcq2iOLKTMuxsGHGPhbuM9
Z9EOHsAcqZ/h8v2kW/LHiQQWFg//O759ORsdcxm7/xAjEa/xYk2vVhSyTh4O
VSkOx/gS5vRkRRhi7thFbGuPRJLJFcOa3kj4nZ/mLPJmocVQwkid30+im2UW
JCgxcLJjeZtoXjDOkies3lxmYZ6usUnFnol0YTlfZ9UgSLQvFN1jG4QbP7vD
9BXD8EE69vNWTiguhBa/fE4PhhslZn7jJwYs860PfpGLxM51yrEV5Tw8GlKw
cJsMQ5n81DotPg/3juyfzcrkINPCVpLKx8lm+RFtKQEW1F7+uvPemIksDdoL
fb5OO0Tim0xn2Mij/2YFFAbDOIz1XdYvEFJbLR4fUGFjh/RNJ8ZFNvyCG8SM
FCLg8YzzPWdrOC7JOmpqneP78JnplXJ8vVJ0ZWa6VXjwXf1vbUpmBDy73swH
VbOx6GD4+lUm/HOJaqi4MB9/3w/VIrKNEShmr2x1kgpB7/ppDeP6YNApA5u5
5yOgPnOkdPIyF3p191YvrOcg/u55j3EZFn632Qbn2QRCUvzBVR/DQJT/+1rs
Gs3CicvfKgqSOGB1OZCb+P64wlIuzCuUice9T473JLNwXoCg0KPM3//N+eaB
P5HId/0qv0AkCtX3F4uaqHExslHW0IDfS8jze+tt+een7effHt7wmt/TppfP
SO8LxX5x2sg+3zA8DzM+3trPggXtW42hDhtGr4uE0mS4mC1J1l/6KQw7NlvP
ME1ZSBfxbcto5D830pA4WBSFI3IX55a4R+Ec3ahR9ScX4ed+3bqVysWP0OOf
xc4y8WlVdH9KDRPDd/z2WxSowuv8x33X3FSwgzlio2VIwIRsBzVGUh2T9+5M
7VaSRPtYwKtdHuLgiaQSBhoUoN4uaG78RQ6DX1z8ysY1IZQavHWRtibaM9ae
tzhrAKvXyR8jlTURbay53/KVIaxLjtOemRvi0ima+bQuAcpPGWl+xwxB+JnW
svOENlxst4VxHHXgeHf3ffy3EnsVHFh5N9RgdNBhNPErAU5rC+/wiESsZ7e8
js0lIN8uR3ntAwI6Fq8vpInp4VbPuL5plCFuCCcf+SOggxNau1LP9mgjoaXi
1MUBTVxwKa90nDSE5aPYP20ayvgRk3Fy3S9lFFe2r2xeqYfBsga5kv36UHhk
fMqhRQ1ruozuCIypAuQVnjcU9bFf9Jf53hMGuGT9bde0sToObg9ilT5Wh6LP
weSdkgQYmGxOpZUYIYSx4mdpli6IlGy7a04GiNren7JTXg/996Vvspr0EUia
3X33JhlbmxZ2LxGmQM/mu0/mNkM8PUbpsBo1QEtr/paqPE3sYy5WcjLUgmfv
qM7L9wZolJG4K/BHDwEUstPrbB3kRAuXFC/UwWTju2biIAG73jSLmOwgYEta
WuXX+5roG129O7RFE99TdydOxuuAGPrGQzZQD0q7zB8pvSDC/FTO6Y23iahV
az77ZFIP0daOq7oIhtgwUyFyZEofWktWGZfpGaDf7ZWLZpkmSjSLN7lK6iHc
YbVgJ2cF1uZ1ayS4yMFKQ/LoShF1VL/402HfoIFB96klQseJEF0U+Hl/KRHv
+jyGVg1qgHTUbfkDD00oi92p3hIki/S+mpNb7ORx+Izv8gfD6viRUD7e/00d
1itkIsx0FaE298bkwjUVXHGT4nBilbCtYcx8lquO0qzMgrBwQ/geamhVkDUC
Mfx9qe0BAzxiLvGVkTDA+9Kbza7hGhA9uM/F5JMu0s3bomyY8lh2glVycpE8
brWVlG06rQnPlHTZlUx1NG6lBr5ZRkDSEZFL3WcIyM2WNQkRNYBJc9szo8f6
GHiv0SThr4Hd/kJNdUc0MCfp/mzxM23cHCCm7nrB//7Xws6uAwSEGL8Y6eD/
92ZLZoDLQ2VQOZILva1UkP1S4aT3VSLeRJgYWK4hwkOlYvKUCgG/g2uyRxg6
WHHc1PfktC64udOj3Q3GyFekTrgu1IfS1CNMWBjivJJxD/WJESa+rcg+pkXA
sc+nm+5/0MTpFbatGns0IdXx9qftLAlH+m6F6NwzRJ/A9b5cJ1V4N5aTbiko
4brWU69WnhqM3x2tnppRRcOFi3MSW/Ux57OscvkGfQj6dj/4JEXGYY27GveP
EVDb/ZL+T4AMhZWKqJ0kgbp/pMh1kAw5+5pjh+sp2PTnt7zWGwJuX3FaQFYk
YO6hX2Qhf84/rwdW/hbWh3y69aFOL1N4UUgeC95QoSOy9dJzUTLyTM+1BreQ
4bxLbbNpDBXXNlbFUj9S8J/ejTwXig4UL4xMVPfpIppnMbDGjgrf1Jz7Nu+N
oe3BK5+IVueff4srDtep4/QdG557vAH+Eg0vr5w3wctts9+kU/TQRFL8NlCo
i5qAv2j5QUF+5cgLhztkbNvhN74qjsjvfTkhURkEMFM7Ym3czdE4GPzxoAsN
U3qkXS/eUVCvvCM95QQFO1MeJTrz/cvgUFKRWKER4oyf5Dvdt8CHRWP73lpZ
QEHkv+NhFqYIPdNwU/m5KbqHX12ICSRgVGFZ2scqAgq9hE6nXCHgoglLqiiV
AEv9eXrfPwJSPh/0bP5NgCjsZE/9puKqjaCdOtMUXIdtwV/7ifDkJCWyvhAh
OVWX2dZGAVuRecs+l4JkyUFmmR4NJ6lffw5eNoXB+tbaQXEq9v5+mMneZgzr
u+G3VwyTIWQtI/G8hAzj+vvS4rJkVF1KsRqYJ+GFqGdUfr0KZoq0nQPa1XAu
osHIRUkXm+pPLtXT0MNjqfY9khvMcDaBFqfgZ4bQXy5r3kcRkFhibRXPx/XC
OZn2TePq8Npv7mS6XgONmk7eo+cJyCtoPmqUboRRF65d4WEDEGs38m5p6qN9
blqyX10LxT8zt209oYV6lZYHfwRN8CTxKqd03ASiVXEx1icp2Ob+yWrxLQpk
K45v1HxtiKnNTQbevwxhvsapYhlRAw4Ncx7Bz9WhcPj1hgElI0wSxdoubzSA
EDmTYnyWhoi+ZmHPdFPsu2LrLp1GRPSDAssIBgn9R4VrJ/SJ8LYYXbKXQUTo
fqHbO28Q0f83O/H5FwJShUO9iT9oeBxiSvZ7ZAqiwaMVJRJaOMcKSaJv0YJ2
V3jJ5xEzPCmKuv3umgnicteTi7OpEIw9oz8uScTQ/ObzZ0/S8JT7n/mZbBof
v57c00Ik7A/jrKj5ydf/VfnzYrpmePZ+xDpzyASf2QrqaslasMhl3X/arwk5
26J+UUEy6mPCRpkNBAxlb6m7OqyK3I5Yn6csZVQECxkkfldD8prUvwKdatjZ
EJhueo+vq0hXN3MZA4StHUn4IU+GtvUNa8tBInK+PDvMvcLH+ZXEzCd3MgQJ
M7O31SjIFI433KlrjA2ckAgVeyKYDqy3RS8IaM776eY5wc9j0+TOHWZGWL1y
60XqjCn+SLmUfx80QfuNxewMOwpSnpl06olToBO5cOPYBypya1/vshw2Rsbv
EzXVk9rYXJlszozRxfIBje1Cunw9t2498IzPS7sPbVNlPeqIvSF+1qJVHSk7
xcmU34Zw9xqsWMM1wyIt4cOyUvqobTzn1knSg2QS5brfV77OcwwW+jynwCyE
spmsT8Lfj63UN8+I2GZwzzTD1gyGjlXsQD9zeGX8iHT6QsbszjMCL65QEDCl
QSmlGcB8+PLeeT6PHDqj/7tjaIEfK+uSdl+3gMo5xR8Hb5lCmaH0YZ0zDT3F
xkUPnxLgLxc3IkD9P0+ebFv8lgA3jvXDI50EqDaxNR23EPHHvVagpJEAx3Ms
/5OlVPB8tVaTU2nw7vSyU2OTMH3rkWrrARLi/wT1fZgwxnaS4tDltcbQXL1S
SyWIBsH3DNuur2bw3WEwl0ei4mZwZPEXWypWbs8N+h1HQaroCaHDf8nYrfxY
t2gPGft137dcECHDqzqETNZSxRVj7fVbjdSxbGZ8XeYzXZT/uc50jddHEr05
78WEGbh6f7fPb6FBfsfpY6faCBDvOjEnv4aAcqsJbpm9JnrrKMXrdmriXW6v
d4A1Ecf2zdc78/1dl55p7NdjANevou6yvoaY37yI2tGjhYc1E+fFk/h9qULb
zjfEBGIR/9nfp5pC+k5Cgug5Cg552u2uIhhjcXqTe0SvEVxlPDcHvDbCsC87
d6BKA0oTwu8NTDUhoRWn+y3GCCq9F5mcfYZQ+hx+VFTeHIbSF37MCvD1Yh/Z
8GmICJkI4WK7SjJyn1XGFEuSUND4rDZXgISLBfq7xNaToNJe2WK9jAQzxbxx
BUFz+IwOHiktMcXsaF2h6qAWymYd5m9+18Ijcce5UwtoEKFFtiUuM0PNMuWw
jT+pCPL8wpS0I+LClYNV9m9oaKqzLthgYw4Hv+u2LV4ksKbtp5a8JyGy0t/Z
XMYMT38xGOuczHAg0ObFlgXasI/NU8vfpYVNQUVR4VQy5mxiDtVQSDjcP+hx
ek4VHqv/SndIqWBiwE6MS1DHw6cBliXW6uje3S0vyeejg9TazV39+nh+RJUY
pERG7yRP+iffl9PeG399qEOGupOz+Y2DZDyTcfkefoefV9sHaY18378/n3Bd
NYaIOkHqUOo8AbQ7d2se2hDwwONpnJgmEeJaSpEJVDP41DZYh/iZ4NidvL5/
mXzdzKVMxCtTsI+aHmecYAKHoqH/WN1UrAso4BxS0QHVP5j6fJcOhO6WNnYo
UTHjX7KUPmOMDzdbno7IacCp/tPFtisa4K2Q6BXfaIRK36oH621o0PY5luZ4
XQ9ZKpqKC9z1EF+39+NbSSr+tPy7udbDGFdnJH1N20hIeBu0QuYqCaRazetf
+bk6Om+VbXTaHLsFKy5VmVAwnsSWW1xEwZBxwiyJbIDQ9Ub7jmobIllWivBA
h88PFu/4jQsWIFtu2zNTytdruuiKBj8a6IKj2tqCRJjVjqd/7CJiY79pDeE7
AdsPr4tP5OdQX3lnAJL5OGf6RfcLEBCeveU+dYUpzsmfrGYyzSHaKLWhNIuE
32st4p0N+LhL9yh5fzNG1DE1+cUsYygrG4g++czPgwHXBeXHaFBM29x/vcYY
apfr9wbkUNHb+rJ0w0sKxL7fN9AwpGARN1n9rxsZDEeLwlZ+T1qtn7+jgss/
P9Hjrw04q+PLbivuqLQeaCfEw7X5fX5yuumTvTUNw8+tknze0hC18PGtd0JE
nHzHvNq3nIBPpiMzPJ4m/F+E7yW2aUFIU/xRhTcB79blm/+2J0DBb5XgB6IR
bnwq0avsN0LSH9q12IXaoOZ0Kyyx1cYrsc0X1vFzRspc2vWmHT/PNn9tWcrn
k2LOuBHjPgU2tkW1swwjkJ06vvgnGuFSboDygXcauHRAmSCTpAVJR4NXU3+N
EBbUkjCWYoQ98BAI/UfDJc9utf1hNPSb9q0LnCDiUfLxDF0vCvo5Pucd7UnY
csbjgPckEdi2YfzCNhJWiYjWlkWQ8GGh6jnZGBp0F68ar1hohu7LD2I01bTx
Kyk/vOGVNhaFu6gzZ8zww2XBu65nZpBaf/vmDmsTCKqWff23iYgIR5MT5TLm
6FoXdd681xxiX0ofsvg+62pCerMkjozbrIxk629moBMKdp/LNMP/AN7txsA=

            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 2 PCA vars 1 -10\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "3", ",", "0.9478027802278418`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV2kglF0btpQoSyhSyr5vsxlrdtkVqSSJmTELM2NQikoLpb2EpFBCpaKF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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 3 PCA vars 1 -10\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "4", ",", "0.9452169748749134`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c8lI8fFyWJhKRQ9l537pxZyciIioaZdefc4TiKKKlQtKUhZWT0laRC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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 4 PCA vars 1 -10\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "5", ",", "0.9500537384728138`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k4lO8bxUWhIqESKfu+zZjFWmQnKUpChNkZDKUklIi+SgkpkRYk0SLS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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 5 PCA vars 1 -10\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "6", ",", "0.9574054085126542`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81f8fxQtJfTUQpcje6y7XLJKVjKiQlesO9+JeFyUhJZVS2hqUsiol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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 6 PCA vars 1 -10\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"11", ",", "1", ",", "0.8648625531778105`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8le8fxpUSbZRKsvc8yzErREYhJWSFs88xDkkoGmZRKe2MhCIjK5Jw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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 1 PCA vars 1 -11\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "2", ",", "0.9621985256297492`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3cgVf8fxpWGSgmhIXvPu81vUUSyG2SF607rXpWMohBKmppGCUlUSqVC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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 2 PCA vars 1 -11\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "3", ",", "0.9548432165196685`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8Vv0fxkUZPUlIJGVvN/c2K2Vkj1JExr2HcVshlYaMhgbtokKpaFFG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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 3 PCA vars 1 -11\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "4", ",", "0.9518966461999228`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl2kglF8bxpWSClmSkrKO3ZjVXlREhLSRIswYM2OGodKiqAglpbK0oIX+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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 4 PCA vars 1 -11\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "5", ",", "0.9592537248637591`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k4lN8bxi0llSV7ZN93s1qGIpQIhUIq2yxmBmOohEqLSpFSSV8lZatE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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 5 PCA vars 1 -11\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "6", ",", "0.9578203437282151`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k8lG8XxkWJIkQq+zp2ZjP2SBSylDYRYRYzwzCIolCptFApUlkqlEQU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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 6 PCA vars 1 -11\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"12", ",", "1", ",", "0.8690411829610929`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81f8fxZWSppHRkH3tcbdZUaRUJIpU5r3XvZdrRqI0CA0NoRSVVQkN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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 1 PCA vars 1 -12\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "2", ",", "0.92106480298091`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3k81G8XlS1JCdEmsox9mM1gqCgiUmghJMxiFsMQJRVlb5FCKqGESqSi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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 2 PCA vars 1 -12\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "3", ",", "0.9348292212442989`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81f8fxZWGim8ZKbL3dpdrZhcRIpWsXPe6w7iuUUZFhchokCKijCRN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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 3 PCA vars 1 -12\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "4", ",", "0.9525287370671338`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k4VH0bx4sKpQWJpOxjZ3Zr2SPSIkq2jNnHDEOlEC1EmzZaRQs9JUQU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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 4 PCA vars 1 -12\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "5", ",", "0.9555738359818146`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c41W8bL0oqKiMqsvc8yzErGVlpSCUhxxnOweGgIUlDRXuRSlQoSaKU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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 5 PCA vars 1 -12\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "6", ",", "0.9498702491069828`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3dcjd8fp5JoaQhJu9uuO7q3iShJmqKteburdW8RJZEWkpGsBlFJRCmy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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 6 PCA vars 1 -12\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"13", ",", "1", ",", "0.8862459284362998`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl2k8lG0bxkWkRRGVIvu+zm59ihBRoojIOouZMcNQCZWKQrsskVBZkqdF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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 1 PCA vars 1 -13\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"13", ",", "2", ",", "0.9601356829794756`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c81P8fFxUVlZRSyp5n3DYrq4hUNMgKd84dd+esEpGS0dDQoEFZIVqU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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 2 PCA vars 1 -13\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"13", ",", "3", ",", "0.9677053704353017`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3cg1P8bNxqUEZFS2XveNotKJZKUECXuzrk7nCOklIZCSaWkZWRUZBSK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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 3 PCA vars 1 -13\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"13", ",", "4", ",", "0.9662282929853704`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c41e8bx0WJIllNyjw2Z5tllpESDbLinOMMHA6ljGgQSjSlhAYlGRVF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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 4 PCA vars 1 -13\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"13", ",", "5", ",", "0.9525576557317469`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3dcze8bxlFSGSkkpL3nWe2QhqZQVCrN01mdczqFJFpKZURSJA0NI0oq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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 5 PCA vars 1 -13\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"13", ",", "6", ",", "0.947234100623487`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3k01O8bLVqolCVK9n1nFsZayRJZU7YojBmzYQxaLFFS0UKRdpStiJKI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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 6 PCA vars 1 -13\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"14", ",", "1", ",", "0.8244087492611347`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3dcjf8bxltSkTQVae/OqbM6TaShRIsoRevsczoNFEJGGkqIbJUVUqGi
jMZVQiiJKFQS3waVJFrU7/z++vzxvJ7Pc4/rft/XoxsetYYlISYm1iYuJvb/
0zr0ok7tHyYk/mScP7iVgTMNtX2JmxhIyz8VvKE9HD4bXZ67zmPiQQYrSqIi
FIOvkx8pMVkoIG4ttG0PBXNjTExLQQjkS58rugkYEJ6ptdXIDcMyQm/ypj1M
OP3UWCYZzIC/hoGJQyULhYt1frW3MiBRu73oyRImdIp2xn56GAbXh2d/xQ+H
QTtFs8z9YBh4a+ekmPgyUMoLShzsYWPcTEH/9DoWpqYOzZmdyoJk76e2XTZM
+I1MuQedCYdhv/tm/7BwjJdcNl4UJYrflMKOcAwHI75W6UgUC613kr/8Fd2z
YnFtdjSbifpALynVDWFoo+UVfAviYdFoZme7EwfNgc092/+FYujrxIpXtWHw
9hgz/TfIRLb6CV3TM0xIEYKbj2UxYKYhRfXcwEatt6bjnrFwWL8vuvNPkonl
babrG8c5uJbfpNrex4OTl9fl6owwVFXMFh6KZ2D+2x+LXyVzEDeXELglh4vg
eaH0nkNMTG2fEsyaxcSpzsuXl/eFYF1QWdS2XWFYlUxM6VVhIzS2VWovX/R8
cMLndGAYvnalC4pLw9DYzZfNARvT3T5ioaocWCykaBk6hkDcpGrDxdAwXGtL
KbBV5KFa/O4G63QOJMxT1N73cCHdcWNHnpCNoV3LrDrbwiDHL90np8pGhrj+
ju1vwyGwXiVj+VGU1+05v28YheGsrCtZ8JkBi8CPUTLVDFBnCror2jfh1tJH
jrvaQrAksspDfU44EtJSZ+8oZsDuxDO26l8mLMxO947dZ+DjrliuqyIDjyr0
1m6I4uCg29MQv/AwdK6PF8b9ZOJkqsTkuvXhON945vLunFD4eLowneUYsJcP
L26VC4Onwu7I8dIQZJn9cbiix4KbzO5dgwlsmARK5lFyGCCeGTIvlmUiK79D
zmFDMNDMcHOzD8H8azal+zvCIWNf2z7DYMDNfWjypC8L2of1aofkmJjJ6K6x
f8SE4MXKZTu2iep7OYI+JbpP/6zKvSF7DnJziO/Yp5igTn/7vtaTiYDVikk7
rzPw++mNkBJRPeau8mxwEel86g1zxRYnJlYMJqh2STOgsSFx8vv3UNw5VR+q
oxWKK21+13pjwjCi6xnmERMOpc3Oa+JCwvGlKn7f9HI+2oecv0wV8pG/znu5
xhUO5KcUgpyz2Xid9M9Z+3IoVn5m5d8vY6DrvGJe5UgkbmRozHWjciB9pXS/
Kp2N3X1XJ+05bMTI3NbnXRcgx3zh2hur2fj20Ub9wl42tqXmtDnuZ8L0WkrJ
PpEeit/rjnwUnXP/L4g4IX4m6wRvfcZDwNm8m8mjkWh4HeB+faMQXFmKxLd6
NqLTvsaTl/HAtD9w8sMuJnLD70w/3s1BwtZvzzkmMZCKKrnrKytAdN0VWcNH
XDQ5Miwb8nn4V0paZ7crAvy4o3Nerhdgs4qOXM9rBiZ0zcfzR1k4L5OSmG/A
g7/JZJEPgQvCcXPp9/kCmItNTHTeE0JSObJPcykPF1/Sr3KfsuH03iPnYnUU
FHOK+N9ORmJP9BmLTzuZeIHyfYrnWFB+kxRQacKFlM5wgutiLtqeTvheZkcj
KZOg+bpMgN9jRWRJFx5GuuUoeQMCeA1c3N1QEIMceufZMEI0zmR8Mqx1FKL6
9pCXcisH2rcrfq8KigGhaotv+O8oqO5w7y3R52KRzyLZ++/4ePzqgj8lkQGx
Qp9L/2kycZisudXiHBd/43SCHFS4oOk38roawhD4JvVaJo+FsoIVrPsnImBz
WK/zeqcApAWr/dPrmcjRKlrzWHSecPxBSfWLxuyrKn8irSNR3JWAxCsRiPzx
/bZvcQR+rDNXTmjgw0/2xiy+TAQGU3N+OMnz8F/uYurqEDbq2B/rrrRxsbnE
zKAoQIDv8jJVW0pZUDCv+/b7BgMPh4rc517j4lXdf7n+OznIso5bln1JiKyZ
1hCpPwI8PtDdduAjCytcFJuMpbn4uYN/tt0lCj1RnB2FbzkgVf6733eFhzHP
JZt5rzmw3q4qk3ktGoprn0n/mcPH+ZbPlPEyFoiMTZ1f3zOw+OZbrT9ekehN
Wp7WvFyInt7kqwOJfKjuuVPpmMmF5GhxTGlqKHY6ao60PAmHe1v58fp+DjR+
dh055smFxrI+Wg+Vi0DpBSU+60R5bdyFEhYXn38fZrsdEeBl3r0bA7TN+HXh
pMLNiCgIXEjzIrdGgDdK12B2cEEKHDjX9ZILpharUWuKi/hG6dFNI3wctZ7p
of3lwdGR8cL/FhdR+7LiZP3ZiAzyWP3kXASOvSZtypnh4onZj9GsZg5gkb+E
OMZGi/uq/waVt2J4f7KPuU00DK02uOexhWiaPdbbmSqAvMusJR4X2LivnJci
F8OFRPlQT75hFIaek0I81Ln4ZFDxa1I012ELfic0OnBA32FoMBgfgX3aFTPf
BzjgqS/V63FgY/6q39au+izsPion81qKDx9x49AVenz01nRseJggREjl2mvF
bgKcvHv9RsG9KPwNVyG2e0fh8n+OClZeHGTf9g2QX8aHuWSlUeA4E5YHOy49
/sBFmdKDVZdOR8No5MFvo8QIjKbU+CvM4aGCPLquIZWPpt2dE2bmQmzbWd+v
ThTCrPgJzYLIhL1GikLoKBsVvH70veXhcDrB59AB0XvreyvX/47At6PFr6S4
UZC8MvClNZiHPoO1MV9/cES8f3omeXM0LgYWH0mgRWMBb0nr6zImgs9ZHSp+
xkaCHJ1JIXLRcibucKqIA2vezwllpUfDjLtGZ+4RIQbmXxkrecxFwP3q8/o5
ojorN72vDY5B+EPn1aHfo1H/OPy/i66RuGDkEudhwUNQat0v95IY7NsZepv9
KRq2zOBLb/lctMuM7FQdjMDKe1aHd08w8O91q3qVNAuKQW8HU1K42Hju+B69
u1xcOPZykYRBOPxzNzT0NrARzl+12OBOBHrvlRzfWSqaw/lrNsbbs+B3/tUd
fZGfCX0O8YzKaNxs8FyqPxCFXj+KWMsTAdzevzEJTYuEf2j9t/XpfFQYB41c
bBOizYVtEf2MC8cf3jMR6zjY837JDnUnHlLnZyVpSQnxS2eJq1cBC2fvu4r9
yhbtnYx9r9Y1cCHX8Kzk9F4uKi+J/aHvjcTZrKwjz+iRUKhKX5MdwEbi9LBT
gykPXqf4c2idUdihcsRrcRYPPq9Lrhwr4aFnR8jG+Qweaugp89uvR2O+3J3J
4rMChFdViE29FM3rkYNlzmostHFM78ymRmHtvPl/DdZEIYzd7/eoj4+krjor
1/c8/K4udzmoHIYPGuGak0WiOoYHFeh5c3HAv3X24GI+qJvOiG8P4mLP1dy3
RVQerGoz/8Se5uLP72O6bvOF8BGc3aZJ2gyzzl83pe9G4/2tLn23gQjknlAf
bNrAx3KPS54ukTz8che4PJvgYdZDab3begIs7lRXklktwL4mBX2pCS6mZaUp
SzI5OHAgUd35UQTq8+rS1i0ToHpOUOlbJS5mf1obn3JfxAtq+17v2C2QWvls
N3ciGpFrmgMeVgtxlbhwRJwXAfIMxfRIIAfH9yxfsOEqD8dTkgLfJEZhQ+q7
vYGiPtVMfm2UHmRDnKV+1UHs/3kFl6e+Eek9SX9k2Fvkq6rIITuC2djlLJ5o
l8BC7yGTQflGPkxzl4732ot08Fxt5c7CCMgvCYq8WhCB7RoKYk80ohGy9L1v
6q5o6BbbjI2MciD+6Be5wEyA/H09WyL/MaHusqLluBEf/G/J5af9ozGZq2K4
uliIE+PWj0zecHFoWZQvPVe0P46lNF1TEOLDA7K84nQk6sNIe2aZM5G4pSrR
ZYiD8UWD9y428nDS+UmVXzUfa/LrW1u6hFjkf8FR8DQabx9alKyN5eFUrcyH
9SIOXgojf7M7EY3uupqnLj9F/bkjs3NlAxNaIZWG1nIi3+i75qGdBxcebz56
harzUf78npdMazT+yvtNZIZEYfSD4q/MBC6ST05NDzZHonUqI+4vOQYpsrm0
t1tjcPJYmkA3PxJNCS7FxiLfs73MLSrgbQyidl0e+30kBsHnx/mzA7nQ2jst
yDobidgmVbEEbSbm2y6S3P2faC6oA8tfX+WiL17qyR1PHtJnaWz00gvHbWJA
uWARFzdHP0QQtCJQxr/THG4nRK4gv/EZgwXH4YykizlsOF50TvqhEYPaFavJ
SaL8a3o0HdaKuODfJ0uoV4gW+aj9kydP8DGjSzm+uSsKLvMPmSiJc9GbNrh/
x24uThravSCsEPmkrs7Rg3GRyGH84YZeZqHqUrca9yYLSj4OtQd0Rb7nsH7z
owAegln1cy01o0A6c+h6IzkaeWoeRsbn2OjuaJkwIfBBM1Od+KAbjaKkHysE
NAHWv389HV7Jg1LK8MyzAj4O6wnkZ4n6b5R6t3DyZwTyeQverFZi44Lj+Ysz
29hg0D57Cs9HYbg05tXztGiYP7q3SOoJH+lmg4su/OLjT4srK8clDIgIecC5
wETJzHD+mlgu/EclHhwVjwD3/Upqg4iPCsGl69Jc+ajtrDvansgFZabBbHmG
qP63p5s+/41BovLF8XcZMai8LytjrS+EUV+HG/exQOSLdz9xFf0/DR9taZBQ
EyBufP6E8h4B7qlVfx/yjsCzCKujb7q4WKf5V8chnQvLV1ckU1WFiDVTvl1u
L8QmT+cJjg0XU/PP7s4T8OHQV7+3+8pmmIxKJV8Scfwcw/K53qgQF/sv/X7X
EYFfgqNDc89y8PX2kVPLskX7sCx4v8MlPdyIfJOwfJsRNnH6XIwtSOig/Eg/
WGSIwXtlY3HairitUGlB36uIaOkU0ud6TXipXxqY6tFE9w/f4FvfjfBwgTp1
esIAbzOWnHc4S4TvEf9C9bmmiLUy2u/40gK77chuB/cRkHfczn7cjITuhEEd
y23mII2mNm/JNMF4Qp9j6jZjeJTH3ce2BQhrM4y+ZW0My6SV/XuHSTj+7eNH
KVVLLOM1v9qRTYJ8JtZn3ySiVXbZZbu55uj84JDVu8sQN2clHvorbop9GV8X
Jf4zREJz6fELn41QmfNY5X0OEY41O/62GOrgG/HuaTZFF/l33i5oWmAOz4y7
IbJGFtCssTq+slkfq6oOvX2zRBegqqy/qUVA5w2T6aE+U+Q5/9w6bmWAu+fx
ZV+eKbSCkhK3KJJgJVggjAi1BJupMlp40gwLMwk/n/60wOYNXclbFppD+mX5
naizRgijTMaV36ai2HLSrEuKCnOXkaATARbYy/F1SH1tieY3F70f5hiBb6k0
vr/bBOs7+00bO4hQk51rUMIiIpRGXf3qlCn4jWH58UwjDD7/2ETuFtUjkF54
ZQ4F3qmpd4bvG6E0zeTr5xozjKTE7R3caQoyVeHL5dMW0N5qX6P9gow/ygKt
sIUUVOs3na0bNIcHefcc7j8CnCZKpQ+NEZAWP1z35CoJXWtf+hrdMgLNqRE/
q00RuXKRRBtfBe7/bjabX9TCckPFwwukDVC+trjy5LQeuv3G5CSPklGRso3x
8gkJHz+t61HvNoRGcQ3ng7QpdOaWVXqHq2Fe9ZbejHW6SDuzcf6DXgOcr33E
/1xsCGcV1ShbMy1sWn7rYZqxIa6tVeLzd2ijVOhVav9YF4UnT1yKiLRAQVaY
n/8fAsiRHYWuB4hgLMr18+4yQUfh7aY1kYZ4mjxv+01tXaTbt2x24SzESrFV
IwmndFHcUnBrVZYRLh9zmaURYITnPvSw1/NIuCoVgLgGErJPqVmzZYgY5Vt4
pRkQ8LnDsEEhxBDbnSncZx7GmFL0eyr7VNSXayo7XY6YIn34ctv7AyS803vx
oX0LCZ6OnFDfCh0czzZs7avRxalGzWOB18lw7rdhRbqQsU63dPC4LgnfTrBf
WYrpQ+WozcZj42ZIzxmVVWNZ4aIWfWCNFAHsCvGoicMEnNe2aqfXWULBuue3
xDgBR4ayGu5/MYL0nwblY/tNoNT6btR1koKEOeeLVx8j4JN40afs1XqQVzsn
HRGphyLjx/5vovVRIbF0Tv6QPupzL0wp+BBgmD/Oi3Ayh8TGDw/+U6Ki6e37
ONoPEqo/NDJmxEW69PwUI5VJA31/35U13VTRf87ZDZkXyFj1989C49ck1FvK
f1FaRsJURXDMZQcL3CaHE2kMSyxMdz7Y5m+Dw6lK6kMBNJhK++Q9k6HifmCM
ATeECq+t+p422+l4klbl4mhDxDbzmzm+NFOUlNCE7/sJiI12+LzYjY6SWl7s
0CANJuuiSwZiDUQ80NCr0jVCVplLtN9OIpImw1419luhMWDyp3KyOeL8cpKF
PGNUhf5D8y8aPKW6b5+bISFgU/B39XgyqH/vla+1JYOT0rrDxc8eFf+SpM4M
0TFmTtn64iMNYwlZLsePU7EluWavl4hfx9aO0SY+ERBvVXdx9X0HuFnuL/l+
2haa0tuORjjYoFZ7A1VxzAofel/mbg8j4cKMgvHJlZa47C+ZlXyNhOvypEPU
jyQ4EqYZn0Rx5KwyPPuqlAgZuKkd/0OHY3L6HLUmKwhXBrCGu8goLNqkLnmC
BMWxRydaWmg4vMifkn2BhkTFbs4tcztk9LuI16nYgLjsTXW3PB07nfrjxNSp
cC6PvKvSSxXpn2ticJMKqyf3leXVqIi1LQ0LvkDBC5n1my8+0cX9vLG0p1x9
nIuqt/TVNsMu+QvCbzqmqFV6u0vRyRbKvRyHbFFcgt++izs2k0B0clMdu2OJ
3HOqb1d9N4B4W+Zoob4ZnhutDuw/T4KEc9bSf0tI6PcVul1OI+KM2PqBuX7m
eDs1rthlYIwKw81fymqM8US3+cFfCWvkLQmILX5Ng8zD+O3Ox2jwadfMcHan
QK306AqjVxaY7RnT+jnGGPaLV5fOIxsi7HvH6fR/JtBMe+X0WdsSPf7mKdeY
REhST9CsztrherkG4x2Bjj3XXP2UU8nwZkTVRD6mouvwrOoBAhlf5wkebHUl
QbBf8u6Wm2Q0V8RqtFSRkDJLEEj+ZQeZ9dvtr2vRQCbWqBQoGKNg+kzLjWFT
mLyPLBjqs8WyC+Ekpyk64rOXUfNP0XEuo6z4Z7speqY9z589ZoeVU07uCTO2
ov61Z2dJUiD/xVHq4RsyPK8vPD/XzBbkZy+ES1ZSMcTTNNBPNEYKwZBasNUU
Gq5XumQkqNCNUFobSLNAzynvR9d79aBcv+/wjJ8hSlmSxL0j+ojV8Gv5scMA
W+rD0m3uEVD+RCtI34OIiCV9Cb8WUrHWbeYIwZGC0z+epgmvUdBQeetH7S8r
SJAmJu/q0zBX1d6KbUWBE58dpetORqT5uMMpUV2ackbXrh8Q8ZMZ8XRRDwmL
FvhcoE/YwL+W5HX3iBXe3pTlZbjRcEPt5LETuaL5jZFa8e0LHZWKgq19xpbI
+JNZVTlogkEKwW7jFkvM/2y4QdKMjsOjViOPy+hw+9IydqvdAFoC0tdl2sZI
3iJPpf2xwLWjCy00rawx23hWmpoSAZ7XXrNeOJlCcR+tKHjYCqbiT1du/EeG
LZvmSSVQsNDLdX3mQQoCiPdsMlxtUcrvu9RrKIoz41fM6h9UrM/36vgQS0Po
mCGt0I6InpOuOg7XLbCyLXZbmYUDPsyKkVhSYAfdc1q/kopt8Gj9y63yDGu0
51tdqXhMwsqRgmP8WBICHeoCZN+R8Herxs7Bk2ToNfCMPLxFceg9Px1fawmP
c9yQY4V0zD4gk/jZj47ANn83fR4F6TJjo8o+ZOz8G/7py4AVGNedN3Lc6TBa
tMBYN9xOxDXbFfEiXmzcRJzKodDxPS8hf+4EDQs2ZIf/iaeh2G08dmMCDXE6
tWZXdlExNmfR0kMdVPhXsqlUYz3cMX720mbcAPMmvi898dQMM7lam+tnmWMf
oynnxYAtbFZrW1U32WDhpqwjx1tIqEtUdB1gkVCyfEB4y13k4wzWKv6eR8DH
7M7AUGcyLF8oNuSCDDPGCavgdiI87rHyUiqImPacTW9tN0aOcjbrdrQZEkpN
3DayrVGc3L6v6CQdymUJCTLnaFjzbXedbCEVsukNflGdltj7oMe/ctQEvRt5
2Z8fGqJX7mP3pQhzKBjHm/3cbgn95d/d39ywhPZQ5GGZhfZY88gpdPiSNYTu
MfX/9ZBBnOb7JJ2yQvbTO9vzFSlQnVKK+V1DxoVLhK1zl1EQo37NvmOLqA9a
Od81JexRnZBq+uU7DZP9jy7rdRvjKnmP4+cOc9TIe0wdF7ODa7/Y4s5zNqia
pxOxYpQOy/zVxe7xBOReS3ro/toO4qEWvVkK9lgZXOTa7E/Bv2+y3k9uiL5z
J8TLXtUWQZfdLeRCaDgQ5vLCW8wEe19nLllYZIZV4Vc2R9KpIB7vXep91RJp
Xd3rsqb08G5boLfysDEGPrvNFZIMMJ2mcjTf1BAf4j4sVBTpMfJwhVGmiFvP
DumRw7WpuE2qGzZhUZHaYTVcYUrFtsHY6SEXazxV9R2JLKPBi932k9xPwf3p
hCK97WTI6c+pIYj4aFdWXlXhQsKpgus2UsoizhhrxyTQbbHwoLqLdDIdR8py
Ps2coMFy6858zj8r7KGnx1slWCN932G7UhHHl4Ze4h/UFfnWg48c+UpkSJYX
Pm/VpqNHJ3Men2ODL7ebH/dpGGJM52qSm7MJolUUOuVXWMJx41/lrYE2MAk6
kupRZI5FNQ2UCClz7Hy0++s7RTr+uhF+DtVRcH1CcaNNCwXrdh0ZUlKigVJt
VDTsa4f5PY0Rj6ZtECdRmvfQWuQjmj62TadaoccqYZJCJaKK+W3FXAkSEtWU
SA9M7REml5aT6G8PqmPArolCGzzRVos9xrIBQ6LfxESCDKkvv9cdVSRjRZdN
FWmEhBM3g6P3Z1DwqaQtFIlkPPT5uIZWTkLkKe/7dNGe7PU/oLG9nw6Z50pO
hScpSH2oL3uzjwyucrt24E8r5BkH5PY/sYaODlGmbsgOctui1szrtoNWqmdX
UZUVNMTbZVWS6Oh801jo1EiDQ/T6+LQ/NMwWJhr8W0tFxtLeKuVWGhYRLm4q
FephoqPmwo5QI/yIWy7sVzaHplP5+0M+RAyON/zn7mwHFeidJlbbYbNUbfFH
STK+JYYnLBgi4T+bvonoaCM8KO6z/VBoAUkj+ZrSQBJWfW7OmJxNhWawusQX
siXipPaTdtqRsO+v3Y0dUibw+ySn45ZAwMu5nrlLe6zxolLLM9/WBmTP4eY5
Ij1dVjLLqXxBg4vrlepJpiUM5zVmUoPMkJcdqnPgoyF+bG+7G7rUAooexJdj
/yyR4C8Z2iLy+7uwTlwwY4eRpS8f3O+1QZfNp6VhA2R8Ob9zmUaaNbr4Qec9
RLqkh1gW2cpSgQCn77kBFOS2+bY2W1LwRUrvnNp2O6QE3T19J1vkj64+2G6k
b4J872d82VYiZkf6GnAmbDEZoVOSu9gOSsvu3t7kbA21k/s0Xp61RJSHdWaJ
qj0cuy8duPXTHnN/FFZwD1CgKPOuoiCYirvcjETnn7YYK+cPp6pY4X/LPdZT

            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 1 PCA vars 1 -14\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "2", ",", "0.9545815858880866`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3k4lG8bFSUtspRIshs7M2axVkSSVFoJYcaYjRkzlKTSIktJka0SJVRK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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 2 PCA vars 1 -14\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "3", ",", "0.9402593269503905`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k4VO8bxrMkFQlpI/vOMJvB8E1ljUTahMRsZphhKLKUCqG0U9mTJSkt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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 3 PCA vars 1 -14\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "4", ",", "0.9572201545080603`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVmHc81Y8XxkVJRRlRpOy97rY3kbIaKivXHe69uC5KUmlQNDTQjhQlUYoy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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 4 PCA vars 1 -14\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "5", ",", "0.9369484677508325`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k41N8Xx22Jb1pQypJ9F2Yz9pQlIYoWsjOMmWHGDCVUWggtSkUqUbak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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 5 PCA vars 1 -14\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "6", ",", "0.9508072313916506`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c8ld8fLyINyWzZe7vLtUtlK6JhC3e493K5RkNGQ6JdJA2V1VBKRlTC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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 6 PCA vars 1 -14\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"15", ",", "1", ",", "0.899506368144467`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl2k4VW8XxosGFZVCk8zzeGZjZSoiVCQR4Rxn4nBQikoDSaIBTUiEIipD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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 1 PCA vars 1 -15\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"15", ",", "2", ",", "0.9452374566510664`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k4VW0XxkUDzQgNyswxn9lUEYpEhUKmcGbOOY6KpKJQvEqTpDKU8Gqm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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 2 PCA vars 1 -15\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"15", ",", "3", ",", "0.9310855441674367`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl2k8VV8bhkWFUqaUMs/j4UyOYyiEkiHRREU4s+kcRCppUPgnkkilpJBU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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 3 PCA vars 1 -15\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"15", ",", "4", ",", "0.9561998739117458`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c4FWwbFyqiQUZK2cc4xlmO+ZZERBQNQtYZzjkcDkpWKrukpVJZFSVl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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 4 PCA vars 1 -15\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"15", ",", "5", ",", "0.9673290067424358`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3cg1P8fx8tKQzKTZO95gzP7RlRGiEqyuXPujuOMhIqKoqKFVFZFQ9Iw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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 5 PCA vars 1 -15\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"15", ",", "6", ",", "0.9552856018961551`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl2k81G8Xxm1JopC0kX3szG4tKgqFUBHCmDELM8wookWK0KK/RCplL6m0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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 6 PCA vars 1 -15\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"16", ",", "1", ",", "0.8610044597943005`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k41F8bxouSFmRrlX0fyyxmrGlByRapSNYxM2YxYxCJkiL8KipLWhCh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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 1 PCA vars 1 -16\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", "2", ",", "0.9350360514264757`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k0Ve8XxouSioQkU+Zr5s7GJmQqYykh4Q7uhHtVIhlKoqRRCdGAypcU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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 2 PCA vars 1 -16\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", "3", ",", "0.9428269058622111`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81e8bxkVGiwhFso89znLMhpUVUkRIxuGcYxzniCJRkvhGpakyIlSK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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 3 PCA vars 1 -16\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", "4", ",", "0.9573032471065274`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8Vf8fxysllRFRKdl73uWaRSEjkQaywr3ucl1XQzRUlFVaRtkyvlJK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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 4 PCA vars 1 -16\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", "5", ",", "0.9449031732131647`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c8Vf8bF5WREUlF2Xve5ZqVTSXSFBHucC/udaV8K0VSKKkQMkuoFA1a
irxRqChEKZIWKSJkNn7n99fndf44z+c8z/NeRy0gdCNLWEhIqHOOkND/TzO/
fNXaCSY8NsQ/GVVkIbOp9musDwO+Y6mfnlkysGGHw1NHaSYUzEuE/VqYGGqL
q5NjsiCItF2e4coCc0dYWPvVnVi6U4a5SdkPvMxai2Xn/NEtNBBw7k4A7H4u
Wy3iy4CLz9X3ifsZKFmhOtb9moEQ3vYtvnsYUC2N3PP+gT9KBl6sFKL5QyV+
+R2XY/544NOlPNTjj3Kud+xQHxvu9Hf/7sezMDt7YoFoAgu2x276ma1jYfPo
rIt3ZgDqHxf/q1zEwFRZgY5SKHE+GZ+zLYcBxv5auVOhLDjnisrx1rLgtKI2
V8BmYjCULyGIYaGTVnT1mzcXo5nPhsUoXLR6tfbt/eOHS/J3z79v94P72km9
P0NM6KoHNnTfYmKuoW9ryhkGPu0zu3r8UwBq3ZfbRE8G4FdPfyDNhgnbTr2t
zVOBmBtT+e/ZbTbs3NwKqpP84RVbUm5Q5o+FHcMrWuIC4extMq5MC4SvtB+9
7wQTH36Hv437ykRGT0GB7dedaLaxr1h83h/r4ozi++XZuNQZ6RKXyUDG0PSG
s17+uPbl0Y5Xt/zQ/DFIPA9spDspHC5cyoKxIkVZy2YnLhz7Ea5YQ/TRGX/V
QpaLcpOwF+lbmRA2iFd408eBT4exN3k7Fz8OrDbt6fSH5am0Kb2wACTN0di3
tyMANLf3BqQUJsxuLPh1RdsfK0QdK2vb/WHs1RUqVs3A0HPaVdo1Bq6vqrM5
0LkTbQW2/tcjfBB1PEF0300GEu6rJ704x4Sx/tn+yQoGZuRTL7FFGKirVN+0
PTQQ3t47I59FBqJn635exE8m9l951VwzxUZOc2bBwTw/ZDmz5pf2+cFKKuDm
awl/PByg+39844cz+hPWheosjLE+tDgls6DrJVJEyWNgj/uhWy7GbJwpfidh
vd0XVvkzfTeZO7Dwknn54XcB0FhQ3z1eGQBnlx8z6R4s1M9PvT/czsC/pI81
VnXEfm0lExWLifkXhNBniXpmjKHC7nYmzuUZvWJnMDEuO5Co/44JT1fZo5GX
GfgbvSbtRCUDkuvWNzlEM7HooAxD9C0DTkNRi3vnM3BIPEnK4IAfbmU0+qkS
vDgqJHVQvj0Ao2rr/dcScwYpX3XT8gB8erg/5q9tEMozz7dZZHBRvMXddllh
IBq+SzumXQlE29E/9ioFfhi4dDn+U0IAenNki6pG+fgl17pqnkIo5heWH15M
Z+PHXLGvIlvYCBO7ocG9HIwPDemhFN1gfOsyX3r+EBt/q1clW4oGQu9SfFkM
gQdz57SkBgkuJP8PiAgeVu3qXWS3KASeWUXX4sb5uPN0dq5yNR8ccYrwt0Y2
TJukns9zZ4NpdST97QEmmqSf8MVLGYja/e1poG4Y2g8Yb8mpEEDwqFBcq44D
hXWLKhf0cPGnnLTF8kAItueZbzcODsEueVWJvjYGtj7v2n23mYEcsfjYYk0u
eoqci09e5sAw1WD+m+Jg/D2xsy5bEAKRRfyvy1dx4V2Refm/bxzYvVmbl18d
ClnVV5LpO0IRLcg0fh/JxFuhbe3ftxN7eHnUs0qXqPM2/2FyXSA6G6Y9CtgC
0E/G8JmhPPyaLCWLOHAxJhdusKuOC7fB/INNV8Nwn69iS1sfhsyk91q1NjzY
YJGUY0kIVG5U/lrnHQbaGbHSEZkwLN7n0l+mwYFl0vpW81uBeNxyfhsllgHT
v8tmVn9j4CR5+W7jbA4MTF0PeQ5yQNNo5vY2+WP46Wl9urs/7lx1YlWkhSB4
Z+uWdF4wSEtctyU2MkGVEQ44rsRCms0wJWGzAK27ukWcNglwszcKsYUhyKIE
nFi3NRjDWwwWRTUF4ZDPuKVzBQtDCXnDdlJcOOfTJpWI+x6xux4VdnKgtdo7
0CyQg+9SYg/Dy1kotPtbkeHIwoMfpS6SlzhQSbc9EJVI8MUsYnXuBR4a8o4v
bFfj4/GRj51HulhY1j9r8nCMiZ/7grK6HULhmpZadN+ZD1LVn4qvhVzsE/92
puFiEMz2LhZLviSA6K+t0W2aAuS0f6BM3WGBX/g9cZjJxIprHcoTbnz82Psw
RGUhD339cRcHY4NQkuOoN4foQ2T8Zlh5gh+sKVxLu1V+cOm8m9o4EAi+dvJZ
H0Iflq3+SuujcnBGwJZPJ3Owa8cBlLE42B5T+0Q6koPnRfeuDNJ2YW2fy/Om
lF0IdiBJ83eHoH3lSM7F6BCQvAaze59z8KTivszOIQ72N88f9xkNwsTT6Pxx
7WDY2DCebbvOwYKSO7E0Uw743mtd67NDcOQUjTH0KAT1+sPjZ1oDCRyrPHcK
DkS7y7ovQ4t2Y8BHeaiZHwIt0+0uRWweDL6n76n9w4OUw7yVa8+zMdO6uyUr
hQ3huz/6irVC8bnp3F+HvaF4r1k5NpPLhvYe17FEgpf0fVqaQ/tDIHP6ZdBR
pxBwl65S77NmwzA7MEsplY2DpyXE2uYGgVPVladfHoT+mnfbH0Tx8DvbpVN7
UyjSb1++cvVeKK588TlfZRCKgi82MqZugfDxitY3HmTDQKRK22uK8PcW55VC
u5m4I3d/3YWzAsh1/stbkCPAeHzNNpkFXBjwbj+SCgrCi4M90/oGPAw4TJge
FeJB/2Y9zdiICf0x6+r7ukxUcgfwtYOLk+aQ+AwuKrf2V239FYLyt7P+/u94
ECkc/PTalwuNY0sSDYq4hN43ZMbtEiA9RO+nhZIAS7grX7fdYUJKVnpiOomJ
KAk6k2LEATfis/QcEQ42vlngx0oUIPnU8VdWcwQYXFg4WfaYg5AxIdHeEeL7
Fr14U+sbBvPHP+Tm/heGxscBX/Id+bj4tM/pXSQf3gmPxlzKwhDTdn5TrX0Y
LJi+FzqCOGD2XjxWUczBmnumJw9OM1CluDSNR/iTrHfHUHw8B7GGaX7DS7g4
n/JcSVgzAErHWuo3VPshIGjdCs1bBB6qHuZt/BEM/sKNO/ZbsfB6W9GfnB4W
/J5iTlKVAAvlrldndQrQv5ki1F4fjDVJFc8upgRjm1/jt62JQZh/uaB8YyEb
nQ5sY8ETDpoTz0c8EuIi+s3KfUvtuIiqm5q/uIrQJdWVjm5XWZjcU/RfI4sF
alJMy5YmDvw27VZ7cJSDqgtCE/RDfOzSPb9xTkQoZB4mbsz1ZEN8yRY7+2gW
3DKCFtB6QuE38tO2zDMUG9rKClPKuLhR8C+z/0oQaujxC7svC2C20/1oVqMA
AQ8rhWafszCv85KoozWRhwL1bolSQ9Eb/97mjxYf/uyBzXVfgyAdcMRz9ekg
/Kq+63BskT928iooe6X98CfA+6q6OweyGa0ptss4oPpkztnrzcHhL27Lci9y
YFqbPLHnLJE3hDT0/yN8Z0Nw1n/LSbtAejEg+q5wF95c79VwHgxBpU5gbYYJ
D7ZrL6x34BO4ko6q2baGi3kP5qvfUA/GwoRzG9cQ8495IaMxd5oDuYIsveEw
Do4ciV1qX0f4y9i90iezIahe4F3eIcfBko49W8ldgdhF7T7kvicc+vKyr0i8
EPA3tno+qOYhvpTdRbXjg/yPonfKKxDVk3MPvVAJRGr8Ua+XsaGQ1ppsld4e
ipqZz83zhwj/ROoOFUk2oi/63k14GYKzJce0RKV4qH5I3rnPl43fM1GvG/az
0X9Cd0iqOQh/petbiqKD4fxUYU0k4SMVCuaG34pCsXeZjFD9MgE0alcOfCP4
q3bTfHJ0PBDl/5UXdpQFojimL5z/h4lGX38XXgwbQd/i7p7dJoBjr1a/DUmA
tCmzOt2XhF6dmGuzQpbwj5T4F5dkeOi+WjRLVuCh0Z8UPc+AicB6/7+LLjAx
pTR0L7+Zi92yPUtTlIOwsbjxdXsvDxa7/RdO+PDR8cC4bNMeLhRT1d5FRHNx
wZ/8zTJNgCfus80v7QR4c0ssck0TE6a9p0y2z2dhvsfGB5ZrOUiPa92uKcbB
3af33MReC6BPRWb8AUJP3sqOJUdxkO8y+ldnVQhezyZF/CaHwfuWvPlHRhjS
U44HqxXzcULK85SxOTGPO86hnh1h6Ftavv+tSRh8c6aCRL04sHlVcjw1lYs9
LxYLRakw8Y2UT39H5OMs6qBtG4GrZ+lrl+q+5SBx3rIdbuoBiMmz8Q2/74dr
429DDJVDYCgmNFd8LBjngoubnzBY0FwdUer7jQWbfPujw8vCEG1WOBglFoaa
vuXWm4ZCcFNZ6aTBm2Ac/Hp4Jj0tCGfCb9/8sCAQDgtP6MrN4WCz/Y8qiWSi
by3LZ4ZOXEiP5LU0qgQjjzHB8Stg4Yv4CgsTOTbkNljXHlHj4ufPmr7jRA7y
ZTVKmiwPhYbbdSdDGwGKFNZq62SzYbLz8OjK5WzQ9BdPv1UTwE1xUJxJ4G7r
m7a/AYQO3O05YR9KCsJJ9WCpecT+R7zN73nVCVDMXfLSlbhn+iPD4sQ1Fhi0
D+t5OaH4Iu/oKt3Ih0HdPaW59UFI6f3c3UwlfK7dkZXn4I9f8p84Q8v8UPZv
pHjjHg4Wv1MQv0X4KOfNGmoToY8u4R20A8Teansene6O5eDmo9/VP/2I+d/4
++LDb2J/2m6BTet3oapCXMxMg4cRpezpoSs8UP8erHck/p9q11gPKR3mImJq
4fQiAvc/trh0XmkJxpMQ09MvezmYoXxIv0vkDpOWQpGExTwIFezu/iTCg896
++lAc0L/PXbNCP8MhPXXxkMfCV14Nedsc4dPCLIZJk/Vx3k47DifrCTEx1jw
6R+SWYEQrZ13bc0Hgm93fA9bX1CH1gFy8R9FNfgEfnXQMSYhO9o37YQpGUP3
7kxGqMgicuRLXOg9KQjmx5M+NC6HxKbTBwVSuvg47OF7/bs2rt02iMs8rI2O
pJU51llGSC+djR9jk7DHVPuwzXNj6OlB/5+OLopSLa2m9En4KKUar9NtAtJ4
Qmt4si5K3kbuu/ZYD2vvRlTgvyVwrG25KHDShMnRNQOHRkgoiLZZ0ptJwWpu
a8u+XBK+rkmyZg6a4LX46gJLSQOwQg1c3aUNcW1e7Infc/RQIvtk5h9xRrWW
p57/oA3JDu0bnzMNYFOz73e7lipqLVSF76SqovhWx5IXSwxwPuzQ1NN3hlhe
Y5q6plUDXJ1LE4uz1QGq/NZryoaIv9NfmlVuhCL7n7unTDXhsnzJwdF8Qyh7
H40NlyXBKmTLr8TnFLCZ8uMl6fpI/Lm83/WVPnZt740LVzTAbr9Hbj2qhvCn
zETcvUHFX+XITB8fUxg4jHqneRrjZdSFOHKoCVpf5rs/yNOGYm2lUusVHWzt
GdBrfmeEV+Qh6XlUE/jRqK4tGXpYLPLZy3tSD0NPu16QP5JwPq3FLrKCDPeE
hFsjFdqwW7BO+GeSLkbjIw4NRerh7Ea/ijMPdKCy26pG5RkZS49qTzxrIKNa
40XWoyEDtF6XmVe5kQq76fL5JyYN8VViRKKRZoTeTc89tK9r416bc+P1N8bg
r1ES7gySx8exX0tY9hqw1ZI9uWS+JqbHMvYtqdLAx82TEiKnyciJlkhqLaWg
6/2WvqUftRB54eTbW9baUJW8U+UeoID+p5sbai4txvHMHQvv92viWtAxuYYK
LdjLLw610FeGP3VR9oCwCi5tkgsK2qeCs6QXHpqWmihJT7sQwjeGxPMMRyuO
Ccj8dyWOR4yQ3eCh9FRUD+9KbrzYyNeCnmF4kYGyNhKt2nc5BCqia7ynqD9G
CTfbr15fd0YbhxoUbTZR9fF0A92/TZqEbUsHdZu2UpGboWDGFjOChVx7yb4Q
I3x4p9Uks1ML3mdbJiaCtDEru7lBvEEX7m0mwuE5ekgcKeh8c4SEkRNLb/xM
JmG9TaCfR6Uqtn6zIJMaVZHRvDzF6zIZ+61dHz5zpGKLWvlQqhoJSdsrV8ga
6UL+tPmOlCl9dHluau/y0EO+Mn1w41xDxPVfWhp52RA5Kqbd9EcmKI4YEKlw
JeHUjzNNFZ+04aJ/PuMvTxtyr1+NO85QQCErvjxOpuL9nNL3ua7q+HZXuDZ2
VAWlOo+3vRRo4N3ok+lhqhYaz52fldlgiHHeWNX5BwYQ3vH2/hc5KmSpXbQA
fyqq3zYz/s2hYne2+mi1OQX0w18LN36kYnHO0sKXyVSs+z2hqNNGgsyHlJT5
HBJmK33DCqyNsW+DlHxVpBEUE+2PdW4zx+W4NPP1jyygN39D0RMxKiTcMkc7
eihw262x3nwvHTQn/r55e+j4z+BangdNDzLOJT1FO3SxR2D9YYUzHaK5tDkl
E3TobhGUDe7RxNRFh4u9p9Rx5o6DYDNxT3RkxO7VJw3R7Dnzc1GcAS7cI9d3
bdLHQ78/aB2jYXsdZwKuFHj6+H5fup8MT8+NOil/SQiMf73PYbMVZt08qy1q
rDFpQNn9rIuGrjcl495zaQiPqznkRujXE90HyYNXDbHf9FG+a4U1nOmUXpcH
Vlg+/7/TIdbmiMySMJefoeFt//Nze/1JmKtUJ7v6HBkF20TOxF0i4aqQhln6
ZRJsDP8y3v8jgcsV7v57iwQxOCukEn15ec7I8zrMwFvjyRrpJeNFvHNI2xEK
ZCfr0trbadgQh1+Xifqxsh8DrxtYIpOuPWdigQWMVr+s/ihFx+02ecPf5aaw
v8u/Ld9PRUfVZ99Tr2kwra9YJKVAhetsTeDJJxQ8E9u6K79eDXRWfrrrBVVk
hzaaeKjoQzwuRme3iw5q5ToOyNpZQPD0yJzwzRYI/uWx4t0uEvK1+H+2PjHB
uezFHeu+a+L8+8/JmQqaeKrt6jWQQ0LTOr9yOoH7AQ+ec8FxI3gLeygkHjZE
x+yUbK+mDlqe/blyW08L9Wqt938Lm6GPMVIblWwKsQf799qn0JCyPW/9/DEq
FMpPO2m3GIN84X59vbQRrFa4lkuTtaCa5q3nkauJ5cdb7D6omGBolRlHYZUJ
RKhpNNMsS0zmbitRO2eJ6EuOmxclkHE6WeVxCOFXvSfnVQ8akmHsUj36K46E
4MMit8OvkYEti7+vrCIjfl6wF3nMEt/20hU28S1BNqqRvyqjA1nJP69mCZ3T
fcO/+uOrBWbcLuvdF7LA/tzV1OIMOuZeO75gw1lD9P1dn5OVYol80ZqNnaEW
xP66c8+IEDjb+LNfU5aC9ZcVcyT1LcAoV8g9rmOOH9zlmhqxOtDhZa3QrtPG
MsfCXjFhKm4mUB7Y/6SgL8O97nK/Ol7s9N5kvlsN5SwRo0OjGjCWLXz1XVgT
4Y3+ieb3DHGje8PKN0KGCFn5NWpMkYrvLZp6OhMUnB1uOM67REGNXg83oJAK
YdL0zG0NGmjnWorlpwg9D2KHqrmQscSrjHW/lIQXeeObtg4aY6WTeCfzuDGU
lmw4T582h2ZM3adDDEt0XBPnJjnToHZoc6HiaSr0wuY6fftEh1zbWOeBB2ZI
mkh+WDWki9Ps39JSm/Sw8IPWdhF9OpSVRuxZBmZw/tQ+eb1bEwGJK2Xif6kj
LlyKSpswRtmziMm+rcYQ1Zl3XEGO8NmtX678itGHbAyt1HeEwEVhgP3sBRos
2LT1VEMK2ksnp2Z1Cd4a3TNPcrRA5Tnqz9/C1tiWNBbmOkzFq6WyeYtlaPCb
1KKVWBqhqkvdNqvQCGs69/x3x9gaXbpSisp2VlDLVh47etMcJ/dt8LzGM0N3
sWlh5WMSJH1Dzu4KocDL+pGn+CsSjB/61DUySFBv4mqvdScj6KLuKVeCv2uz
OTtTSuiIYIatbxU1h1fnNmcNLgWjcSYfpH9REPk74P2nQVMMP3DOEllIh7bS
Eh21AEvoXZn7ftFHC+zwMZrNo9DxXsvwU16WKZZszw2Y2E9DSF9jSZ+5KSJU
a/ULDxC+MNeh1UCcgm1VbCpVRx3Tb9fkyrioQnr6+6q0Bn2scPxWGlSlhxjG
i7xngxZoKOtpF1y2hKLPmVOp7SRIRSX37C0nocx2kHfdRRvRsrzse4TvduX2
ePnZk/GlcX3Gmtsk6DPSTH27jSCYZ5ozQDbG3/Wi9NfdOth2bEdG0RMtRJXr
Ou9gm+H3Gdp2rTY6Ft2JihLLpmEZy79UP8YU4olNm0N7TLBvJ9tYVMcY/Tu4
uR8eaGFVU9zKHU81IaOzX//nXhMIpFOpA10mUPnBPymmSOjmo8lV37ytwHMJ
a/zSR0alzSfNefVk5Dbc2ltM8OaGLfeZ3Wcyzl8w3C25mshR1tzPrQ0UWCjn
fV8ubAVx/TCzFSesMDNQV6D+UQd52VMVJRd0UCO1djZVyBIfBY2WDIK3D6VV
Q5zG6ahONr25dosxzl06+sClzZLQ41sxpXWWWONb6ti6jYKYzxI7hR6TEXZr
p5vVYgtoXON9L7KywBF/h2fuQrr4knpbeLxbG+sCCnfx6VTE3orXTq+k4Hjv
xy1nZtWx6sKaPbY71DH4wVmSR9KE+Ol6CWWyJt5GvFWUJfCYaVd8/OSgAZ6c
UCcHqFDxplb/skkjBQnvTEcq9ahYxpxqq/WmoWGxxyj/Dg2bt0R8KTpOQ8Xf
qFL1vWRIJk4oHBUiw/LO3YeVDiS0rtwc7XzDGFI6KmFRdAskf141ujzHEqfu
5L3/l0ZDh7REuvl3KqLpiftNo8wgQ7KdU29rjlV+F4KOqekh/JbwCyeKHkTu
ljx9rULoWdWQoUE/HZ9utD7+ukwLexhPva5e0oBAXqZHyonIob8Vm65tJUPX
+1TC2lIDbEgp8ja5oI/IuoOfX8nScUkhvF9Wm47L07I7zNspmBELXbWxlAxK
tXbpiIclqGFnjAP+WCJCuLzogRkNQePPwiQ8qegzjZqhUI2QkZic6OlkhFgF
OdJ9PSukdPw3MF5FvGfjeWC6xBy376WsMaw0B0N4QFdXmIyVK3u1ungUOPWa
PySNknD9wx8rCXES3pd1+iGWDH625GUTAQn8DPcKurw5DuQs+FJ2xRxiT+Xs
StIpkAj+IlP8hgLOom4Vr5+mqNjEMWfeMYWqqpHYox+W0JFiSfIJ3ionrO8t
fWgKw+FYP22qKXpeNpfYNdMg2fzN5/kNGkR5sZp/NlFxWvN3zpcRMpQM833K
eeow02iVeCyniuEIW97AIgNQXs7EuScQ+Xyq6YuLvSUSMuItNTyssGtu7c0u
ETLsNucuYYoRvDT/Oi0QaGPhCb0/PYraENGWqin3ImHy7DKvvDISlvsuFf5E
NoGGzePVxl+MEPPb8sq+ubq40fip/8t5bTyXXH9uVZ8Zom+d9hCEm4G8fqR1
AYGnwon0x0LVpnBwLKyeYZrgMmysDRuNUZTrp3qkSws3N3hcb5jRhOxao+eT
f0ywk3kuUq7OGAewZU7wP0ukDK5eIOVnhV7z96v8B8k46hc8zCV42hvknbPW
hQLl53kkT1UK4Gn3/Zwn8dztFLtFjYpPc9WzFfZawvfsHtHHyVZ4e/H+Xm0N
XcSeqlAl7dGFKN9DM3DaAnPc9V/ucLOE3OrbN3zszVA7rPQzJcoEoWvNkssW
W+HoeAYv1NQKksMllRwiFyGzed2ZVjJuc5Ji7X9awHDaUVuI4Ov/ABUY0pM=

            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 5 PCA vars 1 -16\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", "6", ",", "0.9500296884243152`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81d8fx4tC0jBSSdnzGne5dslKJGkRWXe59+K6aEjSUChpaZCQKCmj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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 6 PCA vars 1 -16\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"17", ",", "1", ",", "0.8652435667041007`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c81d8bF4WGhAaS7drcbSRJikilVJJ13X251yUklRKV9k52VlJRUSTr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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 1 PCA vars 1 -17\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "2", ",", "0.9239877545977335`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81e8bxgtJGTlo+Sp7r7Mcs6jIKKTI3mdzBkpWGjIaWpQUGkhCitKQ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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 2 PCA vars 1 -17\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "3", ",", "0.9491254414407375`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3k8FN4XLVuULCll3/dtNmNNipCoqJAQZszGjEGUkpSKFu3SIr5FlmyF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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 3 PCA vars 1 -17\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "4", ",", "0.9292434487086891`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k8VN8bx4uIShJKUfZ9m81gVCqURKKUhDCLmcEYRFFpUUgpCUUo4VuS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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 4 PCA vars 1 -17\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "5", ",", "0.9283901457135768`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8le8fxoWiaUVm9l5nOTgaRJGRKCMr4zjOMY6jIVSoFJF20aBEX8mo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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 5 PCA vars 1 -17\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "6", ",", "0.9447825226592863`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c4lu8fLUoqKqSEsvd6l/VqSHYkKiRkvJv39RoVKg2zoRQNM7OlLUrW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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 6 PCA vars 1 -17\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"18", ",", "1", ",", "0.9027098451418023`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81e8bxkVGRVmppMjezjYrM0VWhIRwjuMsHJRQaSijUko7kZBEJZWS
cFklIxUKLfRNFFGJpPH7/P76vF6f9Xqe+77u93U9K0IiN4SKioiIdM8SEfn/
1TQoV61ukgVZmvS6MQYbZ1vrhpICmNB6dNW7Y2MI3P3tmx3ms3Ce+xLv5VgY
fZ5cL88KRdbxoUQvpxCw/KOiOou34PoEUzszMAjhZ+vMl+QEw2vdejvaEiZs
vy5ZLRbIxLZUsa6TmmEoWab2/fVLJt52+xu8imNB7dqObe8qg8GsHVWtFA2C
aopK+dq0YMjEZU66EN/d4m5OGh1k42rXI/4HLhszM4fnSaaGItY7a+uHb6Hw
+jazdvPZEASx9fbH9AfhZ1meztJIJhY5f7qb7ckEM6FO/mhkKPTnOfp8yAvF
mmV1F4RsFnjzS3R+zg9BN62g+NNmLrzEFR0ySzl45vdsMO5PEN5IJCRsmhMM
N6cpvT+jLNja0A4/U2JhtmHgs+MnmHifI5pXa8NFnZuK9e6pEGz4s7c89zMT
Nt163m0/w9DtlHOyI5gHW1fXvJr0YGx5IWTLE89lu8aWPU0Ow4+pIT8RSy4C
5wcxBg+zMM4PW/VznInTb/PybIa2gP7lUui3giA4JxulfFRk4xO51mzj+lCc
Hp12P+MXDJGt1fLl9lvQNsCbkw02lE5t0xsLZMNYmbJcy3oL+sq3hs9qDURh
d0qxuRwXH/Jd/M+NcSBqkKLUM8jBREnCj0cmYfiyczX9bXcw9Mj3H2vrBiN9
lkZ8XFcI7uwQvNDlB8O0dN6Pq9rBuNym+uqsdRCM/V5FStUwcaZ6+1eF4iDc
WFVvvbN7C+Rm3lJHTEOQeDBVMv4mE6rchTKcO6Ew1j/zcaqCiQpq1ObV35mo
f6DuuSkyDJ3F4yFD0YQOvBPCY7+yEFKZZ0szYiGr7WzeruwgPPnbfSXoIROW
MiE3X84NhrB1SXylayBO6E9a5auHIjypUWayig1dP7ECSjYThVLT068TWDhR
9Gau1aZApB0+fETkWQBkC81u7XsTgq2lnca/Z4LhuPbLr1MeoVg+uNpi1D8E
/9IHai3rCR3esyypP0DUN0/AmCH+V6u0pmMPMww52UYv2KdZUMr8mv6P0JHv
erkDO64w8YMSeCX2KgvSzi6t9rtZcOP4M3b3MrFmNHFhnwQTW2YfXreLHILb
p5uC1JYHwbog033qcRC+rXAJdooKwX+U1JUqXUF4X52w968NDwPmLe1tBTwU
bXSzWZIfhklqWdvASjaeH/hjp5oXBOX/GlqueIWgL0uuoOpbBJj+ynecW7iQ
yL+1byExtw06LFepjFBESZVqcK/wMbT9ZqbtcS4+vTJbfHEPG54c4Yf9W9nQ
K0wp20vogfFyMT9weRik/y+I2HBIl3bfDPEJg++5guvJExEIyilrUHQLB2cO
RfRTE8GFXWmJkX/CwLLcf6p3Jwtjib4530mhSNz6qTlMNwomti/yLeYJIGzI
n6NVzwHJOTbT3ZeLP7dIGy12CvCp+frzjB4eohXV5g4+Z2JStsZ83gmi31Ip
SUWaXAwyDRwTVTkwzDSQ6CniI/Y0mabeKYCYQsSQyiouvkzMZ4p0hMG2xyk7
tyYSm+IOPPG/GIHdwrPG73awsMXi3CzpMhYUOg74VulyMEvffU3QODGHj6Y9
8thCmF2J0e3JjyDm7hpZzJ6LW8m5rhN0HlxHcne1FkfheuIe1dXHhDib/k6r
zjocB9NW7xkr4kG19MEP581R8OlR+qFaHImF8Ws/lmlwQLU4I6nmx0Hj04s+
lCQmjLQWcaIETBwhq2w1Ps8B2dssb0UfBzSNNm5fazB0flx/fpHgRnnxmtCK
kwIE1dh+zjbjg7Rovc+hJqKer5SVvCtZOGk9Rkn1EkJ6X/HnbDEhbvYlIilf
gJtqa1ZeOCHA2EYDhcRWHlxqxfdIxIZhNDV7zFaGi59eeXPNlhE6YL9qyO/m
oO5k17X5IRx8lpGqjrkVihHPeMZpFTYqv1xbK13IgefQ5SXDMmE4YRq7+sKl
cPjG6B/lRwjQuH+ge/+rUGj6v9w/0c7G13jeudf2kXA6uLh2ZxoPpKo/FUP5
XDy0l43qCefANG6h1LFCIXbSqcc0EsOR1dlP+Vkeiu3R/7LuqbOw7HrX8knX
CNR8ydnefZyPwY/Jl0eSeND74PZjaSIHYhM3o26lBmFlY3aAs2oI1nbfzWwa
DsO/J5aK156ysWT1EG2QykF/m1t1dFAYov13oiyUg4QbxWd8a7h4UnDv6ggt
GgpiPtGmCULw7UnzI7YKQI+pn/fDn1iv38j5viccHPGeJb/0E/Fdm8REwDce
amPpFaq9XFhbM1t8bhDP6x8vyulmI2Kz0/qH5wWYdD0sattI7FN/bOLEszC8
uHH17787bHSudf4wqrAVjlxzqmdjJLTom9YWsMMhdfww3e86HzL24iudLhJ1
1rhQoT3EhujdL4NFWpFgHa9ljAfy8E7zwfdfF9hoCa1zerKGDUa8luZoggAz
Ab2iT4i+chevUh+0YiMFjXKX/cKwK2Ou1PPZBBe6Dx+ap8/Fx9o3myqJOt/y
lY+tzuHg1J0rV4vvRaK765T8rqsRyPtgvYDuGoatJjmNYSkcGIhVafv9ZKHH
nqQ79zQb5fL3nS+dEeKDCS9/nWIEJlJqfRbM48LFb+bpN3ke2ne9ndY3CMch
qoVNsaoA+jcf0owJLtu2dTDPZIfiAXcYQ11cpNxn2YqQuHjg/bHK+4cA7/vI
LrtsIiGWP/L+ZSAX12PVFLOVuATvH51NjhZizudGlQfLhVjEXfnyeTkLPxtu
5kW2EPyYy2BRjDjQHBatLPzCwYaeeUGhh4R4Ublsyw5pIUZk86fKGjkoqbwq
kxHER7tCe09dYBQ6EsSVdyhGoakx5EOuQwTq/hl5zjYWYHNqw/e1ZVEIP+O2
s2RECHNW4KUuHgcSvaENfhI8rLtHP7JrmonrHwTBfjIsyG3uGk0h6iRm817J
MJOLi8efLBXVDEFOk7wno5fwJZ7zMs3bAlg0zPRP/sdHhOwG/wTLUJzU3UBb
RGUjqBmz0quE+KIztNu7TIiPXhSRzod8FOa15ce4RcAnqOmT9yEesofPmSQr
c9FtzzYWPuYgNCK2XNImDLt7VsYvtuXCWU66LseKh+9qKx1ci0PRvmpvp4hb
GKjpe59ubOVgvaaYWM9mDqouiUwy9kSgRTz6c6x1BBZUH9pwwZeNA4pXfbv2
hsH1NG8e7W0kMlNLE0Z9BXB/XpZ/vIyLx/MKZM8d5qKWkSL7+ooQ2XO7PK23
RiKk+oHIzJNQiHjdSTevDEV3mN5tSWokBIGRdZfMwxHMHvaqH+Jhasz2l34G
Fz9q7tqnKQTj8ZO5f+fLMPEnZHOxuhsH6gbXFvLnE1wMODsrjljnnZcDf4ar
OKDXHZvcdoaDB8K1Xy+e5sGdf267Cika9UypsOexUei50afhOCJAQPYDnfvg
w8bpkot9BBdHYiWXX+rgQrxSQr1UnY8r1+Z0xIjzsbd9gcbsaQ7Oep1s6CFy
1v79SYvt6gXolxq4WjPMR828zbe65An+qu3hxs/hIJr6eo/bthg4jiiSLuUL
EbHhmW9lTThWeIUpN04KQP5H0TtKzFmP4/eOd9YcZKYc8OtIisTwf2SxMDk+
an/91yYxysZ0y516tQE2dl8OvJvaIcDbAbmFpWIC1FSTt8QTuctijOrmKcfB
x8O6ozJtPGx4r+hqpcSHY7PSuh0lAiyVMZIMfcVF3JIFIg+XCCEMHB52bo/E
iptmU98mwjCvRLnOlshlRXsHYyL+sKDu8Frg1hYG3qfku2d8hKAqlJ+4WhCJ
kz9N63U7CH6v2i+r9Y/g2/GU9sIF4RjNd5LUygpHUzBpt7gBCzvFY66znrDx
c+novdw2Li7LXNZvIXLGhqKml5194XjjevKPbJsQXZXGZZ7buGj3MN9CHuTi
UjD5k8VJIXZnNBfJvBai57bUjnWtLLyLWCvYVcmGhMeGSgsnDpZq+a87S7x/
t/meq9RLIewc7xfKlwgx0Sv3/RjB9cvINgt/IcDLmfTY3+QoWAm5h5btiMKp
4wf5K4oi0FQR+Gmpczjiyh0jfbuiYO/cubesOwqBWT95koSvahyqMHuYw8e2
9oUiiaosOG8aP9E2zcI56ojN88uEv/Vf9W9O5+GQ+BJ/V/UQ+NZczG7ZyCbO
Ib0Cw+UCpNlXaxrHC5DDL2p7zAyF4idu9GIiV1nn2h0YWxIFhczUZJJhFGoH
Vaw8RwUQ/7S1oMlQiF1D+36dOslD5/mGEPJlHuxlD+vKzyI4OrrjTNsJgrda
Fi2Ga7goXZH18dVXPrKZk5wg4lxxXOH6ek/Cp+Tdrer2r+DinPP34JiTRL4P
bZI2UYmE+ld/ZuZMJAqUnLR1zrOxQXtu1tYdRD7QXzjdu0KIsf7R0IjZEfDu
ef43pIoLM9JM2otdPBxR58uIE/3nHYwaC0gRooi7qGO9PKG3uXWZY8ZhYNL6
XcKzItG0RbPqiGwkDOrvLZ39kODcziTN7gM8THY6hGbbB4MSO3fLM4J3Zf/G
izZs42CbivaFKiIHcnrWUVsJPq4IlY04pchD3duGjNdJHGykVWcPkQTYVvq3
vf93FB7tsTp/RzMaVRVzpEw1wrHU1051b7cA1L+7HjoQ5yfDTM+vlAAeYn/K
Tivs5uOsR6TVLn8BHgvoGR1EDkqhlkiIfOXA5Gm+WOrCcDxtT7g4vzkcAS52
02FmhJ6zf9yeucWF1VDTnoH8aEwoxY47+kfhPNOkWX0iHL/WO1+N/x6O7/yM
L9LnwhD0IuOg7hHCD8sD91ldUkfERA/fRUoTAWFD9jrGJDyixvdu3a+D0Xvl
U7GqcqgJdo60z5WFUCKF1N+kgi9pHndPtSzCwJhH4I3P2ki8frs9IVYbXekr
s6zOGeFt5bLnO4v0sI2uvc/6iTFuKtimVgUZoyDTwvKnPgkKM19X8+RJIE2k
Pos5pov3UDm89po2nO7GVmD7ImT76a8bzdeEyYF1w3vGSbjraHehQJ2C1dxn
T+MvkLBvuNXP840JXs5ZnWchbYDY0eVX7bh6uC6edPj3LD28PrI1N9lZC4nP
bmVe7NfGfv+AZPUmQ1jXxv/u1FJDiNHYqkaxFSi63bWofZEBkX9ibLz2GkKl
lp657pkG7Mi792w8qwFQFb2vLzfEiPYvA+mDBiiw+7r1J10TLJ937ec26WD5
5gNJMXIkeCxZ1iFNrI/NUpwoOaUPSpiy/YZjRoje1Jcco2yA2ZNkXSsxHQRT
fsXeLaVCq//swg2fqTCw/7b5pK8x7m1eX+3rYIJnHbluldnamGVZeXHvNV14
vx3Wa3tjhEulx8jLZxsiiEZd//S0HqQO2D3afkATo82v2skDJCyKqjpUWkeG
W2rq7fEKbfh/7NQ7/lsH31Ji94zu0MM+ma3DNLIJVLda1qq2kCFt7PBKJJKM
Go32cw2jBhi3nOXydMwIttO3JA5PGWKWxZObH7uM0Of5xEP7hjaOJdv4Lo7R
RsS6paLdPEV4JND+m/m+CDZackcWSWhi/Lzaa4lSDQx4Tc0VyyCjM/tj89x7
ZLx6t3Fw8YAWkllT2k4JOlCTLq9yC1HCntAH9p/nLcXBs/6y9z9qIi1yynNU
Xxt2igsjzfWXo9Ut/iV3kQoKPeV5vHhVFIbyW2aPqaDk1MlLgghjtJ/lc0ef
moAc8abEYb8R9JsV5JRLjPCmpLR9Q4QWJPex6VE+K3DIsjPaPkwZdRpuRyRP
qeBmZ/EN5xOEXq8wGEYJ2mh2ZwQ/n0/CWqP+7EcLKbhwWsmULWWEPIGB9/Mc
I/S/0WpdsEUL7pw2rfuW2piR83o055EufNMOK066GeDQeF53z35Cz6JZD58U
keFiHRbk8UANzeK9Tru56jjdpnLc7woZuy2VWSIGZGxccWs0cwUJwR4rXxyN
04Zihpn/8Z/6cJrINL1hRkfucsbIBqLPfxcezzWxM0aWKv01o8EE/RqTC6Wo
ZBz9cqK14r022mbuuVx8qgP5ly8mHH5RkHZopcLycyZ4N+vauwvr1cGdufc8
574aruk0+nQINVB2KnS8ZGIFmnIuzixwNyTOOVJ3GWpGEPXvvf9Bnoo9ow2k
2JWEHnrbmP9mUaGZdqewsYIKxr6h/A0DVFzR8lq7MogK59+TyjrPSRBp+fF0
vYIRZh4ERuVZGaNtPKGYvdcYyofs0rp9zHD5FOfE3kQ69CTcCx5LUaGx19Ex
awcVrls1XMziGHhfMSEqs42M7QbXsz1oehC2u9r+1CB4IbTqX+bIQD35ifkn
TTp0NwrLRrZpQlV2ueTSHRo4UW4v9NpB8GVAfjHFgYY2319fFZINMGywfkmj
jj6qg/7g2Xfi/oOANGkuGb4BgZ8XJ5DhmnzaIlOSjLCUl/H2XpaQtn6WW1pE
x5QBZWvLKxqcJa0fizdREZNcu8eV4Ncf0WeXyTeMkEBvyF1fYQX/52O1Ssnm
UJHYniGwMsM68aQgy51U9H58khMXTEKMSTprT5gJ8nzETiQXkpDy2OnoUDgJ
1oZ/me/+kdDo+L7+AcsYUnBUypxkIL12W5bNTlOEr/MNHe8jo2Pzfdu4ShLk
pupPdnYS6/c+UTFfkY4kuYGwGwYWWHBxQewjHVMYre6oGZBhQHJDeaEpmQa7
uxF3FD9SkbblbzvPkwr6wwoFGSUqnsfme9e0UtAi5R2d+3AFdFTcpw0equF8
ZJOJh6o+Zv+u3faVqYs6+a6dcrbmGDkw58ayHAb4PzyWvYkmgc/6aBJdboSc
8wu7nD9r4ua7DwanVLXQrL3ebziL2O+CClJMizGGPcId8w4awT3i28reGT10
zfyU69PUwTtnrSTlF5p4uOLZ/d+ipkidP/9O6WwapCoT4uyO00BmRSVapVCh
dCtjjfZTQjdfSnXqNujDctn6W/PJWph69S3JsVQTKgef2varmkC81kH7w1pj
iFFP0ujnLNCfNrhU1d0MuwsdvBRSySjWlXukPEpF3xHxmhFDMpbzkiPs44h9
7BO7E3OdmL+nZb+bHxJ9Eef7kb9bYMkafo5lAANko1rF4gU6SF2QTq0K0YFu
T0TxlyFz7MvPtje8ZIqEC6upRacZmFs+dnzJSyMM/nXJOnfcAipFzcPO6eZE
/15fOCFGgfZReadWOQpcrihnSeubg2x+j1egyMAXroqmRpIOdh62MRef0cUS
h/w+KVEq9CwGdvY1kTB42q3+ykd1jNrqX5FqUcetUDGjPd80UDNp0zl7tgZi
moIPmd0zhE/j9x//bTCBYOVQ4ndlKr4HmujK+FNwZuzRwfBCCozpwR4bJ2kQ
JU3/uqNB1JkhqZACKmx57MgVa8l4/Xl0+bFjBDezJzy9R4zRl6izpjCIhKWL
3C8yps1Ak6TertNmoOv6HG66Iw2th0aXFhXSoBc1e82n9ww03l9tbPaJgvTJ
Y9VVo4RuesTeUx30IduvtUlMn4FgHRPzHVkMOL7vnLrxWhO/YjXv/zdLE8kx
MlTapDHuz9olNiBB6FZH/KCSvCF0U6T8e6MNILeXdi1wnI7FvaLRHA4F5mya
C9WQAhrb90pAMAW+RvfM0h3MsTpzz1zSXQZ80r9HrR+jgjWwTWHzVRqCprRo
JRZGkIrq66t4box13du2lxtboTZefx3/jwVWnF/+/cBNM7R5ZRbUZtHwuoie
/6CRBO3ib1c+aJHgZ9XgO+cFCak3p5TkjMhQb+VqO7mRYaYhphZdTILTec6W
4yUMaL45thlvzeDX7eOowaUgqv+FVvodMnb8Dnn3foTglLtkletSBrSXLtJZ
EWIByirzK78VzeEfYDSTTWEgpOBw7UwGHYs2XQiZTKAhLrFi1pf1NMSq1enn
Exz5u/i7msJtGnyq2FSqjjpOkArmjKSrY/7051UnH+njcfMbjYfu+tjLbM9u
GSH++2pYNX+pGZQDThzN7CThXXic1f4gE5TZjITfWKuNL/Nktuwc1MGrC2/9
guzI8DfYPjswkQR95kl64GsjrNsRq29A+NtfF0nGy9dELvFAsaypDhJv6Tr6
s03hqJuR6+hBh0J5YqLUeUIPlMBmm1wa5hxq9Yp8awLnxR13hZGG+OjPvdBf
qYXXCwMsL8/VxgKdBP2vcSboUFjVaVlM5I0vEUeklC1Rsn2kMEzMAuFro5o+
DJLRXx/bm2tAx4VHt+OKiLlJ8+hp7Ssg4+Ilw63Sqyn4V9SzUpnIEebLsz+r
iFpi3No3ScXVFL+G6/PUB3TQe+Mrvfo/XdTKOM1kilgg22iHfk6oOarnqwnW
TDDw5NGIwdeXJsgpPFC59rkFVm3mv3HutsC6wGsOz3woWKUQuOj2V6KPt7e4
Wi40R3xa5Xr3a6bYH2zf4iaii6MGT7XiDujDOSQ/OoJB+GHBh3iHfDIO9g1s
PDGjju0b9Xo0lLQw0u8oHU7SxILsIlZBgwZ6Y3uV5Qg91lfMvRLZQ8Ljw+rk
EFUqnlxfU5RN+GfqG/r4Az0qojJY+hxi3h4t9PgWUU7D9NwXPt4Ezyv+Jl5T
jyNjXmSzoHjUBBbld6sf2JPw37hneW0WGTI6qlGJDHO4SUi0FxYycLQ8+92/
kzQkD4+13f1Bx27GoQR6oimaKCvf2qjRsCroEi9thR7G+LmnkgcNIHa3pPml
KgOpgUPV0nWmeF/6rHFoiRZcXAeactW0IFRc8FZmjQmSrUub3S+bQnfz0VSn
awYg8apnD3w1wI76Xf+9kGOgaJvIxxEhkQum5fzNOilw2NSg+usgFZQa7Wvj
HhbYXt+ccbDBFLGitwoqTWkQNwz8u7OQjkF64i8K1QhRjcfX73YnIUlJnnRf
zxLzN2R/2J9uBaq1787pEjNcmk/L8Cyngyk6rKsrSobdlnMLu5JIWNNnVk36
RsIyTn5d9BQZ78q6g5BExhyV/465DJERcdqtgqFoBs8rNX/6Z8wh1SxvW3KK
gk2uDV0HQyjgKLxW9ftKx1FX/uWkaQbU1IykGr5YYGdAe+2WBgssT3Xpu1ZN
x6N8SWrRFANvO9pKbNto8E29vnRdDB2S4UmafwifzTPWpMglMLDUMDfgVrg6
ril+1K1S1cRYrE34sIIB5FszHuikG2L0Z+uHtXYWEJ1xupfpao7o2XU3X4kR
+TjGf45SJgkfzIamhUJtwgcFur4N+hDTlqm95UeCRKtDqweRJ1UCF4u+J3L7
gmXeoS8Xk7D3t8XV+Nm68Dx0ane2iz6eSLvkrBo0hcK7slVmlwg/cxl/No/Q
k/Jhr196aXTYO+TX/GKZINCafe5wKHH+uhCktv+VFi5yMvbLtulAzsnoydQf
EyTMejWlSeTYndg4i//PAhJe9gOespboM3u3KniEjNNrDPe1MBno423OclpL
gXTwfHf7gxTA1/Zzji8FQ+Ltg64bKXg/W/28UhxRz6N58XyGGXov34/T1tDF
yzXaJz7y9SEZ4aEZNm2OIs/wbn9DS8ivvlMaYGeK70sWdQ3/ISHSyfRY2UJL
ZPhkZy2abQXpsZIHnP0UjJMG06lEfrjDSU+y+2qObd5lz0T7zPA/lSu26A==

            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 1 PCA vars 1 -18\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "2", ",", "0.9396688386790936`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c4lY8bxq2KoqKpyN7rbByKhKxCCl/KOscZxnEIiaJSiJREQ9GgkFJR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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 2 PCA vars 1 -18\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "3", ",", "0.9554976216250846`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3cg1W8bxoVEJau9zGOPs83KyspsEeFw9rEOFe0lo6IhUjJDEhoUKeMK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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 3 PCA vars 1 -18\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "4", ",", "0.9535498796985498`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl2kgFF4bxZWSihDtyj4Y26z2SpYUUkRky5gxZsYYQyUJEZVKmyiRFksl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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 4 PCA vars 1 -18\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "5", ",", "0.9454252646989418`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k8lF8bxkOJfpSlKCn7vs1iBkORpSwRKmvWmTELxtKGlEqhokVosZQo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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 5 PCA vars 1 -18\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "6", ",", "0.9500747537763581`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3cg1P8fx0WhJJEoKXuvGzaJUDKKppBw59wdx1GJ6qtBaGghFVFGElIU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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 6 PCA vars 1 -18\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"19", ",", "1", ",", "0.884561486758107`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k4VO8bxkVZimRvse+7We1KERHaFCFZZpgZhqFSiLKEkhYpRVIoISWi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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 1 PCA vars 1 -19\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"19", ",", "2", ",", "0.9228260491201051`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81f8Xx0NJ0TBbZO91t1lJVjLSIoTr3su9171clFApKZQUSctoUYlU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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 2 PCA vars 1 -19\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"19", ",", "3", ",", "0.951470495289386`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3k81F8bLSKKCqEiu7Ezu7UoZE+bJWSbYWYsY6gkSkQoaVdJlKUkSiiS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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 3 PCA vars 1 -19\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"19", ",", "4", ",", "0.9555609398789197`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwdl3cg1e/7xgtJn5SQShTZ29lmJaOMrFRkhTOcczgcI1FSMqNptJFVJClE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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 4 PCA vars 1 -19\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"19", ",", "5", ",", "0.9541378043775877`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVV3c81P8fFyrJyGqRvc+4c+fMklBSlMoo+5a7wzkjUdIgNFRGGkKFpEjh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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 5 PCA vars 1 -19\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"19", ",", "6", ",", "0.9473959197925519`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k8lG8XxhOJsmQtJfu+zmaslexkS1kiwhgzwxhjyVrSRr+0o01SqCit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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 6 PCA vars 1 -19\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"20", ",", "1", ",", "0.8926833686165292`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k4VP8fxZUWFQmVFNn3bTZjrYgiIkqREGYxM2YYKkWlREgpibRRwrdk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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 1 PCA vars 1 -20\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"20", ",", "2", ",", "0.9608586075379647`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c8Vf8fx2Wl4Wulvkr2nnfalYyMjBSRPa7rXq6tkiJF0S5EMio0FAlJ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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 2 PCA vars 1 -20\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"20", ",", "3", ",", "0.9468767740537738`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3c81d8DxoWKSjJSiuy97nWHWbKyU1FkhTvca1wjfFEpERrSEtISQrQo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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 3 PCA vars 1 -20\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"20", ",", "4", ",", "0.9461910372948156`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k0VW8fxU1JpUTRr8zzzJ1cXCqFzCmZokx3vriuoTKUikJpFEmhhCKN
FMnQTpFGEaEiTahokEIa3vP+ddY6Z63znOfZe3/292iGRXmxJcTExHrExcT+
f7UMKdJo+slCz7Sp+msOC3kPm4ZTNzJRs3K5hIM6E2s2ONx3nEc87zu4RYO4
P9qRdluBxUa3nOwD1R0hYG2Iju6sCAbpXc4L/8wQROY1WS8+GYr3NS1nnB+G
YuW3xcslg5gYsmNN054xcV5V4/vLbibWzvx5qNGPBY0LSZte1YXi5vjgydRX
oVBPV6l23hOKA0V1iYkKYajiB6aODnLQqDrwOYfPxvT0vjkzM9jQDX3uaDvO
hvfYtHNgXhjOG86yGZINwWRlsb5yFBPrT1GWyowzwUxsUjgYxYbyWvXgnl1c
rFJtKhAR+1Qsr9macpCJHlppxcdAPp5vclsZFM9He0D7YPyfEDgn9BW+3hwC
T9cJwz+jLFwPrva8pcyGlElQe1Y2E5Nuq35/82KiyVPFbvtEGLSeSwU8fMjE
ih5D30eTXDy1XunBMeVi5erVxTf3h+IH++LKEEYo5nd9UX2SxkX1buFzoRcP
QfNC6IP7WHh2bftNOR82cvuLi1cMB+NtaZ7PgeKNcEszTR9ayIGX+ucbLwQc
5I5OrTkWEIqWDMbGSl4oHr0RzCoEB8tRo139lQWzJRQ1Xbtg+G0bVUtLDsbZ
nvQKa3k+kr2OH3HrY0PCOF2pd5CH39aDBUp/efi8dblFf08oDMnyf5UmQrFf
XDshvisMan8cb06+DIPl5Tk/zumFosP153FxpVCYBbyIkrnJRH3XkHd2FhOX
lt2229oTjD+qFjVeyiFI3psxM+EKE/t2/zr2rYkJM6NjQxO1TKxjOIl3xjJx
u15r3fooLtqD3yf67+Oi3zcxcvM3FlofBUSv0WEj/1Fe8bbCECxoM4p9kxAC
m7lhV7pnh+LPK67lFj4T2UY/bUu02Di6+rbrMw02DAIkSymFTOQ45PeVbGAj
u7xvtu36ICgPycjbLQzC/LNWVSl9YXDqXzk77zRxdf786+haNhYdc7/8ZBUb
//a/uWVzm4UOGr7/dCTOvziCPk28j2WQNK/sYgROFpo+4+SyYLjOnvNpnAV/
d/ndSWVEDhLG7tGoLMi6eTx02M5CecvRewbvWFg1mqw4IM2EqPyJs/SVMFzN
bQ3RUAvBkhhv1u45IRjT9Ah1jQ4Dw3/0X8onDt42Ju78u0IA7749f8S0BSj3
8VyxuISLR7tnRXnReejY/cdevTgE5Lo7x45XMTGQL1/aMCZETsP0msUsIaRL
qlIU6RzUqLxP6VrHQbTMZW1+WThOMQpXnFwvwMcXVv+d2sFBUlVmTlwNG4Zn
0yt3En4o8np5N+0wH7L/N8TmSHxMUglJvMSB//HSi2njQqTKWkRPnBaCN4si
8bGVg+qvLit+7eCCZbPr6POtLLiaylc/rGQhOe7jfa5BNAav/kzQPyGC6E7J
LN3bPAxcTct9n8LHnyqSD2NrBB74bRELZEYiZqHG7MEOJoQyb/7VODGRL5Oe
Wq7Dh7f7Y+e2vXyYHDGW7i0PB+PqZNzYFwEkFwiHVZbxwXA3JUX+IvLU61pY
dDMKmuHNLwTtUdguyjN7lcRCdEGtQso3JhY83e3fYMCDz+05F6Zn89Bzd2pt
MUeE6/2r9z/lRuLHxAWypAMfH+UWVHfIRGH1SNG2hxXRiJ2YcVx+VjTy9r/S
bbKLhDp3xFjHPhzql+t/uAVGQ2Xv474PqdFQTHAeqtTmYXAJ27HvBg/NT075
UVKZqFS4qti4k4kDZJU4sxM8HBT+3PQcPNC0H/EHCA5eocyTrc0NRXXFKnZt
TgR+ZHGbYt0FIC1y98tsZSF41Xpa9x/Cx3ZfKBneImTs+xFQxxbhykAyUksi
IE2lKc9zD8cXH+MFyQ8FiGg3k34nx8VoRuGXlXOJ/RzdZqMeysUdzos7JT08
1OqWzbq5mI9Pc2UaY6sIbt0Vmx4oY6Hu8wVn2bM8cC8UUJyTeci23Ly84HQk
QqV4jJerItG8603PrhdspHC/KYaKc/AtQXD8pUMUGl2OuDryo0Bq+FM7XMJH
w4dKWV81ASzjFWUOnxWhONGpZ06GEPmdrymT1WwknTy5u+0eG6oXu9R+rhai
1bT7XaOIj8GhtDMjqQL0zFM7dXg1oe/4leiqjBBUi88OzgTB3Z6aI60fuDDk
2S9SceFi8fJh2iCVh6YK7QLNQi5iNmxFJZv47rkOYgk2PDwuvX5uhBYDYd3j
iPUXohHuQJonjItAXVue7Z15ESAFjJwYeMzDg/sn10758pH4SHp845gAl6XO
n+6yDoedHfOB3yUeDje+SPAj9BIGurq3nIhAcMBri9mMCLQYfRnPbudCf2fn
+A5vHjqd3d6PLojDyomLZ0rkY6Brsd65lBMJf7vZUtfUIzHXYcZS11McTJ61
61DJ5kCi5vNguW4URMZDg9O9QrzSqf/+q4CDHSqsR2nnOKAn6OqMJkbgFC0t
W/NQOPj/LdMatOUgR1iz5HERG9sOzZbpkBKg4djg4ppGAYZu9a2vS47E8MyK
1Xm9XBy9Vnau4noUQnnl2/6mR6H4vZ2cxWou4sKYPipcHowlG/QCJlk4ZPrb
x0KbjWqFG26nj4lQ1fvx7okDIoyn3/KTm8OHrUGT6FEtH23b+qeMjIn9NCmr
FxFcMLrSQjMzZWHeXbNnag0E9/kfMNzFx0gwuSifJUC971CD748IFN3bbJnf
Ew7JkpG33UFEnuP+yahu5xG8v5uXFiOCWpqs+jDh50X8pd0d1SyMdYzFc58S
/JhNZ1FMebj2KnAvT4kHr945IexMESp9npXNHInCyPySicpmHqSd22Vu+YjQ
tqCttykoGv8kCiViv4nQ2hz2vshRiL1J5uM26yIRmHHnu3NlNPT+NV9s/hUN
a1bQ6S4BD+dZYXZD1ny4XLc4sG2KCdcy9U/mySzIB3aNpqcTnEVWg/AMD6ey
HitL6IRBtXLZ94dEL4YJ3FR1rkagU5dOylAJh3C+14ZEGzbh2+UbDsmyEXIf
4vsbRKBTm4Pee0VjyJsi1tkSjtl/G6YHb4TDL6T1o28mkXOFu1pWFgSPHDhm
ontE/1od/GSqyMP23qUJ/63kwz/t8inLRD6+ayx1XF3BxrH8mcH/lNig7t/5
xOchD+uijyj6ziZyd1rsJ32HEFfj1+sV3hJCrjHTq8CfA4X713a2pXCwOlcw
h9YfhQazsOHMmSKs6agsyarkYy9vo/DAFgFu0dPnvywj9NCZOxDvKUJYY73Y
9GM2ejP/PRD/zUYP1/DqTCpx7hWhRt++CxDK+eB9e1gAGdx/3nsqHD9u1jjs
WRAKanZufNtMopfDAiu0PHnIakld2HSNC+rGPPH4QB5CXHJjf9/lwqLp8M9N
x3goVfySPv6NhzXhx7eokGIwxfym2XklGr2XBrSdRiKwdJQ/L/ZvBFa4nvZw
EPKR3WCw0/wDHzPqpLUua4UjaI7yep/acOxsk9OWmuJhXD7tpIIlH7t2pf5n
fzsCOlHT04UEt2/OCazqUuDBXCnw6Y1NPMRQX+7w3BQLjUM3YrfNjIXQq92/
7mYktowbqw46C0H+RzE8GMCFz7w67cc0Lo6k7w54mhoFibS6NqWKSNz69e6R
9CgH8rztm9K+c7D9TFBNxtMIJLXL1IubROBmIzk4IYjo3YSV8633sTG0z2B0
7iMBbp/7ObMjORxO95Vcks5H4I2lNuP6Px7iF8uJtSwW4Q/3o2FQF9FjV6wm
xsYJjrs/LQ0Y46F852Cs8A8LkaPt8c27ORB8TKs55ifCrY0pJO0oEXImLW8b
POVha5ZPOUmW8FVWettZuUhiXnS/V3w0Eq2hpO0zjFl46r8u8Ws2C5PKo9eL
HvHR6HmifshUAK/y1u7OgUiwfcM8ajsi0FVnVrluEx/q5LYsqcs8nA4lf2Tk
iBDypLpoOV+E3qsySS4PWXB4P9k3SnBLeq1XHcOVh8A/v5Xy9HmouX99tUy3
CEGT+TOeXCF48lz++2GiVzR0nsSlN4vQPb1/829yNPaka52KrxbhaNbecM1y
IVxTwj7KfI9EfLVTlH9XNJ53ngzYpBGDoPxJwcwAHi5rX83fsk6ATW2KYsnq
LCQV5u6dTOPgOHVkRQeR019xt2TclHnInLF4w2otYv4eXdL6vToMF8efR5io
ReA/hmMB7V04ToaXP7rHJOa8mOGWx+Vs2BXZ7/6yOBquf90P/lWMxq1BFdt1
oxG4ulnshLFBBLYNp/w6miMAOdfnifkdHhzm7zNQEOeh6xoTL08RvNVlPDBZ
xcdut1Op8hl8FDJ/8kKK2WhSZffvvc+Gwhrbpl2afARmZ35aNYuPIHarrLlK
FMpTp+3Lo6JQquSqp3+CAxkbx6rAFg5oRopTzzVF+P1r/J32xSj49nb8DWvg
46uTWG2evQAHtMLnziD036BU7PSOmGPK+YueuitwsFPfU/KeNgdM2muPyPwo
+OQ+6jVeHAHj29eVpVoE2PDidRr1XwR+djqyCx1CYbdnekI8LRSV/76WexG5
KNb+UWifwQOv14X6kOCj/0DmljtfuGjqv3PoZSoPeV59JzlDfGy6/Lft9e9o
1E9dk5ITRqOhdpaMpXYkZrA764dlI0H9u63Fkfh/Ei8Ycnk2xcfmyflTC7aH
g/tzi+o55wjci7A49HSAh3azjtsUbz7Mn5RIZihGIqn7KNdmUyQ2ethPca2I
eXHOhu+rib6wHW7d8aYkBmuqSy0FV2Jxgml+X2s8Eglatim8ICG+hx/6LHuc
C8bIh8M9vlwMVQel2J7WQntnV814nC42cocd9M1I4C/xSDCjkjB6vXpis7o8
lP90lDAOyUIknU563aqCM4fv8E8UquLNl7VBlz7poYp+MbDxnj669i/Ntz1u
isoXaw/UfzbBJgu9FLvHZphhonZWU9sEpUcYNpNGJFAm59tv9iSBNJ7RHnvY
AA+t9YM/NhvAtWZzLbYsArUs96f8YV2Y73b5sOMrCXM+VCoURpGxnN/+JKGA
BIXsfx/d3+ije9byYoasMUx7IwocZIxxcUbqvt/ihijNqV/68Zkhkturjpx6
rQdBTHng6rMU2N1K+N2pqwFb5Q8Bqh9UUH61a1HbImNkLWh5HPLeECq3LI64
tGtjXmp9MWlCC6Au9L2oZgL3GzOX064Zo9T+W9ykhQ4srEY/vIo1hFrg7tRY
eRLOMvqcj60jgcNaOH7+qBG2qu78ah9jiJj1A2mxS4whsaPXR4FniFDKr801
l6loM285/1qcBmOHscAcfzPo7Op41uxnjvanRZ51hXrw1rq5jHRDD779Hwwf
9Zkih32Zb8o2QwiN6v4k1xD5lx9C6YAhRu+/aCO/ISH5i97KhXPI8MzIuPq1
Vg9yXvLs5Ho9jKVv3jGaZIgOzrOy2mAjqMfZ3FJ/QIa063q3TzMpuKnddvzO
KPF920YqZj0nYeVUlfS+CRMoS4l117iQMLDu8Vq9S3p4lpzUPXVHH0IXZYke
wUJsm11zP1xfByt05Q8sktaBTm3xyqhFOnjjPTFb8hAZPLUungSxzotXPoP/
vdFFrSBgx+IVutCQrW7wDFPCVgvnZbxWJezN2zD/xpAOrsZEl+2U04P9QsUo
ayM1mC86p5N/RQVn1ykIBAnq+NIcpTzfygDnj+acjhCaQctTYf6hCDOQhX3n
HXeZQlpzWOrgBm30nb/c5iXURS6nYM01f31k2nTGOHCX4PLK2LdJvotxpbPi
klu2Hmy1zPMmMgxxfw09tGMeCXpjz28P91NRkKtkyZExhd2czts/ZhjjdZ/u
Q7lgXbw6ejf+2yI9TMt7351114D4n7jsLCc0RObX4p7eXYSf+6LUDwtI8LDj
hqyt18CPli1OJzU1kftIJSugjIzVqW2+N2XJ8NGsGj2iScJI3/GvnkROFh6y
2pA1aYTKQ2f+US2NUaRGH/GSMsH82YKW/T3GyFe3eEm/Y46LbsW6L0vNcfBz
9sPat3q4+n5/5iJPPSh0Pxt3/EVBS/5umfA9FLwSv/CqwF0LV35OcitXqOOC
frPfU5E2piV/7/K+oYnWk6em5daYIHJ+gcr+EDNIbHh+470CFTNqDi8+coLw
w/NHzH/iVEwOPjoXf5AGespwidcbKkJtlB/7zKHB7ffPJfodJGTIlwkDDpIw
XR8UXWxrhqYzRf1n/EyxJNN+T4+fFZqkNi5/fcUKhtJrSu/JUHHNZvt8UggV
q+O0Pazi6ThI32TCd7TAFuOLhWtphnBwKhc//ssQm0S2r1Wd6FDT0JjMfkWD
gY+ocmSTDoTWnVdnyGgiu9pB5J1kCtux7Fp0mOCR/69vC9KMMft+QbMj0xiN
IX/Q/p2GwQa5zCceNPhvDPr0XyIZlFca2ELkg5veneDgbYPr4zNI8VdtMGFM
iXvwggYPyxVH3ttREZt2a8dqQpf0YyYn7l03QqLFnSL3Wlu8S+3JtJ6whYr0
lkMRtlYgid6t8LhJx/OhxyfjQ0mQ4jrlPSC4WewnmZ12loSm4BOz9yqQYWfy
l/nqH6G3Xa+rH5FvGTgpHflJR49niOLSDjoiXfzZXwfIGDMvtXJZRIH8xO2c
zk4adFWmilL7qEiVf8O9ZMxAOG953blxK5guf3rzzVw6ssyOdMm1WsC+Rnht
4RAV02PB/aW+VFi01C6Yq0SFWP1bz4H1VDyQ8Y0patGEd72qK+eDBk5EtZqv
VTeCpGDifPJWIzQpdG2VX2mNg3sML/gIrBH+Y61qXwwJvqnOpzSWknDyhGKX
2ycdaIsqKbNLdXBfzz3gQz4JqoPDa8QMyPiwNtKpeK8pTIpSOr2STdA1PSk/
oKOPH1w3+ZQEfbRott/4LWGJJtQmNfvQIVOXGG+fRcNEAeWe2SgZSlWHVuk9
McN/QcfpibpmsFF1r5pH1gV9rviS09u0obL3ycrX6uZ4L51Z2H7JFJLUHJrF
cQb6Eu/cftltje1nHb0XZJAxqEKdv0Wd4NWBGTdHTMjgqMo1KqeTEZ4ieS32
Ihmmx8wS3PrJSJ8RHkD+zoD/PL0Uxz2WIJveWlghp4+OuPHD1tv0YdArrPg8
bI21Vmvi9mdZIbFgObU8l44fOx3jKvyIdf565B/PYmDXvLxD4QwGod/LgmxJ
Cj57OM28SfjMo2xJvqyRNT4PqYiLbbHEZ76KjnaqPgrmk+mOvXpY7FgyICNB
xbrP7ncl/lAwmOt5u2xIC9OpDZ8y9TVRxZY03TGmjejJ6x6pZlqIbQ3NtLpu
Au0G13HXFeaIWDqc/H0JFfMmpc140xQc+3J3byTRa+vky75WjlhAgjT165o2
DW+ttjtL59GwUsCJ0nQmo3tMczxckYy2wvF1viNmuNH7vi7XxAzKi9acok9Z
wZtzSas+zxpdF2fx9zvRwF1yvPwMmwbDaKlVH9/SodU0tk0hnY79Pw83Nowa
gEGzknQcMsT817rrJY3o+FQKPdVJGpzedk5ceqmDrnPnTpinayEtdi6V9tMM
Pq1L3GItzDBTf8ZeJQUTuMT5z/vqYgL5nbQLQV8tcN38dFrWcQtYc2geVBMK
9HoN6jYSevmbXrfa72iNIReXosu+NvDb/z3a/QsVzk3q90JeUBAyoUs7zzDF
l+jFLd6njeDSs2lLtZkt/NKq0raW20LzhNr33QSHPLNW7PgzbImX5RYl9c1E
Pg0cTcUqSAiwveM/6xkJ50L2B/d4k6H1kK/n6kkGm8PWry4jwfUELzjrPB3+
NJsL5nMsEdDj56TNJ3QL7+sceE5B0u+wV2+Jcw9NHZ03sc8CesqL9DXDGHj7
7s6npFAGNmw0nS6k0JH7jHz9fj4di9YXhP1MpOGl/fCTs0T/b9ZoMirZSgVN
o8KBUkSFXwOHStXXQtamPIumYE3Mm/q0LOeuETTyBOtEb42wk9lW+GCEyOv6
6L32f6yxZGP2wSOdJNyfbI0XEpypXDESeclZDx5KSZ7aH3XxoqA/IMSejOyF
DlZOXDKMmDkWQS9N8UNWfPPbPab46zGT3v1SH8827je9c1YfyVUGThs4lnje
op//hmSJBdXJyTInaFj24Iz0XgcqZmU+9I7qN8fOgTiBe6MZhjbwC17X6RIc
H0vMGNaGnH6i0bd4c/w9SdWYtjKD+mfhAZklNjCSPLX04y0iL87Rre8Hydi9
ojWMJ05Gwd2r8eXyFLCZX9IFmhScOm0SJ7ucAoM5rzOPr6LAWq3wk4qEDVi7
5m7eEWGNXx9uF2sRc9+nD38DzscY4NZc1+kjYgwUHQ//9irOGo3zNCJWjdNh
xn+iLNZMxsmzu+ucOxg4/d1r1HGpDVyCLji2+1FwvNg4TyqdguirwattFK2h
9edJ5liTFXaFOjzwFDMAKeyzqO20PtzCSmKEdCpu75QozTCnYu/AG5/saS1Q
Ml/XrCX6dOS1k2wkSQfWOZJl7x208Xzz8yXyhB/VDipNVBSZ4d4+LXKYOhWr
jI1ObZ1NRUafxdd6Q0LnOTkd62PouKu4dkxYTUNHp68lfYKG2r/JF7TiyVj4
MSNvnwsZjOqaxnoHEi70SFaueWaOufrq0cl0a9xS7Jc8o87AwerCV/9yaPh0
fV+a/C8attMzEy2SLVGcPUmJ2UPHspDTgj2ahsh5HR3xZ8IQkjXn73er07Hi
bKOG7DuCE5fbm4cX66LiSXDhx106EC2U65+7yhyJl5eKy9wgwSDwYIbrBWOw
RfUP5lwxRtLtbe+eydNx6bSB86cFdJRNyW+w6qQgUM0qRRBOAeWm3oWvaxk4
U5v1vfU+A5slqkrrLGnYsWrQN62FyI1F8i8K1RRnW5bI9F80QqqSAumGoQ2C
pVKzu4dsQbXz3zp13gphk2+81AqswJT4YGAgQcYhi4xtsudJWDVg1UgaIyH6
Vso6+zgyXlX2hCCVjA3Ll/43ySJDmOtZS19ohc0BbhKm3ZaQua+w8vxRCsJt
fV0WaVLBW/BSPeCbBUr23au7U0SHhoapzJ3PDJh3/PLeO9cGahkeAxcaLXBu
0DpJkU9H/9NH51c+ouGQn8U6Ux8aZkam6vxZR8VX19iCjXeoUDYp2lgVqYXD
pPTD5SItfNm8IvLDAmNoeg85V4UbY3Ty4XtnewZaW+/5Wa1iIEaq6coLSTLW
zfV5c0qLjPdWw1MiETH3tr51q+jXg6Te3FtVASQ0y35y36dOhkrQfxJvyeZg
7T1msajfDDt/M84lSBlgz6G4sEXrDfBY1uPkskFL3Bguo6ovtgLZ42v7HMJP
dm2yOwLLaHBwLLn5i2WOullVze665igtCNHY9UIXdoH6K/Zt1IG8q+njiT/m
kHamlWzuM8NW+IiH/2MgOXyJ0YazDAxYvVoWOkKG65y1Z4LPkjEgCMx3dabA
p0TUkG1DAfxXfjrpT8GMydC5ktEUvJXSOqEUz4CUS101pYCB52duxOtpE3P7
ty2B34YMMFO4Voc7ZY33237nf6qzhsLya5c32lvCLk21reUZGVGulocrFW3A
Cal7uZFhA9kv5+t5uyjo+vq1PqCKgmu8/an236xButm83Wi/Nf4HGa7cOA==

            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 4 PCA vars 1 -20\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"20", ",", "5", ",", "0.9445287244585885`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3cg1W8bxkWDIiOasvc4zrSLIptSiaxwhnMO5zgoSaVBaCiFEhmhSQNF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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 5 PCA vars 1 -20\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"20", ",", "6", ",", "0.9435409574593739`", ",", 
       GraphicsBox[{{}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVl3k8VG8bxi0lFcqWQtn3bRbGWpQ1a0oRss0YM8MwKJWioqKkhaQSylKJ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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{True, False}, {True, False}},
        FrameLabel->{{
           FormBox[
           "\" \\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\) (predicted)\"", 
            TraditionalForm], None}, {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(ads\\)]\\)\"", 
            TraditionalForm], None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
          "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}},
        PlotLabel->FormBox[
         "\"ANN layers: 6 PCA vars 1 -20\"", TraditionalForm],
        PlotRange->{{-350, 0}, {-350, 0}},
        PlotRangeClipping->True,
        PlotRangePadding->{{0, 0}, {0, 0}},
        Ticks->{Automatic, Automatic}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8097526572083955`*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"2784685e-7587-4764-a0aa-8b2d3f1de8ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<PCA_Scan_Data.csv\>\"", ",", 
   RowBox[{"Join", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Num. PCA vars\>\"", ",", " ", "\"\<Depth\>\"", ",", " ", 
        "\"\<RSq\>\""}], "}"}], "}"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"pcaVarScan", "[", 
        RowBox[{"[", 
         RowBox[{";;", ",", " ", ";;", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
       "1"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.809752976966544*^9, 3.8097530367049828`*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"8994e769-a327-411c-ac51-9f0ef2487393"],

Cell[BoxData["\<\"PCA_Scan_Data.csv\"\>"], "Output",
 CellChangeTimes->{{3.809752985747712*^9, 3.809753037079328*^9}},
 CellLabel->"Out[37]=",ExpressionUUID->"0fbef0de-0968-415c-a765-f847c3a18da6"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"figure3", "=", " ", 
   RowBox[{"ListLinePlot", "[", "  ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"pcaVarScan", "[", 
           RowBox[{"[", 
            RowBox[{";;", ",", " ", ";;", ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
          "1"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{";;", ";;", "6"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}], " ", ",", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"pcaVarScan", "[", 
           RowBox[{"[", 
            RowBox[{";;", ",", " ", ";;", ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
          "1"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"2", ";;", ";;", "6"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}], " ", ",", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"pcaVarScan", "[", 
           RowBox[{"[", 
            RowBox[{";;", ",", " ", ";;", ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
          "1"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"3", ";;", ";;", "6"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}], " ", ",", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"pcaVarScan", "[", 
           RowBox[{"[", 
            RowBox[{";;", ",", " ", ";;", ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
          "1"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"4", ";;", ";;", "6"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}], " ", ",", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"pcaVarScan", "[", 
           RowBox[{"[", 
            RowBox[{";;", ",", " ", ";;", ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
          "1"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"5", ";;", ";;", "6"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}], " ", ",", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"pcaVarScan", "[", 
           RowBox[{"[", 
            RowBox[{";;", ",", " ", ";;", ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
          "1"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"6", ";;", ";;", "6"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}]}], " ", "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"True", ",", "False"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Number of PCA variables\>\"", ",", 
        "\"\<\!\(\*SuperscriptBox[\(R\), \(2\)]\)\>\""}], "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"LineLegend", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<1\>\"", ",", "\"\<2\>\"", ",", "\"\<3\>\"", ",", "\"\<4\>\"", 
          ",", "\"\<5\>\"", ",", "\"\<6\>\""}], "}"}], ",", "    ", 
        RowBox[{"LegendLabel", "\[Rule]", "\"\<Depth\>\""}]}], "]"}]}], ",", 
     " ", 
     RowBox[{"PlotStyle", "\[Rule]", "Automatic"}], ",", " ", 
     RowBox[{"LabelStyle", "\[Rule]", "Medium"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"0.6", ",", "1"}], "}"}]}], "}"}]}]}], "\[IndentingNewLine]",
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.804584928337494*^9, 3.804584947218421*^9}, {
   3.80458504988518*^9, 3.804585066087655*^9}, 3.804585096446577*^9, {
   3.8045946373730955`*^9, 3.8045946444959526`*^9}, {3.805183157625868*^9, 
   3.805183175381484*^9}, {3.8051832472180915`*^9, 3.805183250814121*^9}, 
   3.8078000844486227`*^9, {3.8097528150050416`*^9, 3.809752819275408*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"ec6169ef-330d-4db8-8a72-6a0507e49759"],

Cell[BoxData[
 RowBox[{
  TemplateBox[{
    GraphicsBox[{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEf7I+nap/IrH1iDxVwKLt22VNK5RmUz+FwJaCS
K2A1jC/gIBb4qu+w5nMoX8SB6dWuLzZfYHwJh3vHlmT8OvISypdx+FItf37v
9VdQvoJDnMkHgZv/YPJKDg0StSVRqa+hfBWH15f2By7lgvHVHMIerrX+sgbG
13C4ZFtWon8extdyUJO+na0Q8wbK13GImyNc2pcIs0/P4YqO+ZSDJ2DyBg5l
tyZYRvbC9Bs6mBkechPeAOMbOYhpXj34/xFMvbHD2tWyT4L9YHwThw/NNtvu
THhjDwBPx2AP
          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEf7J/kTQ29yfTUHirgULbJ4dSmy8+gfA4HoZZm
f/b/L6F8AYdD0tvdjNjfQPkiDoZ3Ppd9tHwN5Us4nP/XvVm3BcaXcZg/4Qxr
msY7KF/BQVkjLfH5OZh+JQebu7+E+Aph8ioO+iK/19Y+eAvlqzksu/WrP+QU
TF7DQXj6yScxlTB5LYdtlw6X5+2Eyes4nJCcse5dN4yv5xCyImN+kj2Mb+CQ
sHTdzguvYfoNHXhu1xzxmwjjGzk89E1LOiIIU2/s0Hlkdt2pdpi8icP+Ke96
ova/swcAXyJiow==
          "]]}, {
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEf7JNOxjm+4X9qDxVwKFA13uh24jmUz+HQHie2
jsn1NZQv4NDSNeWk8K43UL6Iwwc9Z43PDW+hfAkHBas33rxq76B8GYfP63aL
vLkJk1dwCHkurWZ9GcZXctjb3DVvcQVMvYrDzViW+rQQGF/Nwci3Ika4D8bX
cCi/M+mH3CuYfi2HlXeOOhR+h8nrOHhEJuyaJQbj6zlsd7d/WXwapt7AwfzT
uZDF2jB5Q4drzpGBNvEwvpHDH6XO/fmTYXxjBw7+HoeiIhjfxOHRE5vWCz7v
7AGSxVt5
          "]]}, {
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEf7DPcry7c9+KJPVTAwb9P4tPEBS+gfA6HvHOS
KvPE30L5Ag7Zl8vmcM9+B+WLOKxInTtL6j5MXsJhbuqTgvW9ML6Mw/50uYli
32F8BYfY79s74g1gfCWHZ3tbXddEwsxTcZA/Hrba3B7GV3OIspz85X0pjK/h
4NR8rFu2GsbXcnD8dGtG+GsYX8fh1pNQzZ6FML6eg3RtTJXBTBjfwEF1dWi2
1SIY39Dhn/XxgzF7YO4xcjgi18tZ3QyTN3Z4v9a588tkGN/EYWuSXK6R+zt7
APaIXtI=
          "]]}, {
         Hue[0.6142719099991583, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEf7AOuP/ufsPeJPVTA4ZFGo83djudQPodDXm/K
lZoJb6B8AQfFJzc79y9/C+WLOJzY91M6QPodlC/hkLJCXes1K4wv43DJVnJi
72uYegUHs10u1+82weSVHDiqPoTP/wDjqzjE3WWVvJ4G46s5TEmRvmeyCcbX
cFg/4dwU/ikwvpZDYHOsYVQ1jK/j4HsvIar6N8w+PQeVU7zfor/A5A0cBE5F
TVlqA+MbOhRNt3CI3wpTb+TAZyZW88YBJm/sYLfLlNGnA8Y3cbh1ZavvFMt3
9gDAsF2Y
          "]]}, {
         Hue[0.8503398874989481, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEf7J0WbfN6svKJPVTA4Vbizzs2W19A+RwOdVEV
G1pzXkP5Ag6mXx7rn3Z8C+WLOOhvmMnVGAPjSzjEV7SHWe+G8WUcnJNWW+Vx
vIPyFRx2vDTfaaQI4ys5MMp5TFTKhPFVHPIyL60SWAzjqznUGFXcLFsG42s4
LCh+7RWWCuNrOTxbV/V4rz+Mr+PAKlLiyZwL4+s5aFT5y2yeCOMbONjGOaxc
kgbjGzqsezulb4U1jG/kcMWgXZs5HcY3dkh6V20vGAjjmzhk64efqzF8Zw8A
N0BYqQ==
          "]]}}, {{
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]]}}, {{
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[
          1.6]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]]}, {
         Directive[
          PointSize[
           NCache[
            Rational[1, 72], 0.013888888888888888`]], 
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[
          1.6]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}, {{}, {}}}, {
     DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
      NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
      AxesLabel -> {None, None}, AxesOrigin -> {0.6041666666666666, 0.6}, 
      DisplayFunction :> Identity, Frame -> {{True, False}, {True, False}}, 
      FrameLabel -> {{
         FormBox[
         "\"\\!\\(\\*SuperscriptBox[\\(R\\), \\(2\\)]\\)\"", TraditionalForm],
          None}, {
         FormBox["\"Number of PCA variables\"", TraditionalForm], None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], LabelStyle -> Medium, 
      Method -> {
       "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}}, 
      PlotRange -> {{0.6041666666666666, 20.}, {0.6, 1}}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}}, Ticks -> {Automatic, Automatic}}], 
    FormBox[
     FormBox[
      TemplateBox[{"\"1\"", "\"2\"", "\"3\"", "\"4\"", "\"5\"", "\"6\""}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                StyleBox[
                "\"Depth\"", {FontSize -> Medium, FontFamily -> "Arial"}, 
                 Background -> Automatic, StripOnInput -> False]}, {
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"]}}, GridBoxAlignment -> {"Columns" -> {{Center}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
             Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontSize -> Medium, FontFamily -> "Arial"}, Background -> Automatic,
           StripOnInput -> False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.560181`", ",", "0.691569`", ",", "0.194885`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.922526`", ",", "0.385626`", ",", "0.209179`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.528488`", ",", "0.470624`", ",", "0.701351`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"PointSize", "[", 
                    FractionBox["1", "72"], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.5147193333333333, 0.28770266666666666`, 
                    0.06825800000000001], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.772079`", ",", "0.431554`", ",", "0.102387`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.772079, 0.431554, 0.102387]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.772079, 0.431554, 0.102387], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                  "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}],
             ",", 
            RowBox[{"LegendMarkers", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
            ",", 
            RowBox[{"Joined", "\[Rule]", 
              RowBox[{"{", 
                
                RowBox[{
                 "True", ",", "True", ",", "True", ",", "True", ",", "True", 
                  ",", "True"}], "}"}]}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", "Medium"}], ",", 
            RowBox[{"LegendLabel", "\[Rule]", "\"Depth\""}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], TraditionalForm]},
   "Legended",
   DisplayFunction->(GridBox[{{
       TagBox[
        ItemBox[
         PaneBox[
          TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
          BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
        "SkipImageSizeLevel"], 
       ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
     GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
     AutoDelete -> False, GridBoxItemSize -> Automatic, 
     BaselinePosition -> {1, 1}]& ),
   Editable->True,
   InterpretationFunction->(RowBox[{"Legended", "[", 
      RowBox[{#, ",", 
        RowBox[{"Placed", "[", 
          RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], "60"}]], "Input",
 CellChangeTimes->{{3.8097528399652033`*^9, 
  3.809752840300664*^9}},ExpressionUUID->"8f3ceb37-4bd1-4367-800f-\
deecfe3f26d3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<nm-Figure3.png\>\"", ",", "figure3", ",", " ", 
   RowBox[{"ImageResolution", "\[Rule]", "600"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8097528240027237`*^9, 3.8097528431488647`*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"62eddf83-f7d0-48df-b7ad-f26e5d5747d1"],

Cell[BoxData["\<\"nm-Figure3.png\"\>"], "Output",
 CellChangeTimes->{3.809752845174178*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"95321f43-0fa7-4b87-a33e-56d24d95d569"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{
  3.804584970800548*^9},ExpressionUUID->"bed1b3a5-c7f5-4b70-a605-\
2ff5ca5038c2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Build", " ", "an", " ", "ensemble", " ", "of", " ", "networks", " ", 
    "with", " ", "the", " ", "specified", " ", "parameters", " ", "found", 
    " ", "in", " ", "the", " ", "last", " ", 
    RowBox[{"step", "."}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"goldScaleVal", " ", "=", " ", "auHamaker"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tio2ScaleVal", " ", "=", " ", "tiO2Hamaker"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rescaleEnergies", " ", "=", " ", 
     RowBox[{"Flatten", "[", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", " ", 
         RowBox[{"goldScaleVal", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"numProteins", "*", "4"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", " ", 
         RowBox[{"tio2ScaleVal", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"numProteins", "*", "4"}]}], "}"}]}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bindingNPDescriptors", "=", " ", 
     RowBox[{"rawData", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"2", ";;"}], ",", 
        RowBox[{
         RowBox[{"-", "3"}], ";;"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PCAMax", " ", "=", " ", "3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"networkDepth", " ", "=", "4"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"repeatedComponents", " ", "=", " ", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"principleComponentSets", "[", 
          RowBox[{"[", 
           RowBox[{";;", ",", " ", 
            RowBox[{"1", ";;", "PCAMax"}]}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "8"}], "}"}]}], "]"}], ",", "1"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"proteinPCAWithEnergy", "=", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Join", "[", " ", 
        RowBox[{
         RowBox[{"repeatedComponents", "[", 
          RowBox[{"[", "i", "]"}], "]"}], " ", ",", "  ", 
         RowBox[{"bindingNPDescriptors", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], " ", "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", " ", 
         RowBox[{"Length", "[", "bindingNPDescriptors", "]"}]}], "}"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"proteinPCAWithEnergy", "[", 
      RowBox[{"[", 
       RowBox[{";;", ",", 
        RowBox[{"-", "2"}]}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"proteinPCAWithEnergy", "[", 
        RowBox[{"[", 
         RowBox[{";;", ",", 
          RowBox[{"-", "2"}]}], "]"}], "]"}], "]"}], "//", "N"}]}], ";"}], 
   " ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "replaces", " ", "the", " ", "radius", " ", "by", " ", "log", " ", 
      RowBox[{"radius", ".", " ", "note"}], " ", "that", " ", "consequently", 
      " ", 
      RowBox[{"R", "^", "n"}]}], " ", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"Log", "[", " ", 
       RowBox[{"R", "^", "n"}], "]"}], " ", "\[Rule]", " ", 
      RowBox[{"n", " ", 
       RowBox[{"Log", "[", "R", "]"}], " ", "and", " ", "so", " ", 
       RowBox[{
        RowBox[{"radius", "/", "SA"}], "/", "volume"}], " ", "are", " ", 
       "all", " ", "encoded", " ", "here"}]}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PCAEnergyRules", "=", 
     RowBox[{
      RowBox[{"Thread", "[", 
       RowBox[{"f", "[", "proteinPCAWithEnergy", "  ", "]"}], " ", "]"}], " ",
       "/.", " ", 
      RowBox[{
       RowBox[{"f", "[", "x_", "]"}], " ", "\[RuleDelayed]", " ", 
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"[", 
          RowBox[{";;", 
           RowBox[{"-", "2"}]}], "]"}], "]"}], " ", "\[Rule]", " ", 
        RowBox[{"x", "[", 
         RowBox[{"[", 
          RowBox[{"-", "1"}], "]"}], "]"}]}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"shuffledData", " ", "=", " ", 
     RowBox[{"RandomSample", "[", 
      RowBox[{"PCAEnergyRules", ",", "   ", 
       RowBox[{"Length", "[", "PCAEnergyRules", "]"}]}], "  ", "]"}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"separationPoint", "=", 
     RowBox[{"Round", "[", " ", 
      RowBox[{
       RowBox[{"Length", "[", "shuffledData", "]"}], "*", 
       RowBox[{"2", "/", "3"}]}], "]"}]}], " ", ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"trainingSet", " ", "=", " ", 
     RowBox[{"shuffledData", "[", 
      RowBox[{"[", 
       RowBox[{";;", " ", "separationPoint"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"validationSet", " ", "=", " ", 
     RowBox[{"shuffledData", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"separationPoint", "+", "1"}], ")"}], ";;"}], "]"}], "]"}]}],
     ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"networkEnsemble", "=", " ", 
    RowBox[{"Table", "[", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"bootstrapSample", "  ", "=", "  ", 
        RowBox[{"RandomChoice", "[", 
         RowBox[{"trainingSet", " ", ",", " ", 
          RowBox[{"Length", "[", "trainingSet", " ", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Predict", "[", 
        RowBox[{"bootstrapSample", ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<NeuralNetwork\>\"", ",", 
            RowBox[{"\"\<NetworkDepth\>\"", "\[Rule]", "networkDepth"}]}], 
           "}"}]}]}], " ", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "30"}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ensemblePredictions", "[", 
     RowBox[{"varSet_", ",", " ", "ensemble_"}], "]"}], " ", ":=", "  ", 
    RowBox[{"Table", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"ensemble", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "[", "varSet", "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "ensemble", "]"}]}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8045849738954487`*^9, 3.8045849868873453`*^9}, {
   3.804585112646468*^9, 3.8045852717903943`*^9}, 3.8045939786329446`*^9, 
   3.805180962309294*^9, {3.805702771177561*^9, 3.805702778812522*^9}, {
   3.8077951186597548`*^9, 3.807795126030582*^9}, {3.807800272397519*^9, 
   3.8078002728810167`*^9}, {3.8078128969787383`*^9, 3.807812899190322*^9}, {
   3.807813449205829*^9, 3.807813449644281*^9}, {3.8079483330562487`*^9, 
   3.807948333673404*^9}, 3.8097502984028497`*^9},
 CellLabel->"In[38]:=",ExpressionUUID->"eb6dff20-f013-48b4-b936-0534e08e19fc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {
                    0.6549512800111202, -0.07857654908911872, \
-0.5326926181242969, 0.4793650793650794, 3.910137436631351}, "Method" -> 
                    "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.6549512800111202, -0.07857654908911872, \
-0.5326926181242969, 0.4793650793650794, 3.910137436631351}, 
                    "StandardDeviation" -> {6.655153182219919, 
                    4.4189581753740805`, 4.203003712093651, 
                    0.49957401859022904`, 1.33615055026764}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{0.16245754929850084`, 0.3929516772976657, 
                    0.8493533323358662, 
                    0.18973880831225132`, -0.24858524786294695`}, {
                    
                    0.5546022317806195, -0.45588690495551726`, \
-0.006570563927979505, -0.31473269941451154`, -0.6208732962553294}, {
                    0.601254385899093, -0.33170623697004786`, 
                    0.18546411691696957`, 0.2176044711133124, 
                    0.6683677814496892}, {-0.412254385059128, \
-0.40650465254358514`, 0.47489557520245884`, -0.6183224043801901, 
                    0.23864594351164747`}, {-0.3668288355848075, \
-0.6020639907971742, 0.13650274183679403`, 
                    0.659748596764326, -0.22148215934339993`}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.6549512800111202, -0.07857654908911872, \
-0.5326926181242969, 0.4793650793650794, 3.910137436631351}, 
                    "StandardDeviation" -> {6.655153182219919, 
                    4.4189581753740805`, 4.203003712093651, 
                    0.49957401859022904`, 1.33615055026764}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0168755, "MaxTrainingMemory" -> 95976, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 45, 54.7701731`9.491118955383048}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {
                0.6549512800111202, -0.07857654908911872, -0.5326926181242969,
                 0.4793650793650794, 3.910137436631351}, 
               "StandardDeviation" -> {6.655153182219919, 4.4189581753740805`,
                 4.203003712093651, 0.49957401859022904`, 1.33615055026764}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.4227624430989763`}, 
               "StandardDeviation" -> {0.663742817459761}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.4227624430989763` + 
         0.663742817459761 #& ), 
        "ProcessorFunction" -> (3.6501524074810114` + 
         1.5066076403314517` #& ), "Name" -> "value", 
        "Quantiles" -> {-3.063712566299177, 2.7737736107597266`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViXs01nccgNV73GK8DmlImjHX3De5/D7fXkSKg7IaTRFzsgy9lUtYbO65
RK69YeaMXiGZxan39/kexrvk1tyHebdsNrfisLTCpj+e55znPO+dizweulNK
SuqS3LaOB8Xw+PyguBMyb+OzoHBrq/C302ob6W22jMpRmW+KuwNSIPGH31Dc
Y0/GFi+yxdK+EJB7mlCeBVHJWoJPlO6xTxREMLRZy9aHZeKtPuZRwqcvma9G
DkC1sBU6616xe+ezYG1VhQz+fh0WDsmxlW03UO/eY1yTiOFuI8W2niUYlnjB
CZ8Z9Fgwp/8KysDw2QrIrv4KvrNJELr4Dbz4vohES7SJVqI5beqnrOiYPdgt
xEBfbDLK2uVgf7M2TKR9AVfvpxL9Bj6qP7elnilbzBGnHWg6o0sihCLQLemE
yUJl2lKaTot9Mii38kdoeO1Jg9/Iw76yOw43a/+Cj+bj8bKUJ17JUKRmLqVw
dmAdOwLdSJVzOzZ25GDLbTXCScp3jGom8I93BSgnMWjJNLNzGyU4qloFTPDX
xI97gGqJpAmXHUAl/WL8qasRA5X62ab0PEwSdKNr6gDDc8uDIFsO5sX3MoxS
AYjdNdhL0IXZOn8Db08IRlU64ncKh1ndGwog+OApBAQ8RmO+NjHgB5KwsDws
j7BlhLPv0E3Xo+DAmcQzgrNk9fkiExxQAw4+BXDSYRdwedY4+aAdwj+2ocmd
TiTTeC/17+bAgqI/brQFE+GUBq3f30JJBQeE3Q+ws3sGP3/YgiqtXGrTdoSm
vx9PHH6Jgii5UsoxmMaSPao0N9QdDTlqxNvDGdadDkMJh0Jk6TyG3C3CwIFG
nBv0QoNTQ2zOGwNHfcMxVjmCi6nC3UydpxMh4zuIzvXz8LPbTjAS2tL1vjlQ
7VTD+UgbNL1dAsmvY0jYnyY4UdPPsP4boOd+UZTASDBOwYJE6q3gMKNBWvf1
Yr2mJ6aZtQDaF0PTl8dEOtEzjq3n3DAkwxzCE7wh7aEHIyu+Si8LZCF4uYOx
WPMDn6RGWO4JI3MmOlR9nYcueeqkbugZG5M9DUudluS+2WmyfyIVHyWuMtgm
xvG1GsZoQQtqc3yp3dNaHHO1oSNGmuTb/fY05WA7Nly4hX9cqUa/diNiXKVN
Y2M30X7KlaZuGdJXG+UoI46B5gs8tFOwhqO6B9GncBQl/2XCi9EpNiW8Gj2G
FUjg9DU2ZmuQ6SkrFOXX9DqeGW9BicMKiNPVSJFLNBHVcumHcbkgE1sAZbsa
IMtKAObL54linyzj1ZGPvA15uOlxDZcOyWOFsxkZ4WnRU3dsiLqNJs221AcD
fjeuDS1CNslznHhiTheLTrIqge/SlwECnDUpRrWuKvwf+1P1Mw==
                    "], "Biases" -> 
                    RawArray["Real32",{0.00027593516279011965`, 
                    0.05439214035868645, 0.07369846105575562, 
                    0.0032801504712551832`, -0.00463134003803134, \
-0.029719719663262367`, -0.015091038309037685`, 
                    0.07636038213968277, -0.018789684399962425`, \
-0.0048568397760391235`, -0.059051770716905594`, -0.03383210673928261, \
-0.07004877924919128, -0.043720245361328125`, 
                    0.07073058187961578, -0.016615189611911774`, 
                    0.08647824823856354, 0.0022448799572885036`, 
                    0.0296765323728323, -0.037338629364967346`, \
-0.037969380617141724`, -0.009658723138272762, 
                    0.010720055550336838`, -0.08788792788982391, \
-0.1327972412109375, -0.03552662208676338, 
                    0.0024876990355551243`, -0.013955803588032722`, 
                    0.03167672082781792, -0.025435736402869225`, \
-0.06735260039567947, 0.1538240760564804, -0.008642091415822506, 
                    0.05236168950796127, 
                    0.01496882550418377, -0.05724434554576874, 
                    0.03606658801436424, 0.04655080661177635, 
                    0.004194954410195351, -0.018406793475151062`, \
-0.04817672073841095, 
                    0.016627231612801552`, -0.04883187264204025, \
-0.11305466294288635`, 
                    0.10351336002349854`, -0.02992626279592514, \
-0.06737042218446732, 0.032092127948999405`, -0.009745514020323753, 
                    0.04920753464102745}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dYz//3/ykpLU2z0ibKqFR6Pc9RiVCEKArRp+zeWdlpD+0dLUVWIhpG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                    "], "Biases" -> 
                    RawArray["Real32",{-0.004855941981077194, 
                    0.011003689840435982`, -0.01504996046423912, \
-0.09596282243728638, 0.025825057178735733`, 0.034018393605947495`, 
                    0.007615338545292616, -0.13354061543941498`, \
-0.02541099302470684, -0.03610207140445709, 
                    0.04055212810635567, -0.015457766130566597`, \
-0.04789485037326813, -0.04266519472002983, -0.08025366812944412, 
                    0.02700047381222248, 0.03815685212612152, 
                    0.04772551730275154, 0.02865437977015972, 
                    0.042620569467544556`, -0.00011722413182724267`, 
                    0.0351237878203392, 0.001229246612638235, 
                    0.043866101652383804`, 0.02913028374314308, 
                    0.017955269664525986`, -0.013920974917709827`, 
                    0.012798769399523735`, 0.008503464050590992, 
                    0.03224538639187813, 
                    0.01870502158999443, -0.0027521969750523567`, 
                    0.00905823614448309, 0.06680749356746674, 
                    0.03370272368192673, 0.030441327020525932`, 
                    0.03925461694598198, 0.019048618152737617`, 
                    0.008077865466475487, -0.024823343381285667`, \
-0.06856784969568253, -0.01843554526567459, -0.010930409654974937`, \
-0.01798272132873535, 0.007192196790128946, 0.027001162990927696`, 
                    0.006410820409655571, -0.02112194523215294, 
                    0.026246042922139168`, 0.03994053974747658}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUj4/Th1MUpbRIq1RarKES9b1n7EUha0IbKrIrW4j2QlpEEaWihZ9E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                    "], "Biases" -> 
                    RawArray["Real32",{-0.02664017677307129, 
                    0.003968740347772837, 
                    0.0018720254302024841`, -0.04159590229392052, 
                    0.037139493972063065`, -0.00032705877674743533`, \
-0.03341292962431908, 0.02744441106915474, 0.029175342991948128`, 
                    0.023471836000680923`, -0.06380515545606613, \
-0.00610119104385376, 
                    0.0665210634469986, -0.03262576088309288, \
-0.030644727870821953`, 0.014447055757045746`, 
                    0.00581522798165679, -0.01491854153573513, 
                    0.005331873428076506, -0.004142467863857746, \
-0.015964526683092117`, -0.013563265092670918`, 
                    0.02964009717106819, -0.002268929034471512, 
                    0.01208149828016758, -0.01967742294073105, 
                    0.024451442062854767`, 0.010140543803572655`, 
                    0.09273099154233932, 
                    0.008435639552772045, -0.07746811956167221, \
-0.010390101931989193`, -0.01853933371603489, 
                    0.019417231902480125`, -0.015095002949237823`, 
                    0.051033370196819305`, 
                    0.023028671741485596`, -0.022268546745181084`, 
                    0.00964427925646305, 
                    0.0960986390709877, -0.08401191234588623, \
-0.05803985148668289, 
                    0.005640992429107428, -0.009493804536759853, \
-0.011309334076941013`, -0.016917912289500237`, -0.041777610778808594`, 
                    0.030245304107666016`, 
                    0.026086751371622086`, -0.02385042980313301}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUj43TxyvaF22KRKXNkqKi5XfNREohW1GJkKUiQrIUpZQSpU0LWUKR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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.021581925451755524`, -0.017988907173275948`, \
-0.004976042080670595, 0.028487153351306915`, -0.029592126607894897`, 
                    0.01882576383650303, -0.004943345673382282, 
                    0.020809559151530266`, -0.016415879130363464`, 
                    0.02516510710120201, 
                    0.031275223940610886`, -0.023856887593865395`, \
-0.008928586728870869, 0.046382687985897064`, 0.04151396080851555, 
                    0.022555164992809296`, -0.05043455585837364, 
                    0.0150038106366992, 0.007697859313338995, 
                    0.044436678290367126`, -0.013185312040150166`, 
                    0.015300441533327103`, 0.009228837676346302, 
                    0.0054434253834187984`, -0.02126757614314556, \
-0.014422130770981312`, -0.009419012814760208, -0.002966521540656686, \
-0.015393899753689766`, -0.00023467541905120015`, -0.0026615893002599478`, 
                    0.01691487617790699, -0.014252197928726673`, 
                    0.0037362072616815567`, -0.0400906503200531, \
-0.0039025642909109592`, -0.033329565078020096`, -0.02110232412815094, 
                    0.0016328608617186546`, -0.018518073484301567`, 
                    0.0070150732062757015`, 0.024648411199450493`, 
                    0.01841115951538086, 0.040755778551101685`, 
                    0.014469310641288757`, 
                    0.014532603323459625`, -0.024000609293580055`, 
                    0.01925635151565075, -0.02714579924941063, 
                    0.006797595415264368}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{
                    0.17055988311767578`, -0.08310793340206146, 
                    0.1171918734908104, -0.08370497077703476, 
                    0.07305072247982025, -0.06301970034837723, \
-0.33579108119010925`, 
                    0.23337236046791077`, -0.29386821389198303`, \
-0.038919687271118164`, 0.016766289249062538`, 
                    0.21162965893745422`, -0.04007091373205185, \
-0.07870756834745407, -0.19298529624938965`, -0.047064296901226044`, 
                    0.23742343485355377`, -0.10753300786018372`, \
-0.10501999408006668`, 
                    0.036792438477277756`, -0.19697552919387817`, \
-0.079255610704422, 
                    0.24813701212406158`, -0.22496488690376282`, \
-0.05165877938270569, -0.08417654037475586, 
                    0.20721034705638885`, -0.07423991709947586, 
                    0.049870897084474564`, 0.01593664288520813, 
                    0.031235601752996445`, 0.32698705792427063`, 
                    0.3434157371520996, 0.11513951420783997`, 
                    0.13519436120986938`, 
                    0.40760013461112976`, -0.08914646506309509, \
-0.07941712439060211, -0.38064059615135193`, -0.15227854251861572`, \
-0.10240621119737625`, 0.042310234159231186`, 0.04313863813877106, 
                    0.14701032638549805`, 
                    0.11457783728837967`, -0.17217572033405304`, 
                    0.011120030656456947`, 
                    0.1531500369310379, -0.09888888150453568, 
                    0.39894065260887146`}}], "Biases" -> 
                    RawArray["Real32",{-0.002102549886330962}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.6585521697998047}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 0.8629052, "MeanInputsPerSecond" -> 
          37084.02730682351], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.00031450597305767184`, -0.00024389862347334144`, 
                
                0.0007066503926778644, -0.00023258797338732574`, \
-0.00021611586241290366`}, 
               "StandardDeviation" -> {0.9996217018289876, 1.000365412545941, 
                0.9997594200801193, 1.000499697128187, 0.9998270299999155}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 6346474685169178923]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 100, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.1523809523809524, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[359185], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.40986052763743996`, "PreprocessingTime" -> 
        0.3278002`6.967154207705651, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.38086790601907416`, 0.22981159476979174`], 
           "StandardDeviation" -> 
           Around[0.3496857142954131, 0.06827529479933349], "EvaluationTime" -> 
           0.00025157034800970054`, "TestSize" -> 63, "ModelMemory" -> 99880, 
           "ModelUtility" -> 0.3192347471771231, "TrainingSize" -> 252, 
           "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 452112, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.38086790601907416`, 0.16250133705701464`]}, 
           "StandardDeviationHistory" -> {
             Around[0.3496857142954131, 0.04827792394011933]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 100, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}, 
           "FinalTrainingSize" -> 315], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration", "FinalTrainingSize"}, {
           TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}], 
            TypeSystem`Atom[Integer]}], 
          Association["ID" -> 222419388624231]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.1395399586232773`, 0.43360574661672036`], 
                "StandardDeviation" -> 
                Around[0.5777769782417382, 0.03277011597473327], 
                "EvaluationTime" -> 0.00012322505696906678`, "TestSize" -> 
                305, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.15589339594954, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.7943282347242815, "TrainingMemory" -> 
                496232, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.1395399586232773`, 0.30660556379413884`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5777769782417382, 0.023171971226003504`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[7.488077189799161, 1.5668305907112976`], 
                "StandardDeviation" -> 
                Around[0.5661065823922774, 0.050555217686131707`], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.1419112021078861, "TrainingSize" -> 50, 
                "TrainingTime" -> 0.7943282347242815, "TrainingMemory" -> 
                500008, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[7.488077189799161, 1.1079165356624825`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5661065823922774, 0.035747937250225806`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.402710824472673, 0.24730453776523348`], 
                "StandardDeviation" -> 
                Around[0.3551353461855464, 0.07075650132689677], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.3030008539939425, "TrainingSize" -> 252, "TrainingTime" -> 
                2.51188643150958, "TrainingMemory" -> 547544, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.402710824472673, 0.17487071567200121`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3551353461855464, 0.05003240190128365]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00031670830396331406`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.3551353461855464, 0.07075650132689677], 
               "TrainingMemory" -> 547544, "TrainingTime" -> 
               3.9341862741112568`], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[5.214734037066796, 1.0210721598405192`], 
                "StandardDeviation" -> 
                Around[0.533114674960563, 0.04301668420445265], 
                "EvaluationTime" -> 0.0000852424683695912, "TestSize" -> 265, 
                "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.08016951592158295, "TrainingSize" -> 50, 
                "TrainingTime" -> 0.31622776601683794`, "TrainingMemory" -> 
                428640, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[5.214734037066796, 0.7220070483040254]}, 
                "StandardDeviationHistory" -> {
                  Around[0.533114674960563, 0.030417389105128714`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.38086790601907416`, 0.22981159476979174`], 
                "StandardDeviation" -> 
                Around[0.3496857142954131, 0.06827529479933349], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 0.3192347471771231,
                 "TrainingSize" -> 252, "TrainingTime" -> 0.6309573444801932, 
                "TrainingMemory" -> 452112, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.38086790601907416`, 0.16250133705701464`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3496857142954131, 0.04827792394011933]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[3.7539888340346854`, 0.4857594201977329], 
                "StandardDeviation" -> 
                Around[0.5969744694065556, 0.03248216055462233], 
                "EvaluationTime" -> 0.00012738180561453242`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.18812178860501239`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                430992, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.7539888340346854`, 0.3434837800470625]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5969744694065556, 0.022968355995763638`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00012738180561453242`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.5969744694065556, 0.03248216055462233], 
               "TrainingMemory" -> 430992, "TrainingTime" -> 
               1.570265353260354], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[19.17807402864449, 3.704403801446468], 
                "StandardDeviation" -> 
                Around[0.6112181230184319, 0.053259952990810364`], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.21815521123827242`, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                429016, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[19.17807402864449, 2.6194090482560224`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6112181230184319, 0.03766047392547875]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[3.4605037035482, 0.464769911966691], 
                "StandardDeviation" -> 
                Around[0.5768898313881613, 0.032170839006864516`], 
                "EvaluationTime" -> 0.00010543772252266579`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.15416672022748212`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.2589254117941673`, "TrainingMemory" -> 
                424544, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.4605037035482, 0.3286419564431219]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5768898313881613, 0.022748218418214592`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.3911934269532117, 0.22717343957978287`], 
                "StandardDeviation" -> 
                Around[0.3507358957457259, 0.06400370803299477], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.31869576282410517`, "TrainingSize" -> 252, "TrainingTime" -> 
                5.011872336272724, "TrainingMemory" -> 456392, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.3911934269532117, 0.1606358796323369]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3507358957457259, 0.0452574559712145]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00031670830396331406`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.3507358957457259, 0.06400370803299477], 
               "TrainingMemory" -> 456392, "TrainingTime" -> 
               7.849733612802018], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[11.433800699814771`, 1.888212040784421], 
                "StandardDeviation" -> 
                Around[0.5613085976996757, 0.0411100346276183], 
                "EvaluationTime" -> 0.0000852424683695912, "TestSize" -> 265, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.13023827332582394`, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499488, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[11.433800699814771`, 1.3351675383567538`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5613085976996757, 0.029069184260002684`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0000852424683695912, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.5613085976996757, 0.0411100346276183], 
               "TrainingMemory" -> 499488, "TrainingTime" -> 
               6.577306748713622], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 222415093656935]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 5.1541015625`2.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097567738911326`17.333472239079985*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 3.352697695969483, 
            "ElapsedTimes" -> 3.0178507, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 5.587829493282471, 
            "ElapsedTimes" -> 5.424036500000001, "ExperimentCounts" -> 4], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 9.313049155470788, 
            "ElapsedTimes" -> 9.8806648, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 222427978558823]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{-3.525166247038391, 
              9.160944810588841, -4.16891759840301, 0., 5.298317366548036}}, 
             "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 20.722369, 
        "MaxTrainingMemory" -> 994112, "DataMemory" -> 75768, 
        "FunctionMemory" -> 262920, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 46, 15.4349169`8.941079243874736}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.5930126891658296, -0.12459188550683191`, 
                    0.07877115532537476, 0.4984126984126984, 
                    3.752788640390349}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.5930126891658296, -0.12459188550683191`, 
                    0.07877115532537476, 0.4984126984126984, 
                    3.752788640390349}, 
                    "StandardDeviation" -> {6.541567077882286, 
                    4.654669202862227, 4.2690639914784905`, 
                    0.4999974804673229, 1.389244590359627}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.6683662436811868, 0.19454410598840233`, 
                    0.199962638980949, -0.013424266358293793`, \
-0.6894011076414007}, {0.019692106390340493`, 0.511477618227252, 
                    0.7659544970114492, 0.18185125262256782`, 
                    0.3438701752493664}, {-0.18391885887723788`, 
                    0.6335877364007311, -0.39308897998971915`, \
-0.5877383233428564, 
                    0.2545292728089691}, {-0.6277197857674047, \
-0.07127329743885691, -0.2833646225617385, 0.5239426696625236, 
                    0.4960610418241559}, {0.35361067455441786`, 
                    0.5422452712864729, -0.3721749534974086, 
                    0.5888952820097818, -0.3092211303007123}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.5930126891658296, -0.12459188550683191`, 
                    0.07877115532537476, 0.4984126984126984, 
                    3.752788640390349}, 
                    "StandardDeviation" -> {6.541567077882286, 
                    4.654669202862227, 4.2690639914784905`, 
                    0.4999974804673229, 1.389244590359627}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.01361, "MaxTrainingMemory" -> 93048, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 46, 15.4627826`8.941862598184041}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.5930126891658296, -0.12459188550683191`, 
                0.07877115532537476, 0.4984126984126984, 3.752788640390349}, 
               "StandardDeviation" -> {6.541567077882286, 4.654669202862227, 
                4.2690639914784905`, 0.4999974804673229, 1.389244590359627}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.373201690364475}, 
               "StandardDeviation" -> {0.7274642641682195}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.373201690364475 + 
         0.7274642641682195 #& ), 
        "ProcessorFunction" -> (3.262293156184086 + 1.374637970902113 #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-2.6744361661438427`, 2.462679813853266}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwVjXlQ1HUYh7mv0AJSQBZYWUVQ2FFwMZz9ve8KhbYaBXlwyDjrgRm7IqAp
KOqSgBIIK+HEfbQyclg2Cxqyv/croMCsIql54RGoGWYwOEgTLEL4x/OZeebz
xzN/a2JkvJmJiUmKzcxEKvavSk5WpH5p9U52KJSBAcp3Z8AMljPscawip76F
LEb2nP4qOcSFZXrQezIT7HrrgXniJ1xEeSBdbSyV7g8uh/TyDBi1/52Gzm3A
7hpzrF1ewH2uHqSPq+Uo0QzQf4IbFJKQD6r+hbin1ZRUCn9KKxJj/CI7cBmV
Y9aKIs6r/jtmfuUYdFS9lu44NIdW9rvDZ/5LqFCUTB+c3gsbU2NwrMWaNcYq
2ZneUIq3VfOXVKtJvu0aPaxQQwOEktU8Czy4ywn1L1/olXcLwGPWUcyBA3Ro
eS14R/tyLrcK2LCiDdaYlsBtT8ZtsRNBwEgFaFJC2KJnh/UfjXjhy2+AyiIH
IddDjHpDMm3TdfDjKZtxar3FpeMfhsNvihxyzmmiZ655fJKymRJji9DhXyf8
KdgchPHVfFNsFVXuPs7e3LVC59ir0vRNOug+UUyHJdXY+4MLyipus6f3y6gu
25d8bwZyvhN9+trzMqrOLmWDp4SQlWgkTR3Sj1eGQTh+hzMMu4ODxVkStSRi
icM6jGubhpb7byhiVyme1eRyt6c+wVHnCvrj8k5YvF5HdRfUUJphBL+fo+mL
miVYYxYi9Yj8E+ZP2mNHszfeKRFgtqMly3xUye1tj2ZGNx28crzIZY6L4Bcb
d6rs6eA7opaRsrgaDG6hkG+WQS5u7vja8zEMBWo5ncGfbewH1FArZKyuwny1
JZptn42uVTHc9WOm+Lb+JvQ9ncP06WN0JGsLH15jS2HGhzR7yJoFrTxNvaJx
7kTcMElWSenYdDE8CntCVqle2ObvhYIRV7Z0jZj5JQ3zX9n6Q+nfmzDFah0T
TuXSussp+ovlD2jfbgscdQ1gSf/EwxE7NTYf8ePt7+n4qoEJkN8LpIR5ZnjS
poEONi2h97+1BmNPAL9+gYxY7yleM+CEi82F/GS8gdakW7O2Oa38KYGWRT2I
Yst2qyBo4WxMO+DDOru3QtBJX/3mnkIMSw5kls8H+ePacyC03CM1Rx8K6XGk
rrF0Nt0sI3Iqhom80NYWwVz49cZ1EA+uYp2iOyC+NMGFbBdQ+9FM/LohEopu
ubLioWtQIbRjkik3feO983rPMp5maTmM8UniCs89ok7bLqr/NJqFqwUUt/Qw
2+fcp3dbKsdJoRy35NhgmuEF7dTmQFzQXE5eGMEZ978iSdwZWtsfDN+P2sMF
vwVShY8K8lYkkXfuEGVLWkDb+Jg2mOjgqXYtU7UXgt1AE6dUtnIJZRYz7QT+
fyH25b4=
                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.004322863183915615, -0.06274446099996567, \
-0.05025772005319595, -0.017926732078194618`, -0.007000620476901531, 
                    0.01551032718271017, 0.01155171263962984, 
                    0.04758952930569649, 
                    0.018124043941497803`, -0.05030146986246109, \
-0.06267573684453964, 0.010801401920616627`, -0.0018134567653760314`, 
                    0.01539129950106144, -0.023059358820319176`, \
-0.02719414234161377, -0.011383669450879097`, 
                    0.03053782880306244, -0.003929270431399345, 
                    0.001389035489410162, 
                    0.024613365530967712`, -0.015612724237143993`, \
-0.031380053609609604`, -0.025400405749678612`, 0.017531443387269974`, 
                    0.007704981602728367, 
                    0.007314630784094334, -0.04265023395419121, \
-0.013043639250099659`, 0.0396958626806736, 0.048858799040317535`, 
                    0.08576879650354385, 
                    0.06952784955501556, -0.053211357444524765`, \
-0.04254879429936409, 0.00654175877571106, -0.0015417194226756692`, 
                    0.052584677934646606`, 
                    0.04818108305335045, -0.0038238652050495148`, \
-0.04959245026111603, 
                    0.007802456151694059, -0.030872004106640816`, \
-0.012840095907449722`, -0.01587923988699913, -0.02961413934826851, 
                    0.0172528475522995, 
                    0.04657083749771118, -0.007686176337301731, 
                    0.027118712663650513`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dYz+/3x1vSECpNDcqmoqx6v87RoEIlGkZlhWxFg4TSVFIJiYooISJE
er/OqWRWMpI9GlYhsvIh/Hyv6/fHfa7rvs5/z/u6z3k8+i9cM2OJnIyMzDql
f2XGgjC7tWsXbPBQ/N9l8YKVVpYr/9e0/P/zNme4uLvLljdVmdCwojb67jiT
T8U/F4JcLFF9w1OqG2kECTtNxbRlllSjPI09DjyhAR29cMUhL/aLleWS3VvR
LDaVP0TN4/uOPlTefRqKZpcpvzgF3tzMhXjqFLBwk0QxMgecrixG+YHjcH1+
B11Ly6dlKvckNTErab/8NtJqvQQX38uxvoJIHzJ7Y8iPKxK1lkMULBeJC+dH
S7/Wp/Kwv4cg6ogmXsjXxwKjvVzY/yYojbkBAd9jxBhpD3GthSN33kpAx0+h
eLFrPgc6+dAf4RsejhiFAy7PEqMVTDmu840gBGRwVM1PSdKy3VA68htfu7uA
SyarcH+lDL57bxaXjZhOe34ki+dUf4Hjot1C1MxciBHluHhCHxga+xu+a98A
69KzoHfzBzl4OvN2q1V0ce4wtuDu3PLIlirjD0H3Qf5CksxRLG0JEhUqBLQ6
5IPSmj0EZQPE5eWLqBB8cF1QBl159YPqPrSKu9YPxi0mceB5XJe/Wd2h7EGn
4FDsYK6aWExvDeKo5+JI2JlbQzZzT4HCtw6pX84g0UGaJ1RrpdCuliGgQwM4
KfEW9VWqAIOy92xwKk1ardFI4s56un4shsxzGqn6qAL4BAZQuZMCuq7cAo3B
ISR/sAqeDS6ntVkFGF2kDp+l5vy3zRksLlVSZloghU8pgR/KqyFpmxKWOofT
jtQQzrZ0w9UdT6HId4+g0a21zKjlP6mu206K0zgNQ9zcRKGCyH/dS3h25iQV
RUzkKk9Z0fz+S1JoH0FNf0m4M383zb+QJ6ZYHqMYA0toPCJHMfVM75vl+HxU
NQ1tSuDx28dArzEL2c2+A2Kj4kU5h0LQazHkO/76sDZTSQrzXgp6h1YSbNPF
NpcG8UWvTjq+Kwt0Flqx5zpF9PdXZ8t52mg+/h3oF8eS6eAqulUji8N2x/KE
3m10pU2dA5KeQSzsxuHCTD479gM9U2ik3lcbaa7vTdr7YzQdVMqi5w8T+Lh2
H96vu5EuV2qS76IcLMuzwfISfamnUjjVnrgkubFYiS2SrwqtFQzfplmwpbUA
8c7ZJP9hAJdMmoWur/tL36do45MCgQJeTcThKw356bmjdLVOHnpeSCG3rmdw
bZA1zCjw5IVrVbH2RE9xYHtPWOixlb2v9oXKGBc0drWWKj1SFove5NN38RSc
zg8Sh7wdzBOyumFNj07RLqkvnim2oldx30QjtdtilcoXiisvlz51U4ZPz4gO
76iHctX+eGfSLYjLNMeGW0fQ3Hw0TAzKhjZhACqk7OLQDzcE86ihONGpG+0R
v4C82wRS3p0I49tCWWIyWKLh2kGCQJQ8fBi2vLqEPp7hZNsQAPExihgXPh/M
n58AX2NlmvRfNiRJp/PPN49BqZsFf+y6LerYTeHzjlHcOmAFLpm0hU2WPZTY
zO/OXlk5NjUDEuidyjj+b5wWjrq8HLZe/CMs3ryXR5aPgsFV8vgk1AcGrZ/P
rWY3sHuiHveuWox6Ycvxu2MwtvYIwZ7LU8Xmj4mcPSybrcLe0Df2R0nMBhwz
QJdhtCy7Dy2hOWlmnHK3lVZv0aUK9dVgEbqYrgd6oPlnLf40TJadFbzFJqGW
0kAKUZYCGQTuxwU69izM0mS3lFi2v+dH8jIXobo2QDqmryWkZc4R5YwtMaGv
Ifbul8xefUy4IrMGth6xRjP7o4Jy1yMxckK9UFaQxHf2x6FVXTi0D/xB3z8b
89a7WmwU9lMY4mcgyaoaKDSk9uKYr+VCvy571s9UFhYY6fPNPFk+axWDnt0b
pX5+Giw7NBZdO+wgYkM+l69SI/tZdbS9qxyu+duLTztdeY3bLn5ZmCAJedgk
6d39Bz3oHIq2v7RB0zgYqnspcXvoAkh9e44TlOPxxq5uPGvrMnq+P5egTyK4
D3CVLDi5Efv2mIhJs7XQ4t5D8VPMa4j4ew2vSkfho1p3lrnT7aLqcqYwGUVW
st8l7pmnjyc+B9MjpWba51SANQM/wYPDj2mEiqOwbOsVaHwRY/P78wEyTpqI
m58o86AVbtS1ZSJ3JBzjRHsjbq7JoNDKOFSpPyHanVgjnpSbgdq7MsHVIZEq
HO4Dx+ljbW8PMm2uEKe9S4EnnpagKN3NH2/3xAyTrbAhbxu+PnAElzaNxqsT
dHG96Qqpt3Eiq/xaIPbKkcE/JW7U+95zMHVtFa97V4Bqw13pt4vPKGPbWH7+
IBUmvDwpVPa1YIVT1yRqYyRcHxdDhY558H5sMs34vQrv+Y3lI7cd+Oin7uzW
hBC7/CSp5D3lxK4LVDvJHJNeymBB9+80ziSUPz4w5NNXh/DP99fJw3sbpeTZ
8Zb3xsKBYGe+lLcA37z8CEc8L8PI2ep8xXQpahoq4s6t6Sh9I495pU/h19hC
zj9SIyzMfAtlWQcpa7IMTg7IgVZtOVaaOJbjXXvyb6UP4tSGdOlZNubQngGg
H6HDa7sSIeRbCzVopIDFw6+UZb+fJy6PRoV1b8X5yW3CuOWeFPvNWjgeb4Gd
+dVwzeoMrVwRB+jlBQ8uj8J0wxAYufUk3loTzcbJRqJBoz6etrfF698u065F
8wV9eV1uyi7kjvZOcY7NX0GnahQE3ViNz+Vn0+IB/VAn1R4Ty+T4uFEy+EyJ
YO2er8FHnIsDRRUsGLqfzNr1eavhUNp+fA6GRvwQugfUwEmFJSSdMZr6TZ2I
y3f8peliJH1yqSJtTVV43S1TqIjQpnNPDgvODndB7kg2dA1WhpOfc7hfzwJh
0DkHrhgdiy92vKawtiPQ6TIPes7ZyDcuaPHG7k68bLscfjDS5cKRl2BDkQ0a
PJbAYkN7XmP6jlZ8Xowl0TI4x8aEN/zS5B3ekbT4xRz2Ge8utDrMIk3PNrpo
OhVbKt15VEh/jj/aTiW6y1inqha2WCvSjORmeDJtJU355QU+f/OEjjRPKD/i
h4FiNaW89ROixzST24YRvCTanZp+PIXWwZHCFO9mycD3gRSSe0/UDRoNtmvH
YM5mqZizLxMml+iSnt8OqD78nUpHD0O5pr2w+aDbvx2kS56XUsglxUm4/WIw
79P2Yq+2dLRuHQxyk67QzWV7qL33Inq3VQPOblXlt/PyICjkOZlNM8YtBTJc
orWNWqOG8qJ7JjS1S8Id8dlgwyu5mPR45XZFzpNqsve/7JJ9P0iKZhdR5UiQ
2vbOh8V+TXSqSIZTbc9ifGS2kNoriV65nQbFiX48ZNh2bFZPEFTaraj+rzz/
7OmLm4ctgoRZaRC43xgFy0GsGBsjtEGT0MxL4ZhsTFnns0HU370O9DJUYEi9
LXY4XaZ2tT1g++/N5pzL5e9r8mmepRmurXHkG4UrsXt6neh3YwmWnDSh59WT
hLG4lb4cceKAQbPZrVaDxM37KEV5JehpLhWr3zphp0oWvZA644QJltJuG89A
qIsq67qboWI/EygbZgqlhjYMfUKEkNmOEDrSkYIzDTDsz2Fpzh1r7pl/idw0
vSnC8R6V143AxkiiPWHMT5ZqIWoGYPrDIPFccgpsnBDHect2wZ2MNKozqoc7
1mms6BkPfzKNcNnzPpx9uszm2upO4Z2fC54N3oJ+TgckOC9KONJ7D4x30oBD
XvGsk+7MN96ehUVrz9E6WTU09NlGp7NbhCnNSlBBveCj0Q9wyHLlinQDytzS
SZfqnPlrHwmNOP5COtNGGX0+r+S7XxxAcfkfOpQThueVtfHBhW+Q5VUBLTF1
9GdPNN4WX5JXUqoks9afrg6eDl6qSTAwWInvznsqTG18I/S/rkyxpTYcqJMp
bJ2+FmznXoCWVSVkmllOK29tFab7vJboZqwWw2858uKfUTwx7qRk9r1NuMXl
hvDa6D3UQBQrh0lp9JcvlFXbQBPH98OAyk1cbJMAK049oRPVn+nIyyxyg3GY
ZaQJM26pwLsgplM1DuJQp0g0i9nPVtNNMNBiDunvUxQubtpNfhZtFHghl9b7
q4L7oHLacksHH3buJ/Wbabhr6XhoU1LhiXYs2PSYRcl39HibpyH0X+YtuNYe
BNuKNHxeuhus9JbwM7uefCM3mi5OPcoPXiXBr5efKPdXFn+R7oUZdR3wVrEN
pFey2My7lFRm2pHvQi02ndQlPlyqhvHxAMs0LLBhaTlFFPXjX4/OQPTP3tzr
TQQ8nOQsWu2porioFHbUrkObhnbaWvgOLBuqpNfnO6OuY6AkbXwWhDimQNWz
KXzfaSzYFyhThd94tvbfTgpZ0TYur0dRlZiEYXE7mIK2UszOJog49Ql8Sw+j
02QVjJgyQgxevgRPyi+ms6PN0GHLePzlngYRa85Rm24AGp6dwk2PM6ijfz24
d06FlXUyeNHrFRxLyKSNvTzB+MFJ8KtqAdMvQ/CH1mvQr5OKPQ4mQJFuKuxa
2YdXnTHinTO6wR/7fHj2owhmHdHB+7tG8MihmZKRi9257wE3Uhy8mp7p7eIg
7WR6ofwWKkacpjFOYfRAcxfdtOtGMx9NAJ9iF/6q1gZ7DxigRoirsGN7A8hv
7oJc+Spq3F8iyfBMg2mb3wk/o0bjfypBcNzVCfI8tFnr/Xj8M84eVRXKacPu
0Tj9qzdf8bZj2SZL+D7gPOVsURd+DHxJ99TCYKGzBzepbQe7y1+h+7AKOhf7
hw6afBIUjnrh2Zwe6KadRvXF+mLpgZF0r2MQHFhmCReLLPDTxcdC2YT+uOEt
015DRy77JxjmTfOhaIye2K5jLypb9IBzjq/E7oG9cHlcHeldrKM9CWl8eMxD
Khu4j/Zq/4aMB/NxlaEKq08bwxGrZqPurDp4+tuU/2j74ue7S8WbM/eIvSP1
sHxKnHWb814ybTCA3gr/Sfv3qoP2eam03qcXx57swW0FMjRuwmzedrSNQoPs
cWtwuHTEDmOWnJBDjVsabB6YRedcz1EP9UZql1XnD2tFMSIwDce/mio2D5pH
YTmIZs9+steWISxtLYGUoQmYLndc6GlpzQf1ftCFkDfCw6x8sfOsMff/GcmG
69qxJK8bt7gl8JWKtcjRUbByip/kwvX/4ETjCWge9Jq23U3mKdsncPPaQzBi
qRcHnoqi8kujeM1UK9K+5cWTMmx51epWerbYFYpm3ILOZKlwc3Y4jf/en0+4
LKf7CcrCIosM8Dikx+YGFzk8LEWweCrP6xcVQGVgNqx8pwV9P+TQfxN+kfy7
FJvgKa58ZZkmZkSdpnP/OHBzVDo8DNrITTuToHH+BPz5+iolegnUJ0wbF8iZ
cvNEA3hoXgWKv7bTmkUMY6sdIaZ9Li26NQB7JRTDqfN98W3TUigx/kvLti/i
oip5vvLPQZ5oSsgkzpLLrExRa2Ieekmu0LdcBQw2t8WEJU7ApUuEmpWb6Xeo
gO195uLFc0Qf47VBenIHpb43QFfz9Tjz9SMYLi7HuP0bSSE5HibfuALe81cL
EV1xEPhLjcOGnMIX6ra0YIozZD5Yg1/eDeWpe+fRWdED+66O4MOBLWXKwlAq
HRID/f65sv2//Fwc1sOnzAkcZ7KHTPKfWCfYDePqi0Vk0m8lbHCdJLl2XZU3
neiEcaOAs24Vk4b2e+G65kbBPWABhOzPoSAsE3WnHqYjo3fzPYcY0XnAGFzx
WoZubLvIY62UOKolBMnal+ceSMPmwwHIP+uEoVELhF4lfXH9+ExoPZjD0MOD
l6uv4A2PwjjZolUcvtVMMvCnNiis+EoGnQaoWi9PFW2VVG/kgTtC06H+/jBy
bbcDtZYGOgOp0E8vlL+fmy+ObjOH/g2lMDL4nWiV7ka12u6ka7wQFiw4A8lT
asRrNXPF+tw0kuumKv0yyJuFymWsv08DdMJ68frf3mjZrAaGa1Ro+fjJZLLH
n63nZsPc/HH0RRNoxa3h6NvgBxtibIUxLy7CudpSevXpjpiHvfj27jRyXjGL
0+d8hENWDSSdmU7ffIxYJWEnd548IfQ7uFJorM2QrvHQwcfeLrx3ditYGT2n
9aoqqD/Hl+40mVNOLvAy98cQbtZEIz1jxbHl7wRPg+VQPmQIHpieAO3p90H/
pAfLdqzAy5FBUNsyj00ztfjte122PtFGX1Wy4IRHAh5cFoWuWVvwwloRdt4L
AN+pgtgv/BPkBPpj4pl0SQ/PFzaqR7az+okASHvijH/8/vmktJUihXFlPz56
8zBVddTx+U3JlYNphGl/ycnTDwWfeSqiwVt7mhH/k/4+V2eJuwoHOkeCzvg+
LGzqThbjc6lhwlfppDcSXFQ7EP+afKGG7doY3ZXM5WO+kNfRP5LOZx+Fr+vf
UMT7SLZ/QdCr20WKHHOX9hVdArXsYjj7uQwWj7XAdcejbRTNt8L0mmKaVmYK
iz90x/eudvzjgRm7+TTg46ED4ffif9xjXCGMD1xFK/IbWPZRCv4ZrI2XLOWF
VeRKj5o6wSzwLXr5lMJ5oxE4106b5X/Np5E/h5GugQ6eGSMA+X0HiO1O9yel
cK/kGWi4fQCeKdOgkQd2lxlmxEh83I1Q58tYXBExE7uuJ5JrUy/0L0ij6etW
sK+xCDd0dMvW9CmE52OVSKdMC5cpvKTazTXs3VFOSjmz+eldR/aNnMjT085C
9mBraJLMps8PS/FxyEDYnZRK8zZ9Ip0LzuCbpcznJp4VA5uioPTrICgJF6XH
jixHqFPj6Qp6cGhsNDn6fof84IWMHffB+dMnMNTazPG3NlPcRmMy2tODz/wZ
Dcd3BKFGzB7wjpsDu7eVk0zSD7A7YYvbolaQxs/7lDSjXHKhawqE2MnQF4d3
VGZ2GxY1GfDtHVmke6EnLl+SIOTaOKNNZSn3e72NLs6M5RErzfG7TISwJOIH
vJ2lyBN2PRG8J9ly2tdd4maLczSz4SgddDHBq5XbIM1QH5vEAfwnPZvPzTDj
3/+y6SywIfuEc5BSNgBughOOlLizC24m/w9nMdP6lzRebhLeokP43WkOqyxZ
K8QV6+HhAgPaEVNXVtlNE/V/PhKVj/qh4So5bPihxr9tl7B8t05BrHDGqHZn
lFTeEVKzCyl39Ale0B4DB+Otxa83v8HUDntclT1KHL+qByr2qqNTg6exMD8X
+q/fh2rGznyvV6sg+dQD3jibSGY4DWcN9dek9ywacmLkeP7K6UJDvTP6Fsni
hVOFNH6MBHVDK2BL41Cym64FR5qqSdI5nV5dJ3Co0sKUvEE4wH0nGBz9SAcT
q6DURg4Xn+zGH+d2kJqwD5Z6LMFCnbuwM0oLtCz9IOJbGVxPLiL/6tfSKrVh
aPX4KLS8fyTMybWigC5TPPPlKR2ymMrzXHvxZY2+2N9jODd3dNEDq2mSh4mT
cXDhFKz12kjHhuuwr8px+pNoi3K/I2li3xwqvbcbXN6REL//LCT3CRXOLy8W
P9TbQdeKy6Q1k6DAfxWuebqZA14Wi91wk/D7T4H4UMEbzjqMpWmZuXAtRgs+
zjDEhPXHSCWqmt4lZcGYsOOSW5kq8GiZGZX88zY2jaeq+y9o9YtcHtK1mMRs
WRB62HGYeqsIPfvx/agWaDdcjp3334vr8odT1y8lfLRqDvodqoQLi/uwzfEd
HJQ+jn/qRlF602m4ePE5ZntEo+yNTbyt8BiomnyzqYoygSzWFrLfVXPphMng
uF0ZRhu1Q790bVbaGwATw8KE1t7v4MsFFVZtisZrIY+JPqjynckibL4+Ufzd
4wd4Ji+gNUfSRJN19rD91SLK9T9Bp68twJOjrdlLthtvSVwARd21aIm7DLxO
l5/wO2kID7zRQW9HWoLXMqZXhWl0vl4B7T7MZIsHKdC3TQ6Neszjy2lyvNcy
HHffrYaMzL8QV/+KXFfUwvmj2rjvky7JezVLLVtuoPKyGxSzeBG6b6+k4X8V
eMWIJ9hpU4iW6ocktWELeMKkGWBqv41zXK7ToY8q1O+0Bb9caCNce2aI7YE9
Yei1Q1hw7Ty5TxpIQ38cAuvVH8T35ZNxfux1hpk++OSuAfZs+gB3r5r9+2/Z
UBk/CVsuXxLMjoyHx5/P0m5dVzYJP4ab/JbCir5uaDt2CMaWa+DdsemYpOIp
nKyro7nub0DG/zyVtoziYM8TkCSsoYTtuZB8NRRn/1XHEvMGhPBz8Fz5Bfyp
38vP3L/Q62xL+Dt8BLknjYHpT/tLpnomgVnzHzEkXwNuvHVA8b8gvvTgDKg3
ddEIz13g9nUK3AhWRL3DtSRbfJRWz7xNowpSgJduZUlDO/z5du8ffzwl8UqN
+PXZU5gjtHF/c3myvd2To4+P44hhI6Hy1TiaU7oRX5hv5+bLGvCy65KgLDeb
Zo/eLhkxoNBGz3ED5ar+IMP7QXRi8Cg6rhrFz00iIXcFweHBTWTbuoUT7zdA
8NGd1Ghwi8o1U/n0Ygf8OUIR9g3LIN/KbCHZLhbEBzKgva071ViacPOYDFB8
FQDv40ScqJLCTy23UbXNGfBa+p3OWh/m0eULWcZvPs89aMibVR1YWlqCEcU3
oJ+qHObpy3JJuzfmby2hwGvNdFbDBg8cfwoyvduElENDeekmdVjTr1loypXn
Tw6NIL9/CAWEqPDIzRPZeJ+fzelgOzzvq0+mnXN4856FvHV4N9izP5Rbdslh
TlwHrbjrxBtv/xK7Rnugm68XGKzZyI2Dv4LEUZFaQtXZMCaFkh+9p+tX1Pmi
Vz3p740BV+v38Du9ERpy/4qPi0+LejrvpZseaohl01T5+CsdyJixGqpqVPl8
UBFk2InUVSLPsVHW7Gi/DzQ9h5OLSyznb8wRIwVLtlKx4oZgDx4mq3vRb/MT
8cdUc67G/2CO8gwaFzRZclVrHwTtqgFR/hZEr2EenTwHc0UjurLaAV0X1sDf
Ucn01igRZS0UqS5wrpD33zcxdEiMOP1eC00JLhfUmg9Q16tYvPalFw36x8D5
6oNxXe5paNgYIepFfQGVu0VwcpInMjqB3bbrUDi9DFKG9eKnSge4W//nNuNS
JZyV9B7SKjPpi/kc7MvdMOjJeepWHczRnmZQoL4JQgd9heX/3SO9E3eh5Egr
TOrvD3YHnCkveSm/VzXik0f8wa/PWmyp1hO8R8TBnD2TqJv+LN6XEMRfjCaz
k7w/y6/uguyis1CY586Of12x5sckScCWdPqr4oV7XCbT77WT6WzMLemHdznQ
sH0HWddPJx/fKFz3J54US0Xoo7qEFYdFi5cLX8Mlgze04ngPrP12ASbZX4Yz
CpVgNcyeH075Jry8HQ2au/bZtPs9JvlZZVDse43sX41jn7uaHBK5G1MjX0L+
0UpKrZ/FXl/uQ9isoVxxuhuOqR+HjX7a7BXmyJkvCqjPxYEcu2GceLbMkw+n
SoTfgilffZNIa71deUPtdjw7+Iq4d1o6DTQPR+stcngHKmiO4SOKTi+QFKce
EwKNMqC6cRL0+7OUXEMItqSpCvNsRLHCyAxSexcL9RX7eO6nZTCj2hidAtpJ
XW0b3QoxQi+n27B3l5FQb29d9qvTnR5VPYSBK93wurEKmo7VxqJQfZQa6nLX
9XnUZ3cehP8xxtu/53JdN0Xc3Sec+wl3wW7fLdIuKWUVg2ugEz1LfNRLgQY9
U8Fci9EUoSqLFQYFcHtjBQzUcsK3/bWwx4sQydmJxug6QhXnG46htsgQ9qJV
XJ00hXc76YLDXwnfipeSQvZkPqt9CrKsrsHixwo4tDMGvy/158OVKkLhSwX2
nTpTzP3H5pqJyyGrPoqjO3biiHVZUK3ziIrfrxcOvvQAjVUeYv6KYjHpcSL4
NFfbFE9zoVM346DTI5xcSobg8vhd7HVQC+v6nhLf940Ru48thbVTT5D49RY9
L1BhhZhZsG7gMdh7UB9X6Cny0Glp8Gf4Bfxdqs1fr3bj7GfKmCj/SGpfVUdu
VdmUJhMnFFZOE2u9r9OKoCPgUn1JSHDZC259asXiDdq8MnclDPlxAQpX76HM
e4F8lRql3QfPpasV0bTL6gWIKaro2nmbTmotEhxvpvDqgV2kmaGGUTvXCde+
u7IIXYgtyGeqsxDGjcP7wVV0uHo/SCbbQbr8fLQ3icWRgfL8fMY0TCtR5+HH
I1FvnC1m1oXigITbQoVggTOmMTlf85bUDL5PocmfxTEqJdY5bVE81FyJR7Ut
wt6+98Sb+ua4U+264NBDB+a29saHoQdhfmgAn/tPhtfdXEwlN+Tx9n8tsKCn
PMblZOGFczk26+8UQT+d/eD1+D1Vr5PFPfkeoBYYJD4SdXDXQmdyOKtG09M/
C36TLChLy5tbXA4IrzZuF6b9Z46DDK+Jg8Jr4E15D3ySncW9VX2hZrgeT8lK
hB05VwRvNT1MUUmCR2PlOeHaEmHf6dM0+8FuTDghKw5omYXjL4wAL9GQw799
gvA3gFXdj/GzkcOF2Ixf4qkJZqhj0ovDaC4Xvm8mjcnyrLt0PR0YIE8HnOzF
tFNz+GJMCKlFpeKUfk3w54wMtQXUQXBjK60fVPxvfvXmw2fqwWrPPDjSEAf9
V5tLTY0jRcnNm5K7x7dSfmWD4Bdxgu+Y9sRWs0pafLZTeGE3gGb9ScOOM5bi
tgxbfhM+S9y09BtYHtHAWatm0BqcyjqvVOCUw0+K33xYeFBQLEb+20PwjyE3
hevAunMg8d8fRNq3XfFU9ksIGfcfKD/bziFhXyW1tapskF5Gn+4FgVbMKTKN
WkoVdtEwreCtKNPdlPc1G+Lv4HVcsd5P8Bj9TDya1oP7malhi/Fc7pKkU5rs
Lpo2Og1/zpLBC+4vaGmjHxyydmaTm+XUFmGLv8w9wHRIIuKyP3BsQjj1Dgym
tAGB7DR9OpsX7wU92W3QFJIuzt7lIIQv9ccrFYMAE8PpmMtBuuuwE8yO78Y5
PvHo6LIDv3GK+G2PHC/I7I7G3d6Cf7AB75xgSf0ue/KrK+9Ab7MpjDgyhLc9
8IPKya2QOl0WG1AGKo/IYpVMpvhn1Gm+U9kP80blCiaSD5Q4PA56+DhyVly5
0FE9A80KC8HwWJUYN7OMa643kO2HH2J460MojomkgB1DufaCLW7NWAAT66No
fcQx+HQhnBJfeqCfugEu3t1Ib+I38tVbSWhskgS9+78tbTp2CM+Jk7CtNAFe
z5sLO8qGYHm7Pl8O0eK7pilwxDGIpsc9ox1KTZAaJYe04Qqt75xC2ie/i/49
TGHlnCyx9aYmenQF0OaiZlaaasXBkn64cHOR2PuQHIY2uvP8zzG8KHA63pvq
z1PC5qHGSxtu3Lmb/JYl87L1mnzJUkdY5JFEr5QXwIRZ2Vhzc6NgsMoZb6eY
cIR6Pq5ar4AXf6WRU6sL760oEbd0mFNqUraoLR/HPbxiwcpbBbdN6SD3sgze
+uk8RH8bhE2Dbbmo+owwxfUS/C3rjdeae2KIgT4XD5nBrmrGkknWdkJwrzPk
39lCD2y+CePjDohi6CQ4kzYT7x7OA8sNedKUWVPxfmp3niodQvtXVcE4LhXW
jTNhq+kB8NBhKN7ta0H3lIvJ+IK6JMBpKFZ/1uTAj8iDjHpD7mkF9uilir+X
TsAJfcdja2AEqOsXgqaGHkyb4cXhCy6Q/AY3rrz8VDQ6VSsYRT+i+iEzkI+u
JyfPOby1TCq1vdpXuiqxkK2smsF0chU1ehSxnEwzjNT7BEvnv6JOX30e9HSX
sFwjm775xlPBiRE4u84WF9ycIv46s4EDfuaAu8FTWN0zhs40noaaNSfp7Wep
cGnnMVy++ZTwqeMHFX2WoNMnCcQOTqCWvm857+VITjGohFlbuvFCp/2wL7WV
Ci3+E89srJM0rz8EfdathZOBgvDhQxVOXvia/BNHSCo9fTgo44b4cNon8UD5
brQf2geHzPoMZ24Qfe9S431NAyFuy3S03TQO/T+qY79uLvyzxEf8vsMMb3h2
x6uF9uj1uZQKRjthR5EvXjMoFTQX3IHwZUfFb7cshDLTZ9B1UIenpLuz//B0
INPTrFMzElwOvYQg52/C2x19+eGZVLH/yJvw9raUt4f9ocv9hvGJHoNRbLcT
7IrV6aRjfzgaECx8CJ/KR5dZiQ/SRVCPvE73irqjrEE6PXygjB++lIhFOwEK
dmWKbnmWGPGPw+8F5tg4fY+h81dmkuSSHdR1RvK8mkP0eqgu5dat4ydfh+Dz
CBNYFmgF42dmQv7bwdggW0Y9FLMpQvkAz794nyYr7qe+eXEoV+mMsxOD+aSV
Cq7qcmfnUZs5prQe5Lv344ZAEa682Cc6XNBFi5BZQlByL+QaWYzsVOKwgTJ8
zC+KVWbY03QPKzBqEOlmch9MeHxHGFfvzBOv3hEylfRR7GEivg6QwftVWzHx
Q7OQZ/QcPL+fgL37v8PyjHZxtbMvjvl9hXq+juI7yuNFfYOBmJ+fTgvTDotp
E27RWFsHPJ5pjIt/i3D88FIcu+0oidJa0fBYEQSuC+Ax/aeBv8wiDHX6TJsM
Uvj3fQ3Rft5m2JjxnhrCfcT/Ay3tC/8=
                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.013701198622584343`, -0.022305360063910484`, 
                    0.024597348645329475`, -0.0024798561353236437`, 
                    0.01293665450066328, 
                    0.032673489302396774`, -0.03197859972715378, \
-0.01781388185918331, 0.0646810308098793, 
                    0.03435581550002098, -0.008746681734919548, 
                    0.0025620320811867714`, 0.009808429516851902, 
                    0.043116774410009384`, 0.026432424783706665`, 
                    0.03227440267801285, 0.0047647119499742985`, 
                    0.10675951838493347`, -0.007495458237826824, \
-0.04619947448372841, -0.03070455975830555, -0.02027016505599022, 
                    0.041130177676677704`, -0.045895054936409, \
-0.03477669507265091, 0.03481654077768326, 0.028390053659677505`, 
                    0.017701923847198486`, -0.026177149266004562`, \
-0.07558147609233856, -0.004631992895156145, 
                    0.01951509155333042, -0.034384701400995255`, 
                    0.009062077850103378, 
                    0.0010717188706621528`, -0.0069171166978776455`, \
-0.01136202272027731, 0.024209879338741302`, 0.012322698719799519`, 
                    0.009933178313076496, 0.01620808243751526, 
                    0.0340614877641201, -0.029556982219219208`, \
-0.028649022802710533`, -0.015108935534954071`, 
                    0.0070771509781479836`, -0.0065864622592926025`, \
-0.028832286596298218`, -0.026595264673233032`, 0.011715753935277462`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2k0l4/Th1HaRJFdRIsSIkn43jNaaCVKRYui0iqlPW3WFFFKElJIEZUW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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.02052062563598156, -0.0011307186214253306`, 
                    0.0110858753323555, -0.012583697214722633`, \
-0.008088164031505585, -0.05931129679083824, 
                    0.03460706025362015, -0.021975817158818245`, \
-0.008722329512238503, -0.0017739124596118927`, 
                    0.009686388075351715, -0.022727767005562782`, 
                    0.02523885667324066, 
                    0.019894294440746307`, -0.050800222903490067`, \
-0.004598705098032951, -0.007085719145834446, 
                    0.005227462854236364, -0.004925223533064127, 
                    0.016480647027492523`, -0.016440507024526596`, \
-0.001910058781504631, -0.017553986981511116`, 0.04871341213583946, 
                    
                    0.04172144830226898, -0.028355494141578674`, \
-0.01033454667776823, 0.03572718799114227, -0.04169373959302902, 
                    0.02340616099536419, 0.003709989134222269, 
                    0.0002789832360576838, -0.008280339650809765, 
                    0.006423201411962509, -0.010411286726593971`, \
-0.032026588916778564`, 0.017840664833784103`, 
                    0.012951849959790707`, -0.010270848870277405`, \
-0.031232276931405067`, 0.017219606786966324`, 
                    0.0084441639482975, -0.0558299645781517, \
-0.01841473951935768, -0.04544590413570404, 
                    0.04822792485356331, -0.022318163886666298`, \
-0.01579161547124386, 0.039781324565410614`, 0.01990620791912079}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c41+/3x81SVikjMks0EA3xfp2DUmioaKJCRWmXpOUjlDIyI6NSIqRN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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.0030907192267477512`, \
-0.0028635135386139154`, 0.013680470176041126`, -0.0014390269061550498`, 
                    0.011320685036480427`, 0.0057854498736560345`, 
                    0.017547110095620155`, -0.004322272725403309, 
                    0.014225811697542667`, -0.015189866535365582`, 
                    0.017370644956827164`, -0.014402643777430058`, 
                    0.004597798455506563, 
                    0.010301011614501476`, -0.019120337441563606`, \
-0.01689908653497696, 0.0254471767693758, 0.0064851813949644566`, 
                    0.02812298573553562, 0.02272593043744564, 
                    0.0025246257428079844`, -0.0198057908564806, \
-0.005235347431153059, 0.025706028565764427`, 0.017069287598133087`, 
                    0.03333935886621475, -0.01918231137096882, 
                    0.0014670932432636619`, -0.002174332272261381, \
-0.0026877925265580416`, -0.017760762944817543`, -0.019525770097970963`, 
                    0.0004445986414793879, 
                    0.002282243687659502, -0.0008074857178144157, \
-0.009844510816037655, -0.010813039727509022`, -0.015982070937752724`, 
                    0.0032840378116816282`, 0.005853849928826094, 
                    0.007509348914027214, 0.008686797693371773, 
                    0.01155172847211361, -0.031578682363033295`, \
-0.031160494312644005`, 0.014650787226855755`, -0.014034072868525982`, 
                    0.031342361122369766`, -0.03951059281826019, \
-0.006785400211811066}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{-0.14266830682754517`, 
                    0.09969175606966019, 
                    0.09024792164564133, -0.13297012448310852`, \
-0.2506612539291382, -0.18194489181041718`, -0.06409554183483124, \
-0.42778488993644714`, 
                    0.04638676717877388, -0.09043430536985397, \
-0.001288336468860507, 
                    0.2278403490781784, -0.29673758149147034`, \
-0.052959296852350235`, 0.10737123340368271`, 0.09823554754257202, 
                    0.20001445710659027`, -0.29120030999183655`, 
                    0.11200833320617676`, 
                    0.1952853798866272, -0.27159783244132996`, 
                    0.20002157986164093`, 0.12072593718767166`, 
                    0.10179435461759567`, 0.09577177464962006, 
                    0.1262693852186203, -0.08588506281375885, \
-0.06418102979660034, -0.17921122908592224`, 
                    0.15853752195835114`, -0.1782793402671814, \
-0.07070531696081161, -0.16758565604686737`, 
                    0.1033942922949791, -0.14560413360595703`, \
-0.14509433507919312`, -0.026948880404233932`, -0.19386708736419678`, 
                    0.17757666110992432`, -0.03477194532752037, 
                    0.08198344707489014, -0.1451490819454193, \
-0.0300593301653862, 0.049409084022045135`, -0.043413542211055756`, 
                    0.09447328001260757, -0.13277564942836761`, 
                    0.2746594548225403, 
                    0.02769864909350872, -0.11505720019340515`}}], "Biases" -> 
                    RawArray["Real32",{-0.004753132816404104}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.6073148846626282}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 0.6342389, "MeanInputsPerSecond" -> 
          40363.33942935382], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {
                0.009508048826403416, -0.0008080319851848208, \
-0.00520016122351184, 0.06647274041361555, 0.02286249172007004}, 
               "StandardDeviation" -> {0.9826041780920559, 0.9993479225310187,
                 0.9930764636007168, 0.9984709377012381, 0.9964571754447247}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 109133547265549894]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 100, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[362257], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3181904025612408, "PreprocessingTime" -> 
        0.3190127`6.955352966302779, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.5099896149015395, 0.1446700708802308], 
           "StandardDeviation" -> 
           Around[0.3988632688866882, 0.06141579015064728], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 99880, 
           "ModelUtility" -> 0.1956263417601436, "TrainingSize" -> 252, 
           "TrainingTime" -> 1., "TrainingMemory" -> 451656, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.5099896149015395, 0.10229718815414966`]}, 
           "StandardDeviationHistory" -> {
             Around[0.3988632688866882, 0.04342752168745266]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 100, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 195416929234293]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.9209771822998922`, 0.4345200980887493], 
                "StandardDeviation" -> 
                Around[0.5875381828239797, 0.03655951088840491], 
                "EvaluationTime" -> 0.00012738180561453242`, "TestSize" -> 
                305, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.17373521092775324`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.2589254117941673`, "TrainingMemory" -> 
                495840, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.9209771822998922`, 0.3072521079203984]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5875381828239797, 0.02585147806605453]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[10.27741278954391, 1.6806622455749114`], 
                "StandardDeviation" -> 
                Around[0.5353536358328034, 0.038706432095415765`], 
                "EvaluationTime" -> 0.00017913852274073556`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.0827099622992542, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499680, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[10.27741278954391, 1.1884076707302305`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5353536358328034, 0.027369580610205113`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5842684247048311, 0.1918127349114101], 
                "StandardDeviation" -> 
                Around[0.4263546183167884, 0.07447207532430694], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.12496451595178415`, "TrainingSize" -> 252, "TrainingTime" -> 
                5.011872336272724, "TrainingMemory" -> 522584, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5842684247048311, 0.1356320855737957]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4263546183167884, 0.05265970947085279]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4263546183167884, 0.07447207532430694], 
               "TrainingMemory" -> 522584, "TrainingTime" -> 
               7.523765832135071], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.3428485048476755`, 0.22009361122169213`], 
                "StandardDeviation" -> 
                Around[0.4672241266464177, 0.028997640903572267`], 
                "EvaluationTime" -> 0.00010731390959453888`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.055428827511808, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 499552, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.3428485048476755`, 0.1556296849906941]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4672241266464177, 0.020504428521328354`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5928661371382145, 0.148946609390393], 
                "StandardDeviation" -> 
                Around[0.4305830182531365, 0.06330376953123008], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.12045403910663832`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 522648, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5928661371382145, 0.10532115753469079`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4305830182531365, 0.04476252471020314]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4305830182531365, 0.06330376953123008], 
               "TrainingMemory" -> 522648, "TrainingTime" -> 
               1.391017463958849], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.504350323537496, 0.6016411844924269], 
                "StandardDeviation" -> 
                Around[0.7507741277636473, 0.04215057758218248], 
                "EvaluationTime" -> 0.00011392708028640895`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.4176947889636875, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.31622776601683794`, "TrainingMemory" -> 
                424528, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.504350323537496, 0.42542456139570173`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7507741277636473, 0.0298049592392909]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.9899982868749357`, 0.41393931879748247`], 
                "StandardDeviation" -> 
                Around[0.44784216834703455`, 0.03371367136928594], 
                "EvaluationTime" -> 0.00012291233977091567`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.09519133785957024, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 428688, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.9899982868749357`, 0.29269929932143995`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.44784216834703455`, 0.023839165643916846`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5099896149015395, 0.1446700708802308], 
                "StandardDeviation" -> 
                Around[0.3988632688866882, 0.06141579015064728], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 0.1956263417601436, 
                "TrainingSize" -> 252, "TrainingTime" -> 1., "TrainingMemory" -> 
                451656, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5099896149015395, 0.10229718815414966`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3988632688866882, 0.04342752168745266]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.3988632688866882, 0.06141579015064728], 
               "TrainingMemory" -> 451656, "TrainingTime" -> 
               1.566227766016838], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 195412634266997]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 5.7063265306122`2.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097567886572679`17.333472240763257*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.7545401605972235`, 
            "ElapsedTimes" -> 1.8540391, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 2.9242336009953727`, 
            "ElapsedTimes" -> 2.7685888, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 4.873722668325621, 
            "ElapsedTimes" -> 7.9966007999999995`, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 195425519168885]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{4.757558356675843, -0.009002644883284122, 
              0.3856205604535658, 0., 5.298317366548036}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 13.2474935, 
        "MaxTrainingMemory" -> 982288, "DataMemory" -> 75768, 
        "FunctionMemory" -> 258088, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 46, 28.6841972`9.210217612345248}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {
                    0.15074262153228393`, -0.5351985135822155, \
-0.14688781985468738`, 0.5079365079365079, 3.9058870832729844`}, "Method" -> 
                    "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.15074262153228393`, -0.5351985135822155, \
-0.14688781985468738`, 0.5079365079365079, 3.9058870832729844`}, 
                    "StandardDeviation" -> {6.810973596136227, 
                    4.494230081445006, 4.004512577388252, 
                    0.49993700787376577`, 1.3943500799476547`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.023060685413829385`, -0.7220998233672081, 
                    0.47400128094823063`, -0.4639894829855327, 
                    0.19513225058802025`}, {-0.005813679160068656, \
-0.3783362935746944, -0.8762965807034847, -0.22271227678023364`, 
                    0.19832144240482819`}, {0.6436296410019132, 
                    0.1510024474702828, 0.06873757468711338, 
                    0.11377538377080539`, 
                    0.738423627706801}, {-0.592593911795149, \
-0.22280707174917277`, 0.04741589246019973, 0.6190583837303429, 
                    0.46228553422885743`}, {-0.48374347215227587`, 
                    0.5128243009976742, 
                    0.02130650781224943, -0.5821811410816772, 
                    0.40449306687505804`}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.15074262153228393`, -0.5351985135822155, \
-0.14688781985468738`, 0.5079365079365079, 3.9058870832729844`}, 
                    "StandardDeviation" -> {6.810973596136227, 
                    4.494230081445006, 4.004512577388252, 
                    0.49993700787376577`, 1.3943500799476547`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0113053, "MaxTrainingMemory" -> 92984, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 46, 28.7101279`9.210610040017098}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {
                0.15074262153228393`, -0.5351985135822155, \
-0.14688781985468738`, 0.5079365079365079, 3.9058870832729844`}, 
               "StandardDeviation" -> {6.810973596136227, 4.494230081445006, 
                4.004512577388252, 0.49993700787376577`, 1.3943500799476547`},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.3859300229423748`}, 
               "StandardDeviation" -> {0.6772199754285533}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.3859300229423748` + 
         0.6772199754285533 #& ), 
        "ProcessorFunction" -> (3.5231241096108077` + 1.47662507941705 #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-2.5872314729082366`, 2.581449965124785}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViXlMk3cYgIus2EpGtC0TGQ5RkXIYA021QL/3LQiCS6Ba5HKK4tTIZJrQ
MIZOGCi34ByngQkaFMrGcANFpd/7o43HvNgcxwyoFUQB5zHpHCgq0z+eJ3ny
uG3Zrds+QyAQ6EXvpEtMC0pJSUyPsnsf2xKTFX7J76ffO4TvkOQSzQv1ZFFL
usmmPZdLPOlLOk8RPtnsgf/eF0DAjhk0X3WAWzlgBv8EBYSc/o+GMjj80dkG
jZUm9bGSafLFYOyTjpPlWT8dqqgA6+hSFPWZ+ctL/MjQ6Y13mhq4cAcV+ow5
qPXdRazgRBnsGHDiugzzKW3FKiiat5CmJsJoL78BRh7H4Vc9c1mxZxI7szaB
tj8v59MGXakruJfM8QfhvDSVCktn4W3tbPyrw8Zosj0Exvy9ePVZCi16ewqW
Pz3PrQwqY4MLOqBEWgnfaHVcQNUk159qgAPWULbH3mq8WSrH+E4RuTuK8Kre
Baubt9JBWTD/T0w8Kl0+6sht0ECAOY5k0220vl2lthw/Q7tuVKDXHFfcXaKF
XVVjfJ57C4WnZ7Dh61MgV4ypx+tOwxdN5dR8oR6jspxQ332LQfBtysvxJWPs
Hk6WNcCb5uZQ04VatmXeCqgyMWrscKMzxn548JsMHofJYalbA/nd2IRfD0ag
NnMmLjc7MLazGCOiWznsRAzsOEdB8g2Q1FhFIG2D1iJ7jNWqaKJ5GU69+JDL
+eEN7PORYNuwF3YHeqPbkJDVK1u4giUb2cXXd2Hq4hruhUcoPHztQaaaAX5E
60h6sQHWmSVw7XkcvY72wbNhVlgfDXDF1YtldAXitpT9sOe7E3g4VYKq/tnY
0uXJ5XhYYZNmAs5dt2XiCDHTL/uST272pZOf9FKGq4hpigupNm0ttBwRMFGy
mGp3ZsOaRgtZP/PA9gOLkTc5sV8l/ixxUEm5M4RwejIWL2ZuZLUvL9BE2TC/
I/w6RZbYYlJxKKsYWw7q3mysvqnkQ8QPja/sxqBAEEDxvBjv7TtLffte8WXO
nuDqeJc3aeQknl5An2+2R9vCUeO4y2XKdBAywyMbOqqqYwl1mexnrxiI+ekD
HNHLmTR/HYhtr3LR35eirN2bGZLsSZFUD/bOl9TjvTJa2iOhwKJvGesZ4YdH
2+CPBCF/KW4veAX0gTJsGZt1zAKSsvscXdHR6tAsPJzlA2k1Ilb/8S1Y6GTH
invOqY/6Rxqd4ThNakJwRd899Rzub9pa3kmOpWuY7JdFFOaezYQuveo8t7Uo
/TQCK1unQRn5kizex8CvxkX9u66aS6c7NHzNQNNDCnikWghlR66p87dsgjeK
AqqTTNKu/U3QFfuUNH82wfpT4ay6uBJWvy3lQgqecDMXO1Kj5QH/P8bc6Mk=

                    "], "Biases" -> 
                    RawArray["Real32",{-0.11218440532684326`, 
                    0.0038913371972739697`, -0.02199460379779339, 
                    0.05913255363702774, 0.026565304026007652`, 
                    0.02692425437271595, -0.07304118573665619, \
-0.006400365382432938, -0.03992384672164917, -0.06188756972551346, 
                    0.025772230699658394`, -0.0014424326363950968`, \
-0.08142361044883728, 0.05476640537381172, 0.08737846463918686, 
                    0.01050624530762434, 0.009677586145699024, 
                    0.06174479052424431, -0.018360227346420288`, \
-0.011885304935276508`, -0.03705860301852226, -0.07161705195903778, \
-0.029852628707885742`, 
                    0.005513370037078857, -0.059308674186468124`, \
-0.02121489681303501, -0.0615103505551815, -0.11639335006475449`, \
-0.10619481652975082`, -0.01784558780491352, 0.0175138209015131, 
                    0.01346268504858017, -0.1667799949645996, \
-0.035021450370550156`, 0.052776362746953964`, 
                    0.10065989941358566`, -0.06344448775053024, \
-0.09486804902553558, 0.035033710300922394`, -0.006937144324183464, 
                    0.045456476509571075`, 
                    0.04316892474889755, -0.09342222660779953, 
                    0.0008855097694322467, -0.025140656158328056`, \
-0.015288282185792923`, -0.0030452352948486805`, 
                    0.017057005316019058`, -0.05142027884721756, 
                    0.038318388164043427`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c41//3/0VE9kyioUHR0rCe59BCRirVG02kVNLQIMrKHglFilQIRUsp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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.013705006800591946`, -0.030337881296873093`, 
                    0.013427020981907845`, -0.00031497207237407565`, 
                    0.036237411201000214`, -0.024555902928113937`, 
                    0.023690879344940186`, -0.05168936774134636, \
-0.0783071219921112, 0.02429100126028061, -0.04025966301560402, 
                    0.020141851156949997`, 0.03226456791162491, 
                    0.028113175183534622`, 0.07036611437797546, 
                    0.032827556133270264`, 0.043747298419475555`, 
                    0.012622751295566559`, -0.0007410804973915219, 
                    0.023608945310115814`, 
                    0.04263940081000328, -0.0331866629421711, 
                    0.08040691167116165, 0.07134639471769333, 
                    0.01894993707537651, 0.004810554441064596, 
                    0.0366763137280941, 
                    0.004671778529882431, -0.023305896669626236`, \
-0.038361940532922745`, -0.027490444481372833`, -0.07412122189998627, \
-0.002436381997540593, -0.01054669264703989, 
                    0.05588890239596367, -0.023012280464172363`, \
-0.01715954951941967, 
                    0.06316083669662476, -0.03760109469294548, \
-0.039628710597753525`, 0.02243681065738201, -0.020341617986559868`, 
                    0.05619411543011665, 
                    0.039038460701704025`, -0.0078072198666632175`, \
-0.012413900345563889`, 0.13281689584255219`, 0.07061712443828583, 
                    0.00008077290840446949, -0.006236095447093248}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUjo/Tx1NapEUkUihLi7QQSvc1U6RF5YcK2UmUXaHsikppI0sLWrSg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                    "], "Biases" -> 
                    RawArray["Real32",{0.06005050241947174, 
                    0.002019935054704547, 
                    0.038273025304079056`, -0.020320633426308632`, 
                    0.01690281555056572, 
                    0.02006107196211815, -0.08315152674913406, \
-0.027995189651846886`, -0.017703590914607048`, -0.011095658876001835`, \
-0.020068669691681862`, 0.021107858046889305`, 0.006713116075843573, 
                    0.016794009134173393`, 0.02274133637547493, 
                    0.049482740461826324`, -0.009265236556529999, \
-0.038372885435819626`, -0.025602640584111214`, -0.06707651168107986, \
-0.028459301218390465`, 
                    0.015549392439424992`, -0.05287586897611618, \
-0.010770488530397415`, 
                    0.008935900405049324, -0.020190756767988205`, \
-0.018492015078663826`, -0.008018720895051956, 
                    0.059581536799669266`, -0.10275226831436157`, \
-0.006174096837639809, 0.039008475840091705`, 0.014955573715269566`, 
                    0.04215509817004204, -0.00846704002469778, \
-0.03097914531826973, -0.0004003334906883538, -0.0030182702466845512`, \
-0.013472309336066246`, 0.0433579757809639, -0.07060513645410538, 
                    0.034907735884189606`, -0.02522047609090805, 
                    0.06151147931814194, 0.0053591737523674965`, 
                    0.07376852631568909, -0.01723111979663372, \
-0.007039499469101429, -0.016710367053747177`, -0.008256719447672367}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtV3dYyI/zp500aW+JpGjRet9FkRENGSkrkqw+hAZRmkpEEomMtDQkkep9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                    "], "Biases" -> 
                    RawArray["Real32",{-0.006189482286572456, 
                    0.0029592730570584536`, 0.038590412586927414`, 
                    0.046640634536743164`, -0.002788739511743188, 
                    0.010740767233073711`, -0.006780431140214205, 
                    0.02255106344819069, -0.0072220140136778355`, \
-0.02469414286315441, -0.03558126091957092, -0.026781676337122917`, 
                    0.012283814139664173`, -0.0015252243028953671`, \
-0.005338338203728199, 
                    0.05408509075641632, -0.011359387077391148`, \
-0.0324188768863678, -0.002429183339700103, -0.0015505626797676086`, 
                    0.0017329980619251728`, -0.001912478357553482, \
-0.01344726886600256, -0.012762856669723988`, -0.02330108918249607, \
-0.005389018449932337, 0.03289433568716049, -0.04801194742321968, 
                    0.003102084156125784, -0.006692205090075731, 
                    0.0021882581058889627`, -0.027299106121063232`, \
-0.029852712526917458`, -0.03493591770529747, 0.020570334047079086`, 
                    0.04479258880019188, 
                    0.00012362055713310838`, -0.007822563871741295, \
-0.060695476830005646`, 0.054667878895998, -0.029558619484305382`, 
                    0.0003985118819400668, -0.010562133975327015`, \
-0.046755336225032806`, -0.05209028348326683, 0.022358635440468788`, 
                    0.04885372519493103, -0.04882873594760895, 
                    0.015043538995087147`, 0.019708920270204544`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{-0.15286995470523834`, 
                    0.10065559297800064`, 
                    0.09388323873281479, -0.14782126247882843`, \
-0.2502208948135376, -0.20797930657863617`, -0.0633840560913086, \
-0.43324553966522217`, 
                    0.04648209735751152, -0.07430645823478699, \
-0.011269411072134972`, 
                    0.23275955021381378`, -0.3131479322910309, \
-0.06919024139642715, 0.12743069231510162`, 0.13335667550563812`, 
                    0.22094355523586273`, -0.33160877227783203`, 
                    0.13558031618595123`, 
                    0.20300133526325226`, -0.2957439422607422, 
                    0.17743214964866638`, 0.10739501565694809`, 
                    0.11109966784715652`, 0.11670545488595963`, 
                    0.12238537520170212`, -0.08694028854370117, \
-0.04687909036874771, -0.16793008148670197`, 
                    
                    0.15444451570510864`, -0.18018098175525665`, \
-0.060066670179367065`, -0.17210149765014648`, 
                    0.10668154060840607`, -0.18247787654399872`, \
-0.14345486462116241`, -0.033742755651474, -0.2072511911392212, 
                    0.1963987499475479, -0.060702450573444366`, 
                    0.09260519593954086, -0.1404234617948532, \
-0.10417990386486053`, 0.03439488634467125, -0.06096915900707245, 
                    0.12362578511238098`, -0.14717306196689606`, 
                    0.28461986780166626`, 
                    0.03916725888848305, -0.12325620651245117`}}], "Biases" -> 
                    RawArray["Real32",{-0.013302911072969437`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.7572630047798157}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 1.6065632, "MeanInputsPerSecond" -> 
          47803.908367874974`], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {
                0.005459927353459882, -0.05899830624411635, \
-0.0036677637062684327`, -0.024056235039767653`, 0.042545455754911705`}, 
               "StandardDeviation" -> {0.9831261646707395, 1.002140804526552, 
                1.0003397958132785`, 0.9996489329114201, 0.986322617414174}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 4034005007580607956]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 300, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[362513], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3897591320693609, "PreprocessingTime" -> 
        0.3720066`7.022095638534197, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.7832064411728021, 0.3446109340498677], 
           "StandardDeviation" -> 
           Around[0.447788216749036, 0.0779205693132024], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 99880, 
           "ModelUtility" -> 0.07604485814125994, "TrainingSize" -> 252, 
           "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 451656, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.7832064411728021, 0.24367672833769155`]}, 
           "StandardDeviationHistory" -> {
             Around[0.447788216749036, 0.05509816295528182]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 300, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 195434109103494]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[6.516162244059018, 0.9242214600508303], 
                "StandardDeviation" -> 
                Around[0.7728882305477517, 0.049137596021233056`], 
                "EvaluationTime" -> 0.0001497747329571884, "TestSize" -> 305, 
                "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.44819359516259183`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                424656, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[6.516162244059018, 0.6535232617200739]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7728882305477517, 0.03474552735781901]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[18.539563075065043`, 2.9948324309111727`], 
                "StandardDeviation" -> 
                Around[0.5980429129976742, 0.04407167115396481], 
                "EvaluationTime" -> 0.00010731390959453888`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.19371753561101634`, "TrainingSize" -> 50,
                 "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                428624, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[18.539563075065043`, 2.1176663204146826`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5980429129976742, 0.031163377531192075`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.7832064411728021, 0.3446109340498677], 
                "StandardDeviation" -> 
                Around[0.447788216749036, 0.0779205693132024], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 0.07604485814125994,
                 "TrainingSize" -> 252, "TrainingTime" -> 1.5848931924611136`,
                 "TrainingMemory" -> 451656, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.7832064411728021, 0.24367672833769155`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.447788216749036, 0.05509816295528182]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.447788216749036, 0.0779205693132024], 
               "TrainingMemory" -> 451656, "TrainingTime" -> 
               2.6120738350565853`], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.335162012495212, 0.4674900686243047], 
                "StandardDeviation" -> 
                Around[0.5898676005735578, 0.03464709399581264], 
                "EvaluationTime" -> 0.00011214911128437225`, "TestSize" -> 
                305, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.1770028382390828, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495584, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.335162012495212, 0.3305653976616103]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5898676005735578, 0.02449919511284683]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[10.649923483650069`, 1.9723023915609774`], 
                "StandardDeviation" -> 
                Around[0.5365291754007451, 0.04380227619639017], 
                "EvaluationTime" -> 0.00015459545750832804`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.08674291202709661, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499552, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[10.649923483650069`, 1.3946283956232124`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5365291754007451, 0.03097288652987358]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.0097678292525132`, 0.46394757850447854`], 
                "StandardDeviation" -> 
                Around[0.4988419724784556, 0.09573448202562931], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.03537974165671942, "TrainingSize" -> 252,
                 "TrainingTime" -> 5.011872336272724, "TrainingMemory" -> 
                522648, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.0097678292525132`, 0.32806047887559486`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4988419724784556, 0.06769450143370413]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00031670830396331406`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4988419724784556, 0.09573448202562931], 
               "TrainingMemory" -> 522648, "TrainingTime" -> 
               7.849733612802018], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[17.9183104136497, 2.886739825784441], 
                "StandardDeviation" -> 
                Around[0.5887928108776015, 0.04322011528135079], 
                "EvaluationTime" -> 0.00015459545750832804`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.17807255799118737`, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                428832, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[17.9183104136497, 2.041233306333451]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5887928108776015, 0.030561236599107474`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00015459545750832804`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.5887928108776015, 0.04322011528135079], 
               "TrainingMemory" -> 428832, "TrainingTime" -> 
               6.577306748713622], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.440565551973297, 0.4050461965737506], 
                "StandardDeviation" -> 
                Around[0.5232726977789298, 0.03477858441729978], 
                "EvaluationTime" -> 0.0001185978783392367, "TestSize" -> 265, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.05873367492535586, "TrainingSize" -> 50, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                499616, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.440565551973297, 0.28641091229111837`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5232726977789298, 0.024592172881541467`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.9721259876918199, 0.4254030438413012], 
                "StandardDeviation" -> 
                Around[0.46294328340813734`, 0.07739941487520234], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.044078303548332864`, "TrainingSize" -> 252, "TrainingTime" -> 
                1., "TrainingMemory" -> 522648, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.9721259876918199, 0.3008053770375822]}, 
                "StandardDeviationHistory" -> {
                  Around[0.46294328340813734`, 0.05472965111812651]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.46294328340813734`, 0.07739941487520234], 
               "TrainingMemory" -> 522648, "TrainingTime" -> 
               1.648107170553497], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 195429814136198]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 9.5404132231405`1.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097568057909074`17.33347224271641*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 2.133025219610147, 
            "ElapsedTimes" -> 2.6289661, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 3.5550420326835788`, 
            "ElapsedTimes" -> 4.710432000000001, "ExperimentCounts" -> 4], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 5.925070054472632, 
            "ElapsedTimes" -> 8.9480564, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 195442699038086]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{2.858864173869224, 0.24123912459719887`, 
              1.249400159230766, 0., 5.298317366548036}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 17.1348988, 
        "MaxTrainingMemory" -> 980856, "DataMemory" -> 75768, 
        "FunctionMemory" -> 260136, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 46, 45.819797`9.413628027180762}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {-0.3869384062945835, 0.07798684265555786, 
                    0.0503947460591552, 0.47619047619047616`, 
                    3.8063835369343817`}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.3869384062945835, 0.07798684265555786, 
                    0.0503947460591552, 0.47619047619047616`, 
                    3.8063835369343817`}, 
                    "StandardDeviation" -> {7.71964477599424, 
                    4.163381852739683, 4.216753109094347, 0.4994327848429293, 
                    1.4411801972011815`}, "Method" -> "NaiveSampler", 
                    "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.43803319650918443`, -0.4881198066408155, 
                    0.351632103676579, 0.5715982867824253, 
                    0.3456822751201734}, {-0.6491281802915321, 
                    0.23959493383037989`, -0.1273633565476584, \
-0.5123231940422133, 
                    0.49247374903594454`}, {-0.4694893530153898, \
-0.15093096236188844`, -0.6845674882527132, 
                    0.22672361295649907`, -0.4865833426670378}, \
{-0.059195535471818314`, -0.7083879669944452, 
                    0.2126613176420167, -0.5988554259316984, \
-0.30137969342443544`}, {-0.40352838845953065`, 0.4239571380054119, 
                    0.5884521705959035, 
                    0.027729506917659217`, -0.5571178530693373}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.3869384062945835, 0.07798684265555786, 
                    0.0503947460591552, 0.47619047619047616`, 
                    3.8063835369343817`}, 
                    "StandardDeviation" -> {7.71964477599424, 
                    4.163381852739683, 4.216753109094347, 0.4994327848429293, 
                    1.4411801972011815`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0111338, "MaxTrainingMemory" -> 93000, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 46, 45.8447292`9.413864278162414}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.3869384062945835, 0.07798684265555786, 
                0.0503947460591552, 0.47619047619047616`, 
                3.8063835369343817`}, 
               "StandardDeviation" -> {7.71964477599424, 4.163381852739683, 
                4.216753109094347, 0.4994327848429293, 1.4411801972011815`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.3738601025507347`}, 
               "StandardDeviation" -> {0.7537545891229451}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.3738601025507347` + 
         0.7537545891229451 #& ), 
        "ProcessorFunction" -> (3.1493806297258025` + 
         1.3266917567474865` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.7627288526542797`, 2.377657127020997}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViXtQlHUUQPEBwbCsJcjDYXDdQNpWR1oeGex3r6YDQTjgIsSgQQtJISvK
U6gERxMEAXk1hkKkmLxExKEFg+/+aAE1xY2hgSmCIld5rohIJLBC+sc5M2fO
xsjDiuiVRkZGiaYvpVAe3ZGQoEwLMnkVB5QqV5nq1ZS9xPgllt026F7xJ0TY
y+ijs1XouE/ATNVpEMunwERBEJtGAXtYr6f2+itMZ9DC0XFv1nQzEIfeKMTz
Sf3gaJ8O233PsG09u/GCWyb53L8Bw51SyI8zZReW7CDxIQd5/YOU6/AMLNu7
SLSJQUhjIR/W4MkgNBjGh9wwOy+M32b34man0h+h2R8j95bx/pk/0eBSBxeX
fpr8z78AD6ELeB93RPuGRW7n2Lu0Z6CFPMuVfNrti3BkpZbGhjvh5/o+LlZw
Bc+KRvjMWC9Wfmc1901yMd+glWBjaj8NqayxqcAF3kkuoho/M/5pQQ1Blww/
mXxCliGLMHn9OQWes2C2H5bCskpC9Vf2sc+XE+ALmuQHflsG3iQEhbuf0gaJ
Dbs9PkZt+6ZJctKLaH8Ma9EuUvl71aCXqkDnGyCfzzdGj5j7uGGgEi4ec+Jr
192ADucbdMlgxUhVhDnRKVi4VQ0Hu4hne1oh5Z85zt5tK/6YYoMnBVLca/8d
55OwhgsEFT8RXAAQHcOWQ9XgtbkXnlSv5rc89gTp8dMgCimhTqEcTsy/oNLZ
I7hQWktJsY1w+K0eLnCHmCSuGlwqELAVl1zhkGaq7VFlGTnPXeZysJCxoV55
d2Sf14O1ZRQ8VYEHhEFcX/wONnN1BVnlJ7UKj+l58yxbFGunqNioghwHTSAr
uYZ/7dtZaH5ujblhn0LU4zeRuduBdNwJ7RQP4HuPbApfFwlZOmuW0P4B6C/m
wHSVnNlYebJRvxwSfTxKcRG9MOQlZw6cTp5eOchrfNzaTqwSMV2egjuzW0ih
1zrktg4RuLnEGRcyrNDt12ISf1XoVTt/Ah+JM6CuOwkONtzlT233ZRhmoIVx
J/CInyM7ssBfHCzYQqUY21tW4R+pw/LAv9azgWRzTIMKmFga4e5Yn0OPHgM/
llFNYdrDNNthoLm7pzCjSQ8RucfBzuwySdWt/H6XKVIl9Mnbt8iZdP/7mL34
JfN5ag53ZiUs1WoXr6+rxtbb9+jtvxV8cfm/8ijBBMToikjZJgaDSA09stcp
b9ICZ28VsrqRjUy7thNCS7NhUwVjoWc3sqp4Aft6kxo0TgHUJIuClv+MSeq8
jguyMoX5UQ0ZwtewuyssqSlxhDJNZ/jPrnZxUc+LmIu3lIVPW8LUrVV0qPoH
du/y73jdfz36mrSwuZJFar7mjvgsgGaG9DTsZ4a7HmpIkRUP/wNMaP2h
                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.04788484796881676, -0.08294273167848587, 
                    0.06554432213306427, 
                    0.030507657676935196`, -0.14618922770023346`, \
-0.042509038001298904`, 
                    0.1042979285120964, -0.0064206114038825035`, \
-0.16889293491840363`, -0.06274817883968353, -0.1032729521393776, 
                    0.1856440305709839, 
                    0.005558015778660774, -0.054994452744722366`, \
-0.02647293545305729, -0.14572714269161224`, 0.2204206883907318, 
                    0.19177332520484924`, 
                    0.018546829000115395`, -0.02509944699704647, \
-0.16045500338077545`, 
                    0.13101038336753845`, -0.1723625361919403, \
-0.2679140865802765, -0.1862889528274536, 
                    0.14185091853141785`, -0.217739537358284, \
-0.0730079635977745, 
                    0.06141216680407524, -0.01542381290346384, \
-0.009534959681332111, 
                    0.028629109263420105`, -0.3128587305545807, \
-0.0348394475877285, -0.2379956692457199, -0.1615743488073349, 
                    0.010751204565167427`, 
                    0.0032455273903906345`, -0.19380219280719757`, \
-0.059240493923425674`, -0.25037819147109985`, 
                    0.0006951174582354724, -0.05500957369804382, \
-0.021322375163435936`, -0.018595248460769653`, 
                    0.09596693515777588, -0.03613059222698212, \
-0.10101613402366638`, -0.05755486711859703, -0.03246146813035011}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtV3c814/zN0JGKqSUFKKMpLK97mgopaTQMEpLaZP2tPcKCSEqkkjTeL/u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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.04079507291316986, -0.028521377593278885`, \
-0.04955223947763443, -0.007642554584890604, -0.16342848539352417`, \
-0.16565901041030884`, -0.03516688942909241, 0.09980762749910355, 
                    0.1145424172282219, -0.1921171098947525, \
-0.05377039313316345, -0.20927366614341736`, -0.06914550065994263, \
-0.16195781528949738`, -0.08289079368114471, -0.12986350059509277`, \
-0.12084749341011047`, -0.0742897093296051, 0.15990880131721497`, 
                    0.058722324669361115`, 0.05897479131817818, 
                    0.03470078855752945, -0.03499051183462143, \
-0.11816702783107758`, -0.11438813805580139`, -0.17955425381660461`, 
                    0.041758038103580475`, -0.024936579167842865`, \
-0.026644635945558548`, -0.007254059426486492, 
                    0.07880567759275436, -0.14738550782203674`, 
                    0.06902004778385162, -0.1277609020471573, \
-0.18571576476097107`, 
                    0.03345790505409241, -0.02372354082763195, \
-0.09910484403371811, -0.05571192502975464, -0.12938188016414642`, \
-0.026058629155158997`, -0.2891887426376343, -0.02094418741762638, \
-0.21473629772663116`, -0.07167310267686844, -0.13067831099033356`, \
-0.03556028753519058, -0.05101192742586136, -0.13966867327690125`, \
-0.09696412086486816}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dcz9/3wNtLSsoobaOMiBT1fp0TKpVKaciISEZDRiqzIilFkpDIKIoo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                    "], "Biases" -> 
                    RawArray["Real32",{-0.12602248787879944`, 
                    0.03478510305285454, -0.17272290587425232`, 
                    0.05443398281931877, -0.08780957013368607, \
-0.06038989499211311, -0.06226813793182373, -0.028566664084792137`, \
-0.16144609451293945`, -0.05309927463531494, 
                    0.027993209660053253`, -0.05608516186475754, \
-0.06986012309789658, -0.05272010341286659, -0.12145981192588806`, \
-0.018695225939154625`, -0.03793293610215187, -0.18829655647277832`, 
                    
                    0.011648055166006088`, -0.02940887026488781, \
-0.027308054268360138`, -0.08907473087310791, -0.05346707999706268, \
-0.1627492755651474, -0.06784509867429733, -0.18635240197181702`, 
                    0.01419330108910799, -0.10179963707923889`, \
-0.01727111078798771, -0.132029727101326, -0.1610773652791977, \
-0.11316835880279541`, -0.07250623404979706, -0.19117037951946259`, \
-0.025489501655101776`, 0.05341969057917595, 
                    0.006498648785054684, -0.09277083724737167, 
                    0.000721149321179837, -0.07559213787317276, 
                    0.04353608191013336, -0.07072891294956207, \
-0.09503473341464996, 
                    0.04341055825352669, -0.03508458659052849, \
-0.08070681989192963, -0.04371432587504387, -0.05507151037454605, \
-0.0497639924287796, 0.07911638915538788}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2k0l9/Xxs1FEpGhZEholLHke+/dpEgKKUWlkDSIaKRJ5ihRKIU0olSi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                    "], "Biases" -> 
                    RawArray["Real32",{0.058787789195775986`, 
                    0.025009267032146454`, 0.046808287501335144`, 
                    0.02238808386027813, -0.04306371510028839, 
                    0.07882747054100037, 
                    0.05140193924307823, -0.006503131240606308, \
-0.03740773722529411, 0.025277597829699516`, -0.07656839489936829, 
                    0.0016163918189704418`, 
                    0.020914247259497643`, -0.06640785932540894, \
-0.023364635184407234`, -0.015186995267868042`, -0.061383556574583054`, \
-0.026985052973031998`, 0.009650759398937225, 0.00882901530712843, 
                    0.030008839443325996`, 0.08599334210157394, 
                    0.02588690258562565, -0.07666066288948059, 
                    0.027608493342995644`, 0.011356892995536327`, 
                    0.013393256813287735`, -0.0019657600205391645`, 
                    0.06332886219024658, -0.030116284266114235`, 
                    0.0952816754579544, 
                    0.007426427211612463, -0.03936631605029106, \
-0.01635671593248844, 0.09639466553926468, 0.062428008764982224`, 
                    0.009565222077071667, -0.048564612865448, 
                    0.04694852977991104, -0.02674946002662182, 
                    0.09016190469264984, 0.0810076966881752, 
                    0.08630267530679703, 0.03633123263716698, 
                    0.002910807030275464, -0.018518507480621338`, 
                    0.00988623034209013, -0.0023578580003231764`, \
-0.06698671728372574, -0.07591104507446289}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray[
                    "Real32",{{-0.13837051391601562`, -0.03427697345614433, 
                    0.07993220537900925, 0.09855276346206665, 
                    0.043294068425893784`, 0.031066356226801872`, 
                    0.1645406037569046, -0.04158394783735275, \
-0.044624410569667816`, 0.08070361614227295, 
                    0.0026133835781365633`, -0.09759718924760818, 
                    0.15723192691802979`, -0.07662941515445709, \
-0.08837699145078659, -0.11663910001516342`, -0.15362344682216644`, 
                    0.010650827549397945`, -0.09896034747362137, \
-0.13798795640468597`, -0.09825459122657776, -0.1216922178864479, 
                    0.01919553428888321, 0.10952286422252655`, 
                    0.19824083149433136`, -0.15364401042461395`, \
-0.13749408721923828`, -0.2668219804763794, 0.022167211398482323`, 
                    0.10280009359121323`, -0.09415030479431152, 
                    0.03095972165465355, -0.30655738711357117`, 
                    0.0908631831407547, 0.07389768958091736, 
                    0.04433823749423027, -0.08801952749490738, \
-0.016170142218470573`, 0.06550358980894089, 
                    0.025926345959305763`, -0.15935607254505157`, 
                    0.03993915766477585, 0.03146551549434662, 
                    0.19831527769565582`, -0.03332317993044853, \
-0.13472816348075867`, 0.08936356008052826, 0.08833042532205582, 
                    0.10595261305570602`, 0.12131454795598984`}}], "Biases" -> 
                    RawArray["Real32",{0.01190964225679636}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-1.406190276145935}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.3658213, "MeanInputsPerSecond" -> 
          47709.378618330054`], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.018396424810047596`, 0.019113786099809477`, 
                0.02170719487767393, -0.008367853612063719, 
                0.016016399347389403`}, 
               "StandardDeviation" -> {1.0091917919203084`, 
                0.9982679145302454, 0.9961709079914097, 0.999603327785921, 
                0.9701720189675255}, "Output" -> 
               Association[
                "f1" -> 
                 Association["Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 9007930618388924026]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[362705], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.28268844257062575`, "PreprocessingTime" -> 
        0.362032`7.010291953004845, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.9926095105811533, 0.9627177735978669], 
           "StandardDeviation" -> 
           Around[0.361378994524134, 0.09544967958170637], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 107736, 
           "ModelUtility" -> 0.27316941329959377`, "TrainingSize" -> 252, 
           "TrainingTime" -> 5.011872336272724, "TrainingMemory" -> 522648, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.9926095105811533, 0.680744266079867]}, 
           "StandardDeviationHistory" -> {
             Around[0.361378994524134, 0.06749311569430771]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 267318976736660]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.730662059542, 0.46784888611410425`], 
                "StandardDeviation" -> 
                Around[0.6780342658567611, 0.03711844216264912], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.31551299023553414`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495776, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.730662059542, 0.33081911994185587`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6780342658567611, 0.026246702160289848`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[9.34715075331265, 1.6136740344926483`], 
                "StandardDeviation" -> 
                Around[0.5421620728737908, 0.041050625742263265`], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.09602058390288193, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499552, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[9.34715075331265, 1.1410398524144063`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5421620728737908, 0.029027175834305405`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.9926095105811533, 0.9627177735978669], 
                "StandardDeviation" -> 
                Around[0.361378994524134, 0.09544967958170637], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.27316941329959377`, "TrainingSize" -> 252, "TrainingTime" -> 
                5.011872336272724, "TrainingMemory" -> 522648, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.9926095105811533, 0.680744266079867]}, 
                "StandardDeviationHistory" -> {
                  Around[0.361378994524134, 0.06749311569430771]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.361378994524134, 0.09544967958170637], 
               "TrainingMemory" -> 522648, "TrainingTime" -> 
               7.849733612802018], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[11.425803452107074`, 2.2628670024076984`], 
                "StandardDeviation" -> 
                Around[0.5307645840885713, 0.04639349980786457], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.07707327375068229, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                428752, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[11.425803452107074`, 1.600088602325759]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5307645840885713, 0.032805158317117826`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00014229478653976401`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.5307645840885713, 0.04639349980786457], 
               "TrainingMemory" -> 428752, "TrainingTime" -> 
               6.577306748713622], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.11243590388775, 0.48740770097592917`], 
                "StandardDeviation" -> 
                Around[0.7384361040100289, 0.03750196701049545], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 99880, "ModelUtility" -> -0.4000644722937138,
                 "TrainingSize" -> 10, "TrainingTime" -> 0.3981071705534972, 
                "TrainingMemory" -> 424656, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[4.11243590388775, 0.3446492905626245]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7384361040100289, 0.026517895180955528`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[2.9823966872065677`, 0.5616159054598139], 
                "StandardDeviation" -> 
                Around[0.49142590818287096`, 0.03627628208443896], 
                "EvaluationTime" -> 0.0001430034169695532, "TestSize" -> 265, 
                "ModelMemory" -> 99880, "ModelUtility" -> 
                0.002609074696202196, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 428688, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.9823966872065677`, 0.39712241517285735`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.49142590818287096`, 0.025651205058142855`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.585430954544137, 0.38661943389437803`], 
                "StandardDeviation" -> 
                Around[0.39263173795473255`, 0.08437660201705588], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 0.1996217692957989,
                 "TrainingSize" -> 252, "TrainingTime" -> 0.7943282347242815, 
                "TrainingMemory" -> 451656, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.585430954544137, 0.2733812234452188]}, 
                "StandardDeviationHistory" -> {
                  Around[0.39263173795473255`, 0.05966326745973873]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00025157034800970054`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.39263173795473255`, 0.08437660201705588], 
               "TrainingMemory" -> 451656, "TrainingTime" -> 
               1.391017463958849], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 267314681769364]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 6.5578512396694`2.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097568196823987`17.333472244299976*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 2.62544857875685, 
            "ElapsedTimes" -> 2.1462566, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 4.375747631261417, 
            "ElapsedTimes" -> 4.1449077, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 7.292912718769028, 
            "ElapsedTimes" -> 6.8496731, "ExperimentCounts" -> 2]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 267327566671252]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{-7.22661819619284, 
              2.152496674228478, -3.2995241272622993`, 1., 
              5.298317366548036}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 13.887598, 
        "MaxTrainingMemory" -> 978936, "DataMemory" -> 75768, 
        "FunctionMemory" -> 263400, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 46, 59.7093252`9.528616991302068}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {-0.13397522960928632`, -0.25940132943554134`, 
                    0.3072121421653826, 0.473015873015873, 3.8640782057154}, 
                    "Method" -> "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.13397522960928632`, -0.25940132943554134`, 
                    0.3072121421653826, 0.473015873015873, 3.8640782057154}, 
                    "StandardDeviation" -> {7.141914775746749, 
                    4.460185423257507, 4.3262886218924965`, 
                    0.4992713259249969, 1.3786839392202825`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.1782346049135846, 
                    0.5279853998488324, -0.6549913394559408, \
-0.07588749309924911, -0.5046694728102653}, {0.5994845345179972, 
                    0.013200997440138973`, -0.38207840584371616`, \
-0.5875481167084846, 
                    0.3863254183723397}, {-0.16832214449136199`, \
-0.7605032607522428, -0.16418285486621917`, -0.38768376754816886`, \
-0.4648093508167303}, {-0.4791689862656871, 0.3250932414890387, 
                    0.4129643591684543, -0.6985861584880896, 
                    0.07841737157483064}, {0.5923811752241807, 
                    0.1923702834026332, 
                    0.47697679739186805`, -0.10347451131527818`, \
-0.611444500802379}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.13397522960928632`, -0.25940132943554134`, 
                    0.3072121421653826, 0.473015873015873, 3.8640782057154}, 
                    "StandardDeviation" -> {7.141914775746749, 
                    4.460185423257507, 4.3262886218924965`, 
                    0.4992713259249969, 1.3786839392202825`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0121559, "MaxTrainingMemory" -> 93056, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 46, 59.7352566`9.528805561833021}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.13397522960928632`, -0.25940132943554134`, 
                0.3072121421653826, 0.473015873015873, 3.8640782057154}, 
               "StandardDeviation" -> {7.141914775746749, 4.460185423257507, 
                4.3262886218924965`, 0.4992713259249969, 1.3786839392202825`},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.428015827826004}, 
               "StandardDeviation" -> {0.6952216070108207}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.428015827826004 + 
         0.6952216070108207 #& ), 
        "ProcessorFunction" -> (3.4924343595497795` + 
         1.4383902771658759` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.4597035137900294`, 2.575143333840041}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViXlQlHUYgBHkUhJDBFeOoEaOwINjkY393hcYkpABZTGOlTzRWFljWQ5l
TFMMR2ghQDAglU0qHDZNFOLa7/2pGIYkDIdsxrEzIkcJJpGFrRPpH88z88zj
uidNst/YyMgow+KlJLsPhSiVu3NizV7Fvt1yP1/5q+n7EtOXbFbqSLHyDRZ5
8QV98PSCuOhrEUXfNkPzsGVoo3SA8KsSMt5YIDbYXoH8yFz4+MBjank7Hi2z
xsHr+gRXlmvJxgSRuC3aQAb/frKUFMAfFUK0i7Wm0dRg0h51x4lpKyiUvYPd
ruGci38RW1x8GtZcQ84wvow87bxhnYsdbd6YQb+dPQi9T2LQs9mEBd9VsLSB
DTR8zp8/lfmIX/JuJzVfOgEz8niKylmEtUpjbK/L50ufF8OFuk9xgOWSR5sG
0mp/5PxWFLMfRPUQF/gthKgSOP0aE/CtVsPOgQi2vUfO37Bfj3fSjCg51RaP
rfLCRB8FjegL+VAHKe6Q6YMi7vmAcFJFo/eayKFP25pqU0dh2WeQq3JFL/eV
4HHjLh+6pZXirVRMkT0LneXLxVec2mFT3Hmyq1fjSOUS/E/1kI1uv0qJJdHk
bSfgo9JlfHKril4LPc80shPQljRH3M8BNCaZBIteAzcldYSojhJKHMzE76Zi
cKx3HgLOmzLSV6LN+DS3JZxD89ka+uSIDLQaDV3y+B7OaVegrlpEO1uFmF0y
K+bkc/B6vDleHPbClBZHfHHPnj0RJ3HJpXKmDmmCVWcnuG36A9Dc18Hfl8zy
8+UCqpNeh/6Dv3NCn03kE+iHcZVdcPmxOywtXst0x4OQj2mBPrca3EO2+GRG
gGnHBdzepn/ArX4A8sma1UeOUGOGLf8gL4R6fmon/6ZlLCVQTR7+JpAZOksJ
fdFU0i+Dh4X3KaUgEMtavVG42pMtzRKymw+CqLHGElrejEW1IIVVHfmS4iMq
eeP1C1ResBKvtgUx49MfAtbkYXbaYmr8e4pvP/Yn9B92o9uO1ij6hcgwMsQv
uAZDg+4L/pnCmZy683jvXVboc0unzZi8RVEFTqwpTsM7f1XLTgYnsZmtUhjv
tEOzrb6soiwVilRrufd7ytEPAtjq8HletO8cbFAZtBYiD5INO1Ou7jCTfeRA
CnktfDZkxHWXCkFU1Q9ZCWL27OkQ9Lw1z3ks+pePTi9CLksGi2NNWcPQMGhT
7NmC0Yy4PKm3TfL0GqldxNgiChMvX6qn+UPPaa8mgjmfsaWFvqPMws9d29Ml
xbkiDtPRAqn/VzquroBT/GXtovod3Hb2FxXHfkONMVEws9MJzNSD2nXdOdDh
qKAGzRB13XkEsulh2l/HoPrme+yy8CTsypC1DdZIwflzR3JSOvL/A7G47X8=

                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.10552814602851868`, -0.133736714720726, \
-0.042655233293771744`, 0.01196028757840395, -0.06437624245882034, 
                    0.05236706882715225, -0.05990537256002426, 
                    0.03479304537177086, 
                    0.007389480248093605, -0.0497652068734169, \
-0.014604655094444752`, -0.01452568918466568, 
                    0.0032940309029072523`, -0.03008287027478218, 
                    0.02644963748753071, -0.09905267506837845, \
-0.010780244134366512`, -0.020328057929873466`, 0.12103937566280365`, 
                    0.03504398465156555, -0.051878493279218674`, \
-0.04381280392408371, 0.019038638100028038`, -0.02022228017449379, 
                    0.008425652980804443, 0.012862601317465305`, 
                    0.04051617905497551, -0.09327594935894012, \
-0.03949882462620735, 0.021563349291682243`, 0.00901913084089756, 
                    0.07291606068611145, -0.11173991858959198`, 
                    0.013793224468827248`, 0.044539861381053925`, 
                    0.07054377347230911, -0.03774232044816017, \
-0.014900613576173782`, 0.034182287752628326`, 0.024006478488445282`, 
                    0.09447579085826874, -0.01961449719965458, \
-0.015134189277887344`, -0.040925994515419006`, -0.052675679326057434`, \
-0.035345885902643204`, -0.04294541850686073, 
                    0.05996024236083031, -0.01840684562921524, \
-0.040949005633592606`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtV3c014/3NrIihEJGVJSMIlrv170qpCShRJK0h5ZKWspWVomGhooGIWnz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                    "], "Biases" -> 
                    RawArray["Real32",{-0.01630706712603569, 
                    0.026624498888850212`, 0.02250717766582966, 
                    0.031841203570365906`, 
                    0.028353752568364143`, -0.033209916204214096`, \
-0.04244786873459816, -0.012327836826443672`, 0.01675405167043209, 
                    0.0074883014895021915`, 
                    0.026453837752342224`, -0.010385391302406788`, 
                    0.00013920584751758724`, -0.003680399851873517, 
                    0.008197935298085213, 
                    0.038071125745773315`, -0.009043112397193909, 
                    0.011740321293473244`, -0.016856810078024864`, \
-0.0011527561582624912`, 
                    0.021685579791665077`, -0.023857975378632545`, \
-0.010688627138733864`, -0.05237194895744324, 
                    0.025855831801891327`, -0.023582443594932556`, \
-0.04426809027791023, -0.048882320523262024`, -0.04220300167798996, \
-0.1281292885541916, -0.009845620021224022, -0.045768171548843384`, \
-0.0676029771566391, -0.03050338476896286, -0.04172632470726967, \
-0.07776583731174469, -0.017542261630296707`, -0.026855507865548134`, \
-0.046475183218717575`, 0.013769199140369892`, 0.039485033601522446`, 
                    0.05162574350833893, -0.0266452394425869, \
-0.023762663826346397`, 0.006674553267657757, -0.05717229098081589, 
                    0.042681124061346054`, 
                    0.04334919899702072, -0.06497275084257126, 
                    0.029523517936468124`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2k0lt/bhkkkGZOfTFHJFFGReO5rEw0iQxSigQaNNBNJyFgiY8aUIipF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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.059035368263721466`, -0.026069970801472664`, 
                    0.01155082881450653, -0.05920049175620079, 
                    0.0057778749614953995`, 
                    0.008961329236626625, -0.04157523438334465, \
-0.0032188608311116695`, -0.03809036687016487, 
                    0.033748503774404526`, -0.04677334800362587, \
-0.001863946788944304, -0.007428830489516258, 
                    0.019644845277071, -0.020492181181907654`, \
-0.013371121138334274`, -0.026476232334971428`, 
                    0.004917110316455364, -0.021270541474223137`, \
-0.03801601752638817, 0.03196290507912636, 
                    0.02233692817389965, -0.042091380804777145`, \
-0.018672216683626175`, 
                    0.006298442371189594, -0.003563374513760209, \
-0.017998110502958298`, -0.015764985233545303`, -0.009620975703001022, \
-0.022365760058164597`, -0.04289453476667404, 
                    0.00711140176281333, -0.025595426559448242`, 
                    0.020930549129843712`, -0.021366434171795845`, \
-0.014668800868093967`, -0.020931629464030266`, 
                    0.002567283110693097, -0.014419910497963428`, \
-0.025688836351037025`, -0.0014973190845921636`, -0.011536220088601112`, \
-0.03924369066953659, 0.010751000605523586`, 0.006479298230260611, 
                    0.028784003108739853`, -0.06842604279518127, \
-0.017646245658397675`, 0.03534641116857529, -0.030441779643297195`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUj9/XxhtUkgaaJJWSaFIpUt97HyKJFGnQpEEoIpr8DAnRrDRImpMK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                    "], "Biases" -> 
                    RawArray["Real32",{-0.013454713858664036`, 
                    0.024096207693219185`, -0.014362758025527, \
-0.02445852942764759, -0.002147816587239504, -0.020358895882964134`, \
-0.01607956737279892, -0.009386977180838585, -0.01594322733581066, \
-0.028194762766361237`, 0.0004512071318458766, 
                    0.0005142106674611568, -0.006595427170395851, \
-0.003154839389026165, -0.02952205203473568, -0.022708913311362267`, 
                    0.0026250984519720078`, -0.00612247921526432, \
-0.005628494080156088, 
                    0.003402590285986662, -0.014945968985557556`, \
-0.02564947120845318, -0.024933399632573128`, -0.0002905749133788049, 
                    0.017459072172641754`, 
                    0.018830658867955208`, -0.006214562803506851, \
-0.003552182810381055, -0.002340140054002404, 
                    0.04516352713108063, -0.017799172550439835`, \
-0.0026389036793261766`, -0.0506894588470459, 
                    0.0018538495060056448`, -0.009562557563185692, 
                    0.014873418025672436`, 0.0027497506234794855`, 
                    0.004766985308378935, -0.035282205790281296`, \
-0.006559779867529869, -0.006861141417175531, -0.015971563756465912`, 
                    0.010825620032846928`, -0.001437550992704928, \
-0.02400459162890911, 0.030688226222991943`, 
                    0.014542500488460064`, -0.009698324836790562, 
                    0.03498400002717972, 0.00015349971363320947`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{-0.11180505901575089`, 
                    0.058728672564029694`, 
                    0.10196302086114883`, -0.08694233000278473, \
-0.13930509984493256`, -0.14398236572742462`, -0.053475577384233475`, \
-0.35948777198791504`, 0.046851400285959244`, -0.07092688232660294, 
                    0.003640317590907216, 
                    0.1733810007572174, -0.2833479940891266, \
-0.03412897139787674, 0.0988064631819725, 0.11092402786016464`, 
                    0.1541479378938675, -0.2727901041507721, 
                    0.09578432142734528, 
                    0.19266538321971893`, -0.21926939487457275`, 
                    0.1533481478691101, 0.11124030500650406`, 
                    0.09139133244752884, 0.06615392863750458, 
                    0.12203458696603775`, -0.0608195997774601, \
-0.0489405132830143, -0.1352088302373886, 
                    0.14355522394180298`, -0.1470658779144287, \
-0.0688815489411354, -0.10699417442083359`, 
                    0.05427762120962143, -0.14169026911258698`, \
-0.16465911269187927`, -0.03509954735636711, -0.16049133241176605`, 
                    0.13408713042736053`, -0.04899066314101219, 
                    0.06024467945098877, -0.14999397099018097`, \
-0.032185062766075134`, 0.06277455389499664, -0.05435983091592789, 
                    0.08839141577482224, -0.1266549527645111, 
                    0.2087152898311615, 
                    0.04040279611945152, -0.1428670585155487}}], "Biases" -> 
                    RawArray["Real32",{0.009425664320588112}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.633537232875824}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 0.5695354, "MeanInputsPerSecond" -> 
          44948.91801282238], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.007234391056873069, -0.01704758663383118, \
-0.006428973272998564, 0.01412068595439248, 0.033028265848228135`}, 
               "StandardDeviation" -> {1.0053255629002817`, 
                1.0110230489469751`, 0.9949359917461342, 1.000800114101418, 
                0.9853619566558464}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 1300959820338794715]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 100, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[362817], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.36352462523369977`, "PreprocessingTime" -> 
        0.3735775`7.0239257049509725, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.548808937653322, 0.18364093830470155`], 
           "StandardDeviation" -> 
           Around[0.40888232000837493`, 0.0638642699898909], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 107736, 
           "ModelUtility" -> 0.17038607405888706`, "TrainingSize" -> 252, 
           "TrainingTime" -> 1., "TrainingMemory" -> 522912, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.548808937653322, 0.12985375277871486`]}, 
           "StandardDeviationHistory" -> {
             Around[0.40888232000837493`, 0.045158858385380383`]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 100, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 195468468841893]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.0488376764720893`, 0.38610390073213546`], 
                "StandardDeviation" -> 
                Around[0.5726401799301253, 0.02982109323080884], 
                "EvaluationTime" -> 0.0001497747329571884, "TestSize" -> 305, 
                "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.14604298570026086`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.7943282347242815, "TrainingMemory" -> 
                424720, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.0488376764720893`, 0.27301668645027055`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5726401799301253, 0.02108669724590118]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[10.593574928638247`, 1.7834523752480744`], 
                "StandardDeviation" -> 
                Around[0.48625063548411623`, 0.035270501921745724`], 
                "EvaluationTime" -> 0.0001430034169695532, "TestSize" -> 265, 
                "ModelMemory" -> 99880, "ModelUtility" -> 
                0.013448907110655495`, "TrainingSize" -> 50, "TrainingTime" -> 
                0.6309573444801932, "TrainingMemory" -> 428688, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[10.593574928638247`, 1.2610912684611686`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.48625063548411623`, 0.024940011084719556`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5548226455233197, 0.18169804886179003`], 
                "StandardDeviation" -> 
                Around[0.4138922482743449, 0.07003157493930268], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.15568974135075286`, "TrainingSize" -> 252, "TrainingTime" -> 
                1.9952623149688797`, "TrainingMemory" -> 451592, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5548226455233197, 0.12847992247853637`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4138922482743449, 0.049519801536754796`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00025157034800970054`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.4138922482743449, 0.07003157493930268], 
               "TrainingMemory" -> 451592, "TrainingTime" -> 
               3.288406128435381], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.279395996806326, 0.37959232778227553`], 
                "StandardDeviation" -> 
                Around[0.6016512556560507, 0.029714235632782894`], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.19493289571043593`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495648, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.279395996806326, 0.2684123090612337]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6016512556560507, 0.021011137513715725`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[6.500186855603132, 1.2062321492393557`], 
                "StandardDeviation" -> 
                Around[0.44303937909352764`, 0.03393384722624111], 
                "EvaluationTime" -> 0.00015459545750832804`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.10571300344007384`, "TrainingSize" -> 50, "TrainingTime" -> 
                1.5848931924611136`, "TrainingMemory" -> 499488, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[6.500186855603132, 0.8529349324123721]}, 
                "StandardDeviationHistory" -> {
                  Around[0.44303937909352764`, 0.023994853485423403`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5576772778911215, 0.21138162202581326`], 
                "StandardDeviation" -> 
                Around[0.4115600174281535, 0.07142097107597595], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 0.1605003518431054,
                 "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
                "TrainingMemory" -> 522584, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.5576772778911215, 0.14946937835266422`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4115600174281535, 0.05050225296675086]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4115600174281535, 0.07142097107597595], 
               "TrainingMemory" -> 522584, "TrainingTime" -> 
               7.849733612802018], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[11.041888067974385`, 1.8445532643598586`], 
                "StandardDeviation" -> 
                Around[0.4855810517001665, 0.03557534184321448], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.014683441206255976`, "TrainingSize" -> 50, "TrainingTime" -> 
                1.5848931924611136`, "TrainingMemory" -> 428688, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[11.041888067974385`, 1.3042961214886384`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4855810517001665, 0.02515556546036649]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00012279953685898285`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.4855810517001665, 0.03557534184321448], 
               "TrainingMemory" -> 428688, "TrainingTime" -> 
               6.577306748713622], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.7796094043113115`, 0.3391038645567568], 
                "StandardDeviation" -> 
                Around[0.4505950724993449, 0.03123854820647034], 
                "EvaluationTime" -> 0.00015633372739584048`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.09023486310735429, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 499632, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.7796094043113115`, 0.23978264215464726`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4505950724993449, 0.022088989271218037`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.548808937653322, 0.18364093830470155`], 
                "StandardDeviation" -> 
                Around[0.40888232000837493`, 0.0638642699898909], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.17038607405888706`, "TrainingSize" -> 252, "TrainingTime" -> 
                1., "TrainingMemory" -> 522912, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.548808937653322, 0.12985375277871486`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.40888232000837493`, 0.045158858385380383`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[2.7048315872041195`, 0.3027115387750156], 
                "StandardDeviation" -> 
                Around[0.5714579902608481, 0.026595521133767897`], 
                "EvaluationTime" -> 0.0001497747329571884, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.14288169402484607`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                495456, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.7048315872041195`, 0.21404938181122804`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5714579902608481, 0.018805873342877415`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0001497747329571884, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.5714579902608481, 0.026595521133767897`], 
               "TrainingMemory" -> 495456, "TrainingTime" -> 
               1.6521447577970134`], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 195464173874597]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 8.4066666666667`1.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097568372604264`17.333472246303792*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 2.5573760929366296`, 
            "ElapsedTimes" -> 3.0657975, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 4.262293488227715, 
            "ElapsedTimes" -> 4.8510178, "ExperimentCounts" -> 4], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 7.103822480379525, 
            "ElapsedTimes" -> 8.9291081, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 195477058776485]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{-10.81468744341777, 
              4.0530403824280565`, -5.995407601384168, 0., 
              3.912023005428146}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 17.5791483, 
        "MaxTrainingMemory" -> 932632, "DataMemory" -> 75768, 
        "FunctionMemory" -> 270056, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 47, 17.2893494`8.990353593827228}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {-0.18759691876557874`, -0.115148957104377, 
                    0.03171426831017434, 0.5333333333333333, 
                    4.008299489077854}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.18759691876557874`, -0.115148957104377, 
                    0.03171426831017434, 0.5333333333333333, 
                    4.008299489077854}, 
                    "StandardDeviation" -> {7.407797765413257, 
                    4.402328045513056, 4.135468532351013, 
                    0.49888765156985887`, 1.336578067043575}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{
                    0.4744474248581376, -0.48846096444023257`, \
-0.18575574351712132`, 0.6890289828884549, 0.16443658885327894`}, {
                    0.2498219730947369, 
                    0.5164142345402359, -0.7350574728907217, 
                    0.08000983107269274, -0.3524120579697855}, \
{-0.2605968590501811, -0.5808732847476661, -0.6176394316359168, \
-0.43548246977139876`, 
                    0.1534667883612019}, {-0.5876262538600932, \
-0.22274406758722876`, 0.005977273611333584, 
                    0.4065840953279059, -0.6631245069786016}, \
{-0.5470587588477749, 0.3281669270409396, -0.20897636226746769`, 
                    0.4048232696123231, 0.6208705040169673}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.18759691876557874`, -0.115148957104377, 
                    0.03171426831017434, 0.5333333333333333, 
                    4.008299489077854}, 
                    "StandardDeviation" -> {7.407797765413257, 
                    4.402328045513056, 4.135468532351013, 
                    0.49888765156985887`, 1.336578067043575}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0194512, "MaxTrainingMemory" -> 93000, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 47, 17.3232593`8.991204548881855}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.18759691876557874`, -0.115148957104377, 
                0.03171426831017434, 0.5333333333333333, 4.008299489077854}, 
               "StandardDeviation" -> {7.407797765413257, 4.402328045513056, 
                4.135468532351013, 0.49888765156985887`, 1.336578067043575}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.372295622099715}, 
               "StandardDeviation" -> {0.7086779547230512}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.372295622099715 + 
         0.7086779547230512 #& ), 
        "ProcessorFunction" -> (3.3474945936857874` + 
         1.4110781820365732` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.4916243317369844`, 2.447621052057493}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViXsw1WkYgJXLuOUWQ2lzv4U1Kwn5vV+tLFlZjrGNYU2HiBIl1iGbVcM6
xJFNTGdYBttg0boclvO9H8mSy7TIqlWzTsyy24nkklJj64/nmXnmMYtM5MVs
V1BQuKj6QTx+6pGkJH5asMrHiObH73eO/zidP6D8gV6hHmnrvwJeimlI+VsQ
+Rq5mO180LItRa++ApBSHio/LWLFIkfa8ekJ7sWdYxh0w4Qtz21xS9ZGh+Yf
H4eUfRVcrNOqx6OyLtq0UoF2M0rk7oUjeHlCAO1n8vEvszrquDwLfSUHsMLS
A20FOrAw9Quc+CaehZaexGNxt1AxWgWqZsLQP1+E9dFHPR5E/QDSlP2cRKMN
traVY2LtFVLZpYsjfD8YOngfT4fnML5OBprNXMWGKCEuG/8JkzW7yZpzBPJH
7iF3eydRicuDupcGsCtmjLa8l3Vbe0+jwsJ1dPq3DgN6eSQsuxRjZ3LZZ4E1
4DA1CYO33NE0Jhc2ZXuIrVwPVPNMuOIAH3b662Loau3ELCUJarlscfbVPrQj
+BKOpyqyHHNf8pVpHVrliqGk6wBdFFxmJ3OT2M4MAXYtZ4NrwDD1FskhyP4h
tVjxIyZiiiIdHoSIUsHwRRaEcyOoGfMQ+suy4O+4JkxW6QGhcMSTRopQbGNF
qnzsuNTRPJyVa7HF/E7I7r0rjUzfxCeGvkyeL6PtltnoM+zOvi0SoL4mgvY/
VlQvqhrqexrh7aiQrKm9gi+DvqeHLfzJ7z8qcXnXCmAz8ywGLe2CDeU5MB1V
Y+NF1/CsmSsTlCawMZkcaiqq0TD5KdjbF2PLH2641ygVJ4Zl1GH9Hpe1rgka
75zI2H0DYm0vwVrZJNfcEorX9XPwkks5eGc2YVXGNPSva7BBPVMabnmEhBWO
Yo+PhBtxC8QvrthJHSuSWRe/knui0Ujc7HRJp2cwM1iyhXr+BFeqZk4Sm4dh
cKEM8IyYDlhVwoWWaox5VM+1bviyN77qbOicHDtUcw+txRVDuncoPG8YAu0l
AXs20Q6Pgzppt+9JHNP5hBw2G+h+ezOCCDR0yXcmYpQ5v8N0aTjyMnvQrsaI
iCUTnnPnbNhUxyJe1/ZCnuoKaMyKuhVXC9HqlD7Ze6yEe9A6wkkWQrjcTT94
Fe6OLxXNGe+gOkvQuo3jPXsgZKAZd0gsYOy/QvJeMiXNmxR6TlbuA/I6n/pH
/4opN5OgT0XISlznITvxDkDmDnbeqBZWJ2LpUcM+GqjmQ5lxO2xoN1Ln+QYw
+bmAWRbVSo8nDOLzNDc2GWvHlhqsSWrKGpQnRxDzoELstXkDwRYrdDrSiRjf
S4SqS88g8/xvOHVRnTa2fU5O7b6BV4N/Ii7b+iHHwQkMB/aS/wEsKvrz
                    "], "Biases" -> 
                    RawArray["Real32",{0.008934367448091507, 
                    0.06017737463116646, 
                    0.019792893901467323`, -0.08230657130479813, 
                    0.02527426928281784, -0.027939535677433014`, \
-0.02601640671491623, 0.026250945404171944`, -0.023618297651410103`, 
                    0.08638308942317963, -0.026954295113682747`, \
-0.06809969246387482, 0.008470884524285793, -0.04517268016934395, 
                    0.001812278525903821, -0.04212582856416702, 
                    0.08534365892410278, 
                    0.03276048228144646, -0.09986679255962372, 
                    0.00004938898200634867, -0.007471783552318811, 
                    0.04405602067708969, -0.019232792779803276`, \
-0.023225877434015274`, -0.004839747678488493, -0.03697642311453819, 
                    0.0319499671459198, 0.010784202255308628`, 
                    0.006204338278621435, 
                    0.05018668994307518, -0.02327118068933487, \
-0.004113288596272469, -0.012035518884658813`, -0.07849542796611786, 
                    0.021161619573831558`, -0.004662989638745785, 
                    0.05177481472492218, 
                    0.0026162704452872276`, -0.020157095044851303`, \
-0.00667335232719779, 0.07433824241161346, 
                    0.07812361419200897, -0.014907690696418285`, 
                    0.045323099941015244`, 
                    0.05842813104391098, -0.0058043599128723145`, \
-0.018075674772262573`, -0.003081794362515211, -0.048382747918367386`, 
                    0.016580061987042427`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3lQz+/XxkshWmlRKEm0EJIWfd7nRKKFQsgW0SZk+8qSrUV7UUlClEhJ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                    "], "Biases" -> 
                    RawArray["Real32",{0.02640034258365631, 
                    0.0034802821464836597`, 
                    0.0192875899374485, -0.024774130433797836`, \
-0.019389713183045387`, -0.04078267142176628, 
                    0.02512948587536812, -0.00009695460903458297, \
-0.009315119124948978, -0.04157246649265289, -0.007842653430998325, \
-0.029101813212037086`, 
                    0.0027870365884155035`, -0.010025774128735065`, \
-0.004463827703148127, 0.02375885657966137, 0.026843667030334473`, 
                    0.013735456392168999`, 
                    0.050510820001363754`, -0.03692056983709335, \
-0.04464295506477356, 0.02209194377064705, 0.0318228118121624, 
                    0.0012393980287015438`, 
                    0.018028851598501205`, -0.0345778688788414, \
-0.042602453380823135`, -0.06475616246461868, -0.10724855959415436`, \
-0.005779804661870003, 0.001093213097192347, 
                    0.006624023430049419, -0.01754714734852314, \
-0.026936938986182213`, -0.006036600563675165, -0.025355475023388863`, 
                    0.04504503682255745, 
                    0.026115532964468002`, -0.0246712826192379, \
-0.0018326081335544586`, -0.06176421046257019, -0.029304957017302513`, 
                    0.0020021451637148857`, -0.004467777907848358, \
-0.012912316247820854`, 
                    0.007247322704643011, -0.029927309602499008`, \
-0.007675454951822758, 0.032251663506031036`, -0.0039210813120007515`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dYz+/3xxvaRhGKSItEUWm+X+dImZV2SlZFyZZoWC3aIVESkaymFan3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                    "], "Biases" -> 
                    RawArray["Real32",{-0.020639672875404358`, 
                    0.019136331975460052`, -0.008708317764103413, 
                    0.08675595372915268, 
                    0.025088468566536903`, -0.025191204622387886`, \
-0.038346655666828156`, 0.02088790200650692, 
                    0.05260312929749489, -0.03635010868310928, \
-0.027707194909453392`, -0.002709144027903676, 
                    0.06567339599132538, -0.005207874812185764, 
                    0.007644379511475563, 
                    0.012325834482908249`, -0.00990070030093193, \
-0.02430487796664238, -0.030956173315644264`, -0.013676096685230732`, \
-0.004059114493429661, 0.0554959736764431, 0.04017866775393486, 
                    0.0376562736928463, -0.0032853782176971436`, 
                    0.019990159198641777`, 0.022161871194839478`, 
                    0.013624753803014755`, 0.06084254011511803, 
                    0.024590397253632545`, -0.01575588621199131, \
-0.005985495634377003, -0.04032890871167183, 
                    0.020415762439370155`, -0.010493950918316841`, \
-0.00507732667028904, -0.026741504669189453`, -0.035385482013225555`, 
                    0.019736003130674362`, -0.0031734248623251915`, \
-0.018358172848820686`, -0.024246837943792343`, -0.01946725696325302, 
                    0.057794567197561264`, -0.0072385407984256744`, 
                    0.012908591888844967`, 0.06808605045080185, 
                    0.022634562104940414`, -0.004142239224165678, 
                    0.06761779636144638}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtV3dUz//3TyppUamUUkaTEkXj/boXJaSUBiqrjIYRMpPRotIuZDSsSEiR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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.01305316761136055, -0.014188561588525772`, \
-0.0031370683573186398`, 0.026547126471996307`, -0.01662496291100979, 
                    0.01711839623749256, -0.010974296368658543`, \
-0.004276732448488474, -0.011030230671167374`, -0.020983990281820297`, 
                    0.01684209331870079, -0.03861277177929878, \
-0.018684709444642067`, -0.005495419260114431, 0.01977156288921833, 
                    0.05682998523116112, 0.022417251020669937`, 
                    0.011882009916007519`, 0.04805576428771019, 
                    0.02391742542386055, -0.013085860759019852`, \
-0.005822343286126852, 0.003786746645346284, 0.022849008440971375`, 
                    0.008603250607848167, 
                    0.003549157874658704, -0.04470667243003845, 
                    0.037042777985334396`, -0.003534050425514579, 
                    0.022301070392131805`, -0.023686036467552185`, 
                    0.007645869627594948, 0.02815929800271988, 
                    0.01879492960870266, -0.03212076053023338, \
-0.014522499404847622`, 
                    0.0026656538248062134`, -0.0038022371008992195`, \
-0.04814721643924713, -0.017989031970500946`, -0.02529163286089897, 
                    0.025131937116384506`, -0.0034532444551587105`, \
-0.00404493510723114, -0.007339701987802982, 
                    0.06575274467468262, -0.000028945927624590695`, \
-0.020886611193418503`, 0.01119307242333889, -0.008502502925693989}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{-0.1879662573337555, 
                    0.1072503924369812, 
                    0.022467896342277527`, -0.12503959238529205`, \
-0.17603950202465057`, 0.12168888747692108`, 
                    0.07163219898939133, -0.037538085132837296`, 
                    0.23230138421058655`, 
                    0.14981630444526672`, -0.05018230900168419, 
                    0.19978775084018707`, 0.1070965826511383, 
                    0.2000676393508911, -0.0669052004814148, \
-0.07581960409879684, -0.13067948818206787`, -0.27795344591140747`, \
-0.051367465406656265`, 0.04488769918680191, 0.23437528312206268`, 
                    0.03640049695968628, 0.1784161627292633, 
                    0.020353304222226143`, -0.009584734216332436, \
-0.23062242567539215`, -0.04712652042508125, -0.03866029903292656, \
-0.022420693188905716`, 0.14653412997722626`, 
                    0.10639366507530212`, -0.14205005764961243`, 
                    0.18082787096500397`, 
                    0.0246407650411129, -0.05665576085448265, 
                    0.11262228339910507`, -0.14458441734313965`, \
-0.27887487411499023`, 0.025314390659332275`, 0.10929932445287704`, 
                    0.020128721371293068`, 0.10902076214551926`, 
                    0.429317444562912, 
                    0.13968834280967712`, -0.03006848134100437, \
-0.08019664138555527, -0.24704962968826294`, 
                    0.23909379541873932`, -0.03480904921889305, \
-0.01850632019340992}}], "Biases" -> 
                    RawArray["Real32",{-0.0029902812093496323`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association["Array" -> RawArray["Real32",{-0.52606600522995}]],
                "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 0.5297419, "MeanInputsPerSecond" -> 
          48325.42036036795], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.05882561852674986, -0.019900744504348214`, 
                0.03685545523161221, -0.027310430861184808`, \
-0.01965553885720857}, 
               "StandardDeviation" -> {1.0478791018545242`, 0.992279743534539,
                 1.0154418871329955`, 1.0016439940127218`, 
                1.0019094474895238`}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 6782895645784446440]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 100, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[362929], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3443540802914145, "PreprocessingTime" -> 
        0.3853235`7.037370489944999, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.5237947425286652, 0.12305392054144614`], 
           "StandardDeviation" -> 
           Around[0.4021486123632836, 0.05753945375446008], "EvaluationTime" -> 
           0.00019982943044351853`, "TestSize" -> 63, "ModelMemory" -> 99880, 
           "ModelUtility" -> 0.1895400238517848, "TrainingSize" -> 252, 
           "TrainingTime" -> 0.7943282347242815, "TrainingMemory" -> 451528, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.5237947425286652, 0.08701226166644715]}, 
           "StandardDeviationHistory" -> {
             Around[0.4021486123632836, 0.040686537935548474`]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 100, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 211909603650996]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.0476366336570795`, 0.5212614409482709], 
                "StandardDeviation" -> 
                Around[0.6874531938631788, 0.037994276868372555`], 
                "EvaluationTime" -> 0.0001444183103262347, "TestSize" -> 305, 
                "ModelMemory" -> 99880, "ModelUtility" -> -0.3294107276771556,
                 "TrainingSize" -> 10, "TrainingTime" -> 0.3981071705534972, 
                "TrainingMemory" -> 424848, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[4.0476366336570795`, 0.3685874996655934]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6874531938631788, 0.026866010819905414`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[11.914083525146694`, 1.5548417875775196`], 
                "StandardDeviation" -> 
                Around[0.6528978874376021, 0.038623550071085075`], 
                "EvaluationTime" -> 0.00015633372739584048`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.2786067256809861, "TrainingSize" -> 50, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                428688, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[11.914083525146694`, 1.0994391716682774`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6528978874376021, 0.027310974168762416`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5237947425286652, 0.12305392054144614`], 
                "StandardDeviation" -> 
                Around[0.4021486123632836, 0.05753945375446008], 
                "EvaluationTime" -> 0.00019982943044351853`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 0.1895400238517848,
                 "TrainingSize" -> 252, "TrainingTime" -> 0.7943282347242815, 
                "TrainingMemory" -> 451528, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.5237947425286652, 0.08701226166644715]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4021486123632836, 0.040686537935548474`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00019982943044351853`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.4021486123632836, 0.05753945375446008], 
               "TrainingMemory" -> 451528, "TrainingTime" -> 
               1.391017463958849], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[19.886479639508046`, 2.2893758993822764`], 
                "StandardDeviation" -> 
                Around[0.64068044363125, 0.03447398871001288], 
                "EvaluationTime" -> 0.00007748126967994144, "TestSize" -> 265,
                 "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.2586589167069485, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.2589254117941673`, "TrainingMemory" -> 
                428688, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[19.886479639508046`, 1.6188332231382587`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.64068044363125, 0.024376791191398586`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00007748126967994144, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.64068044363125, 0.03447398871001288], 
               "TrainingMemory" -> 428688, "TrainingTime" -> 
               5.224540458945794], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.11797174182639, 0.5899376557469401], 
                "StandardDeviation" -> 
                Around[0.6218937653490413, 0.038234075037387696`], 
                "EvaluationTime" -> 0.000180876792628248, "TestSize" -> 265, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.23041617533751324`, "TrainingSize" -> 50,
                 "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                499680, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.11797174182639, 0.4171489168559564]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6218937653490413, 0.027035573731332137`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.000180876792628248, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.6218937653490413, 0.038234075037387696`], 
               "TrainingMemory" -> 499680, "TrainingTime" -> 
               1.6521447577970134`], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.211588625227671, 0.40681735948045267`], 
                "StandardDeviation" -> 
                Around[0.6635085677761015, 0.0347031928182412], 
                "EvaluationTime" -> 0.0001550077694574061, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.29337377858775493`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495600, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.211588625227671, 0.2876633135930335]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6635085677761015, 0.024538862970602645`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[12.683955358564567`, 1.5419026655730663`], 
                "StandardDeviation" -> 
                Around[0.5862332804249452, 0.0324723302194772], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.1701610023015433, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499552, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[12.683955358564567`, 1.0902898307563285`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5862332804249452, 0.022961404899121178`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5485792684290938, 0.14629927372231855`], 
                "StandardDeviation" -> 
                Around[0.4124536911639545, 0.05990573357710134], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.16381557906237398`, "TrainingSize" -> 252, "TrainingTime" -> 
                6.309573444801933, "TrainingMemory" -> 522664, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5485792684290938, 0.10344920853171831`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4124536911639545, 0.04235975044432301]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00025157034800970054`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4124536911639545, 0.05990573357710134], 
               "TrainingMemory" -> 522664, "TrainingTime" -> 
               9.471859998463529], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 211905308683700]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.0000166063636363637`3., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097568510678656`17.333472247877772*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.9499419062277346`, 
            "ElapsedTimes" -> 2.3097524000000003`, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 3.249903177046225, 
            "ElapsedTimes" -> 4.2506262, "ExperimentCounts" -> 4], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 5.416505295077041, 
            "ElapsedTimes" -> 6.9643649, "ExperimentCounts" -> 2]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 211918193585588]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{9.654463080833843, -4.444024296716794, 
              3.4225881955038027`, 1., 5.298317366548036}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 14.2754663, 
        "MaxTrainingMemory" -> 979000, "DataMemory" -> 75768, 
        "FunctionMemory" -> 258104, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 47, 31.565533`9.251788031613943}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.2199454322323976, -0.1764151266221364, 
                    0.13218182715306545`, 0.4857142857142857, 
                    3.7799026394952184`}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.2199454322323976, -0.1764151266221364, 
                    0.13218182715306545`, 0.4857142857142857, 
                    3.7799026394952184`}, 
                    "StandardDeviation" -> {7.044081142415497, 
                    4.392872807174989, 4.258432196106646, 
                    0.49979587670102577`, 1.3964414082899055`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{0.19790164477202737`, -0.6290433215564143, 
                    0.30499544326461137`, 
                    0.49063013104544617`, -0.48103980365449006`}, \
{-0.04429529870009254, 0.5449468479081099, 0.8105570496409207, 
                    0.006968350118042829, -0.20980841461229177`}, {
                    0.6484875040880368, 
                    0.11393993648831197`, -0.17099098548803193`, \
-0.5178154264542701, -0.5187590143048326}, {-0.708003163326399, 
                    0.04154168675005226, -0.23301787076746217`, \
-0.1515208502982838, -0.6478810946536846}, {0.19253140853138104`, 
                    0.5409523192438398, -0.40797034653275843`, 
                    0.6842091293294966, -0.1889981712232903}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.2199454322323976, -0.1764151266221364, 
                    0.13218182715306545`, 0.4857142857142857, 
                    3.7799026394952184`}, 
                    "StandardDeviation" -> {7.044081142415497, 
                    4.392872807174989, 4.258432196106646, 
                    0.49979587670102577`, 1.3964414082899055`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0244198, "MaxTrainingMemory" -> 93048, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 47, 31.6223808`9.252569468791545}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.2199454322323976, -0.1764151266221364, 
                0.13218182715306545`, 0.4857142857142857, 
                3.7799026394952184`}, 
               "StandardDeviation" -> {7.044081142415497, 4.392872807174989, 
                4.258432196106646, 0.49979587670102577`, 1.3964414082899055`},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.3612114174459227`}, 
               "StandardDeviation" -> {0.7222997211226054}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.3612114174459227` + 
         0.7222997211226054 #& ), 
        "ProcessorFunction" -> (3.2690188690314104` + 1.38446682278347 #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-2.900552464618383, 2.4636881805552857`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX001XccgBFi5WVkqLVTrrqYvL+e6/f5Jq9LdGK4q1tyHWJ521WHhrqZ
OM1Fu3k5XieFM10m78b382VdM5OSYThOpunMcayardU0mv54nnOe8+wVJwXH
qKmoqKRobSo4MtVTIom8EKL5NqIj4x0d4t9Oh000Nhk05hHTxSrYSJBiztka
0jukzrJETwT+zRwESOPZtlQNJrZVotD9a1aakQ7OWoTdcskkw00yMntYj+hk
m4BiawULt3EmgTvc0LKiEN4X7Af9JGMmj/ED2Y18bu38GH4Y9BfoTRbh+Pdl
UPInE7RK9Zly7BIcX3Uhd5p9qWuYL/d5vC2JuxtIXg8foJXyVHSU+3Dnpr+h
qXMqZL91CUTcsyUhWkep2LuWquT2owX/GW39oRRkknbs7CyG4cBG7pNuBVHo
rXm83hAy6awpVzreTpORT2IKJrDe8zHwaB4X4WeOxgli+mIjGw+1GBPRAwMW
EK1GJmtUWOyud9nomwLoOzJH+91EbHDlOjj5BuNMrCFZX/2U1K9bsCxLIRsT
zWNLyhB6OiYgq0tjr6O0maJNE5ajOumCcI7radxBfjEaJkfxBhSdCER1fhnU
pAswUeNHdO3LI3kBVcS8owvcTeepn30rnLocDWlePDLI6ZGEJitSK6/n1rpH
ON2anfjr+Q64JpOwqJoeKN9bC6LJPoGF9RXwtauHUDUp1h3mg6rXAup255Cc
+Tj87XERjETsgmqRNeo0LBLrGF12cQsP7BwE3IriLAoN1eH+wHW2FDvAJcQ+
5lqXO7EuroHISovozjpgKQENVLnkAqd8rKlLkBaR+PyL5mI3vP0iCzru/sOt
lkyA6/H3iNzoGujc3kqcbWTUMd+MaH8VBV5hxShPCYFjV9TYrYVOTluQBZbP
PVhXvx3LXbTFVPkrLBo8B1q5h5iPXRbN3G6HtTeH+h6FGLDfBftAt9sDHYzN
YWrmBEkuMCSiZntS6JSHle9Qbjo/j7ilcuBf+Ybzdn9ElQ+CWLimKtPcnQgt
Ew9xXEudSAKmUJlpQtTWvoP4cCHX5mPD3nhNwQcds7BPGQmGXxQRT39tynSk
qBoah33l99HxWA5RjAiJL38XDK88xyUns14vyyH0djeBv+0dWLsolMR9KWFG
8lJuXdOSKTLTsNqwjSScVOLBe1NUnV/pERhTDFW7K2hyXS6UnZ6DM8tHsEV7
A7Y/OcOmj/FY4t6nEHbVAJpKexlvhmNO2a9QtykROvaYYZIyHVpXPkOZazY3
3Hy696OMn7F2QJt9e+EObXz5FEdfVtOpAw+5lIGrzKRczC67boH/KrPRqreQ
jVoNkeCegySj+ieWeHM3c7vyMbm4TYr00h94Ul+fPAvuwsnxavgfFEfkNQ==

                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.16798801720142365`, -0.0571635477244854, 
                    0.008352573029696941, 0.1350194811820984, 
                    0.06860601156949997, 
                    0.0068525634706020355`, -0.11918018013238907`, 
                    0.0973631963133812, -0.06989268958568573, \
-0.029055414721369743`, -0.15258364379405975`, 0.007717078551650047, 
                    0.02295723743736744, -0.03598048537969589, 
                    0.02038639225065708, -0.25827756524086, \
-0.1204037293791771, 0.1799176186323166, 
                    0.07597064971923828, -0.10381383448839188`, \
-0.10444506257772446`, 
                    0.10227497667074203`, -0.05696207284927368, \
-0.20436885952949524`, -0.014775066636502743`, 
                    0.12786218523979187`, -0.007381260860711336, 
                    0.06414413452148438, -0.012626309879124165`, \
-0.26507073640823364`, -0.18495267629623413`, -0.058068182319402695`, \
-0.17273235321044922`, 
                    0.059587512165308, -0.007257513701915741, \
-0.21498802304267883`, 0.040534406900405884`, 
                    0.002656527329236269, -0.10330870002508163`, \
-0.04570503160357475, -0.32125866413116455`, -0.1277991682291031, \
-0.11942896246910095`, 
                    0.0749429240822792, -0.06533616781234741, \
-0.15903745591640472`, -0.03725222125649452, -0.06043797358870506, \
-0.0037821978330612183`, -0.2590477168560028}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c014/3x7Mq0SLJSnaLSgvv170qKRJpiTQQqk+KoqUlOyuzIUka0rAr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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.008338474668562412, -0.09253893047571182, \
-0.1261073797941208, -0.13166853785514832`, -0.08510199934244156, \
-0.17583224177360535`, 0.018999023362994194`, -0.1543598771095276, 
                    0.013394147157669067`, -0.1295062005519867, \
-0.06338728219270706, -0.11001741141080856`, -0.07337434589862823, \
-0.07839538902044296, -0.010750174522399902`, -0.0321485809981823, \
-0.09096059203147888, -0.00073569908272475, 
                    0.21007958054542542`, -0.07051661610603333, 
                    0.03533736616373062, -0.055966392159461975`, \
-0.045466650277376175`, -0.0034261373803019524`, -0.08977439254522324, \
-0.14090386033058167`, 0.05104832723736763, 
                    0.09680506587028503, -0.046792685985565186`, \
-0.13727642595767975`, 
                    0.008638313040137291, -0.1466328501701355, \
-0.06586246192455292, -0.15306301414966583`, -0.09763260930776596, \
-0.02609591744840145, 
                    0.07718916237354279, -0.1333298683166504, \
-0.02622729353606701, -0.0770890936255455, -0.005260053090751171, \
-0.18259954452514648`, -0.0778609961271286, -0.12645836174488068`, \
-0.02432023175060749, -0.10452841222286224`, -0.0487259216606617, \
-0.03818816691637039, -0.1037069708108902, 0.005431976169347763}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJw1l2k0l4/Txu0iZE2IkqJVsqR875mQFqVdpYSEqITS7kdFqVCIJFFJRVQk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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.026186954230070114`, -0.017195679247379303`, \
-0.03588709235191345, -0.004755258560180664, -0.06743607670068741, \
-0.09048894792795181, 
                    0.015227540396153927`, -0.03278021514415741, \
-0.06587295979261398, -0.032916851341724396`, -0.08409146964550018, \
-0.14208944141864777`, -0.10669207572937012`, -0.1780037134885788, 
                    0.06840703636407852, -0.10960360616445541`, 
                    0.04756602644920349, -0.12517814338207245`, \
-0.004405707586556673, 
                    0.0005613808752968907, -0.04907872527837753, \
-0.1322375237941742, -0.05557956174015999, -0.142596036195755, \
-0.06704360246658325, 
                    0.004310688469558954, -0.144998699426651, \
-0.06587386131286621, 
                    0.10539962351322174`, -0.09429466724395752, \
-0.020833604037761688`, -0.08294740319252014, -0.015284514985978603`, \
-0.022148191928863525`, 0.049067966639995575`, 
                    0.05304164066910744, -0.055991172790527344`, \
-0.07223308086395264, -0.025487447157502174`, 
                    0.024298982694745064`, -0.02920001558959484, 
                    0.011741247959434986`, -0.028413530439138412`, 
                    0.05139850452542305, -0.1745680570602417, \
-0.03649285063147545, -0.1463056206703186, 
                    0.04662652313709259, -0.06301172077655792, \
-0.06094936281442642}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2k01v/TgEX27IRCliSlxZa4vzOhRVpUoigVLdpooaKFUihFKSQVKSSK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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.029984096065163612`, -0.01501714438199997, \
-0.029602713882923126`, -0.026768632233142853`, -0.08707591891288757, 
                    0.03592248260974884, 0.01799744740128517, 
                    0.013789525255560875`, 0.016388511285185814`, 
                    0.01638071797788143, -0.02253972925245762, 
                    0.05512424558401108, 0.009665731340646744, 
                    0.030023451894521713`, -0.057952575385570526`, \
-0.01566123031079769, -0.0040742927230894566`, -0.06281504780054092, 
                    0.06628453731536865, 0.01385607197880745, 
                    0.014813829213380814`, 
                    0.027730261906981468`, -0.012829751707613468`, \
-0.0058312914334237576`, 0.0010523989330977201`, 0.02587554231286049, 
                    0.052877508103847504`, -0.00768838869407773, \
-0.03445788845419884, -0.01640786975622177, 0.07406559586524963, 
                    0.05123766139149666, 
                    0.045108772814273834`, -0.0589623749256134, \
-0.04075250402092934, -0.00463675195351243, -0.005404480267316103, 
                    0.028796549886465073`, -0.08413241803646088, \
-0.04774066060781479, -0.0036896527744829655`, 0.017425905913114548`, 
                    0.02838650904595852, 0.05380021780729294, 
                    0.0013227902818471193`, 0.0831013023853302, 
                    0.0021757271606475115`, -0.051214344799518585`, \
-0.015213659964501858`, -0.041020240634679794`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray[
                    "Real32",{{-0.14380691945552826`, -0.05055857077240944, 
                    0.054303787648677826`, 0.09840547293424606, 
                    0.06576219201087952, 0.08082980662584305, 
                    0.21963906288146973`, -0.02905287966132164, \
-0.0011380026116967201`, 
                    0.06761963665485382, -0.0018149755196645856`, \
-0.06593120098114014, 
                    0.1530655175447464, -0.0684346854686737, \
-0.06939098238945007, -0.13423140347003937`, -0.2055799514055252, 
                    0.06677967309951782, -0.05969635024666786, \
-0.10756976902484894`, -0.07467242330312729, -0.07081309705972672, 
                    0.0008826432749629021, 0.08038798719644547, 
                    0.19147124886512756`, -0.18630072474479675`, \
-0.10637389123439789`, -0.29733750224113464`, -0.00014683307381346822`, 
                    0.09532035142183304, -0.06028399616479874, 
                    0.008518369868397713, -0.32771897315979004`, 
                    0.1276182383298874, 0.022163623943924904`, 
                    0.05139277130365372, -0.05467528477311134, \
-0.024046041071414948`, 0.10891281068325043`, 
                    0.022925350815057755`, -0.13180746138095856`, 
                    0.06238684803247452, 0.03353572636842728, 
                    0.22519280016422272`, -0.026988161727786064`, \
-0.1250624805688858, 0.11248085647821426`, 0.0692424401640892, 
                    0.1131386011838913, 0.1052950918674469}}], "Biases" -> 
                    RawArray["Real32",{-0.015915988013148308`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-1.2230398654937744`}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.3766546, "MeanInputsPerSecond" -> 
          47613.25006817436], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.0334226038913223, -0.011022120524956857`, 
                0.030973774104587848`, 0.04402821618088736, 
                0.05277394530329653}, 
               "StandardDeviation" -> {0.9694315124994303, 1.02905470203117, 
                0.9922360227833651, 1.0003808453909682`, 0.9829102513864603}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 1029524590084133981]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[363041], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3253151000217618, "PreprocessingTime" -> 
        0.4304127`7.0854300708814115, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.2909973960765214, 0.3054435062080107], 
           "StandardDeviation" -> 
           Around[0.3037192721044823, 0.05918331910382758], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 107736, 
           "ModelUtility" -> 0.4602379637440581, "TrainingSize" -> 252, 
           "TrainingTime" -> 6.309573444801933, "TrainingMemory" -> 522584, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.2909973960765214, 0.21598117450907967`]}, 
           "StandardDeviationHistory" -> {
             Around[0.3037192721044823, 0.04184892627144382]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 267370516344260]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.240714288202744, 0.5372084701182861], 
                "StandardDeviation" -> 
                Around[0.6821928340533085, 0.0379928489420521], 
                "EvaluationTime" -> 0.00012551194090250548`, "TestSize" -> 
                305, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.32181504245309756`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495728, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.240714288202744, 0.3798637521314908]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6821928340533085, 0.026865001123521186`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[7.937530451635011, 1.4971882076250922`], 
                "StandardDeviation" -> 
                Around[0.576303808444173, 0.047556974944454364`], 
                "EvaluationTime" -> 0.00015459545750832804`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.15843022026370124`, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499616, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[7.937530451635011, 1.0586719343242352`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.576303808444173, 0.033627859475942413`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.2909973960765214, 0.3054435062080107], 
                "StandardDeviation" -> 
                Around[0.3037192721044823, 0.05918331910382758], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 0.4602379637440581,
                 "TrainingSize" -> 252, "TrainingTime" -> 6.309573444801933, 
                "TrainingMemory" -> 522584, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.2909973960765214, 0.21598117450907967`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3037192721044823, 0.04184892627144382]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.3037192721044823, 0.05918331910382758], 
               "TrainingMemory" -> 522584, "TrainingTime" -> 
               9.471859998463529], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.6739030055970203`, 0.3486836874157632], 
                "StandardDeviation" -> 
                Around[0.5537971894396945, 0.02972070671329046], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.11289877727424369`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                424720, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.6739030055970203`, 0.2465565998608166]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5537971894396945, 0.02101571325862423]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.920397109947666, 0.3637445822519835], 
                "StandardDeviation" -> 
                Around[0.5062125190938611, 0.03734415160047672], 
                "EvaluationTime" -> 0.00012135285045061535`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.027027101000687836`, "TrainingSize" -> 
                50, "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                428688, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.920397109947666, 0.2572062607302454]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5062125190938611, 0.02640630283435555]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.32800576165305767`, 0.1523286762429704], 
                "StandardDeviation" -> 
                Around[0.33845921878557417`, 0.053908366997605345`], 
                "EvaluationTime" -> 0.00019982943044351853`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.35881403137266366`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 451592, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.32800576165305767`, 0.10771263994057449`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.33845921878557417`, 0.03811897186669982]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00019982943044351853`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.33845921878557417`, 0.053908366997605345`], 
               "TrainingMemory" -> 451592, "TrainingTime" -> 
               1.391017463958849], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[28.407549607344123`, 4.721685435555235], 
                "StandardDeviation" -> 
                Around[0.7861458318721458, 0.062130988585843615`], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.4682491612157055, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                428688, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[28.407549607344123`, 3.3387357901108636`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7861458318721458, 0.043933243350874]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[2.6718750745160205`, 0.3484676381838588], 
                "StandardDeviation" -> 
                Around[0.5534397989721447, 0.029703075006981106`], 
                "EvaluationTime" -> 0.0001550077694574061, "TestSize" -> 305, 
                "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.11225377181302387`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                424592, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.6718750745160205`, 0.2464038299838668]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5534397989721447, 0.021003245759528996`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0001550077694574061, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.5534397989721447, 0.029703075006981106`], 
               "TrainingMemory" -> 424592, "TrainingTime" -> 
               6.577306748713622], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.433107206567051, 0.2781337251188086], 
                "StandardDeviation" -> 
                Around[0.49191601402969165`, 0.03691024066499712], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.001370942985758683, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 499696, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.433107206567051, 0.19667024310818473`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.49191601402969165`, 0.026099481469446923`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00014229478653976401`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.49191601402969165`, 0.03691024066499712], 
               "TrainingMemory" -> 499696, "TrainingTime" -> 
               1.6521447577970134`], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 267366221376964]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.0000163074539363484`2., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097568670808955`17.333472249703185*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 2.0117826509028354`, 
            "ElapsedTimes" -> 3.9005654000000005`, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 3.352971084838059, 
            "ElapsedTimes" -> 4.4869911, "ExperimentCounts" -> 4], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 5.5882851413967645`, 
            "ElapsedTimes" -> 6.8726107, "ExperimentCounts" -> 2]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 267379106278852]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{-13.060469205364882`, 2.2505554067043327`, 
              2.3025629375567593`, 0., 1.6094379124341003`}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 16.0463778, 
        "MaxTrainingMemory" -> 971552, "DataMemory" -> 75768, 
        "FunctionMemory" -> 268504, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 47, 47.6144694`9.430313810024183}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {-0.13798832648355533`, 
                    0.1143876007909966, -0.1167828726727519, 
                    0.47619047619047616`, 3.8559847289823037`}, "Method" -> 
                    "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.13798832648355533`, 
                    0.1143876007909966, -0.1167828726727519, 
                    0.47619047619047616`, 3.8559847289823037`}, 
                    "StandardDeviation" -> {7.275829732486965, 
                    4.498149872409801, 4.2822000842124694`, 
                    0.4994327848429293, 1.3627792142561215`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.5175891914225614, 0.2696248378811559, 
                    0.2333086838603484, -0.7310494249353912, 
                    0.26558929206028903`}, {-0.6149192971128796, \
-0.03256526303164687, -0.33054477556212386`, 0.5027014635770732, 
                    0.5087682690065642}, {-0.38587103896644903`, 
                    0.1283673383395643, 0.7172419606635033, 
                    0.4064039684865111, -0.3937323354724092}, \
{-0.13931098154984128`, 0.7203111638579318, -0.48524625846375297`, 
                    0.03714557939513775, -0.47423681027476067`}, {
                    0.4308963665051196, 0.6252324400656827, 
                    0.2939510977942408, 0.21520687058947954`, 
                    0.5391581142659748}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.13798832648355533`, 
                    0.1143876007909966, -0.1167828726727519, 
                    0.47619047619047616`, 3.8559847289823037`}, 
                    "StandardDeviation" -> {7.275829732486965, 
                    4.498149872409801, 4.2822000842124694`, 
                    0.4994327848429293, 1.3627792142561215`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0247791, "MaxTrainingMemory" -> 93160, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 47, 47.6713159`9.430832001150316}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.13798832648355533`, 
                0.1143876007909966, -0.1167828726727519, 0.47619047619047616`,
                 3.8559847289823037`}, 
               "StandardDeviation" -> {7.275829732486965, 4.498149872409801, 
                4.2822000842124694`, 0.4994327848429293, 1.3627792142561215`},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.424855708249562}, 
               "StandardDeviation" -> {0.7259883361136649}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.424855708249562 + 
         0.7259883361136649 #& ), 
        "ProcessorFunction" -> (3.340075298220649 + 1.3774325980953974` #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-2.6087233438514876`, 2.5388363488297214`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwVj31Q03Ucx7fxqDCKIQ8qDCNDnQ/h8BBl3883cZ0IgiQaIFJNLcG5RNCG
U4ThGQcKahfqQfLgiYALRTJU9vt+viWdJSlnIODQ1GASOkMUzVXeLfzj9b57
3fuv11vrt676TCISiXLcx2eVRr8kO1uzM8n1tXyq2RKu3PL6VI7jMk5pxU6c
bEzmH/ROo4ZNOtwn+QokgzVMZqqHbmcH23bwMGlXmFXXVyi46piPsMaRh40b
nfgGkz/pe9wE1FfCV79Yyg1VMv4kPYE+nX+W+X5bQCMn1bCNg0W45+ViTpUU
chxiXuv2GKt9/fhQ5tegXucC8St/xChrBXi1pmPI1UT8U78Nk74YZmsjK9lf
/kYE3TL6x4XfoNI4As32QvI82oA+vdG07EEx4/ZUwfiGiGYMcKHfRYoHj4lp
hVMFxJYfwmeg5bM79sNQHSMw5xEsHr1CxrzEGKZaSzLzX6AoLBi1TU3Y7n8B
SnY8hBPZegF0/5LhVgHesc4khsIJbN95f8qr87HHNp8Xdd/FNvM2/vK/IHox
U06VN9qEsA5vCGy+BKleztyyWkJOCEdgoLEASxUiOsc0jd9b0EXKPomkrfGf
o1vEmzRveD91qOX4+8oeEu84AtobB6j8bSfsblTR0SqrQExi9jzLyjxrXXnd
VD1GDM2l7y8s5305ESTcWkjU3Q24NegH+Fgjwjv3vOgt1XqeG/aEVHUl4YZF
92FT068k6x8bkdkuC72Wb0A2FM5Krop5rAqh/2kPjHROord19/H05Aa016by
0NhEuuUAE8S6GtZlLMDUqAQ2PfUuxJ1bQgdH9VgUMajSB9RCWnAMWjIAhi95
kr1+W2mx3ZVo5pnQPa1OiF9mwu8eyqFzUTAuqjiDilcDKIhE9HivjJ3vz+Dz
6EyIu70GfUL9eNS6k/hz8C5+a7zrVrSUp/QJLEiXxVp8FCwtagGd+LAJpWNq
Lq97j62YYoF66VTwjJei6CN3/sg1gK33XsiY5TCkxVAwdxxAP5dcHlHyANM1
ZjbmsJLzZx+zICcjL64eRFmcN+/36GI5owYcat4L28/p4dSzo9DlIiczbpZg
enMyYw1aIdFzFrm37Cfh+qAnD/tlJzGE/G1uaS8FaX0brjYcxRe7A+FQiBHU
cTZw22BhDZvDISXUThR3Mqlv7w4svpgNvtuvkdBrs8HW9iW2Fxn59LkBfGK0
mqdMCYbd9s2g7Wgg2qKJTOfhjN5lI3AlbxY56zqBOwIfQFnicTzzcgpfLr4M
lZ1KPpxQzi3CDJqS1wfu5bVo2/MKLUt96QIvDz47N5EHnrwJlz48Au8u34Vj
j0qxs8rEI6fv4a2Si3go9jR+n3wZW2J2YGX/KAtMN2OlMp8nnkrF9uxS8j9e
5/PD
                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.03545049950480461, -0.023834550753235817`, \
-0.017786245793104172`, -0.006013981997966766, 0.034032728523015976`, 
                    0.00672453548759222, -0.05383041128516197, \
-0.028840377926826477`, 0.02950175106525421, 
                    0.0010760414879769087`, -0.0012956225546076894`, 
                    0.027891438454389572`, -0.0016516080358996987`, \
-0.0057947589084506035`, 
                    0.011531095020473003`, -0.005723069421947002, \
-0.042233530431985855`, -0.02434602379798889, 0.018815135583281517`, 
                    0.011076669208705425`, 
                    0.047083161771297455`, -0.01027498859912157, 
                    0.07936614006757736, 
                    0.01545735914260149, -0.042392026633024216`, \
-0.006682931911200285, -0.05745891481637955, -0.020520126447081566`, 
                    0.013163695111870766`, -0.016239583492279053`, 
                    0.04382430016994476, 0.013554397039115429`, 
                    0.04175787791609764, 
                    0.02224874123930931, -0.023189762607216835`, \
-0.006307628937065601, -0.033665407449007034`, -0.0014892518520355225`, 
                    0.006906623020768166, 
                    0.049394749104976654`, -0.038249384611845016`, 
                    0.004837998189032078, -0.018816586583852768`, 
                    0.030634334310889244`, 0.05256424844264984, 
                    0.02508997730910778, -0.008445287123322487, 
                    0.0433022603392601, -0.07025282084941864, 
                    0.018710928037762642`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3lQz9/3xxOKNpUllRaSUkhZUu/XOUkhu0iLkhIiVAgJaS8tiAilaLck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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.017663124948740005`, -0.005493446718901396, \
-0.018349824473261833`, -0.04937826097011566, 
                    0.009441596455872059, -0.008158431388437748, \
-0.01840856485068798, 
                    0.010235241614282131`, -0.023572899401187897`, \
-0.034657321870326996`, 0.006939902435988188, -0.04202713444828987, 
                    0.0277412086725235, -0.020552199333906174`, \
-0.028350112959742546`, 
                    0.02721257135272026, -0.007507826667279005, \
-0.008236288093030453, 
                    0.0333053395152092, -0.002590940333902836, \
-0.017908301204442978`, -0.02012200839817524, -0.006433433387428522, 
                    0.0013869628310203552`, 0.04543786495923996, 
                    0.02631705440580845, 0.016051746904850006`, 
                    0.020652374252676964`, -0.034010980278253555`, 
                    0.010675756260752678`, 0.04773559421300888, 
                    0.02078632451593876, -0.02153399959206581, \
-0.017533160746097565`, -0.005734287202358246, 0.003149226075038314, 
                    0.02893119305372238, -0.010398972779512405`, 
                    0.02672622725367546, -0.035504184663295746`, 
                    0.020708506926894188`, -0.03062143549323082, \
-0.0006489857332780957, 0.008447786793112755, -0.037162020802497864`, 
                    0.006457206327468157, -0.02889513596892357, 
                    0.01132962666451931, -0.011813127435743809`, 
                    0.0005069630569778383}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtmnlQz9/3x9NCO4W0yF4pWlRSvV/nWKMkSghpEcpS1rRYKyUtWkW0WStR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                    "], "Biases" -> 
                    RawArray["Real32",{0.009025830775499344, 
                    0.000917163270059973, 0.0016360790468752384`, 
                    0.04360872134566307, 0.0223703496158123, 
                    0.009444581344723701, 
                    0.04218003898859024, -0.04330386221408844, 
                    0.02981053851544857, 0.03547809645533562, 
                    0.05897822976112366, -0.017631012946367264`, \
-0.006311420816928148, 0.03919852152466774, -0.04145033657550812, 
                    0.011025483720004559`, 0.007881403900682926, 
                    0.007444798946380615, 
                    0.004654551390558481, -0.015267825685441494`, \
-0.0026069728191941977`, -0.022549718618392944`, -0.017441876232624054`, \
-0.008072559721767902, -0.004382438492029905, 0.0423797108232975, 
                    0.02522343397140503, 0.02971699647605419, 
                    0.005011777859181166, 0.020250869914889336`, 
                    
                    0.025880763307213783`, -0.0034129389096051455`, \
-0.008027086965739727, 
                    0.004243890289217234, -0.009628760628402233, \
-0.013984146527945995`, 
                    0.013370421715080738`, -0.00019007742230314761`, \
-0.027742547914385796`, -0.02395295538008213, -0.016345534473657608`, \
-0.027467578649520874`, -0.020370958372950554`, -0.02818114496767521, \
-0.04296846315264702, -0.022352414205670357`, 
                    0.012604912742972374`, -0.021802740171551704`, 
                    0.06853333115577698, 0.029279425740242004`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3lQz9/7/tv3nUopRYuiUEL1et63pSI+lizJVgpJZI0oIVqVVLTRgmwh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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.0037465153727680445`, -0.010959669947624207`,
                     0.016820555552840233`, -0.012689155526459217`, \
-0.03091016411781311, -0.010094298981130123`, -0.006369369570165873, 
                    0.002042371779680252, -0.012134743854403496`, \
-0.026688912883400917`, -0.02025674097239971, -0.010617648251354694`, 
                    0.009916947223246098, 0.02731563337147236, 
                    0.005699383560568094, -0.02056037448346615, 
                    0.008744513615965843, 0.017434099689126015`, 
                    0.021508419886231422`, -0.03925638273358345, \
-0.003102643880993128, -0.03950568288564682, -0.0010313709499314427`, \
-0.08099723607301712, 0.014241629280149937`, 
                    0.068978451192379, -0.030901238322257996`, \
-0.01061635185033083, 0.028544213622808456`, 0.004464442376047373, 
                    0.06405282765626907, 0.015692878514528275`, 
                    0.0026867790147662163`, -0.0027372026816010475`, \
-0.002801893511787057, 
                    0.01901073008775711, -0.018414942547678947`, \
-0.002991472603753209, 
                    0.005357618443667889, -0.013123578391969204`, \
-0.00003076200664509088, -0.05085029453039169, 
                    0.024966487661004066`, -0.007097311783581972, \
-0.029180770739912987`, 0.011422840878367424`, 
                    0.0054598525166511536`, -0.020130423828959465`, 
                    0.028679711744189262`, 0.006263226270675659}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray[
                    "Real32",{{-0.2581600248813629, -0.10811889171600342`, 
                    0.1148960292339325, 0.11356765776872635`, 
                    0.02955416776239872, -0.2185443937778473, \
-0.3035092353820801, -0.18066690862178802`, -0.05525583773851395, 
                    0.053845103830099106`, -0.07645878195762634, \
-0.19858984649181366`, -0.26079970598220825`, 
                    0.1037219986319542, -0.04828255996108055, \
-0.27226921916007996`, -0.10773663967847824`, -0.11205365508794785`, 
                    0.07791772484779358, -0.2538710832595825, \
-0.06169841066002846, -0.20269154012203217`, 
                    0.20841507613658905`, -0.20216329395771027`, 
                    0.011041177436709404`, 
                    0.04024723544716835, -0.017530273646116257`, \
-0.2839530110359192, 0.14384189248085022`, 0.02021699957549572, 
                    0.042327940464019775`, -0.10461893677711487`, \
-0.16041602194309235`, -0.0877472534775734, -0.4104112982749939, 
                    0.329092413187027, 
                    0.15072010457515717`, -0.3192231357097626, \
-0.06245363503694534, -0.08994056284427643, -0.14181829988956451`, \
-0.23674394190311432`, 0.08505314588546753, -0.22916235029697418`, 
                    0.11116866022348404`, -0.221586212515831, 
                    0.1657416969537735, -0.1151229664683342, 
                    0.2074371874332428, -0.16697004437446594`}}], "Biases" -> 
                    RawArray["Real32",{0.012213320471346378`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.9765923619270325}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 0.5637398, "MeanInputsPerSecond" -> 
          45411.02118388661], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.03396813193801678, -0.03236537237495911, \
-0.08241749671875881, -0.008321877626864323, -0.018982116000987443`}, 
               "StandardDeviation" -> {1.0094895347547925`, 
                1.0147120234180782`, 1.0004368189504143`, 1.0001101954713336`,
                 0.988492998431958}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 755079437332258812]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 100, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[363153], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.32022133024553917`, "PreprocessingTime" -> 
        0.418592`7.073335917477006, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.5046536684947245, 0.3066397882977201], 
           "StandardDeviation" -> 
           Around[0.36869076933766914`, 0.0678757780222056], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 99880, 
           "ModelUtility" -> 0.268459246264102, "TrainingSize" -> 252, 
           "TrainingTime" -> 0.7943282347242815, "TrainingMemory" -> 451720, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.5046536684947245, 0.21682707368692522`]}, 
           "StandardDeviationHistory" -> {
             Around[0.36869076933766914`, 0.047995422917814404`]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 100, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 291718685945297]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.615985673292086, 0.2761601653594542], 
                "StandardDeviation" -> 
                Around[0.5123472378076541, 0.03178718592121359], 
                "EvaluationTime" -> 0.00011938151200477971`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.03675866361689206, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                424656, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.615985673292086, 0.19527472561926834`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5123472378076541, 0.02247693471972768]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[6.733160464265487, 1.0947440158942252`], 
                "StandardDeviation" -> 
                Around[0.5174665405095171, 0.035410676095471515`], 
                "EvaluationTime" -> 0.00015633372739584048`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.04796223393976795, "TrainingSize" -> 50, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                428688, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[6.733160464265487, 0.7741009173022001]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5174665405095171, 0.025039129193508283`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5046536684947245, 0.3066397882977201], 
                "StandardDeviation" -> 
                Around[0.36869076933766914`, 0.0678757780222056], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 0.268459246264102, 
                "TrainingSize" -> 252, "TrainingTime" -> 0.7943282347242815, 
                "TrainingMemory" -> 451720, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.5046536684947245, 0.21682707368692522`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.36869076933766914`, 0.047995422917814404`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.36869076933766914`, 0.0678757780222056], 
               "TrainingMemory" -> 451720, "TrainingTime" -> 
               1.391017463958849], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.693440689775074, 0.6480857577868817], 
                "StandardDeviation" -> 
                Around[0.5334544565880612, 0.03787695707112546], 
                "EvaluationTime" -> 0.00015459545750832804`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.07890028296302554, "TrainingSize" -> 50, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                499616, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.693440689775074, 0.4582658341215264]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5334544565880612, 0.026783053195704565`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.7163370007524092, 0.3235142991849634], 
                "StandardDeviation" -> 
                Around[0.4196662525602356, 0.06874002207491695], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.14287993794059273`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 522536, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.7163370007524092, 0.22875915476450115`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4196662525602356, 0.04860653574808674]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4196662525602356, 0.06874002207491695], 
               "TrainingMemory" -> 522536, "TrainingTime" -> 
               1.391017463958849], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.516834982775947, 0.2080647780789543], 
                "StandardDeviation" -> 
                Around[0.485811453317359, 0.025369209859889153`], 
                "EvaluationTime" -> 0.0001299709711359511, "TestSize" -> 305, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.018363704873731956`, "TrainingSize" -> 10, "TrainingTime" -> 
                1.2589254117941673`, "TrainingMemory" -> 495584, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.516834982775947, 0.1471240155057027]}, 
                "StandardDeviationHistory" -> {
                  Around[0.485811453317359, 0.01793874032527224]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[11.553251934096874`, 1.8921459302466568`], 
                "StandardDeviation" -> 
                Around[0.5808612301657391, 0.04205329045510568], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.16431350851573723`, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499680, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[11.553251934096874`, 1.337949218271939]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5808612301657391, 0.02973616685201274]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.7739652920976663, 0.5547854763858824], 
                "StandardDeviation" -> 
                Around[0.37187486328145203`, 0.0759895897688973], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 0.2559611815979216,
                 "TrainingSize" -> 252, "TrainingTime" -> 6.309573444801933, 
                "TrainingMemory" -> 522976, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.7739652920976663, 0.39229257245626664`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.37187486328145203`, 0.053732754225171174`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.37187486328145203`, 0.0759895897688973], 
               "TrainingMemory" -> 522976, "TrainingTime" -> 
               9.145892217796582], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 291714390978001]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.0000171137543252595`4., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097568812168161`17.333472251314614*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.6792682972845419`, 
            "ElapsedTimes" -> 2.2200603, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 2.798780495474236, 
            "ElapsedTimes" -> 2.6399361999999997`, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 4.664634159123726, 
            "ElapsedTimes" -> 8.0235296, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 291727275879889]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{
              5.978080265467851, -1.6514724013405755`, -2.1290168518478425`, 
              1., 4.605170185988092}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 13.6297466, 
        "MaxTrainingMemory" -> 972096, "DataMemory" -> 75768, 
        "FunctionMemory" -> 258088, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 48, 1.2457375`7.848001524492448}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.6843109497645806, -0.14584151799708364`, 
                    0.15095088043573893`, 0.48253968253968255`, 
                    3.8032488057860454`}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.6843109497645806, -0.14584151799708364`, 
                    0.15095088043573893`, 0.48253968253968255`, 
                    3.8032488057860454`}, 
                    "StandardDeviation" -> {6.744633460284918, 
                    4.654168973214924, 4.317563227265356, 
                    0.49969504431621586`, 1.3590848008482437`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.6376671154680679, -0.011849155493872466`, 
                    0.47143665995990236`, 0.3038356238326526, 
                    0.5278935846368945}, {-0.16459484208668307`, \
-0.624539149785697, -0.24426795847045094`, -0.624592987369552, 
                    0.3647960429292996}, {-0.7030779091908019, 
                    0.13910541865064338`, -0.05156256456410401, \
-0.30008254541050616`, -0.6273937391984749}, {0.18415033202820974`, 
                    0.5256417328369142, 
                    0.4780765949415915, -0.6538459032688311, 
                    0.1836238766112038}, {
                    0.19508792025874958`, -0.560500579037414, 
                    0.6977569142725536, 
                    0.0018747099828113046`, -0.4011378545028679}}, 
                    "Processor" -> MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.6843109497645806, -0.14584151799708364`, 
                    0.15095088043573893`, 0.48253968253968255`, 
                    3.8032488057860454`}, 
                    "StandardDeviation" -> {6.744633460284918, 
                    4.654168973214924, 4.317563227265356, 
                    0.49969504431621586`, 1.3590848008482437`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0106695, "MaxTrainingMemory" -> 92984, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 48, 1.2706709`7.856608070565391}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.6843109497645806, -0.14584151799708364`, 
                0.15095088043573893`, 0.48253968253968255`, 
                3.8032488057860454`}, 
               "StandardDeviation" -> {6.744633460284918, 4.654168973214924, 
                4.317563227265356, 0.49969504431621586`, 1.3590848008482437`},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.386783063105441}, 
               "StandardDeviation" -> {0.7345619956960581}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.386783063105441 + 
         0.7345619956960581 #& ), 
        "ProcessorFunction" -> (3.24926020824664 + 1.3613554823952163` #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-2.81732052946029, 2.4573731584046707`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwVkXlQ1HUYhzdwCYgUWWRh26UIryVEWSIG2N/7jSOBdIxroHGYCk2I5Wzl
hhyIY5WrhYS4DFEMWwUhwNDd3/vlkGtEiNgdY0RmQAmKGEOOmWRHwj+ez8wz
nz8fu1OJwVEGHA7nrPH2BEemecnlkRkhRq/kTGSciyTu1SnZhrtNwGkLonLI
g8K9eeh4Vg9R719hJmW5cOJ2Jga4qWCtxBPPGFfQ6AvH2QcmYcx0uAMefU9A
DVVGcCimTOP4dSA0CK8xRdV1Gl9OK3t48wp+P29AxgcCUTGeAIZdiSiJR7ZN
/zf4xNthma8TmmVYgeqDBnhuEk/3bMgx+p02TNo/xFyXBGFzaD5KJCvSb1Yv
wFuJDNPV3QOjr9ejdWEm2ZyyRWGlP2Tp2nHosYLyYmuR1/0d/mPwMx5gHoCc
Z0+CZqMxo+4+JkotSayyEvbXhwOvleB604xn9I1plOsvYrvTeVSnh5Px5Aq0
bT1PJ1fLYWCagmDWC3fUqMD98W6ycHeOsVqVMlpnF7okuwTq+d8x9cVV/OHD
PxhWvYsVuuehsm8HvTPmRdyimnFTT0H1dja7yBZS35JkatqZjZMHy+BdsZZt
fzkPNyfS2OEEb7Llo8CCT06Bar4RcrnpcG1kCZ3Wx2CFPQd9iw0oZ9tgUCST
fvGoHL322ZGjfB2zx78Q4761pG7bPfY+K2YfxhnQteQIGtjxGqr/q0ex3oOu
2zkhp0cDrgIn1lKvAsa9EoLNlYT35TPQ9rpKl41DyNOtdanHWhKENrujT8Yu
6LCegrsCU7pRG4QB18U0djSNvsF/COYjShy5Og4fGRZgtdob80UX8aQfH+9Z
fsyEsDuhI0REdAoBCcn6FRvse5lzRal4r/RHVCnKwUKmxke7tVC5YkqzTC97
NiURMm40gUn9LYyuIAUjnMM0QSXZFOUJjNfkDWJnIyKMczjdzDkIZQu/McUc
e5KSeh8ivKvBQjnBZsElOObSgladYVJlRjDlJnDpgMdzTBdkamaCqyDUxBH6
4xfBbzSFVjpoYadAx1bFyvDwrBmJOVagsRyKIDNbfMKfasesTC61T/fDO0/a
sE/EI3M5LkxtuojGD65jv78I56QLsLXmI60X38SBDR7h/vKS8VcsMdLjNsz8
vpOw1JmFLktCqkuxpgOtZXikYid8Kr6Fda4R0LdSSvpSithcmaumpeoIZMOk
ulvbj8apNfDXm4XUuucJzMiboT6ZQ4eze+Crzw3w6fAgq1tm2VVuNwhF1nha
Xw3L9qWUX2vMBnTdQvMKKZ1JEFLtkphcjvkTEks/I/lWxcj26iFs7AXr4n2I
2HSkw5jnv4BmjWjaxGEXTngT25JarMlpJJIDFMbkNvDTbWvyP8Cz8e4=
                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.03525044023990631, -0.059552308171987534`, \
-0.048196665942668915`, 0.021076252683997154`, 0.02745862677693367, 
                    0.050948694348335266`, -0.050787921994924545`, \
-0.03769264742732048, 0.012293906882405281`, 
                    0.0010427962988615036`, -0.035816702991724014`, \
-0.05197542533278465, 
                    0.06949391961097717, -0.017041128128767014`, \
-0.0528140552341938, -0.014223379082977772`, -0.05518941953778267, 
                    0.008250372484326363, 0.004884040914475918, 
                    0.00008792178414296359, -0.04102738946676254, \
-0.010413420386612415`, -0.033687226474285126`, 0.026426954194903374`, 
                    0.009766649454832077, 0.02632151171565056, 
                    0.055940449237823486`, -0.020355509594082832`, 
                    0.030327077955007553`, 
                    0.03737746924161911, -0.05332060903310776, 
                    0.001448171678930521, -0.013689336366951466`, 
                    0.01685071736574173, -0.0764707624912262, 
                    0.0012619253247976303`, 0.06858474016189575, 
                    0.08481687307357788, 
                    0.017144745215773582`, -0.017285030335187912`, 
                    0.0552789643406868, 
                    0.1023382842540741, -0.05818331241607666, 
                    0.04934210702776909, 
                    0.05313856899738312, -0.0027564694173634052`, 
                    0.017291557043790817`, 
                    0.018599428236484528`, -0.033020880073308945`, 
                    0.08479088544845581}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtV2k01u/zRlFJyJJCIUkbKlJ5PjMSolS0J22k0ldUUtqj7FvIWknWyBJK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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.07234267145395279, -0.040231697261333466`, 
                    0.0687790960073471, 0.018059128895401955`, 
                    0.008265621960163116, -0.04635176807641983, \
-0.023199016228318214`, -0.02881789579987526, 
                    0.03263617679476738, -0.028878452256321907`, 
                    0.01764983870089054, -0.02828955091536045, 
                    0.045073866844177246`, 
                    0.049865469336509705`, -0.023421887308359146`, \
-0.005845381412655115, -0.023791011422872543`, 0.05647458881139755, 
                    0.04859347641468048, -0.028851574286818504`, \
-0.046932097524404526`, 0.017672576010227203`, 0.0028861702885478735`, 
                    0.024544429033994675`, -0.029617302119731903`, 
                    0.029430992901325226`, -0.0795559361577034, 
                    0.007401090115308762, -0.010899702087044716`, 
                    0.03437351807951927, -0.04696320742368698, 
                    0.04106709361076355, -0.0008965669549070299, \
-0.052839186042547226`, -0.02858520857989788, 0.011377385817468166`, 
                    0.041965510696172714`, 0.023588472977280617`, 
                    0.006800808943808079, -0.03308533877134323, 
                    0.007129162084311247, 
                    0.005542021710425615, -0.017764074727892876`, \
-0.03560396283864975, -0.03966353088617325, -0.026716094464063644`, 
                    0.007487827446311712, 
                    0.014057895168662071`, -0.0011091608321294188`, \
-0.02260568179190159}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c01+/7x+1kFCUkO4WMlFG8X9cViqIl0dJUQqWhlMqnskJGQ1lNkoyk
osj7dV2ElvZeKE1tpT349T3n98d9n3Of+5z7r+d9PR5Pk8BlvgvlZGRkVir/
23znrXELD5+3drLS/w5B85bYD13yv8uh/780l5eC7QIdNHhYB9/cu+h2r1lc
lJHGBo996fYtA9R7O1lQ37MDIvtm0aLd3TG17ph0zxEH0bl3NW0YrI+mdtNZ
dLjIz7z7c0ftD8rIr+elrtlwO5ppRLwZPD8ii1maQdB+eRNPt86gslU5YDfE
Fq9uPymOSR/IWu3lYuHISCqeo8znngwHpVFqmKxrBJMN/GHYwzvclOlKspM/
kU7kAmqf1k5tTSmkqahC48PCOG2xPDrmKKPKPolEedtxSb3rHJTt3gJKN3X5
bLQLnV7WSI07Z+KdM3ZsNDEILru+l1QYKfGl0Gm8yqOApnd4YnbFsuqYhzJo
Oy4Ew/3O0M/tCRxS+YJOpvwSD8/1hZq++mhtpokFJ/7Sq9n3hClLvkHK0a8U
Y2gv/q3TQc0AD+429wA9O/QOnIb0wQhHW7SumiKu/xklZrz8BY8nDuTsSHWc
OSeIE+6HUog0Csybt4uKNk/hs58hNBWFiJ477gm8qSdoHywRfi8eTV6Tf8Od
affFc7eewnyJINiUX6RkZTvI9tXA8P82waJtHaRzSYEudu7kPg3H6UEvB448
ncUvilRoxtSD4sKqWg6OHoDhAYli3q3DPOmJHE7doMdtNlnShtZvkD2oAwoX
NsHufVaoobEG67fFwXD1UZznE4EzN2uISX+vQmXkapgdtKy625UlGNi9SAgZ
ZyBOcTfkqte10Cv5F81fehL3nJ+Mv9XCq4MP7ESppRG8V3gLW4cr8J+HE5n3
mqKzyWzEtgbqafEQFoa68rVxC3hMRi88bR0h2Op10gpLa3xx/ADeLc1m/yWW
/PdNGQhOZXToahn+6KuDQuNMbNpxFO07JHxj2AzqnuLAF0rWgE3WOhrsthe0
zQbjA9bGXUOmsubwpRw6vYFerzDnFlEbH89fyOVeY7FwzlEYdm4y/TWNgNta
fVl5ZDwH1Av0ZbgJ50me0cRjGZxrU0lNJ8PwvoWUbARdjOyopGtCBa2sdURx
cjRln9hK7nKB0pD3W1H3Xjx/efUYvDf5so6cHU0L2g6LLL/Qu8cThY+Ne6Hu
rh4OCnfhT55nYMDUL9J6o3dCnEImq/sp8PGQT9Qet5XTCuqFmf0n8ftgBe4Z
po92I2aR+V9lvDiklJ5PjaXjfW/C7MwzNHT4cIyaPxzr5s4UZxf/hnWWDqC9
U5O/khPI5vaEq2UGKK90VlKYvoIljfY0ZqArBOxUx0ajH+LRs57YOOornFWR
48fSWmGdxcDqp8MNeeIFb9QPzgGrWz0oe30yji6bDZZLY6Fo2Uuqsw1Gg+Rr
wiPPGO7874p4dKIcy6w6wkpdgah+ZiTYvzSiUSvmwUz9OspbVwkmdc3gMO0G
+DmO4OMyAdTawwGTJjyHQy+8+O27TlLY2xevaj6F1EOPxCFVKTwwNRaObreT
Ju8YiINPPiaLbm44dLopfk7YgnG2Rvw6dTA2W2aC4mQbPPkqjaa+vS386soH
9QF90FnShw4E5sPlPB960nVFIk4cz30VDgqhjn60wyZHcmyMHtZNyMG7z49T
GpWLqBOBKt9iYOT+Goo+/QMe2Zylma6qtHzFLGxKeE49LiqyTvBXcFNHqLw1
C2qKdDluu6YoFyyPK+uvQuGnRHzQrYiwaJE0qasOzlclSsz7Hwe9IC1215bj
3KFnue2AJj54QoJ7TSDJDs2klAo9tv0QA42999CFYxnYbZkuemcaUWPmETi+
Up3WKW9EUx8bblizlqPy75E0ahR3qcrj1btyrLZclG7q1oMvFRngV6NqdhTG
otrN9wL9boYLX53QquILhWVYotmyYJ4bfwDnnUqkYaPcyUrhI+l1xbPe52LB
QWs5bzvgivuOAuiEJovv770BJzlFtj9/hq4NTmY11QqQ+fUX1IaMhYyaLJgV
LFCjsQm4Dv1CsvFvwL5XtORNcIOws82cRq3W4vyNWyGvxoENy3ug0y4V3Gzh
hQmBDyQ+x6PJ3+gTdMQpoGpBDKx17YuvovqRq802UvFbBrlzv0iyppdTwIhO
6a0JunB0QyiOU42jriU7QcPiOSx0Gi6mV3nS2lo9SFw3jsJW3iRH11688awJ
jBjbnUZnyGHgH3tyne1Kaho59GdEGuRn+ZHl/e3QdH6X0K22D18fkw+xqjWw
vcwe/a8ZsM4iJfKO9QeXxSGi6R4rCpQUU8Z7H9pLI7n+pDG/d9wAqtwO14OI
MtbXwQErORi7vFmQvJzI6tUFkBhbSra9ztOQk/r4bVILhYT6sKzxEM5tmk6r
zZRZ5s8paUTXbnKefx9N44aDsXcZKs97AyfTi3jSeiuYLbcPcm+3krJyHxzg
EwVv07ogR/+roCBRgRWfFsOpqKNi4xpfjNW7KbVTkUOfgDOwqu4W7a1yoeMx
30Wt9fbw5+R4mLMlGiwXjcXT70/T+IhiyEo8RvPXlLKW321hUdUFmLrvp0ub
lTe1Xf5Mk77/pZhpQ7B76Cu6ISvhJh5BAV+PCTOdOqA04AhtidwHi36dA4XO
MbyqqFiwjLgtKH/rxXfGy0iLYjQ5vz0cunAChfqYgqW2IH5WcYVnJ3+BmPUL
Vg2y5IX5ReBUZYxW++9A1PxqOPg7iC3DnLkJaqhuWDY4DALarKcGNwtviOmO
Iazk2AMMjqWJ6uatVbMnPKUpr+IwOKlYiJpcSgFayhidaMQR/95wmPEZupwL
aNyL/fA5uhWif5tywshasfXWBeh1y5BNtRM4MHcSDFSNEcJsdHFDho8Q7JUF
URt+gMzIJko2yRJcxmizIinB5do6KhraXZj1URdrWxzI4McW2O2xUwj+uYsO
WyTjgDBHlryTRd/83bQnpA9kzjfC7omrsVRpIT/Wc8SUYYVcvdie078ZQP2w
0bx2dStdOR8HE3rvBDfHIBjckgxD3adBt96yvOFxC5lGHKF0tXiefrWXgK1r
yND4O0zrwUJMn1VUtHoMdCysxuAhQdXaPcqp+dBLqgrJEua0voK3zxvgkZMx
bFxpx4KyVPg6NBrMz1jB/c55tHjWfYqwX4T9Fyjxrv9KICvQhpdVRgP/y3zf
GluK55HV/23Pg/WDp0qb6tXoUtNhif4zFXSfJguXf/XGIMwQA/pWcXfNp5SC
ydTLoh9EHvHAwFHbYYm/Kudd2MoDPRLp/Xgd4LKeMDhyAZhPD+CNG5dyVrDA
0U4XoCLNhIY+DKSuuJG8av4uVnm3D3SP6jJFnoT/TnrxWe1cMpx2hWYbmKHe
Zyue7g10uaoegioSxU2dieLBO18op/tSSFmdjZOH5IojI0eKb48+ALXGj7Qw
3RvHrZmH551t2Le8J2XWe4J2rRMNNAuCiauSUP9MNaWZTpUczWBozzaGaX4f
KenvUDRTT8AnqSn8ZEqX0NC+QjDatpsb8nXw9sMOkcP7SreY3AS1/QHSPznb
SXN3qaTz4U2wfm2GU/Jq+L+MFTQg/iSF9zrEbXn2kJC2H6w7ZtOiw28pN/QK
HEvoyQu6FwiaFmG41suLf+xIosN2c1kN30Py4Fiu9crCTKdJ7BWzFx6+ugFN
Tb+EcTASU5tTWdSL5npzbUzZk0odd3eyZJ0BbRymjHZGt6jVXkOMiW4RjdxP
uwxZWiT+N0mRowpqYbT7YbFL8V+uTVoEmU4jlnM8CZUXunFcRQE46e/E81XJ
WPO0NxbnjsN+Mm64M6YEfjoHsOpnJXLN8ICIq2/JKvI6ux0bjNp/E2DWolOi
yZydEG1nh2q2rqLxZi/c0FlNnz2UeFrIX2HPsS6xwNaHpvzRYfuXd2jSPl12
KRvA5p8Gi126mvjTwwzPPFcVn1uZSi62v4BBX2y516JMtArZKypMCCBXz1EU
kxVHs317S+sjRrDCNj1UvVYG0N8LvXsk8aAX52ir7A7M7TkNwFpDPHTaA5dG
6EDmFwWM6mmFlR9vkN/dJCj/bcvW3SV04OtIinHUAtXYcA52i2XTwhqY2XKU
f5jW0jOTXJg7NFHoqdebx41NRq+p89FK1QauOttx9+G92GyRCz7aMIxNOuZA
Y/VDIctyCKzSVIGeQaV4umAlVibVoOxWe+7AA0CKiaL/PwdpS6inEI88UfL4
N9xK2iRUntwCbie/U/TFJaCod5OerWD6tPYIbBx1R+LQWwW9JpyAc13hONV4
P62oDmbXjHKKbbXjmmXWrNhyW2LYbws1TJgHx00G8sp4JTobKgNCa4W0LmMq
rH9VByl+o/DrvSOgmS6HJgueij48WWxdpYSXHuvArt9H4ETua0j7z5qC/NcK
JT+d4cPCPBw8eg+uKQkXO0Upr/tcKnoOCMEOyzFoO/8XzdlMUJSyFCZoH6L+
XiM5z3qJNDP2MkwOLeLmPk7SnyU6qLPSnC8csBBvGZeJ6+s7IDIwgFqWGoJ0
mB3GPYvHXwNK4PetGdhW4wZbdZuFzn1XJZ/2H6MTD9Jp1249HGh5W1LW1gjX
Co/Q7eYddKPvXVIIfEovtw0TNlk1ioM29MWFPr8FL9WH4D2zG4bYXqP0+8k4
yDiafz6tJNDuhTOmZeEav43gNyUOju/owQ0vztPlLSPZMU8JgsfFcIVuOfm/
0Kati6aznq4laKSl0bd3Blj//TROlJyA6OLf4meNf1yc4gTj7Puw7RczGPEg
nuLLS2nQ1Hj+fT+PQh8YQMKavZAyz4F3ha3lzsadHOlzA44/CYXnr2fx+Q3n
oWDEb5I9oUrLtj+k4KBHYlh+HXeTtYbkv2E494olxf6Vl/rc3QdyGhdwcXOO
8NtOA2ISJopssVcy+O44Xpa2FRY0L4ePFfYQIPyWPj22EL56a2GqzCfK/+AA
g7yvwNby61L/0cOxsjSO3zjGURzOwvtx5rC/aAruf+kIizSqMKboDjmnDBK2
jy+FziwjLBQWwOAHtqhamwXX/LYKAbZynPiogg6V7MZH17R43CwXkkndz05L
99OfTbYktIzGaMGDLwe7iO+jztFnMyVcXBJCXRemCOOuz8XFhXeg94YZgtyM
XdBb+4f49vxL+Lh4MXrmpmPA6Fz687WBnpilwslsBssLDiz/vJxWDb0LCbMf
k2nwBWlO+h3QuDRCeDy8Q5j7Q4T7Xn3Y6WyyENRqAyUGyXCis7/04pZaqdyi
7WQ64zRqvR0lXaA/g2/9cuAQpQX/KpkbRj3SQNlrqvD70iZ4PtUTPV77QuAF
eX78307SDA3g4qnTuTEpFxRG6OD3JF08fXWbIJX0ZYPuF+DZvhpa4TECwn4a
sWeaao36jG5cOdOaBsXbkusuAZwKPbGjNgFW9NbDMWEXaElbFPQYlSkundEo
Wl6rE0J6v4TwRYGSH3fVYfwwPVx+y4G3yYg0fmajxGCgH6501GVH5VBuyFxF
qw8q4I9L32n0huHokS1P5u3vRY2bFyXmMcnE6RGsUboSXbXHc/BTTyh7Owij
ncJg6O9H0O3nCNjo84fySlbj6VqBz1T6w+TnhWi/bSiqhOzB007VUKKTRVcq
tfjMnx305tVbaNuxjpaJ10mYLovzhqSKoctraU2OqRj28h04GpoI8mYyhJ9q
oMxvLCy8GA9bEuS4wH8GrNTx4xBnNd78KQZt5a/TGNMn8HXZWrp/dyi77t1B
jqlKqGN3i4JSzkPirzGgWTVdfL3DmrU6z8Ozwo2i+hYNTruXToOOxMCPjQLb
FCdz0hUTPJW3m/eqewOv0IeSIkUcNHI+l8xoI3p1mqbv70mGM2bwEDVdPqT4
CBwXO/PdHcG03sCJZ82WwXXyyqxooo6zC/9AkBWJGZ41tOqvP4ccbRZa+pTA
6oRJ4qF0GV7fXAjw/iFN+/iL+jt0QYdpL7HkfDaOO+uB3xb1xdTZTWLu/Dd0
cIMXr1lbD8ubWNw4cjBHjDpHNk9HgkWXIadPmMJbFHzR6vF0VCd5vOkcyFsW
foa05WYY7G7OU/McsasggONMv8Gy2zE0IN+Ddm/V4m6ReaC1Qhk/h9SL7w78
pZ4L/GHu9s/iwGnOPMrHhiY2OdPVLlcssw1k3c2ylHkulIJqSXzYViVYDlxJ
4TdeVl+sm8tpy44Qp2aKB7WdUMvFBy2i2ml2QTmdXR4tvB3yS8hXjocmmS/i
G1Nbzp/QAyUJ4eyQUjDcvFsF3Rk4mI9uT+XJ6+PFRYrWVNE2FX7MyIX4l3pw
+/xsOPV7HLZtG4ON0hRSuZEMDg4IfOcOJWYlcipNhviyBAh8EQ0rzrSK/VQT
xCcO++DCSzeseKPJ47JKacOoWFryUt9FXr9KPGW5Hjj2pxDoZIX3ZMeQoL9e
fHx4P0XeUUXnTBmcNFQPdqaG4ZQ99ZJX1yMpXP2JqJyZL7xOQo4NT8f6o070
trIXa//ohn83H5fcrRzPjgflqU/dIarW0cI0owz6+8aR2wNbqOm0IS7fpwi/
prwA24gEzP/4k35cMqSyaR+EOvEXKd84Lnx9/UHIbHwNU1Q9eeRmC875AHz2
11iuKlhKpc4y2PNuM7TL9eZB15EPYqJg9vEblFUpcMlzbfa9Egxvxn8g7dhv
4NPQRCfk1Vio2k/Ns5zhq89sPBWaUv3VxQSfRj0Q3JSLYGmnD5V9HEg5De8E
+7CTpO1oSxXdhuGOr36UeqM7vSwLgwO1Z2l0UyD/PfqULL+qYfWJcpr6XcJD
WhxgQK+z0HN5g/jZ3Jv1pytSW29A7/QVPDzMi7Qcs+HbvKss73ATxslfBMzu
jtska6CVY9llujsWfk6hHSW5OOhbLG9O9+TlFuqYpFIrbFhJVNrzl/B2Twet
fkr8yFCeepvY8J2Mx+Ki4CWYNM8CI/rug+HdK4SovvdgSeF0arTqjZeeBlA7
D5IMsf1KGg6unK+zA26YmrJRQm+hoM9n4UZyL8q4s5tiU1rIyzBfTK41xXu6
EXyqOow1uv2kVmMTnpF8lGqy9wor++jj6UcXUF2mFBYUl/HUEWe5tnsRPYkd
IeimZYtjxcWYZfUapMsukocoy0cyPpPU7gCV+G3jrgcKHBG8FwopXnBM2svT
iq/S+Q8+sCz5pzhstg83XneFnH881ewVCOtPHoCmHYFkGFYMY4IfgUzOcLg/
0wNnmRznshHIx3Lludr6Lw1dCmSQ6cPOh8tp16RHovVL4BnLWuhUYQQ0LxZh
/pI6au0rT141wWg95DK5eQwQHN70ZXGSJR9wdWP1mNHSI/r7Yd6ZSHwRPwfy
/eXw1nyC4+En8L1SEu4vPyHRfDAIr7xdTh9HfRP23lLlPQGB+Mu9ngzXdWCg
si3X12lLvx3ejt+u9cahmjPp6akdHNd9JG6edRW+LD+D2z17iRqrB8DaKbch
cMsH6N5Xn8xfFdHqOcliD3NzqLAz4+Ywd77kOIRHt90mqaUdFGSI1HeDLu1J
Hw8j39/A056FFKF4hP1DR4Fw5jmXH38M2vWrQHaRPzfWefOqfYvZScGVlMbk
0pvWBFw8bIXkbHdFdj+bgDGDTtGB0SvJ9/x3mjZ+NxyVSUSvBxt5opJIxWcr
hQNm1mTdNh1dNwXTkNM6KKO4BXdurYHFOtNxycFr+KbfPwc6YMl/vDuFpDpZ
8nFIwc8Rm3iprDwPTjLEz/p7JFeubKJMGQt0SPtJC839sdi5lEKWa+JrswGs
oKrG/ZfJ0jqnHKniYzeWqdsrJE3Op8qGGXzk6BsK/WCF1sVD8Y/xHlbaE4CD
p9bBp93aGBglzw6lDeBVOQRblZ4I37WaYV/8FphjaMe7vHpD4RJjzNzQg89P
WSC8e7SZYs39ofLPvz77qVL0fPJc4iq+lpzaY4qqB2rg5lZtLFoxEWtOR/Ds
cl2e8NxeoKhVmGO4AoLPeMJUozlk1ILC1plb8MNyPxiodJCm5enST+lA2tw/
BPQXzIUgDiTPfD+UZkTRxtJOiixppYjINDHwTwzHtwSIC9Z68ZDIuf/+2lLc
OPM09C/vElXb9fh1/274cM5q8P7ugb4/PdhUM0/SabRKum2UI+g/LQPXKceh
tssUay/mo0RVm1+dcKFBq+zgaV4VRKYdBDnlbex6qpXiLYMg1GckxuXHg9u3
OWwbJMDiye/E8NXz8UyXPK5pD0a/M4eEjq1J1PePC7n/vC2dOWEtRsy/CpsW
mNCrYmWINWmiWepj+fWLu/Cqazj2OHVNErqzE1obhuGzftdI9+8/bn6qwRkt
ATiodYS40n0Iy983J99qFWqtGY3FPW3YdMcdGGU/mdfYpUJLjQF92yzgpaWe
KNSoYas4H21bdoDRGVXqM0MOI09EO180243lf9x4msYn2hR2hfLNPMizxRlX
vfHEA2u8MHDKTFL+h6k0q+s8WKFeiLDeTG9qJ1OAaQddD/5AlvY5NLhNmy4W
d6OaqUtQsn4JuoXGiU5W0/HhaXm22R8m2Xd9LqdCLWlUWqJlgB+aLaokrcRB
dP2pL2Qo50ruLZkD5W9nc15mPUTgaLSyv0Tqvgw/6uahfIAmXNWRFw6WTqN5
tyNBefJTunFJhXqvzBeyFB6II262iB8OVZNEeRd9DyyXPDKcDSO37eAtucvJ
6qoyOHRPFJ72D+HbV45SfmIi7T6ggnqn8iCr31/ybe3BXx8eoQnPvsGSLU2w
+cQctllfR4WvSyj70C6iCfmSNb/12P36IdozNYeyFeLwyK/eHF0DNGWlMX6Z
NBafmp0nr6NrcMDACqocmw5PjrlzWV0vGju5L+9PL6d8xwp4MX4L175xINsN
A7D8sRPOdymH79+64INhtWRJ+mT+4rELYkM2oTdPRFeuJetAURyZvxZG71fh
EXk92CM+TOwsUROTdVJJR9uI76WOEgpmxAoXz5rzQ7fDsLPdG63k1Fimubc4
ZlIVFm1YIJwcNZpif9yHl/VKvHbpYEhvqxPeVOyUjPw8UThdX0Rp28pAfkUV
Pahbw7LbP1ON4z2Y/Po6RD7fRRf/TEfL7o3kpYQ8aGZvVr11U3AIz6Iyi/O0
6/h4nBJlxMk5cdL500+cPpWzkj68BJg/xpUrXzvzss8RUP3rDfiaqLDR5kqI
278Jwr1VMDFvn3jCUQW0/gaCg9cDuNw+Hx5aPaM9V2Tx6gk1MU7Fhv3QGrd8
+wMa/21F9ejngs6paCjpmgThS4zgUu5FmLJ1HnoOnY+H5jTSlaMq2DNxJk++
t5f0LPLAcPFg0vjzRvJpU6Zorz+Hzv6tg/6fmJY3+4lBA2V5xdAFfMVVG5Ve
VoKc2Tk4kOGCzTKHoeHtMYnr8B3gM2snbXI4DMfUg7il67JQ9a2RNo9OQkNV
Fb79XYWhVwD37erGHbszsatlIFv/iOa1Ew35du4a2H/OmZ2yz0q+RcynjryB
VJ3hD/fCrHBuWVl1/5YJGHq8F9/6DrjKuxWmP/pCpgl1QpD9AVz15TBsWKfH
2rvOCePWfyDN2kThZuRmPBSVSAd6y9FJwxLhfZkuHfQ+BGeqC4XkqHpITRLJ
8qIOPTu3ChfsG4iD5u8j/wMxcOtJIpZsF+GGbRQvtl0rdDRMEKtydpPtrpV4
1qdCtFCfhQaa+0k2zx0zhzVDbIvvP9d2gHDdvhxpLkuX3HUFx3pFcrFax1XR
nvi6/xRSWNwm6r53gisfw8BM35df3Bws3OhZyH5zW4V99dt4qkVPvuzxlsIn
3xHfnkunXK1qskoBtLqjjBv6BfGTa2a43UdKSWpHhQk7osXqcYfBPeMaiDMf
0ECNIShqHobs0FQoVG6nS87TMO5SAxrvW8RBtrEcmnKIY7RdefC92xB0bzeQ
RTA33veHRb5GbFp/Db4rJnPY+iO08ekQ6THt54Lb6zw43N+Wk1fJ8hvtKBpx
Qw16ynxntw+HhY7idP45rggvS+04A/OpcH6ZoDDfmq2PGeJ/Y/PpZZEbzPDa
AZVHvGjp2F7cb3wBjf6oCl96puO9Cd407J2WaPphFDyar83PZFfhxyPjuPpC
FETa5QhvVg932Z+16V+vTsN82aEcbiXCLDcvzrg6gW5xMk9IiOWfA3ZKS9tk
EcIGo0yfT9JHUZtAqEtBcNwoxoc0wTY1K7z1SYbuH5El7cXfIG3mWrLaWg5K
D4fygoDnNPfiKXBpN4ZVlWMovttJDBv9BXz1s+jk1QvOGyco8fA7i2jP9Xx0
2XYWDuRow636vvwxqEDsCjTg7+OK+UTmWxjROwbur7OifHct8FbOEvpEprL/
7l3CnfvDMUt1GO++/0V0DhLhwbVndMoihyJXeHPNQ1XMW+GEoTcdJauaEiDE
TYFcbUvxeqIsvDv7Slo56R+3lUU4svKvoPKiFajxPQ30mCUdbRwkXv9vFRxS
OiFqpKZQzJYI/Pm0AUwffiCDmEuQe8IRd+M7ijfeIXiXLkXXpTawpfkiOY5/
JoaEH4KLS2/Qd0U1frwtmSqGyYutf+XYHr5TVfx7agvuCTccDdBy/kpUDS8W
eKExT09KgaIn7qyPTfD4wj3h/RRXyDuVJHREpfJXmWtU3+MQdfXUxoTNh6DH
jtnSIOk4tAybwyvSn0tXL/IQOzp90Hz1IfoyMJw1jC/Rxj7GmLthD35etBme
qZ4Hz9F7SGW4MbN/Ol06pc8x4Q7Yry5UuLi5U1idfwjq8s3ZJXALex1W5oaF
Ryje1gSdbicJd/3G4RQPe671ySHP4r1C37LdkP0qla3SjtC5lb9p3+v10Nq/
CH2UEnjWzzYhz8UCd2wtg+V+CmR8XU6yLNqTvZLl+IdfjTRrtAIVZYZQQVVv
eJhszl+W76Z5fu3ipI9D0fueLY3qp4IbdeTxhk0/XG+lxZNPzYAJqXI80zAB
y28Yc6PrcPCc91x4eLc3f1RowTBhCs+dmUtlfho8OuuN2KOpCYxFW76zbwka
tVlAzzvf6Ne+7fx8qxv5728lq8+xPGfVUVyW//rfvNkutubuJvmdCdBrtD1v
6+WMhn2KoKxwA4We2euy/rUNFBuYkNvpeXR17USOZG0XYXgvMa7Rl46H9ESr
ScPg7JXfsFupG4/dvFP6ss2VNX9PRr3fd8nmuCmqp8rD4NmH6I3bPw/d/gay
z3qyloUFXp9awkvim2CrcyAu/LlEPNZzJGaP+QR6M9/R9f6PxfdzDXCKawoV
Xh/Kv/odgF3BW9EnKUw0Or4cb49ugAVv2mH7j9/CgGtu/EKzhNaoXQHNRD18
V3mgeoRZuzhgQB/eL/cK8lIWcpSnNn/6x/2glFooKL1GE/aWk8yuIupxKwke
DLgGFdfiqfDcAv5mYU2HFrlS5aajvGbcdmFsy1AMV2yDUu9kwX91F9ev7oKH
jRvp7jQPzCjujl19UtmweY+43teax4a+gPSsUeLFE2GsuyVR7LD5RPZbhktG
+rljwfTxYF+uDsfTroCTmUi343dBTrMn56UDKx65IbH2LcD0z8fE4KbhrFNQ
zqmfXfHvpD20rNhVeBw4DhqmtwvWeVK6tiwdslIe09PAIaj+Kw3C2otpxpUS
co9spbbOUWB43B/nmLj9y1WRcM75MJT2y+Wt2YfhQ+R4YdE5Wyw41AHuCoXs
NIDFzJo0se1WPryY2179ZoAvP2k9Ci+z5blSMxaurtkCj15sZgeDgThgiKv0
YvRcvLO4ghzaJuJ/u9TY9IoWPxjjL6maUA/PeqyhzhnlkNvvu3jFzhGi7eSx
bddL2vungh4cTgQX5xb4HneOtGX2w7KKR2By7i7N/nOQDQreCibr58BhpTJw
vyAjhM324rw/ymJ9/GUhcuNf8XxDAqd7XKdnezRYce5zob3Ug0TLDElSylvJ
Fq190EcU4LbBTFSs2cNG/yEulQ7AHI8yync25+2xH+hv8z64rr8VAhN92Wjv
au6sKxauzp6HF0epii6/ZkGzijGON1fjBt9m2GH/z5GSvkPFlXuCed4knicm
4rOVX6n/23N09PRGvr+7RGy2GMAZWmt5sLEydyqPouq5x8DKPpp/Nmej02Yl
FPWz6ZdyheSsTALob5wsSuduhZREJ+GtxklqTnYAzXx38cXaPsIwKiGNrG6S
/hdaKKEyCZd+IVgv68YK6Wcoyq4GRLtEnuWgj5b+f8mt857YLCl2ubE2iM4d
rYGXm1WExxvWYHuto2CvJztiD/fCXVIR/jxpgWluqvw85J3g4viV/iszpc5L
hZDy6SVdWamIvQek0wA5A7z8KZYyB6rw9Z82fM/dmAc9isFN9qvQKNcTeL0U
Bly4Av4vEsm5fQHX9nkEp7v6oL16Dn252RNejp9ElmE9sULuOYzseCys/t6d
Ti1vEM3/roAzDsP5ex81Gv8iGeRqx2DBTnXILomjT03ubPGxGlTfDMTUzWm8
IigSVm41Q+3i49D9mRYa51ry21ffqdL1E60/1Z1HPzomKpal0Yypu2jNyxei
U5A9CumOcKRrCb1UP0HDZulip4UIX/xSucF5ufDANBf3rLlK+xwTeXmljJi5
WYGfX5AKbqNUedjPlbxTI1O81O0MzVrcgYuK9fj/AMsK/6E=
                    "], "Biases" -> 
                    RawArray["Real32",{0.06750857830047607, 
                    0.010367859154939651`, 0.04592949524521828, 
                    0.014159416779875755`, 
                    0.03410537540912628, -0.11046506464481354`, \
-0.08416710793972015, 
                    0.033945176750421524`, -0.004949913825839758, \
-0.004959591198712587, 0.057333964854478836`, -0.005931582301855087, 
                    0.03993654251098633, 0.022738464176654816`, 
                    0.01717834360897541, 
                    0.03398149460554123, -0.012671508826315403`, 
                    0.07422419637441635, -0.006055812817066908, 
                    0.01796804554760456, 0.016459833830595016`, 
                    0.04580112546682358, -0.013110422529280186`, 
                    0.036924149841070175`, 0.04167995601892471, 
                    0.08201567083597183, -0.04383415728807449, 
                    0.016737449914216995`, -0.010685669258236885`, \
-0.019139006733894348`, -0.0027339085936546326`, 
                    0.010899083688855171`, -0.06662371754646301, 
                    0.013564268127083778`, 0.0012214566813781857`, 
                    0.01286894641816616, 
                    0.01450413092970848, -0.07078153640031815, 
                    0.02976190112531185, -0.0518919862806797, 
                    0.03536728397011757, 
                    0.002340528881177306, -0.017091820016503334`, \
-0.020832043141126633`, -0.048354022204875946`, -0.019153932109475136`, 
                    0.03735041618347168, 
                    0.05539461597800255, -0.021314509212970734`, \
-0.023200755938887596`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3kw1+/XxhWhIrKvUQmJFiJ83ue0SEpaUJKlotJCCqmURL6RZEuhSIWS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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.002676769159734249, -0.017799878492951393`, 
                    0.0007857239688746631, 0.035577986389398575`, 
                    0.04675895720720291, -0.039213187992572784`, \
-0.049524080008268356`, 
                    0.03429940715432167, -0.023750118911266327`, \
-0.01251388993114233, 
                    0.02768821455538273, -0.05601431056857109, \
-0.017518576234579086`, -0.021180540323257446`, 0.02934657782316208, 
                    0.05099788308143616, 
                    0.02665235474705696, -0.0018909696955233812`, 
                    0.05792144685983658, -0.01793503575026989, 
                    0.00800190307199955, -0.0031350492499768734`, \
-0.047768544405698776`, -0.01266222819685936, 
                    0.020010024309158325`, -0.010791491717100143`, 
                    0.0004935454926453531, 0.028277739882469177`, 
                    0.006256365682929754, -0.01744220033288002, \
-0.029359569773077965`, 0.014009038917720318`, 
                    
                    0.012360010296106339`, -0.028640393167734146`, \
-0.0015023706946521997`, -0.027503805235028267`, -0.010237975046038628`, 
                    0.01250311266630888, -0.035799574106931686`, \
-0.018555480986833572`, -0.060378625988960266`, -0.06520125269889832, \
-0.026777664199471474`, -0.029436418786644936`, -0.022844545543193817`, 
                    0.009603477083146572, -0.006273886654525995, \
-0.029714491218328476`, 0.047706201672554016`, -0.010669657960534096`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{-0.18386971950531006`, 
                    0.10681872069835663`, 
                    0.015667064115405083`, -0.13172660768032074`, \
-0.169342041015625, 0.12074311822652817`, 
                    0.08961658924818039, -0.03224627301096916, 
                    0.1972644180059433, 
                    0.11678849160671234`, -0.04297206923365593, 
                    0.18111549317836761`, 0.10301630198955536`, 
                    0.20242157578468323`, -0.09816621243953705, \
-0.07256916165351868, -0.12728072702884674`, -0.2759075164794922, \
-0.047366879880428314`, 0.04851330816745758, 0.22630345821380615`, 
                    0.023091871291399002`, 0.1767045259475708, 
                    0.026200735941529274`, -0.04085474833846092, \
-0.2427448183298111, -0.053829438984394073`, -0.028116997331380844`, \
-0.017084425315260887`, 0.12191056460142136`, 
                    0.09932702779769897, -0.14378111064434052`, 
                    0.18114885687828064`, 
                    0.028394289314746857`, -0.05735272541642189, 
                    0.12322165071964264`, -0.1159067451953888, \
-0.30679768323898315`, 0.03405569866299629, 0.08578550815582275, 
                    0.017406078055500984`, 0.11814124137163162`, 
                    0.4175909161567688, 0.13511036336421967`, 
                    0.019618965685367584`, -0.06833615899085999, \
-0.25824621319770813`, 0.2377171516418457, -0.0490989163517952, 
                    0.014571704901754856`}}], "Biases" -> 
                    RawArray["Real32",{-0.02166847698390484}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.8032698035240173}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 0.6022247, "MeanInputsPerSecond" -> 
          42509.050193391275`], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.04551549258621522, -0.07220279128654788, \
-0.02396255582485952, -0.013147765968898864`, -0.022024127109034022`}, 
               "StandardDeviation" -> {1.0332809614558836`, 
                0.9975514464059461, 1.0009807557513255`, 0.9988803901841378, 
                1.012671218000131}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 5498296724524219486]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 100, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[363265], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.30848088162576465`, "PreprocessingTime" -> 
        0.3769927`7.027877934204646, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.5568036730031378, 0.26143610600004974`], 
           "StandardDeviation" -> 
           Around[0.4031239691566751, 0.07363912944221301], "EvaluationTime" -> 
           0.00025157034800970054`, "TestSize" -> 63, "ModelMemory" -> 99880, 
           "ModelUtility" -> 0.17944909051975033`, "TrainingSize" -> 252, 
           "TrainingTime" -> 0.7943282347242815, "TrainingMemory" -> 451656, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.5568036730031378, 0.1848632433996402]}, 
           "StandardDeviationHistory" -> {
             Around[0.4031239691566751, 0.05207072778926276]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 100, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 211961143258591]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.9672864600855424`, 0.31905670374560724`], 
                "StandardDeviation" -> 
                Around[0.5630167885021327, 0.03430433806696229], 
                "EvaluationTime" -> 0.0001394557303846194, "TestSize" -> 305, 
                "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.13084568441617372`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                424672, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.9672864600855424`, 0.22560715880154622`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5630167885021327, 0.02425683007126485]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[4.441728066917129, 0.75891259075072], 
                "StandardDeviation" -> 
                Around[0.46108779566083014`, 0.031573958120779975`], 
                "EvaluationTime" -> 0.00013683847771505932`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.06738506002480948, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 429144, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.441728066917129, 0.5366322392476852]}, 
                "StandardDeviationHistory" -> {
                  Around[0.46108779566083014`, 0.02232615989610358]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5568036730031378, 0.26143610600004974`], 
                "StandardDeviation" -> 
                Around[0.4031239691566751, 0.07363912944221301], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.17944909051975033`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 451656, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5568036730031378, 0.1848632433996402]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4031239691566751, 0.05207072778926276]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00025157034800970054`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.4031239691566751, 0.07363912944221301], 
               "TrainingMemory" -> 451656, "TrainingTime" -> 
               1.391017463958849], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[7.389902603967213, 1.3146851154990244`], 
                "StandardDeviation" -> 
                Around[0.4317296486714524, 0.03240791101387402], 
                "EvaluationTime" -> 0.00009501323862597485, "TestSize" -> 265,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.13187500302768462`, "TrainingSize" -> 50, "TrainingTime" -> 
                1.5848931924611136`, "TrainingMemory" -> 428688, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[7.389902603967213, 0.9296227602943795]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4317296486714524, 0.02291585364200052]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00009501323862597485, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.4317296486714524, 0.03240791101387402], 
               "TrainingMemory" -> 428688, "TrainingTime" -> 
               6.577306748713622], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.4222522004322034`, 0.25354559743369887`], 
                "StandardDeviation" -> 
                Around[0.5439516140460556, 0.033338463066055715`], 
                "EvaluationTime" -> 0.0001299709711359511, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.09646946151041835, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495456, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.4222522004322034`, 0.17928381128536294`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5439516140460556, 0.023573853308345254`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[7.700393372769614, 1.2644887335495398`], 
                "StandardDeviation" -> 
                Around[0.49235715169096994`, 0.03478589423362969], 
                "EvaluationTime" -> 0.00010526756791294945`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.0013384016992735726`, "TrainingSize" -> 50, "TrainingTime" -> 
                1.5848931924611136`, "TrainingMemory" -> 499424, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[7.700393372769614, 0.894128558226869]}, 
                "StandardDeviationHistory" -> {
                  Around[0.49235715169096994`, 0.024597341702237572`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.6782610711768793, 0.29282746517786223`], 
                "StandardDeviation" -> 
                Around[0.4248623705598708, 0.07054790614478174], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.13013848871795808`, "TrainingSize" -> 252, "TrainingTime" -> 
                6.309573444801933, "TrainingMemory" -> 522520, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.6782610711768793, 0.20706028634493398`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4248623705598708, 0.04988490283348727]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00031670830396331406`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4248623705598708, 0.07054790614478174], 
               "TrainingMemory" -> 522520, "TrainingTime" -> 
               9.471859998463529], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 211956848291295]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.0000126601783060921`1., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097568950341328`17.333472252889724*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 2.6574211064435356`, 
            "ElapsedTimes" -> 2.3696593999999997`, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 4.4290351774058925`, 
            "ElapsedTimes" -> 3.8177838, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 7.381725295676487, 
            "ElapsedTimes" -> 6.9244726, "ExperimentCounts" -> 2]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 211969733193183]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{2.342857453477421, 
              5.200288278290438, -7.987489123641171, 1., 
              1.6094379124341003`}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 13.8155674, 
        "MaxTrainingMemory" -> 963448, "DataMemory" -> 75768, 
        "FunctionMemory" -> 256040, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 48, 15.062057`8.930459235035011}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.3513804565861468, 0.21554516103397572`, 
                    0.16473891013321845`, 0.42857142857142855`, 
                    3.8245450859583796`}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.3513804565861468, 0.21554516103397572`, 
                    0.16473891013321845`, 0.42857142857142855`, 
                    3.8245450859583796`}, 
                    "StandardDeviation" -> {7.329660301041778, 
                    4.261053491063938, 4.035170550119767, 0.4948716593053935, 
                    1.3817756856631809`}, "Method" -> "NaiveSampler", 
                    "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.11710951775380742`, -0.6872196191103066, 
                    0.5049879948123852, 
                    0.18656114044203181`, -0.47349405691485835`}, \
{-0.0651163047996617, -0.48223061920260873`, -0.7672030382685476, 
                    0.41343923412853345`, 
                    0.06067119998341203}, {-0.5687086234961707, \
-0.36950139332255605`, 0.049369037157591326`, -0.5067098228269465, 
                    0.5299500688881899}, {
                    0.516735272449215, -0.2794182543981053, \
-0.27123801204852055`, -0.7053723150318569, -0.28946491207487723`}, {
                    0.6257798234751853, -0.28386085403795835`, 
                    0.28351236685015163`, 0.19989495540774344`, 
                    0.6383458096688409}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.3513804565861468, 0.21554516103397572`, 
                    0.16473891013321845`, 0.42857142857142855`, 
                    3.8245450859583796`}, 
                    "StandardDeviation" -> {7.329660301041778, 
                    4.261053491063938, 4.035170550119767, 0.4948716593053935, 
                    1.3817756856631809`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0182268, "MaxTrainingMemory" -> 92992, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 48, 15.0939711`8.931378462371807}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.3513804565861468, 0.21554516103397572`, 
                0.16473891013321845`, 0.42857142857142855`, 
                3.8245450859583796`}, 
               "StandardDeviation" -> {7.329660301041778, 4.261053491063938, 
                4.035170550119767, 0.4948716593053935, 1.3817756856631809`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.4230197168538874`}, 
               "StandardDeviation" -> {0.652990770274976}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.4230197168538874` + 
         0.652990770274976 #& ), 
        "ProcessorFunction" -> (3.710649257467373 + 1.53141521369268 #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-3.113765200741151, 2.3015942450903646`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwVkXs01nccxx+cijCXYrXHncewkUltjd/nS49xcpvbOvYcdjxEx61tWuRQ
LoVc4pkn5Z6oXCpHc+my5/v5usxzxqEH42jaUjGSlENMs2PTH6/3Oa/z/vNl
Gv5tQJQyj8c7rro5AeIk14QEcXLg1ncSKY7b6xD37nTYZMsmfwaH4/i1kxDT
6AzfeZZTieQKjDmcRck1IdoUhLN9wT7U70UBO12iCsHJ7aBzQQutxw04+Vg1
rozehGOLnXR84BNSNiflUoZyyXYrFxDFGuCpdY57eDgFwopOYM2qGlFUt4KJ
qJALctGnSTH7WFF3GXXe4JGmiWBYzpzHud4OeuQ9PlNK2IN3prwYTerFWl8x
8LtE5FWtDs2vCKHSeVXgjZSCXUAa6049g7ShEZd1tNiUcAjkcBaijE5D5HNj
1lzfA/G1W4mau5ANCVJAkVgFxnp8Ml9nRBIDNbjs/aqkvVIZZfJqtscjA4Q9
hM7YJjqPxjgSg9BUVFM5jLv0z8v8rjsR/9YRfBmeh47iVCIvFrAotw2u6kk7
ZF9VwZoeTSofWYXMHSE03UGVqMhKocDwC/zspxY6XGkGOl95ks4MbYhYq6K/
ZalzyhkKSDUXOZfrjnAObzzJh/JDTDKsS9RG41nRiBt51WAB23M+ILV3B3Hv
+nPI7fkIHlqehPt9S6iisGJlvf6Madzm4qe/hM4sZaL9wJyFh1dRk0cl8DQz
n0TPF2KHqSqIs36VlYWok1jdWC43+yn6b5GgbbEYllzP4Vt+Oz1P3KlE2Ij9
fU3OCX1FZEeAIYt7UIG5uaHcPxf/ki1crSc7gWGmvB6k6pmwk9wlM79cJGFu
JfTTgTyWVXmOXX97GaQN+kxi0QVplo5g+fUB7P/7P2ovdEEBv442NjtiUWsN
TKtf5lp6C9DebYnaFf6BOjfmODczMxIsncfXB35kgvVE5Pmucq2zNsxu1pZF
TjwDU4s20IyXOIW6HiXDpdFEd7Kaxg8aY1fsbmLeGYTLYnsm0rdAwycu5PP+
VDr2cpLz2iaggjsrUD47A/LfW+mEtyE5euMb8E77gXWuZYLaQjupE/2MPtbH
ibeFF8YMX+JMR42o9T0+M9eUkkv8DVhU98VHfhNQ+saTi25rQdvhZ1QxuosZ
CIV0+oUUnGazqd4tGXbX9mFkoRM3mT8M90Xx2NGvB1rpLaixPAU2umuw7diC
7F8IxFHXCjix+D4zDTMlSVUGsKIUhtFVr535t5ZhhCpgf4QJ2KsNgkB+hooP
zUJQcCe6xzbD7YwLaCTjsWKlHK6FOygrzL6JG3k88vheOecXM8D1fX8EHss9
SHJ6ImSY9GCWlSOcUmy2DbQjV5Jy0CBFG/FjH8xvC4GIsCaue7cH+R83d+4L

                    "], "Biases" -> 
                    RawArray["Real32",{-0.05448827147483826, 
                    0.11301953345537186`, 
                    0.049586303532123566`, -0.024942345917224884`, \
-0.014315977692604065`, 
                    0.06440119445323944, -0.005861174315214157, \
-0.035775285214185715`, -0.0002119048440363258, 0.06329989433288574, 
                    0.0041520483791828156`, 
                    0.022542336955666542`, -0.02221115119755268, 
                    0.05227293446660042, 
                    0.07439474761486053, -0.0448293499648571, 
                    0.06996584683656693, -0.0036265782546252012`, \
-0.022764138877391815`, -0.06183722987771034, -0.02718028798699379, 
                    0.03038964234292507, -0.027306891977787018`, \
-0.014909772202372551`, -0.007770754396915436, -0.0589350163936615, 
                    0.010921893641352654`, -0.034329600632190704`, 
                    0.006140455137938261, 
                    0.023802783340215683`, -0.029688788577914238`, \
-0.07167692482471466, 0.022465582937002182`, 
                    0.010761404410004616`, -0.07143417000770569, \
-0.024530308321118355`, 0.011912290938198566`, -0.09069453924894333, 
                    0.008367621339857578, -0.01961102895438671, 
                    0.08516013622283936, 0.0643002912402153, 
                    0.011836178600788116`, 0.0026740459725260735`, 
                    0.014495763927698135`, 0.011199175380170345`, 
                    0.0006089269882068038, -0.02102806232869625, \
-0.01705149933695793, 0.05160992220044136}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3lUz9/zx0uLVEohKi0kolQqS71fM2mhzZIkREghWQpllxYpUZGIkAql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                    "], "Biases" -> 
                    RawArray["Real32",{0.02600148506462574, 
                    0.05448365956544876, -0.007958677597343922, \
-0.015444950200617313`, -0.026863355189561844`, 
                    0.0004602964036166668, -0.019400089979171753`, 
                    0.026622412726283073`, 
                    0.022137943655252457`, -0.04669921100139618, 
                    0.0490170381963253, -0.07391920685768127, \
-0.011267413385212421`, 0.014277501031756401`, 
                    0.0038222919683903456`, -0.004162868019193411, 
                    0.05012672021985054, -0.0012619771296158433`, \
-0.01408112421631813, -0.07792901992797852, -0.05193863436579704, \
-0.00040857511339709163`, -0.00699372123926878, -0.007960150018334389, 
                    0.012693910859525204`, -0.0017989147454500198`, 
                    0.009267967194318771, 
                    0.06483935564756393, -0.023043544963002205`, \
-0.040415141731500626`, -0.0309341661632061, -0.01456671953201294, \
-0.03128056600689888, -0.03662806749343872, 0.018122877925634384`, 
                    0.041469573974609375`, 0.030475961044430733`, 
                    0.0447135865688324, 
                    0.025477292016148567`, -0.006032094359397888, \
-0.001427114475518465, -0.0614638514816761, -0.033516447991132736`, \
-0.022678593173623085`, 0.009084787219762802, -0.00031500787008553743`, 
                    0.04547400400042534, 0.005203323904424906, 
                    0.02806537039577961, -0.06936786323785782}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c014/3x+2RmR0lUgktofB+3Zu2CkVLQ1JKw2hKKcnKKCRZSUOFllEh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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.01784466579556465, -0.0239943265914917, \
-0.015059313736855984`, -0.06661643087863922, -0.013824418187141418`, 
                    0.030709700658917427`, -0.05740229785442352, \
-0.016844438388943672`, 0.0402703657746315, 0.017589455470442772`, 
                    0.0034919355530291796`, 
                    0.0011392892338335514`, -0.014704565517604351`, 
                    0.007685787044465542, 0.01744324341416359, 
                    0.03744078800082207, -0.009002930484712124, 
                    0.0055076382122933865`, -0.04938459396362305, 
                    0.00529421865940094, -0.03322503715753555, 
                    0.002008529379963875, -0.02384432777762413, 
                    0.02983194962143898, 
                    0.01809406280517578, -0.007386989425867796, 
                    0.0018935238476842642`, -0.0025472480338066816`, \
-0.011266542598605156`, 0.024425730109214783`, 0.0025790242943912745`, 
                    0.007041097152978182, 
                    0.011697315610945225`, -0.020044703036546707`, \
-0.00985475443303585, 0.025538509711623192`, 0.01461762748658657, 
                    0.017098423093557358`, -0.0025932807475328445`, \
-0.04572999104857445, -0.023679442703723907`, -0.011633004993200302`, 
                    0.025286061689257622`, -0.031434543430805206`, \
-0.025538470596075058`, 
                    0.006225102115422487, -0.02879011258482933, \
-0.022045833989977837`, -0.026096491143107414`, 0.030049651861190796`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtd3dYz9/7f9qDSgpJS0XR1O71vG/KSkqlJRXJFpIikmhSykgqbWmSlBT1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                    "], "Biases" -> 
                    RawArray["Real32",{-0.009149770252406597, 
                    0.0023451363667845726`, -0.012224884703755379`, 
                    0.02552482672035694, -0.008456866256892681, \
-0.03594936057925224, -0.06560394912958145, -0.006287539843469858, 
                    0.033666301518678665`, -0.03237951919436455, 
                    0.004521417431533337, -0.0566713884472847, 
                    0.005968807265162468, -0.019723620265722275`, 
                    0.017746450379490852`, -0.006355064921081066, \
-0.005658627487719059, -0.012352414429187775`, -0.01705864630639553, \
-0.0073249018751084805`, 
                    0.005968117155134678, -0.026135005056858063`, \
-0.027648910880088806`, -0.0015008649788796902`, -0.008888686075806618, \
-0.01608888991177082, 0.016024410724639893`, -0.0015085393097251654`, 
                    0.019746171310544014`, 0.011008776724338531`, 
                    0.034167565405368805`, 
                    0.03516334295272827, -0.01828119531273842, 
                    0.015065052546560764`, 
                    0.009071199223399162, -0.00295632379129529, \
-0.04415510594844818, -0.03861977905035019, -0.021316373720765114`, 
                    0.008226449601352215, 
                    0.055737778544425964`, -0.016567425802350044`, \
-0.015552820637822151`, 0.020308909937739372`, 
                    0.0110062500461936, -0.005176061764359474, \
-0.017513828352093697`, -0.02634573169052601, -0.0010161035461351275`, \
-0.022323589771986008`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{-0.11552315950393677`, 
                    0.2501068115234375, -0.28056296706199646`, 
                    0.26036667823791504`, 
                    0.07622644305229187, -0.2166566550731659, \
-0.098300039768219, -0.1063191220164299, -0.05656187981367111, \
-0.17187057435512543`, 
                    0.16734230518341064`, -0.12036016583442688`, \
-0.11237199604511261`, 0.05340462177991867, 
                    0.05076247453689575, -0.14863450825214386`, \
-0.25220242142677307`, -0.17615751922130585`, -0.17893272638320923`, \
-0.008981944993138313, 
                    0.1599888950586319, -0.0696200504899025, \
-0.02664678357541561, -0.2297503799200058, 
                    0.0017223398899659514`, -0.011208860203623772`, 
                    0.22240695357322693`, 0.2538411319255829, 
                    0.2555693984031677, 0.05777382850646973, 
                    0.23175892233848572`, 
                    0.01976054348051548, -0.08986719697713852, 
                    0.1448313146829605, 0.25745832920074463`, 
                    0.041836634278297424`, -0.07641028612852097, \
-0.1813937872648239, 0.05161828175187111, 0.14889389276504517`, 
                    0.1835290938615799, -0.2688100039958954, \
-0.2665920555591583, 0.02705516666173935, 
                    0.16572320461273193`, -0.08618604391813278, 
                    0.00635419599711895, -0.19267380237579346`, 
                    0.07607121020555496, 0.1587498039007187}}], "Biases" -> 
                    RawArray["Real32",{0.021073095500469208`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.8619787693023682}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.0973916, "MeanInputsPerSecond" -> 
          50221.76440201299], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.05137619234598285, 0.025363559869356084`, 
                0.07158664905700256, -0.024533224966137173`, \
-0.0012270514431276872`}, 
               "StandardDeviation" -> {0.999671769230852, 0.9965737985995617, 
                0.9938173411997046, 0.9962334739984703, 0.992821432751315}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 6712086033293239617]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[363377], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.4261922841471343, "PreprocessingTime" -> 
        0.3710362`7.02096127694738, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.6342473555733653, 0.5013405387050183], 
           "StandardDeviation" -> 
           Around[0.3904295742253078, 0.09769387708156732], "EvaluationTime" -> 
           0.00025157034800970054`, "TestSize" -> 63, "ModelMemory" -> 99880, 
           "ModelUtility" -> 0.19849594382615177`, "TrainingSize" -> 252, 
           "TrainingTime" -> 5.011872336272724, "TrainingMemory" -> 451592, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.6342473555733653, 0.35450129460203517`]}, 
           "StandardDeviationHistory" -> {
             Around[0.3904295742253078, 0.06908000296478128]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 156861007818224]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.5136244668415446`, 0.3810725215426288], 
                "StandardDeviation" -> 
                Around[0.6343771038222609, 0.03349492690444414], 
                "EvaluationTime" -> 0.00012738180561453242`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.24857212504375126`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.2589254117941673`, "TrainingMemory" -> 
                424848, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.5136244668415446`, 0.2694589641066495]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6343771038222609, 0.023684489949480185`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[13.069529607096916`, 2.352662737684457], 
                "StandardDeviation" -> 
                Around[0.4906295873488592, 0.03925060403899089], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.0030131310549649237`, "TrainingSize" -> 50, "TrainingTime" -> 
                1.2589254117941673`, "TrainingMemory" -> 428752, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[13.069529607096916`, 1.6635837756615872`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4906295873488592, 0.027754368281638547`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.6342473555733653, 0.5013405387050183], 
                "StandardDeviation" -> 
                Around[0.3904295742253078, 0.09769387708156732], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.19849594382615177`, "TrainingSize" -> 252, "TrainingTime" -> 
                5.011872336272724, "TrainingMemory" -> 451592, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.6342473555733653, 0.35450129460203517`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3904295742253078, 0.06908000296478128]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00025157034800970054`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.3904295742253078, 0.09769387708156732], 
               "TrainingMemory" -> 451592, "TrainingTime" -> 
               7.523765832135071], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.5896302358846657`, 0.5709033273731651], 
                "StandardDeviation" -> 
                Around[0.4360597513404022, 0.03530350371669897], 
                "EvaluationTime" -> 0.00016249866665033437`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.12073253054981092`, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 499680, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.5896302358846657`, 0.4036896141875285]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4360597513404022, 0.024963346877722323`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.4960615586723505`, 0.27163628487345903`], 
                "StandardDeviation" -> 
                Around[0.5822903084557246, 0.034117876766343126`], 
                "EvaluationTime" -> 0.00014342569646407457`, "TestSize" -> 
                305, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.164045332504692, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                495584, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.4960615586723505`, 0.1920758590503437]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5822903084557246, 0.02412498202116818]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.6767491507459155, 0.6403313906427182], 
                "StandardDeviation" -> 
                Around[0.39046594313994126`, 0.11442535901554934`], 
                "EvaluationTime" -> 0.00015873015873015873`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.19027702116730427`, "TrainingSize" -> 252, "TrainingTime" -> 
                1., "TrainingMemory" -> 522520, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.6767491507459155, 0.45278266853007815`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.39046594313994126`, 0.08091094729960019]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00015873015873015873`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.39046594313994126`, 0.11442535901554934`], 
               "TrainingMemory" -> 522520, "TrainingTime" -> 
               1.648107170553497], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[9.632025346665154, 1.760974753247851], 
                "StandardDeviation" -> 
                Around[0.45184831592585883`, 0.035737589915478284`], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.08553305113844567, "TrainingSize" -> 50, "TrainingTime" -> 
                1.5848931924611136`, "TrainingMemory" -> 499616, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[9.632025346665154, 1.2451971895198626`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.45184831592585883`, 0.025270292172498668`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[3.8073960081174443`, 0.5886862517362231], 
                "StandardDeviation" -> 
                Around[0.6176876286805365, 0.039524834628857954`], 
                "EvaluationTime" -> 0.00011928350291736266`, "TestSize" -> 
                305, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.22412514577538956`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495664, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.8073960081174443`, 0.41626404059397437`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6176876286805365, 0.027948278591342336`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00011928350291736266`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.6176876286805365, 0.039524834628857954`], 
               "TrainingMemory" -> 495664, "TrainingTime" -> 
               6.577306748713622], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 156856712850928]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.0000109773553719008`2., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097569114820298`17.333472254764704*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 2.659864420132365, 
            "ElapsedTimes" -> 3.6681847000000003`, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 4.433107366887275, 
            "ElapsedTimes" -> 3.8058151000000002`, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 7.38851227814546, 
            "ElapsedTimes" -> 6.645217799999999, "ExperimentCounts" -> 2]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 156869597752816]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{1.4281067184743153`, 
              5.165011933852659, -1.2213463494536325`, 0., 
              3.912023005428146}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 16.4575002, 
        "MaxTrainingMemory" -> 954648, "DataMemory" -> 75768, 
        "FunctionMemory" -> 258088, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 48, 31.5209249`9.251173856859115}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.04234761684719868, -0.06408263537281496, 
                    0.01654995742754136, 0.5365079365079365, 
                    3.827378654863957}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.04234761684719868, -0.06408263537281496, 
                    0.01654995742754136, 0.5365079365079365, 
                    3.827378654863957}, 
                    "StandardDeviation" -> {6.663388385322805, 
                    4.500311115098071, 4.340534004591226, 
                    0.49866538938644267`, 1.3415510206249994`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{
                    0.4694553652891904, -0.26957655568423905`, \
-0.39654195279259086`, 0.6567277708282123, -0.34409774094733714`}, {
                    0.4747529014335822, -0.2869975414443786, 
                    0.5815064329716008, -0.3559219176310179, \
-0.47687729107998206`}, {-0.6839224708614571, -0.32467712715520697`, \
-0.16144405018804328`, -0.0714422355384039, -0.6290203832890925}, {
                    0.2610998758524549, 
                    0.5134782251705964, -0.5496126216975362, \
-0.492150220091393, -0.35196746162144227`}, {-0.13527102890929849`, 
                    0.6898447413789575, 0.4200791982682856, 
                    0.44126227055815087`, -0.366929226546154}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.04234761684719868, -0.06408263537281496, 
                    0.01654995742754136, 0.5365079365079365, 
                    3.827378654863957}, 
                    "StandardDeviation" -> {6.663388385322805, 
                    4.500311115098071, 4.340534004591226, 
                    0.49866538938644267`, 1.3415510206249994`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0148405, "MaxTrainingMemory" -> 92936, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 48, 31.5498472`9.251572164847303}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.04234761684719868, -0.06408263537281496, 
                0.01654995742754136, 0.5365079365079365, 3.827378654863957}, 
               "StandardDeviation" -> {6.663388385322805, 4.500311115098071, 
                4.340534004591226, 0.49866538938644267`, 1.3415510206249994`},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.428575232740297}, 
               "StandardDeviation" -> {0.7238006869384689}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.428575232740297 + 
         0.7238006869384689 #& ), 
        "ProcessorFunction" -> (3.3553093780729624` + 
         1.3815958150437775` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.8014679422007056`, 2.08410318209142}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX001XccgO+lS6cdWlTLpSJ526y8hA739/nkZV5G3HDKKu9ZWpqRuNbL
lkJGEa7ycoq5OesId10U/b6fr0ontcnm0NuUlTNjKXUs1svW6o/nOec5j1VC
avjnehKJZOfstwqPz/JOT4/PjjB4F0nxKa4uKe+my1tkb4mqPE6OPBWqHeXQ
2OvKenrSIGdwH1nm3Gemg4nceQtn+xqruMtDE+iUNoKDVkZPzc4r/vPQEhZt
BGWkL2u2ssTH/mbCcFARnq/IhXInGeWxFsXWPF+QREbTkMEctNo9DneCZbD4
7xA25CHwrd9tY8H6w5CkXQMluvsUxEqZQ5MFT/6sksXuCeVBuieU9MIHbqxO
wLh1Sax2OlYUix3goV4LPHQ5yBvNf2I3NSfIqX0+39/zBibqa+BRz2xoNnbk
Z7/thoBli3HHLTduaNwEv5/WQOJOE/zIYiW6J6rZxKsP0bPfjDzPVXObHa0w
vXweHfoig95rD0LHMnv62aaMxPwZ4XGoO5oPXaaFq+VUsCAXG47LueyKMcgy
y8FWV8jE7hR2XfEcLlytFrW/SBF3fw/KcDfKQSN6/3QYdMmVqLnYJ2y7lMH0
VF8L/YcvwTPlNeGTU7cFr4YE/NFdwZ9nLcKbEMvHR/zQJiQaLKrkuCHtClnZ
jYC9yVqIi7aGvW9myA/c+NAuBZ+Z1BM0PpshL8wUt0TY8ZLC64wPp4GBfjEG
dZZQr60DuJcZClGFUkyYVSKMLr9CVel1lCAehTJcRQcqPenfWbWK/uQkuvpb
m6LqtRpHjy7lVV77Kf+ytxATkMsGnjZienM7DcZchOzifOHTJR3ooynCfa/K
2PaKk3zzKiUP6OmEO82TpIoxwLRED2g9ZEjJc5dQ5w0/ilvcxlKblLRI+yVM
nlCwmYp6euRiQGuHJih5qFOxMXgp7tg0RQ+cSrhp3xEaqzkoqCTOfFOcK/8j
3xDdwrWQlVIuzrdchxMfq3C7+3VmotPQMtVKrJ3yp+osa27nM8xCBryxdcMz
tibrpDCxolA0fyrBBy/uQMjdNuY8YolnWiKgaSyGu07WwfbSJqwwryGvst14
rMOFGlaUCtLs9YIYOI8H9hxD9SljfD0TRU1Wt6Eis1dQOQzQmLae/SOYcZtB
W5LvdIMfzvSKt0b7yMnjV7L/aq9XpflNOLcilWoKDMFi4hqpz+pAz1iKXZ1q
RbS0iMSCOgibY8nXG83F2oWe8KDVlzpku8TxpHGwTuuCepTDS90ItP2pT84Z
izDT+i9SDl+Eb5QCecW/pIziDmFBjeOFw6oWsu6TouWlQcH13oxo2r0Hps/5
472uTeAb2U22U9tgKtKI7pp7YVSohkrXGBDEHaHYJ2pI+ECtCI4PxP8BBWnm
ag==
                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.027100203558802605`, -0.06073014810681343, \
-0.1005212590098381, 0.08940383046865463, 0.008368824608623981, 
                    0.016566863283514977`, -0.02591596730053425, \
-0.07205389440059662, 0.008790167048573494, 
                    0.024373965337872505`, -0.0241891797631979, \
-0.04192432761192322, 0.046011701226234436`, 0.0335114523768425, 
                    0.1052689477801323, 0.06491616368293762, 
                    0.028319794684648514`, -0.04870159924030304, 
                    0.06663460284471512, -0.03339496999979019, 
                    0.04588428884744644, -0.04879032447934151, 
                    0.018468191847205162`, 
                    0.098038449883461, -0.01039451826363802, \
-0.013082788325846195`, 
                    0.04874599725008011, -0.15812937915325165`, \
-0.018329491838812828`, -0.03739131614565849, -0.009655874222517014, \
-0.02849026583135128, 0.043802905827760696`, -0.032392553985118866`, 
                    0.03581003472208977, 
                    0.055463675409555435`, -0.004833390936255455, 
                    0.032554931938648224`, -0.029754554852843285`, 
                    0.017018970102071762`, -0.11618407070636749`, 
                    0.017910564318299294`, 0.015223612077534199`, 
                    0.021405469626188278`, -0.03156974911689758, \
-0.08878166228532791, -0.11116482317447662`, 
                    0.06308885663747787, -0.015824658796191216`, 
                    0.007671022322028875}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c41+/3x5FdSLI+tlQkKym8X+c0aFGRlKgoJGlr0iJklBIlpcx2RqWs
9+ucQntoUVo0lCbapfXre12/P+77uu7r/u/c93k8H8cseLFPmJyMjMwy5X+b
z+xVIyIjZ0dNVvzfYc7sBY6DFvzvctD/r082c2HSpwfiva2H+NI8WbY+8VDc
u2iHdOyEUZzr7ituWJBByeoZ9N17A05cJYtb7N4LC311uO6iNUft+gi5GVEw
5+Fazi/piWYKaRK1Cns8twPpTP1RcmqSh9mtE3Hyt2KSX/2k6ovCAbLQteei
B73RJuweLRmdj56/9Vl1nBz47E2UWAbKkbvnApY6Lea/W4fS3ikmbHVJiWvc
LlLobF02jnsp5n9CNpHu5PnF2rTqoDE923mR7ONH8MCr+8Wndvtxu2YgZ/pq
YvRsGXz7TBFdG0LB0K9dsH+RKG642h83Pv8N5xZtx9O3kmHfA03ca7tDYhTw
E5a2ZOGzGcdRq0oq7HJIoFNZSlw2YSp0t5oKCd99IXRsb3r+y5JNg4aia/MY
NKxsrna/sJR3/tjFs/ua8sCUQjpRU0WPnxqysepQWhjaIpa9Gy8JdZ5EMvlt
lKeTAx7t+0nF+BloXywEdzd1Kq+qoLxEBxSEUWggP4C/5kglcTRcvBhfJiqq
9wV0GIJ3IuLRcagvj1s5EtNBBssku2Du4zWskxyLOb2fU9PSVvGA6j3S98yA
kw264tgbiyB66AIKOLyfUhQO83NFedz1+zxF+W3E9bVFaHOkD6xXCEbjyAjc
Y69MJQEnyWX6LjpofkJSb66Epl6tNO7uaYo7bYXnZz2F6QXe6K8+H6625dHM
/IN8ZXs2Peqmwuu3KLD2uhTIvLMPJy5toabaSEoKuwkn6uL4m9558d6PBJii
lghO0X3x5+Fm1yir4bzVtB226HdSkvQTTNM15J2RDuz7OJXrmzbx/sRGsbDx
nXD/dTyd608wZy6B/Z8NfPjDGfItvSioBXjRMytfDvppg5Pv9salZ9+A9Zu1
uMHak90G7YSMjiDBfekZkDQ7Yu+Rl4SRldOElyuL6FFbMY2bDuy5bRU1zI0F
26EunG27n9zW6aHleQlPzxpJrY+SpIXrT1HfVZrYNbyNTH5Pg5hmwLj/BvPc
HT9ohrsaH2wcxPPzo2mH/WJq2jMWVmqlsKjVKZg9XC7kH/Lnu6NeiI8mmuCg
9FraeNoFe3yI4UiLc/gs3gjGDkykZYuC0P9CWvX6YalQrr6VWlNcecDtbHKK
60nD9WvhgFsGdUhHocPkRaQR6Sj1CWwWi7weUPqsVOmD1DIa/T6LfKJqSFKX
jMuWZMCn1/r4vTWAcjW6YMWxGbjRtwYEcyuuH32ApmzPEsV1AXRJ8xKkGY3l
eOkqtls9WRhttFrY7mHFn6L2gqHbURqyJBVL+JtUbUOzuCKjEt593S1eqIzB
l0OLRNtDEZC5cLkkzFyJpYfMMO2/d6LfTkW8smoVJTbtJOGAwJLAV6SYvpvm
9dCD7FvPBfe9u6BLypj/QhdrNUNhemQv/vGgGnKidtNaZwMedLQUjxrn0WPt
XhgXEQm1Ch44pTALGqe/pQSvQvo1OJO7Dl0QoofnQEpT9b8+2QM3Bt+jYYlp
sHfWH1GUuUtnPw6iL0M3cnzbUfpvTSIeqHgPD1NUeX9XHCtG7xcltfrces8Q
zs5L4jVDJ/LBk7fEm4bhmHfEj9+YFfCKZx/h5aH9QohrsqD5p59YsFQeZhWt
Io0fJzF0pjw65T+geX01sH/WXjL4sZLjh+jx8C/T0H3BONR8L48ahmZclbuS
Zb7U0/wpsSz7KRQH2zrg2d4a7F6J3PnEnCZvjaUbs03xTXUJGB1V5gVv+7NE
/j19dVnK48zVqFxrAzTefwUXuju6atjUgY11G3V8mYH3fl2CiuZODK6uplSZ
OwKtNuOMjhR+3n8geIzz58DYUSzcno9u0ockXayOd9SlovMeJ9YK2kwrPp0R
1sa0kVySB9tF7aR6yoeGy/Xi1OIk3NC1mRZ2OdCLmkz4+qJS9PkQyBEd94QJ
6kRaNgy4Pw3yozPh+qd1oGhwBGTSE+nAZhls/PwbcHYyHFQwQDkXNazPOE4D
NvQHmV+j8NQmb16hO1U6/k8PDlKZxidO9xZmFqtSVGo3smo3lb60j6ffOXoU
m5wAhQZ6WKIsiHo6IvSnE8KaGa7inb2ZYp7sSRBzpnLLVnMaZhWCXTnruJuM
EnueaaE0pyZRf+UYfKYwkd8p5FHCDUWe6DxR3HzJEH8kh/DeJZb46K0DstwR
Ub/nCdGl7T6tah9KX3cZ8ZjBTowm8TQt4CI0LjCiB4b7cbKDBj5qDCClw5b4
LDaWQiZacHa0NlhUDOA/crmYs80A4xwOc49vN0V9owIcM+k6tW6aSIceqPH7
HYnixvu9cNrX7hx1dhYapkSjxzUvsHh7QFL8IpqmKw8A+ZDuGFuihcE1ZRgd
coLibp2SpjlnSM1Kuv7lhxPXZXRRo0UU/p4ZI55ZKsdntldjr0t92W6QLToX
DKOhnnrQLdUe0ww3oeWx/XSn9wKSmZVJaZOzaVJWIngveeYyK1aCKSM2svrT
Vopq/wHne1hC01kXVKhBYXTYDNy35wcMMXpMAZ6FgoNFMbpZPSB7Lyuh7bQv
vcgI5/QBg9BcWE9Z18Lhl60NHbKcj3ndDHBZz9vkn6YOX2ISxYWu69l4yXgc
k3gIkix7YsuJsVzfbQve7JlMee16uK4tTdTLGUhen/sLoXHeOC9gAklC26Co
ewlI3lVB4ttoceBtF1ypMRndx1wn27oczht5RBynOwh36qzCef0KsPqvCpf/
tKWmhyNpcPl63D9YBR+H3sTcqlQem7IaPc29QD1Fink1fdCszY6+ftpN4ZMO
wZidj8Vdis2ibOJSPPu8hh7cNsSzPqWUMuYthago863Jtyj+ojyXnqyFKw0l
dLhYlp9tNeWgryLKRpzlcNMk3Ja+Uwg69g4WXD+F5hGLYJefFd+OSpEeHrIH
B28yhrYEgW4Fa1LeLY/qli1dUiu9Nah4QpUbXs1EvS9BuGnTNlS8uQsXPtki
KE/uTmqHNXhQgTX/DWuiP7YVtH3vMKxRLeAeF77D0b5GaHH7H39SlYRvJz6C
tv41QXVRBM/QuilRsfejh57OgrWrMS1YPwN6nVwP6k2LWc26G09/OAuLgu/A
llw18vOQcOPZJMEjvQc73OuFGy1Ow7CsVii13EO+uxN5RY0dWQX64r3FMcJF
Hg1TJ5SSs89+6HsoHa+Ni4fdkkB28zeFq43tdDRHD093ZWPmnxmsahtPn4Jn
8NIAa3i5eqXkcbdCHt88j0f2kocNtptJMmUs5MQpQbSPDvXdEIsGC/pwecFU
1IhOg5rhyuLsTwIk7tDGWQqGqKh4HGS0zTC8z1b2ct2O45YPR5vIW+JqlSyW
nCqkAcens6PmVvFKpge9/rqNDL4P/5dDJyjtQB7/+bAEvVS0aMGAbHHLk3HI
07V55ZtEPifzlmyzKmhg37Xw6GYCNx37KiYPVUbFmi7YldofI2Zf5TiJE8/J
mQ5b/PqgRfISXuj/kx4K+nT4zGqyWOmKoQFrqHTVNH68yYqsI8ohOPs+2O9p
prSWZF5amCB82JstLAgIhprUL7S/RAsakztcHBOPiW6GanyydBz0u35SXBsy
THxkWOTS9NOHTv77w0P/NMISjV9gVKmEvRsnikXhCVyfU8dL1/2F5UUj8dza
CrgwNFbY0jGWV3O86PjMF/qOyBLvBWpznIMhdBv3mCxODeAdF+RRbaoVDr/9
H/b0cMWdXW/h1MzPhIc3UsLf6fjsSxyGHPlJ5vJPKWRcmDBt1VuI8huILvfH
8/6xtuQ32A1+LbiGIbbdaJmfIaqGJdDzTE1uH6HLeVeTyee9LP99Ph67bv6k
oq5kLHowCL8v0sGMDxtYo60v1gW70jwSsN/mOWjsaAVB81/BwM4OUnW6Jo6I
OEatC8Ohc2MhHpjYg7/brKX0HaHY8P6sNNK6jE0c+0LxtVDYp15J3pfrwG+a
Ay/p+AjdF3wiGZ8UOpI2j7d+dud7g+X5v6oHmP20GOSjNLBfa52gOnMMlxgZ
YciyBDzsZYRdSYZgu+6V1DOjgdq7tsNq3yxqm1H4711DeUjSZuoM2yJe11Zn
m8FdNPXHTCrvCGcdT2f+VuEFc2Ofi9vrc0CJGrFblDXme40AlWtW4rPaXXz3
0zi+VOcq1epQF8MVbYWBmdZCUsgdWlT3TiyYaU/21xxpiMl+ete2mXbNOEgt
w3/Apteboe/ja5Q5TwsKfJNoQ5cef69uoZ3WZ6inTSwkj3xBbiH7CQdVcGr0
JehweUEPFjfTninDeFpfFn+WhlCPtdF4PrAd5FVKhK6LipS1WgZXzQoi83Id
TsO9tCNmCh78XE0q3W25vSGQn+iV0/AmLx6n0ZOsR4TB2nRTzDZ4IWTKpMHI
00r08b8A7PHeiq8tVWFPk4tiCRwX97xeKQSFqnIvhWPQPcuR5/nOpSK563xX
dREdGbwcmm5ch9neBmz2pi9pnvPEC5TNV0L8KW+oBb+Z0B3//LalmH/O/ai/
Hrd1KsKcE7rQOCGUJi6xh5Nh4/HAYR3uvrUHT1n4A9qeycH490GcG+kE5KvC
eUdSJePX1gppQdO5Qj6KZrxqIpOAD8Las+dIdqEi/Jjyipo3JpKm/A/K755P
P79vgZhKd/HDGi9S3ePOm6eNhdzli/nO2U1g+Nmf7104RiUR3UDnwGZWOD+B
fZ70xa0/lkFtnxysH7Me7wdO5KUOf6jHtT5i370XaJJmgfTX9jRULMzmo590
UK5YA8sfeLu670yBUTF+8GzueOxZqcHhDdvgzaZ4oXLoDnowJ5HVvjwFrWAF
tnGvpY6Vu7H3tQ6a6eoEq0apQplCF/R/pUnrlhTT7jtjqEHqAa4PM7hpXyM9
SSllrQUpcLtoAYRd9MHCzErwtx3EcY3yeOm5DBuPLKLzD/+5ySdtNrG+DIe+
PaCfwxjciuNcY6b9Ep2LVPHynhu0NjtXWH36qegYVA6qL++A8sxdMCClHcpp
F1Rv6g9TLJ0w0fybeKv6P7b9uBhGvzHGad23c7huNKR8NuXvr8/hY9skYaiW
XZVRSF8sm/lTeHLNWex/ZwxvSJQ9cyisH+5o3MKhL7bhvqeprqn5kTTJTYXl
yIg7I5PoRGp3sZvTTbQ+XgGNJtkSn/8aYfIMWe6jriEu9I+D9Ht+uDBNF7N3
3+X7WzdTFz+QPtl2gSJlM2mXtAyEJjnxtJUtbI+YRXcq9+LWb3MEn8m5wmXD
TknH78H8NvcseL4z4H2vItnAZp4YmppJdocNeNdHWeE2L+Clq9zFLbNk6RTK
s9qESHSY0I9dwtRRDB6OLmZ/6UbJWvr7bD6fXDwIow7049gvAbDmrjcGfUiQ
qh8cwF9+WPPtfZ54essXEN6O4ArLqzTysBK3n/AXptrFCsrdOqDg4VZIPDcF
46euwgZzZ/47I4NULonSJd19qPSMDA+K2CG5cOYDuJeVCtNjLdhibwt9soum
RNWpOGRnHCyPGoOFIAPnKQeKepQwtBdQ0Pcx+GdTN8F/7RRQ0IoB3eZZJI3s
JMu1czgyfwmZzJvNB3UkNClkFm8zd8ZahRmC3JIy+jTYlEzCvgttt/y5tCMO
FazbhLHXPDhEX59lH9tx6Zp2aq49IJyszID8kz3ZIH0jKhUuofir20CtKkN4
O7gYDl3PJy0vHTw3zo4LT+fB7z+m3Nf4t9ht3WBoTS4WpRnJNEYhxvXTuvn8
Qej5jxG/SMF9Dh+Z4Y1XPY+QNNmMty52A/2+BixbvxtKVMJhrK88dej1ROG4
HNtsaxArnjrTNvtiqj/WTwh60B8bnijD5EcLIFHuAOvHGIMkJYU9zgdj9Jc8
YcDCm2KAxTLaLtcJdzdcE/z4A+jK+ELdXn3s3eUmykdsBF/7Eg52joER4QMx
x2kc5jvqYGCHLPvOa4agKaUc+MkEni1Kg7h9I0l+UDf4bTee8r4n8DHLEbR7
Rx5MKLoAMRNzoXmjMb4blkHjisZDamGTUKn2DG74KuGvMd04MEVAt3OfwP67
LZ/4uBP0EzQweM5i4V6oI/L8fbhEsGeLgLM0vvCucGq3Gr8xTcfc+xv5TS+J
0O9sLgRU9OK6D0Zo/PoDNaV20o9hutjabR0uGx7Bf7U+0rYdunDphTrOnVBM
U2uDac5Cbf4SmSkkvdlFbd2s8YFud+gTiYLO0N/07fx9GNCQSFf+zXqpDWXg
aHSduuJKhCTVUfQnVpvv3rsvNNcO5BabqeJnw3QoD+vNJqOPgonBXlj97YFk
69bPpKl/XfT7nIJ+SmYwG9aIj1siwLO/Mf3WbKeYf3XcahyIsp+/0N9PprBN
4ZGY/U0LG/fkCNIKFXZQH4O36zXE/V8H4qjka7C+93WwVNglfPmRjG1DrDD+
pyIfKfdBFf/hbHf3D20a84cs4ifBU4mVxDJ3Kqc+Msd+bukwdSML20UH9hbl
cGUZ8tZ5gdjZ6YlD5vbh1Zu1MTjSSpwxfjR/PZDOod7q/HHQBejnpY4Ukclj
d26BxSPPk6pPkYjnfdlx5xo+90ceq1oc+Cz244H7ZHmHqQf6D9DgXfHb8OKJ
33S9ZzqvEVV5WTFChfwQ/HjPDnQXRHPEw0B+aOCF1zp2guI9b5hirMtVJZXS
xT9Howr8hr31n6k5Yywdsr0oZIcFcHf7ZNbt9hS+Hf1KicfO8MDJqqyedkro
E/IEvkbVgtrTi+C6wh4nzO0BXXfM4ZLNS5of2h+meofzaiNzts/9CyvaDSh4
6gHY0C+eJPrDuOuOhMuX3ZI0rc+hfiG6lPiwG5hvNuJ1V64IbpnT4UpSDRWU
HSOL5xXCwcFNrgO+ycMzF0V4/7qGv4RfgtBeMXjs3/ypcVYNq69eq85auE24
55jPls1byXC6NRvULsVM+2xe4vMfFoyS4ZtSZzjenEbKnoPAPkgOj4sqPEiz
VnjZeRuuRayFGg9PPqGbBo+XWFLvTypi7fwLQtXfPeKXMeV0IOo7aKb5UKNi
h5B+PBEasg0w2mwphK4/zqu668PL6x9pf/VYtL7yXrRMUuMBB5uEmTU1FDhf
HkdVSigoN4HubJ8oKY9dxzcXu1H/i5b4Zps5TbgTi4fkLgvJ1zTg3ZhRuGmG
iXD/rY44fyeJLTm7qccuM2juSJdu1s+mD9EiTcq3Q1W7eup9xZH2v55IuevD
JYXv7kP1mViWeg0mqb4n9ywxFgxeBOOhYY+FC97j2OFqd6z2CoWEPwqYWdmL
5evk+P4RgXMajsOkdy9FGQ2iL7kW6LdmMocNHoTP9nix0ox6GJD7H0qjM9hw
hQw2SF7CRuXBQmLdk+qeF5fDWHNLeDdwE3sFzaFpTuq8+epQnrtbh5epyqGp
nx861b6jeLflHN9SJoaOigFh+Raq+DGQA5J/QGSwA5etWcmyz4/Q94Z7oF1+
FL4+vChIo9V4bfVZWHljNa63fl8tF31U/PxhEE7YLc+3HtlBwpUMwa7GnedI
JNzgcZsWTi1Eo3fvISC2WVhWZifYxttRzENbHK+vI8RWzRaUpx6jhFtPweS9
LQ9XsqMfLeepeJAZl31sgTFXjGlwoT9cvunFjbdXgFrbexHe5WJAhRP7F50V
324biDPwI6x/lYIaUdE44ZE837Gq4Sl2PXH61EtSo/hGKI9xwaUbtchs2iH8
sHsRfWv2wQSDTNxp9gr61n2CGTlnIPqsPg5JNeNE7fnizKs5dE/9jqB1ShnV
8ptoev+5dGOKgLOUj4PK3hx6m5Qg7PdPpsHWrpjjspXkQ1JgeNQ6qLncB3Wm
38R5Bj60Vu+I4L08HwOPrcGitavERE1bsdUihMa/X4DLEmPwqFwZj0r6C3LJ
E8CkpzV/qvAgx2VSmtNtDyjdiSR71z7c6mpK+0KuCCPTfaSHNjsinkiHhZPG
c9sQJfD5box5PBzF56e51UEbR3xOlJa9vUDtBSbsnHpIdJLtRz9X6KDR6kN4
ZEc+DL1izQW3vXHKKDWseDUa7nxZJgrv1/DJzlTxkGw0OrJIwpXs6sfiJNFl
aDyMaJgDVxUz4Fi39Swx+gi+cj15bnsW3wg/JyRO0qVMvdHSPSPHY+7Hw3DM
pQWHn7zoqlN9E/5+KxGywuM5odKNw+5q4ojSd8K9Cw9hy/oE8dEmD1Z6TdLa
DWEod8wZHzXLYrdpyjhJrhQM1IcJuTNaSW60Hr26PZurPY+C+MQal68ywXMK
22nqOEM+nmKCjX1aRNN/jvt59ArU3aSFnnuXipOGmYBeWT6NGGmKGYmjIefo
PNJap0HxqUlgfqAP1y66AP7yR0F3aBttiFfm1Akj4GtuPlT3WS2KBWdJ9mQR
+mZNZIfW6Tjl22nB+bs9b25soJ/bJ1CqThIstVxDN71d2a/BFep0/CFMVILN
nrsh6WQsLh/2HoZ1jYEb8haoGOcA85f/gjEH57JlMfAbDwNOflqCOyyn4aPl
sjTefY3Q+qsX5pvKQWusjMumKobxYcWopa5Bdc3XSKtsObiEvCD7GhP8OWcj
iPsMKdH8mtBeVQeV0CImL0gnw1v3wTRTDSUyHUJJyDUq23xcqOw2lK/0TqXC
ZUbQfdQ2Xmw6Cif5xPNf3XfUfMiO38ckgpNkMqe2OOH469/IxW4xn1mXQjPL
lvPXknxU/7EGJxuP5ZAN6vCr50JJSpOzsDzBn6vifwnvO45wgdsqHl/nzy++
v6eRfR6DgkIP0VVlKW+3fizUnMsFw4pDWO+0huZs7wXv9vXn28ss6PKCMfjr
okCPT0zBL6vLIV5hPS+/g3jqkA5rLDkvnBZ7YKe1BDpXtIqqKxJBWSYOPWfo
ou1TOTzydKO4rvIOXNrdj9NvzuKahAL2Hu4AZ0JX8pbzF4XSJYPJUeEkPH8R
zW+XJ4heEQZcrF1NER//4yahJ/a7fF+4/z0XbHrI8pb3ezmzNUfMvdsLh9iN
4Wd52vCy+p501vHtwsDq61Q9IRrrWr3ALrAQp9ELQSYjDHdHOMIWy61wChJQ
IrklzB9cwjNiV+JOw0Dx9I4ETKvs8Y9nFeRzrAnWoQwuz1bCH8u0eUr4abHz
11mhn+NbyXw5a36x5w9s8/CDpaUVqJKUTRv6+0JlliLekvRA0eYYjZ7fzlH5
sWg5AuGEWiec/aWHIWeOQI2FBgxd+JW2f9iGiXsCodLCA+r99mH438vCZ6sS
XH3gMYT7KPM5GwlXej4iG0tnrJq5GIK+uvGlAfGwVN6GnVIO4LMVeuw0CzA0
5hUk33JmF6GdroTvF4WULhfz/Ndw/vsqejfFDhtclHjRxYloGDOGq3TKQEzI
oLgNwZj1YaO4+rkMPs3vxdObnLh/TDC7TLUnj4AddEvbHtas0ODrWkacL+OG
ax6+otc738PrqDZqf7CfJifcEXuZGbOZ411SveonvFzAFHdsAvbE0bzQxYx5
SD+6Nzudhx7+SkY6LyHCLAg/320WR364Tv2vdMMIeSthbtpfWHq+B475x6la
JQuO3zVL3HipGdzOROBBm7U0avsJsT7mJ+VNHEvepbHivbX9oFv7dvz1thQT
a05XzzE+R6POp+PVj0m0cclacttvjvFnP5NRgK7E6vZ1UdXHE2XllFF9YgCc
EVJISfVfn2zvw6Up3mSk8hY8ImzowIguwnkThOVnRTi6yxcen7TBqI7dNNC9
HFoOZEkm1E+m8ceGU+CTQvI/oszepU4486oH+zvdFMc+3gIX90h4xbF50Mfx
ECf+10N0UV7CJlMuU0ymI2ZUVpPC0WbJktZL9FnRWTQLOIqZsVX4LHk9VNYW
wbtr5TDL8Q89/HgHCn2Q2++clH776iPsfpLCd1rekIpqPjzT20G9FhlikaYq
Dq//Dlu+uXJ6CFHolNm0IFqGrnuM4V+DCiizlWhugB3umdKTTKNr6IVyDxI7
/wDXL8OOsL1QaTANTncVk0FZEh73TeK5fxxFF/d2YYJhCGvu+1fvp5fFfrH1
IOP3j4GldRxlK8/Zlt7MB1Wp+loC97+7idxfTOTn16vo0eQtUDX1NWmeKAa9
HZ84s8sLNAdriRskn8T42kZR448z1dmMANz2HmbOqaIGuUuk06EqtZueSW9r
E4VfJofxVYwvLXL9QcW3sqDtlRp2Gk4Bg16FpDhwI1i/vgCNnUrg//agGB7U
gx44GwkjskYKC8frQtnBVrg1SovWJJ2h26ozURp6nEw16mHhiyfCqMMV1Cfv
mjggqRiT++ZC/dunQn+90YJqVCLcbrwI6bszhYQB7vzKX5/M0ixxecULKn/f
X1o/wJYibebgu5+HMV7uEM8oTqWeLQ/hSZ0vh6yxxHFySRR/VyRRe9o/tzxN
F3f0oQ+vNMnJxV1osdPkc4XKWDimTTTRmgSjvqzgaZU74OvJGJ52aSDF7pZH
Z/e7ZJSeRi+8zfj841y4YmDHJy234G69NtFC5R71NpHHza7DoGBwoWi22U/I
dN5K8VsieXnnQzr855IwrOUofz85kBXqUzk6TuBRaR4Ya3EGKpaNgiTZCZzh
HgzZunkUFtgM2llNYmnFBxj8NhYOHnHmxfoPJL62tmjpulri9CWRKV0bMoRL
NLYzhDFiq/gmPgMfH0VhQ/Zxod/Gt1CXoMthN01xunkvrmk+D/WP42jxuTie
26DJI2aehqyVOTjiiQ0fSLXB197JoBRahx0mG2B2U5kwYPJ7ynupL1hMt+M+
Wun/nPGiuGvzUXhfJZVMk8oJgUYOqNPoy0YUTj+P/pW8yVPEg0q5HFRRRcG3
7Dha9zTdGKQFMheGs2EvNXA//4CDhpmBpwuLT48mS2Ke+8GiqelCun0JWmzO
k7TYXKApJ3XpzuFsdCs1FyOrC2n7MhPUdXskuTXTCD4K6WB1olq0M/dne2sj
Ln77gG5+dRS8rUKQ7qvQouEl8HNjJ+k9C2fNUCl9TlIRDZom4pRpUsiTz5dm
1TSBpOYLHOofQd2dFvGFcjv+db1MzNaopbsfjaVVjb15xbAUWjBhP80NI3r4
1RUfnPrHN7UVMGFwK5hL98Gg3ar8ckcAe7ct5V2eqbjbdRaoFA3Bs+FfwUR5
H+yNMWLzN4G4+oK79N4ac1Tb1wFhgQU4+/dhMBg7Heb7ZYo/k/2wScWUZ48a
yD1V5oFS1STS4Uy6WrwQlj9JpK3tY0HvnAzEB18hb694WnFqHNq1jWPjfp9p
8/MYYfYRgky7eJbJMuIrR+RJa0YPalqMIn6fh5a3i+jL07E8uiMIrt0dSrdP
e4lP/1iSrIcM+sIuUrE8DTqnATPj4uDm8FRaOUhCar2e0qOlF6kpcQDGpn0R
YupSMK9PqaBTo4o/b4zA464L6Va4DXm93s+DzrVJ/eYkwhA7Kz5qtoPafEfy
LbgK78MOsIP+C+FRlQ+3nFiECYPNedF9X3q+ZSnv9gpntYlSsNQ2Qb8+kzB+
jwrbrhnBi1ZVoGvUadJaWYr6258L9YbaHH/vrSTkhoRVfu6F3hSKl//ldnj3
vcKOIiV6pzcWNFcH8zm/0ZTQcA2GmA7jQDsfvP84D62v90NfiRu5UQ0YzDLm
Y5+12NHhClTN+I8/bNtGdH8ZjC6/Tx4+20DzjQoeNL4Jjkr7aPXx6Sy/Tpnj
+2/EHbP3scIqZT5rsYQ2KmzD1jm9oT1qGWwYuh4CHRPJ5LIXit6j6dbsY+LT
B8EU63xVrK5phfEf1bj9cye5Jg0Stx+xpNoUG3wRHICPDe3ogmIdDb88gz9M
Zz5zejacsTQVgy3HC85XYynxbgZIp25C+aZaUBwRhB9uapKtZYEwK9GNqwoy
6FH1E3pXJY/pI6dCsPNLwb7oAKp/Psoo54VG8mowSUYJ/77OhqmvlpPW1hyp
zAZfvvHaEF1mGdH5bs8pd40i2PZPF9qb54hw+SecHeTAd1fI8fep78XMvFni
zTdO3MdVltPlqzG/9DV9zTuHq56own+ZXuh05YOQpV1Kdbt0+cz4Fbh8wFZY
0fmTTnxZBb6mdRD0qgWaIw25RbE7rXALwdojLphzRx13LlFFpe4L+JzFaDwj
eUoPs9zp4B4TdNVaymfaSynj7RG+vtmLshV6s5NfueDdV4BmRwcxfOt10guU
5UpJMMaPT0ZXTzNQvWIvvvx4S3KeO6BcJazKY+Zd2jP8HJyavBPaRi3iLdO3
0SrFWkHp2C/q1ZTBe2zLYZzGTF4xM0GYpp2EKQ17+d26fWigUECXO+L4o5GB
EFkwHDy/AM9q6MW7f/QHlSGzcdmyHlwuM58K4+ai/CwnLAm4RWpRd+GmQQXQ
ZQd6PaAA+m08iPftU4TUo3shznIRN+n8wADfYXziRwR2+d+kyz9VWKVchvVt
JvG2mU5s6OaPKjrd+fJWF7SY781fttjg0MuVeG3oJArd8lBc9k2NwyckYEr2
aCy3zgTDA2psHL1SWBQ+jrXmadOtba9gd3E8uK95AFGbk8nCTAeTIhX4l38f
LvrbKdbn6DIUHBQXpm5AzWHJonL1LkptGE//B+MD/os=
                    "], "Biases" -> 
                    RawArray["Real32",{0.05260360613465309, 
                    0.03259154036641121, 0.015079653821885586`, 
                    0.005706590134650469, -0.014245710335671902`, \
-0.014738037250936031`, -0.00418961513787508, 0.005576719995588064, 
                    0.04475278779864311, -0.07407592982053757, \
-0.06485266983509064, -0.054751452058553696`, -0.038278188556432724`, 
                    0.02021988295018673, -0.005678442772477865, 
                    0.02552790381014347, 
                    0.025260305032134056`, -0.05077072232961655, 
                    0.024354374036192894`, -0.08645257353782654, \
-0.049111876636743546`, 0.050243671983480453`, -0.019740335643291473`, 
                    0.012014131993055344`, 0.028332864865660667`, 
                    0.01927153766155243, -0.034480445086956024`, \
-0.046943943947553635`, -0.0460134781897068, -0.014869721606373787`, \
-0.035862550139427185`, -0.006466621998697519, -0.012469370849430561`, 
                    0.025312846526503563`, -0.07104668021202087, \
-0.07379257678985596, -0.0161503367125988, -0.03132551908493042, \
-0.03749694675207138, -0.050806205719709396`, -0.04252518713474274, 
                    0.04224136471748352, -0.060112759470939636`, 
                    
                    0.039188042283058167`, -0.03187362477183342, \
-0.05478726699948311, 0.04598795622587204, 
                    0.027721937745809555`, -0.0013523743255063891`, 
                    0.0021246089600026608`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtV2lUj43TrqRVCylaECVFpKjQPZOibMmSJWuWQpRHklRIpUWFSlTShiIR
kaLfPaOUJZSkUonsWbJHiLz+57wfZs6ZMx9mzsx1Zq5r8Kr/5q6RkZKS8lX4
5+au9LfbvHllgIvc/wKPlV5jLLz+l7T4fxu6bzC6mMdw5eWbuH7qTdgbbsGy
nzeCXtI5cqPRcHq3lVhQtl/82JpEeTecSLaR4Iu/u7hTeRymVJ4hDetf4PTh
hGi8OQjkyn7T3LNtQl32ci7scwKypb/CiNcroGCrOc76MxrnpVUB41+y3VZG
w8dH4KiBbvyq1obPrbLFV5NzcEKBOtXOEDhWdimv32lG2sljhco1LqA5Np5v
qlWCX9Yuri0W4ZHDLNFUyCCJdBoklP6ifrJSdOK3KoY9jKMHI3YAJWYJNZ/7
kfHlu1QQeoXklh4TRgQrjz8/tRu+LIykiKrxULtLVRydfY1Gb9kKXvMvYnm3
/JVj9qrc9eAw/PmthSOkhvKJOQ2CuHo9aLXEQGbNSNBv00ID0wLRf+Bw1hy8
HB6IN2CFVD/2yRuKzga9qeRXCFL4C2ioKYKG7+0UKBPP8a0vhCEKSWLH4Wdw
L9GDZsgugozQLeQ6rjdkOY5g4wfH4NSYlzTbfyhmXF/OUadMhU9B8qCcGkPL
3jbCgHQB1/jXw8SyYgi9NQ0P1cWQ0kcpXGA2QcJbEmjbBVey9MuHeLXxoDev
hQakVcPuzzdwY/Yxmpt9R2KsfIYGTnEWNQ8dRO3hA3jJf9dZo04a+4rJMHFW
PLTssaCcqNtQJNVJuunpNMpOQcxfGYVPVFyoz/YgjFHLIYW5lahrNUEc8MEA
JV8OwXD7vvgz5g60Z8fS/uieJBtUY2NU/oGmj8gVqjY48sHsG7S2/j2d3dtO
d+PPcMqGCfxm2xt4KYkWJYauPJvvcWtJNXz7MAZ/SM8nf4PFgk3MMmgyHMXD
dcbwyHUlZFV5gDyNA/HVLxu2Vnbgtxsei3UHFLg5RItj48Poykh9nv99F1zU
fy7SgCuSktB7cHXNQvDNk0G3qQW4pyMct92Kpse5pXB9mzv2e6zLJMt44bWU
TbS2LW+YoMJLpHVouNk9qEs7LekaFQcuuS5Yci8aw87Hgseb8yQ5dgGMf1fQ
uslM++p78vRJY4SR5rvJoMBc8Hhhjxu2nyepXSZw9fcoSt3rbeOj3UBDXnhz
8oorfL/DlL0GZUh+a8byXWtL7p4/l/9IZ8GQ+fK4+kIxTfxiyPuT/pJ+2DNY
1GsjeURepdaianFWvj4vrMpjp8054K2eLz5WlkH/UH8aetsBZmnq4ZY536Ds
xnnBdv1tcZ/pGFBPGYh71YNpVH0UJkbuIzh1HY5XubH5sj5css0AD1hs4Yj9
yuKuJV1ChdNVIc9Fg9TtGumRnw9PsSij+s8OOGv+IajLtAfrX3OJ6ytF3c16
aJ2qBioLjwrCilx6OKWa6l66UV3DYvh7fANsL2iU3Poqw6/Fs2LPyqPgajNf
3NW8hWruf6XshliM7foPn1i4wJ0uNWxMW4n+Kof4b+BivuqZxDulTEins5qM
3PtBQW8F7pz1Aa7494XK4kNwRSUcdP2LbLxeObLJv/twe8Egcg3tw6MmSyD4
70x47auNy1uWCGtmTeYI72IarDyLTUq20l4rBUlcRS3vCjlNdmuryXaSL82Y
G8bHD50Es/xmCFRJgB/S+qLs8foJ2v5rMNhHHku7HOl4eBjaa1rDjjX3cMGW
RLpg4AQLZmxCHZ39ePaJrXiHsimv6xZMM5uEk5aEgPGdvzBcxh7JK5a/ZG2H
34c/UKfDXIyo+QpST2P4t0UI1jeY8pP7fTDlvCdfGaOJ6+MNBavNq6Fi9nG8
l5wpaMQE0cHHSjhz/h9aq6XP7mIkmBWk8NHAL5zzcSm6LNktrFiTQbazN9Na
TVccHmCMUk+9IIh+kvdFK6h7PAiOhoykqMw8qJ0zDy5fDIPucuS9O3zZYaA7
T92iicZXerKlTBfdvzAamy01UdtbBzeVmvCt2o+02LdQHJ/cAegmy1f17uBy
RU9xq6M+al50w/U71tJbXeTYnQlceFYevAuSSW9zMR04JUtBGz1gU9d22Dhz
I52L0sH9zb1YnPqTNvhLyFDxNPfOsqWkmg0wo3UTjOj8RIsWnPw33/5ofqSU
NMLdWMb0DIRc9MCXL5+K7+xfwkt2oXPSO+jyIV2eP18CPcr0+YK6PZ4uz4eC
5/ugVDWVX1tFQd/NltwncDG6TctBd+qHemdOYGdsb7zzzkpYpZ2H74Jl8JyJ
Ah97UE55b/pgZ8tS7OyWwwCz8/hj3US27BvGY0e8Eo76SkT7dSfAd3O0jcNI
NSF+oiHWBRuKMxedZZ9z/3ASMxe1LS+QY+tRutS7Q/Ss6sXyNwup/9RoGD5r
Ls6z1aKB/jv4lZw6GTuf40T53py7LU/o2n8QHEdWk06KH80OiAZz7VGcUWJF
nsemCSnPzfhUa1/IKVfn8AAH1g3U5Z9GspzvPZx1TvbClgs+OH70ffJKuQOx
By6T9bUKqtVvh+IX1fRiY4dgfqIc4jePRee+k2w0CodiZ+Fu2vK6gCxOFED7
kwiO3vsR2rufgHMPL4milxIoPgxlTcXukvF6yySgdhSvVm+kl8fCSGPcWWx7
VwEjK96DIHiDW8NHCh9VQ9F+YzgvzR57v9yHlhnHUaMrRIx+GgynTtpA9PVI
Wv6qE3jbI/KMGUKlEn1cm3MNbuxqoYexcvxeUwZfOFlDBOyjCfZrKNslFJ33
u3JLaBX5mU3H/lO308V3JmTfHcFHZ+3h/PSlOLUwHaQq+2PorvtUO7SQrm7/
LTpElMDm3l8ovF4RYb4WWpUk86xdJqjrZwd2h3viqjZVPiZrYEOvVTn4xw7a
2N4G8zO/Qsy2gyStbcnrvh+gyYEtkPhzJkpWKdOeEA+avewXRSi3QfAjXa63
6IKfdeehbMB9Xu2VSceHdAjbB0bz7f763KYbItz881dSdduLdgkD+fralTDd
S5V9+6ygpgvv6dRS7SvmWQshsdqC//PtoBc0B0jBCityXCj6+AlKUVbBen8R
DnyS5lcquWLXLEsGs0IYBhFi59I3ovyMq+Ccqkyd+1RxdyTRsPyP4BVxkJ+Z
+9PgNH2oXX0ZtDSXoluUB+mO7clWkAo1xYUk/2Q99X8fBXXLxsL0819gsdUO
uPp4NPV8tpa6px2hhteJ5KtoSQfqWwTPN2Vkmb6b+95PE9VbewqnJ+VQwtdw
nunSSC/MjXjJoj584NIXFKuzoKP8MDfrRsHnm/HiBD0D1q/Joq6HPSGlUosO
uibTtE2JKBuRRPPGeJRUHHYEl1Mnqeq/hbjMPZdjJ82kyPHjyWpSKeU364Ds
/O1YJr0XHsxRx2V9tbi1tg9/GGRFL9P7waIjPmAYuQ3e+czGuLeh+KngkrXm
DG/QjvtuU1DvwsErOmji+A6SfqCAXyXNlK2pANWvFKB/XyM8O7tBcnfiT3h+
5jQ16CpLDuys5UNj+vGL797sUWbNei3OmHy4gzabe3L1izKKDhjCfW4lcldd
NJR32uDsrk08IlaJ/1g/ER7PjBfq7aL43KUS0AkuhsOVJ4WOp4kcpRuCab8c
uFeYFX6PeCXaD6yzab+1GdKiZTDrpT3IeGVBfaEWfhu1lM0WJpOmSzg9LdVC
9+HV1OXgC0dueKGzwjgJrvSnwNdJGBZcDb3wEB2IPE63FMZzaNYdCFRSxynL
lbGj51G6JR1Btop+gr2jBk5uDcIB58qFhNwa4eTKCeLiDz78aEeHOCX5BYnb
5TDSaok47M1ICm52RAODkzw154kkICkDvQLHk01vDdq7IoWuqL+hYpllOGVD
PKlUm4FphBw6J3ixieUveqkTyJQRIWaMVsdt76/BlJw73DqzgJ4PtqHYWyS5
vs6Bb5tG0rmI6TjYvAU8I5tg14m7tCt3piiXdNbGeNxM2N09E43XW9BNNz3c
WbmdnXsehrS3rpAx9L04bLUMx42KhrXr1tBQ6RSImpYGHelbUK7ZAjcJIIzr
cRGmmAxl95R3VPilmAYWL2Adv8Xi87A74rNFz/l9zGd4cWUcKqwyYHu8Qcr5
W2G2l704PKo/eUI4191pE2daHOH607Gk326IlT+M6OaXS/BIv0LcaXUK5XPl
2DByLLrd/UHTHldRynwDfDT8BrTXDIbKHh7izg3hqJLnjMNPt8LShF0g5WPK
hqtyaVlgL5w2TJmPT2qFqr7L2e2/BpLXrCRrZT/O6/Gailao49kIWaH5qQM0
TXvCvnfyINvJouT2kh547+YdyNu9Fs5YvqHWWissbW+A4f/wFDPEDKLi7TF6
eZ4YGvwMzK8Oo7yRElGy5RiW3blLzVMviXp/g+mq6yeon23Inju2wrhWEUy3
ZPLTIwpY0Ps5RGaeEHy3vqcH1ZbcaD2TRjl9tHkx5gddCwqiN0MdhfphO7G+
bhAqbWwRF4/Kp01nouCj81ugHUp4KVpLPH5mHpsFzWAd2zEsN8sP9oV3Smb2
WMR93P1F7wnRdFXDjf4Yr+B+q2pt7n0YjXNuSMFWkyV829cZ1x7Ig1/GiZLh
93bT0+m76LjMDHa9uQmddpiiVVsIBvf/ATk2CXSg642gb5yK4w4+gS323qz3
5wkU173jCGkD/Hnhw4Qm6w+i2rWLFLDrOQ02VhJcnNSo/fw63HBkpRicFgM5
U46ixZXTtChgJQcmudOO+nyxQiedtN874ZkPh6FvaRE8XfSQHC6GQ+qiXuhc
PEVcExcNjT3+8eB7iri3fhLVS5vi9N2T4PXvOSXpl+qFw6Yy4r0fb8jr3Hjs
GJ0jnHhhTQ5GenDLXpH9+72A5x/u0albZSCJKoAtZY7ACQ8gY08E5g7fyGXL
HGCr5zMx22sIX45Qph5NF+lx/WcoPbIN/y7tgJphA9nNd6FQvl+Z7xf0wowE
xDln93PJ67HCbctBaGdojV+2HsOHG61Ives9PY+6IGqYmGJppzk8uj4KR+QN
pfoXIfxW45nEvuaDmNc2geZstSRIbiOrmXr4aKQ5+6QmwOk0P1aIC8S713ZR
v4HxkMTV9GVqqeDcVUw3dFeQQXIdhCafBF0hWQxZk0d3gxpIr58m/Wc7T/h1
2BW/GjuKSa27bXqeuS9uzW2k8MpU+FJ3TFiueRGVA5L5cMNETl7twjozquGZ
cocweWgOmRWMpM2J7RO295fDMXekBHyegJnlurzt+GtYajkDL/S/Te4Lgsiu
ykZ8etCQ/wvIEya2pNNk30KaPkmKH0XMwaOlr+Br3WP49P4TvO6MoabqwZR0
PRYzHmkR2XuSYvI18evsE7Tv4hwIPHgApbTH4piOlzB51ETepM80PUgeHwYO
Ib2T+nzXXI7/HuoSdhhtgz/ljrg8eTKs2u+Cs6pt6YlPBswwjyZF08n85PVr
Qb7PSio8Wg45k2VxllYmN60KEZ/3koffvnZ4W2kMpms5sGW7HikMTYHFb5rF
UVmrIDzEEB/U3BVrfmmw9S1FvpM2h0+2FIBGUTWtaTyF17vD4Y4/cJvGe+he
2UjKFU3wOuggrE99jgajp4DRe3lcf3gH3TteIFGqkMf3mQ9Fy737KXu0B6sV
3fnHITW4akwkt1i6Cq6pRtzcu07sLR2KgR3v6J11Mi40z8b4oaqcEX4Dm2Qv
wei3t8S8b7qoWT8I3rRUQJS/PbWWF1D6vMG4bHcDJKgcpPPSRfBgYKTQ917x
Pz0izUZW4fAq8BZcnKjGOvsmsKXOD+HPo634yylPUqMUAjemiLTIKB73z5cB
0lgK1Q+kee7khxBn4CK+NH/Ge5SHcUulJYUp7KPeRVo8cNg9krtviuNiDmJT
ZChMEy1p7eqH4KfkD0WnTeDeo8m4VcEbs0ty+WGYHu72jOLmyAvU40QVbA+b
brPwSxR1HE2F16e/wYaYnbBUahitOWbMH90m8olp/bjaaQ0VVHyg9sI+rOaj
yFkzgqAkwJfqK8rIouIuFA2WwQXqUzjdfBvcPtggutVtgu41fdnSxIlNi2S4
LX8ifJ5VDHtUF2JloAK+yvkGR/8uEQ0MZfnkibVobn9MbKndA/J7VKkkbhUv
2FlKPxdasIVPA20c1wOls4bgytIj8COmE1pm9MZli0rYNqIImoyjKHXFYPJx
M+RHb7Zj7KG/YF/thaOkhvGQhyow8UMf2jQ/kw58rMGoee30Oe4SjHkxl5vM
ewiq8tdtEoeq8Nd15vCh8o0438UdpvZMJ4cnxjYrrukyO3aTgU5vTmtdJhrI
XYHyS87wMiMPpA9cpC8/2unvs3lQm/uE7veroTzhLsT3LKf+HZpYtPGzoCAg
jwvvhv/ax/F4aQHznVbSgMdDcdnGfiwZNpvDY0dz+6XtWDpVCass7ODnHGNY
KEnC4mE+4nKxL5rqnIRXGAlqe5XFq7/a6VN/RR6WdVF4398VQ9b+R2Pn11NO
SpQQem4/O/5SY7UrTXDu6hwb713T4bDScVikO4fjJZsopVFd8BCH0FWjUZjm
9g4vbhmLZcpTIFjxg83Eq142SqpXQc7Dhr+ZRXNw/moozq+DNZUnxTqXPbj7
8i9Y4dYC7lsN//3fItqX/QtqO2vY7mgxqe82p7bBp+FM52hYkGsIw3QPiz5j
H0jSDozEP3+W4MrbTrg0uQc5Yjo6es6DR30TaehfMz466bUwsk6eqw9XitY9
Q/H7QHOa+7EHy61zwQkxE/CDtDofy6+h2wvyxNm96smjZwSiwQ2x2Nde6CMf
xRubvMnWejSPazxD2Snr+HruNsnaayOwyXo1yhn4gYldK6TO+fezonU5u9dp
oe/LCpi6Yxj/Pq3BekeOc76qCv/J0mM5eU2+nhgC4UbWvEs+k1JXZ/C807Ec
OiiJjRqj6U6TIl/eFcKF749g6mMZvOqTDHIWF6iqtJI8vcMkQUazOeNsAKlp
ZYKG/HAO9fkGV39kCvOnH5RcfxvDlQsEjguopg2rnlOj62rcm94XujZeppXj
r9FRt54C/w0A/+bpE7TvZ/CZvzfo+bT3LH6Rg4IabTSvewXn3vTDu9N1+GGE
Ex/b05OcpNohsrgR9lzLpPH5UcLO16LotmsXD5ybTr8325LppBqaq7SAun5O
hVK5GlHm2D1q7pcrztc7gPleyfDh2SVOHUPw9I8Z7slPhO9y0/ld5yBuv3kB
/Y6oshB9Xfyw6IJNxTtd4c1ZE46wdwCTBZGUutHDRi9pCKoaBdgU9nxE5w0s
OXRIAswzBP54ENivaRjOSttDUnpSEs05C8S4gDhS+1pPoYtjsGpTFblaLYSw
bz8oJdqC3snkwOYDWULZiQQ6/L6WzsS/o0FHilAl4Sb06WfO8StHcbh7P34c
P09ia+XGsjFnKfxFT14zfQ/PPiGFp7PV8NHvcjg915yvGZrQ6lM7hJ2GkbTg
nQcvGuyKpVXltP6pEz9qO0v7dt6nc6iLTw9fxFlvWoWIUz1oa+Juemz/H89e
Ysn7Rx0npTRbwa2gXpBNMcWNcYsFb83ZuH+rhBLlS2H0t4V8/vlSbNM+SO5P
EuG/dYOw/mchPmx8BhZ2F2FdTCtkm78kFw8BFI7E0t13/emrjhpplMnyaL+n
5Hf4IkWE36bRjcH8cc5xMPtkg4sO2wqPkwZR9PaBEGxcYrNRbjTe3WwuRA7X
EBM8TKjgfJ2gUPVGOL3ylFi5Ps7m7R9ZISIrmvNPuZFylAfYxbuhUfZsamv7
CjIr9ghTfQ3xcYgCLhkTbWO2aRAb1J+gNEddKDLrwd3/cHn9RV80nunArY82
C1q188Ba/gF43ErjRX/i4cerLtjafwZu/G0kjm2TJ48e00n6qw4PT0impaGX
oMhumLBg5lDYvy8SLnU6s86xp6S9VwebutVYqv6HMCXAT+hlpQthH4fwNaf+
mKvbJgRNUgfl3um4+s4I3v51CW/z+0F918xEV/t7tFh1EW4NuEd+ggQmpufy
GzDG92Z2/KXqED14lQ52Ac700TaUVBe+hcyzy2FHfQwljrSmARJtapFVoODJ
ipy20pkDsodQx8geFBn9lvwGHYXtjmG46LEKPzg5AwuvJJLR+GH89KAp7ohr
AoOvf8BRfiIkXErBXS9UsUe/C//4+UPhdON5yJBTpstvBFbRU7AZ/WSDsChI
hVs6bwpxW1LQZEg+ydW588rOHLCetop9bN/TqagbgurH1XDUf4/wZ3x/HvUy
hW8P82T35bHCj70XKOPzTVLdPtemtXdPdLxxAcd1nQeV83Px3Mhx7F64DiO+
KGK0jyzGKEyBWzKKXPZ7Cglq3fDOZjcJZYfA0/slzW5JEAodbPlUfhp8GJTG
P0/NFTM6PUBX0YkeLxxB275swJHKFpz98DAqPwnn+OnasPLMKlybJSGH/r+o
cJYimp7JpbiRLP7xqKIne1YL428/FJOG7OX199SF2WIqy4XqoXmHM0k7XaNU
zxQ+bzCD95XH8MGLtTTkngbEfFJC40l6vMXjMX4dZwSYo83375tgh8tajDbu
oIVlK2HT6Yvk1ZHCbuoOWPo3E1PPJdGYgBaYmFYqmipE4/P8PNhsr8NHy3QF
seIznHc/DUV/pMAgUg6Orr4l2qyLxhc7P9soq1yC7xfSgeLPcTGNZ96hTw5u
8zhwdBzsf91Oo6oChG797bTEbQ3enhxCxqWRkKwhje+t46i1ZQU5HV/CWQ9q
YdaTLvqu9EDce0zCBh4hpJ6iwClBSzlllxo8tUFqrNRCk7AwHKK7StB6YS3M
3q+Jg/N74MsNCTZ/BiniT+dJ7P/AEM1OzeNBw3Qo9EkoXfJUw9UHEmn3pCeS
SUtu4Iz/rtOkYnvUv7WEMi9ZscFbdUwrsxMMu77QkvW9JJ1m54najuPV20eE
ZyqHRaeAxdSv8jnUbj9N+UmjKPV0ohjitxOSYueytGMNzDLXIIfFqdw8VA4X
xxfAKtnLnP/FAMIadHjYwXG0fNdiVC1ZgwMctWCy+jjQ6I7i2QqegnudFFhX
HYYzryfBu9m7aXSDMw4uOke2k41x5z/tXMSptHdHJAWHO3HguqU0UxjNp9fY
8/pf8eBetQkLag+IMpe2sonmfohe2wH1k/Il8869F2btmI86KWGkrfJIUlI7
iJ8mF9LmI8NYu3E8Kk+/ICpmbUT5OSVwo202S20keOFwE0JOhFHAURsONjbg
ktDvNj32P6UtwRv54uYUQWZaGA/c0gzDj3SL86/7QOqSl9D3phLuCHDgykvF
uH3zvXE+T8KQLwCOKj2Gjl/LqbmlURLZyP/uqTGkNGfSTcXl5Ns6ltblVLC2
ZTHk3egCl82AezIfCoLuF/pkl0ujdzXCa8X38DRcHz0HT8Jrwx6Cl2MRQaIi
689sAmn3ZC5vcJQ8E76Djnc3XB11BlX2ttr0wT3c4JDIN/yUeOjmKLH5/iJ4
WvsJDA7NIa1Xvdg3xV2sdAqwSZjcRC4yl3BEbj+UneaJEL2QlWy6SWtoLJ1K
WgY/EjrFsP7Fwrl5nnQkKYeGz9lI5Y0H4Y6GEp7/68wH/9WM/21CV9rvYhjZ
smdWFdV6HkX3cW1w5KYhe3mFg0/xT+JfTbBo0CDubrsCITZrqbJfPrx3mQJF
F8ah+zA5jvm5B4Y0e/DwsfH0faE8P998lR72ipY47H4CR3wM2HjiAVrW1x9G
GFUBhOeAOr2iPtlVFNQ0Qwzt8YICzZaR92B5fpyvjbSkTDh3Vh9ti7eQ1rUp
eONyBST3ryb3hl74uO0g9tLV5FUSS1SZMR/DTsThvmfHYJhfCwVuUJTM71zD
C9bICQs051LK8b3g1ewFavfmseG7xXzUeSwYxtWJwwvD0OPQLMEpJo5cjW1Q
z+4KVY4txurYiVA6Mhp6a36BPqG+lJs2jyI/KcOiMHcoy+wtXDi1RWLGU+DD
vkLJupcHQSmhEIq8Cm2+KfwQv7lO5+hsIzbduprV7l6j73arcIjlQg71Msfc
fc3CuXVyOFlXircsVQBWCoIE7e8w7VcmTDeVZr89AqT3qiCl382ksk4LVu84
RD1VwmjfXzNc73QIigyCyTxwpnB0mAY+VDLGtMYfwLIHUeVHPCbcGol9Yydy
ZO902p2qyqcCfolSo76Q0qAe+ND8DYVH23P01jwwGRPAra9MOOxaGDYk9KBL
7ldBKSIZyt/OwRHj++PA/CzKG7CEn/YaDE+T4gWHoj7kraGF2QFtorP3Sawc
HUHlu0thV2Yyh63YRSu8jsD6yR+IVv2kKUEncfrCUhrr6QoTOxPwT69w3Hkq
FM7IPid7DWkeDPMnyK5qhr2h7mLohlWcHmLIW0emc53rGVgrLcfr6m7BngOp
oHlqD9qN7IeOunPJ7sJN2rRem4dfkePeI1rBZvtu+v45o2RHQ5aoPtmOc3Tc
6F1FP/a28hL8ErrBXKkn0fC5aKKvSCEpOWCWsQTvbvKl9KdJAnrP4kELcycE
66+jjkczqVmnWtg/ZxO2vFrHR0ZHYKOsO7RnrEXXXGcc+ywQvsoTrZDOED9N
fSTo5U/mwtYXMOeOAs+2H8mjRkTDls/63PZTGu+5BFGRnhbG3pDh0gODuNAN
MW2ltfC1QBfH7NBjI0M5jn4eiaqno9i1Ig9WPLKkR42Pyc5uBKs5jsObtvvQ
THE9D7mCuFs1i/Tjg+C2nhPbLm6GzLQXVLRzDH9ccR6k1nbBTUrnOccv0+83
nTDlDIot871h2Codnv9uMy/cEEl9bZ9C+4MwKrd+LfYNyAK19Re5sF8S8YRm
fqJ5hl6XlUJbbDMdkdbB0LV1E6bvUMSoGjvR8o4BXu79Cgp69sSfzw9RSXlv
bE2eQZm5ERCg+2/v7v705eVgsX9qAeWUO1Cw/ErRwt8G7RUN/vWuwFLfGig3
s1ZU6DsAIx6W0+R5a6lwhxbrP9DBjml7OdppLB6xD6aI+YchPilXnHakSVR7
78XvN0u4/E1vzgvoi1nG8dygthe7tYKwdUaMqBHmCwlffETDWyHQOOOSWKGj
jkr31NjV97Qo690oWJh6Y5GVLr2/rYF2awV+93AgVa8yo4tPros+DQP4/HSC
QJdjYPw7y6bZXZmrit7ChLMDWcX/ouDUUw7nbU2FCS6HS658mcD+117TaT9p
WrKlHx8xLoe1MlliaI45OmWZlSi2h+HMXi+F7g8xNGX9XIjSyQLXoT24sb1G
vLj4JKkOzaPsEblwaFmlqJrui1WDpeG12TgO2DYee0dHg52jDkeMa4d5QWP4
tNIj6MP3aFNGnNjPSRWbz63F9RTAFUcWikeD9sIgOeT6CVttXPcm4p2zblhp
M5nL54fj9y43MbxXHB57ZkfzhJHw57c5n71yQFg+5KCN9apqCtnQCs1fvVDY
OQNPBt2RLCj7Lo6t/kierYNZQzkHU930MDC3BiY1p9H1QhO8cuwRvB16h+yX
uYtdW5ahfA9LSAr2g30/b5DFnxowvngM3X0t8UaULNno5tN5vZG8wFUX+2v4
S8aHpGByuAo9fV1NRqnb6Tp/gDqZj/y5UwlpzVtSb9oLEX7mAOrJ5Bc4lX/P
/CHajR7Fb5rC+V5OGK9w3A1nzreQnUu7qLDega52B4Fy3W+4aLQa0+1yaKnP
RHhadhiip4xHYc9CvNA+gYQWeWq8dEu8liiPk7ftx5CJy0BGdiPeeDxZVG/0
kchM2scyO2Zxyf4KsdvEF90V60jtpAakHpPmd1a18F3fEx6vSIHMIF2YfkCV
Qpf64+qg0TDrsBKaRfRmydazMEncJ6h5TEOzHyZUdrkY6hsP2/zx6oK9zhkY
/dkP5l6bAR/rfkDblzBJxLYh9CcpTvBdsxZ9jrWw1T9Owds3clSwMn3NCSWx
X6X427wWiiO9kBYmCYEdszHhYD1JFLXFRvhFm8ryudni38yFWFQ3mTPhsWMF
yb6wwmm9DGhIXg9+7y3Pn/NFCi0oprYwK8hpmgz4MgKCGs7/07pm4uWfI/Hd
84EsF9eH4+YPFos+uYrD81OhPFmOhzXu5iSXnmKM8QPQwJ9k4W4Jidnj0cpi
BHevaIO7W8rpm74KTUwwhsWn4qgxM4Qkrk2C1N25aHSzQujRZyj2ntEAny6f
Fbs/LIeOkuvCgwHTsc4nnSzMppDCvVhat9VWNG1wmfDMQ5HnyKfCgRxtlPkN
wqmhOdAmN4f1zDKhKNCbDQ9NhUOnZDBVaRFHj/WnjZ16aNesAn0iO4U9b3uJ
9Y3n6Wb2K7BQVeBRhlvE6i1lNOduAl0fGA4ls4148W1p7jw5AWyP1hBtfk2L
3X6DnbPj+MoP/vTgwUphUldf3BcWBQO9RoBKYoSg2dQIl17uh8dnttOGfvcp
abEDsWkqXX5+nAYEzoJF0weg1rHXFOr6C/p7PCejxab4q3E0qQYmwbpmW9Rf
owW7F9eC58/1eCyhA4I2TIETzhaUHfuWZs09DlMehQgD/LbzuVUK4vknI3Dh
BDeuTUGc00eDb+omipPxEaSUZUDrnXP05+5+YUyFFdUoDYJ8X0Xe278vmN5u
F43M3sLAs5mQ+/gKRL/sw15jwmh5hin/H7iLJCY=
                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.011363907717168331`, -0.0804571807384491, \
-0.11731007695198059`, -0.01578902080655098, -0.04742230474948883, \
-0.017186058685183525`, -0.010582301765680313`, 
                    0.027008384466171265`, -0.0314730666577816, 
                    0.01566052995622158, 
                    0.007200160995125771, -0.030581815168261528`, 
                    0.06581803411245346, -0.029141198843717575`, 
                    0.0017384078819304705`, 
                    0.017468666657805443`, -0.039648596197366714`, 
                    0.02640012465417385, -0.12200609594583511`, \
-0.027597816661000252`, -0.008488748222589493, -0.033251650631427765`, 
                    0.0040050409734249115`, 0.018370021134614944`, 
                    0.01028355397284031, 0.0011433935724198818`, 
                    0.04136081784963608, 
                    0.03369051218032837, -0.07278192043304443, \
-0.009283648803830147, -0.023094017058610916`, 0.024792462587356567`, 
                    0.01806206814944744, -0.07105705142021179, \
-0.06598832458257675, -0.008840044029057026, 
                    0.0368741974234581, -0.014614545740187168`, \
-0.050046157091856, -0.03706686943769455, 
                    0.022671883925795555`, -0.00604147557169199, 
                    0.03788727894425392, 0.003973152954131365, 
                    0.03938742354512215, -0.03648681938648224, \
-0.0026730436366051435`, -0.030199546366930008`, -0.01372185442596674, 
                    0.019113456830382347`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c00P/3x8kKRUbDJu0iWYn3vbQXlZEkpKWikIa2TVZSsvVRFEWk0uB9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                    "], "Biases" -> 
                    RawArray["Real32",{-0.01811496540904045, 
                    0.03158624470233917, -0.025890443474054337`, 
                    0.028404338285326958`, -0.09930502623319626, \
-0.018971914425492287`, -0.02353900857269764, -0.03727893531322479, \
-0.02432730235159397, 0.0199737586081028, 
                    0.03403042256832123, -0.02016459032893181, \
-0.04011442884802818, -0.01526610553264618, 
                    0.0105536337941885, -0.02728472650051117, \
-0.03488403186202049, 0.035992253571748734`, 0.012777205556631088`, 
                    0.013712296262383461`, 
                    0.04941752180457115, -0.024890940636396408`, \
-0.001803908497095108, 0.01600596122443676, -0.03121953457593918, 
                    0.006345773581415415, -0.0008898216183297336, \
-0.026629671454429626`, -0.03125980123877525, -0.02450725995004177, \
-0.010600179433822632`, -0.005802494939416647, -0.006543825846165419, \
-0.03442828357219696, 0.00647661043331027, -0.021826934069395065`, 
                    0.00680233770981431, -0.05289740115404129, 
                    0.030780253931879997`, -0.006408713757991791, \
-0.0382319800555706, 0.011250601150095463`, -0.007668930105865002, 
                    0.003511713817715645, 
                    0.026556191965937614`, -0.06772302091121674, \
-0.014105710200965405`, -0.05437183752655983, -0.021681630983948708`, \
-0.009797574020922184}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{-0.12213268131017685`, 
                    0.22370854020118713`, -0.30093351006507874`, 
                    0.2474382519721985, 
                    0.11276881396770477`, -0.25041401386260986`, \
-0.10864553600549698`, -0.07953047007322311, -0.038075581192970276`, \
-0.18053032457828522`, 
                    0.07442105561494827, -0.15449127554893494`, \
-0.087982676923275, -0.021877676248550415`, 
                    0.09449981898069382, -0.13972724974155426`, \
-0.2581486403942108, -0.23426605761051178`, -0.14297281205654144`, \
-0.07610414177179337, 
                    0.17627298831939697`, -0.07338259369134903, \
-0.013896271586418152`, -0.20777902007102966`, -0.010787670500576496`, \
-0.05011796951293945, 0.19472374022006989`, 0.2789916396141052, 
                    0.2736121118068695, 0.06853725761175156, 
                    0.2629948854446411, 
                    0.04878266155719757, -0.09811088442802429, 
                    0.15360356867313385`, 0.2710251808166504, 
                    0.01613652892410755, -0.05935997888445854, \
-0.1407802402973175, 0.03930910676717758, 0.14593711495399475`, 
                    0.17902110517024994`, -0.22920691967010498`, \
-0.2594269812107086, 0.02138221636414528, 
                    0.14169107377529144`, -0.16080638766288757`, 
                    0.027343541383743286`, -0.1931789070367813, 
                    0.10241985321044922`, 0.05474981293082237}}], "Biases" -> 
                    RawArray["Real32",{0.011467166244983673`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.8641446828842163}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.0734771, "MeanInputsPerSecond" -> 
          50458.49127810196], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.053258222392057346`, -0.012672957419556099`, 
                0.013678600983731928`, 0.014152612891664931`, 
                0.00495636710532431}, 
               "StandardDeviation" -> {1.026254801912451, 1.0119232157896243`,
                 0.9720614057715917, 0.9984683185627793, 0.996508666825108}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 3311916246135074562]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[363569], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3232392187807308, "PreprocessingTime" -> 
        0.3905186`7.043186717202223, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.13796639958876805`, 0.1462331506440217], 
           "StandardDeviation" -> 
           Around[0.28384706595111453`, 0.06224341116015433], 
           "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
           "ModelMemory" -> 99880, "ModelUtility" -> 0.5232176569102178, 
           "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
           "TrainingMemory" -> 451736, "ExperimentCount" -> 1, 
           "MeanCrossEntropyHistory" -> {
             Around[0.13796639958876805`, 0.10340245245466169`]}, 
           "StandardDeviationHistory" -> {
             Around[0.28384706595111453`, 0.044012738115527555`]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 156878187687423]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.465469400098392, 0.580703314325385], 
                "StandardDeviation" -> 
                Around[0.7230197374498523, 0.040641021736023464`], 
                "EvaluationTime" -> 0.00014342569646407457`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.3800398050617604, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.2589254117941673`, "TrainingMemory" -> 
                424720, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.465469400098392, 0.4106192514169829]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7230197374498523, 0.028737542063892063`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[14.21786672991483, 2.225209686158982], 
                "StandardDeviation" -> 
                Around[0.6138008082101367, 0.04363646611958835], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.21921273258904328`, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                428752, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[14.21786672991483, 1.5734608586450054`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6138008082101367, 0.030855641100177952`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.13796639958876805`, 0.1462331506440217], 
                "StandardDeviation" -> 
                Around[0.28384706595111453`, 0.06224341116015433], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 0.5232176569102178, 
                "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
                "TrainingMemory" -> 451736, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.13796639958876805`, 0.10340245245466169`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.28384706595111453`, 0.044012738115527555`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.28384706595111453`, 0.06224341116015433], 
               "TrainingMemory" -> 451736, "TrainingTime" -> 
               7.523765832135071], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.8706420414197753`, 0.5232323575978812], 
                "StandardDeviation" -> 
                Around[0.7294757881389505, 0.04304847568518695], 
                "EvaluationTime" -> 0.0001299709711359511, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.38948544758196335`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                495520, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.8706420414197753`, 0.3699811481936864]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7294757881389505, 0.0304398690767399]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[2.2639707359209433`, 0.3621100825928692], 
                "StandardDeviation" -> 
                Around[0.5037510657004933, 0.03177760803506397], 
                "EvaluationTime" -> 0.0001247628175937306, "TestSize" -> 265, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.020045492086573136`, "TrainingSize" -> 
                50, "TrainingTime" -> 0.5011872336272722, "TrainingMemory" -> 
                499552, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.2639707359209433`, 0.2560504949374386]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5037510657004933, 0.02247016213148185]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.36874546534302266`, 0.17524197127260246`], 
                "StandardDeviation" -> 
                Around[0.3488457644238867, 0.05625760126168126], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.32819970241180174`, "TrainingSize" -> 252, "TrainingTime" -> 
                1., "TrainingMemory" -> 522520, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.36874546534302266`, 0.12391478623535535`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3488457644238867, 0.039780131345423686`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.3488457644238867, 0.05625760126168126], 
               "TrainingMemory" -> 522520, "TrainingTime" -> 
               1.648107170553497], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[9.046709921565794, 1.4674232419643365`], 
                "StandardDeviation" -> 
                Around[0.5380507922797451, 0.03816637676587193], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.08746598858053634, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499616, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[9.046709921565794, 1.0376249252637302`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5380507922797451, 0.026987703824468735`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[4.676300187314483, 0.6860476145188835], 
                "StandardDeviation" -> 
                Around[0.7150766039386276, 0.046580925579152], 
                "EvaluationTime" -> 0.00008711582237205455, "TestSize" -> 305,
                 "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.3707595274267923, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495520, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.676300187314483, 0.485108920443157]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7150766039386276, 0.032937688350964285`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00008711582237205455, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.7150766039386276, 0.046580925579152], 
               "TrainingMemory" -> 495520, "TrainingTime" -> 
               6.577306748713622], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 156873892720127]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 6.7`2.*^-6, "PreprocessorMemory" -> 
        37264, "InputDimension" -> 5, "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097569266048533`17.333472256488637*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 2.6598644201323642`, 
            "ElapsedTimes" -> 3.7100709, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 4.433107366887276, 
            "ElapsedTimes" -> 4.0661185, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 7.38851227814546, 
            "ElapsedTimes" -> 6.6257685, "ExperimentCounts" -> 2]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 156886777622015]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{1.4281067184743153`, 
              5.165011933852659, -1.2213463494536325`, 1., 
              1.6094379124341003`}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 15.1111538, 
        "MaxTrainingMemory" -> 962552, "DataMemory" -> 75768, 
        "FunctionMemory" -> 258088, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 48, 46.6327785`9.421266156293024}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.12038043558658644`, -0.06372621581653351, 
                    0.3662755768689114, 0.5396825396825397, 
                    3.9504542391754565`}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.12038043558658644`, -0.06372621581653351, 
                    0.3662755768689114, 0.5396825396825397, 
                    3.9504542391754565`}, 
                    "StandardDeviation" -> {7.279040531654311, 
                    4.5331510878835255`, 4.15872355380296, 0.4984228085113518,
                     1.3469506834365252`}, "Method" -> "NaiveSampler", 
                    "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.3533703717341042, 0.21665223208355647`, 
                    0.8210117190567741, -0.032719874018559816`, 
                    0.3912292904798466}, {-0.5699724696303442, \
-0.4219390937509023, 
                    0.17632296557758365`, -0.15712241674600705`, \
-0.664320361718632}, {-0.4747514598612467, 
                    0.3578063582176355, -0.4286336322400761, \
-0.6442367843252241, 0.21867289821471336`}, {
                    0.5076420209950973, -0.35645151747812015`, 
                    0.2661276944843642, -0.7369780823440082, 
                    0.035794560767573334`}, {-0.2591744472813936, \
-0.7210729069965524, -0.20074667748803016`, 0.12674473506598308`, 
                    0.5970921304811311}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.12038043558658644`, -0.06372621581653351, 
                    0.3662755768689114, 0.5396825396825397, 
                    3.9504542391754565`}, 
                    "StandardDeviation" -> {7.279040531654311, 
                    4.5331510878835255`, 4.15872355380296, 0.4984228085113518,
                     1.3469506834365252`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0130219, "MaxTrainingMemory" -> 92872, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 48, 46.6607037`9.4215261478882}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.12038043558658644`, -0.06372621581653351, 
                0.3662755768689114, 0.5396825396825397, 3.9504542391754565`}, 
               "StandardDeviation" -> {7.279040531654311, 4.5331510878835255`,
                 4.15872355380296, 0.4984228085113518, 1.3469506834365252`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.332970671658213}, 
               "StandardDeviation" -> {0.677467386962688}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.332970671658213 + 
         0.677467386962688 #& ), 
        "ProcessorFunction" -> (3.4436649151742897` + 
         1.4760858149693863` #& ), "Name" -> "value", 
        "Quantiles" -> {-3.1341862692498825`, 2.3333059363764934`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX001XccgLlCThh6kY1hmTu7LifaMvb9fL2NzYTYOLnX4VZ343QRSeTd
kdfaaM5UdHMw00hxInJ/n++RJBuVOCQXLZy8mzVrzTD98TznPOcxPxzt/w1P
RUXlxNZN+UtOucTGShIDNN6EVCKzt5O9mXabqG8yESumh0YiUW/SgIm/vQSy
sUb2vFRIz50pwp0vXkHOFW9iaj/K/S4QM6vGJNS0tcWhx4jvUR/kH/HCZ3+f
5xYLf2D+nnrsLf5+rpkuoFpNCaRefpcYdF/G/n06OFszSMqzwmmi6W6uwnU3
yxAeZH92DuOaVy6Tijxp651Q6ImUkxSdEPi3eD9KKzWRLsWxAylN3CWBHauE
nyFn8jo3kOeHBY/HuA2fNtYfzhHdn35EQUg79mf0gbG5DQRHmMN8RyDNcWuH
09lp+J2qlIT1vkALEzkSx7eBrzEO1lNix30VDgoBPx3NGuuw0/0sPpTr0+Sk
fCpxlGFrgjr4TFogLyMAGmVmrNCsjXN+0PTpXRdtFlVjREu7L+KBeheqQYpA
Q6REJIWQfSgcjud5wIXbvTAXpEdT0+7ByKMPSP02TTqoW4UHE8aI8MMMej9y
ikSrZ0FklzOWSFZgXXwTW7Stka/lTUNM9qCvvwrmTHMKs9eqMBrlgB27JHC0
vAEFRcskzMGKei1ps6tLOaRZ/yJe6/eBQN0erEx0B4vsC5Dgl48ijXquwNwO
lXJb5nx0DeXcl9z6F+OY7foMjI1yINAyF1NETRyu2rCXDZF4k2xB7XkjetrD
i94O52D0pA1rVbumuNvY5ajUUsM5eUlbVRwfaptcaY/vZ7TvmAkqH/KIqn4w
My6uVkS0d+H1kb9wtJRHpcmp+LTbhuW13ONWeMsED9fCI4e9hGiVoDOL4cpU
tzKjpHTIbP2DPO/tw9r4r9k/C+Po1luOwhBH/O+VAmKln1Oa3Iouyla89f4K
VDSLQBqThdrvnId4UzUsNxvEHaV72XDDlFPUUDHYpy8Rm9RTIOpT4tkyPVYk
iGfVE6s4o5NJ4zrcaLqHG4TlzmFM6QgJ6+gkH0cUYddELJn67QScSdjFNmQn
SV1+HjNd1scC/h1uOvoK95rbDtukxrStbZz7KEgBod7T4O5mjUNR61iglo3f
R6fgE9NivL82D5pZc0ThosIW2wgNDiqBfMNQtjAy6ySODMapRRPaKBzH7Wmr
EKprgAO/+uKGuQz8PFbAy5BHkxZfEsUoI5IbnxBLW1u6ZdkSdZU1oO0kZbwF
Y9ArC4CWzKskoOMBDEztYMN7nqKhfBmkt45QtZkKVvfVDagadYZj2dPUQmjM
0GUnFXjO4nrVDBdabUWVT+Joi7kRzB8XgnD8F/wf7xL11w==
                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.02350745163857937, -0.014133933931589127`, \
-0.029236160218715668`, -0.1259966343641281, -0.014800352044403553`, 
                    0.033364031463861465`, 0.024935053661465645`, 
                    0.015842752531170845`, -0.0814945325255394, \
-0.010178301483392715`, 0.033856917172670364`, 
                    0.002298124600201845, -0.01627849042415619, 
                    0.07923701405525208, -0.07600615918636322, \
-0.020380213856697083`, 0.09359686821699142, 
                    0.00944382231682539, -0.007963246665894985, \
-0.05394952371716499, 0.016588542610406876`, -0.07956693321466446, 
                    0.019532091915607452`, 0.01784435845911503, 
                    0.10359030961990356`, -0.0649598017334938, \
-0.023393722251057625`, -0.017029238864779472`, 
                    0.0017788548721000552`, -0.05020243674516678, \
-0.019332585856318474`, 0.009801098145544529, 0.029295213520526886`, 
                    0.005296990275382996, -0.048621706664562225`, \
-0.04524370655417442, 
                    0.025013817474246025`, -0.017491469159722328`, \
-0.08176306635141373, -0.0016983377281576395`, -0.0076573193073272705`, \
-0.02625407464802265, 0.04719335585832596, 
                    0.0763777494430542, -0.03574790805578232, \
-0.057586491107940674`, -0.028997769579291344`, 
                    0.046140678226947784`, -0.0596536360681057, \
-0.12318892776966095`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3lUz9/zx1u0oBKSSokSUUgLLa+ZsqRFspbshRZJIlGEdqVUCklUiBKV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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.07399478554725647, -0.0017532483907416463`, \
-0.094442218542099, 
                    0.030937885865569115`, -0.00898236408829689, \
-0.029024776071310043`, -0.05412016436457634, -0.00633789598941803, 
                    0.033286966383457184`, -0.005279942881315947, 
                    0.00162789027672261, 
                    0.023256473243236542`, -0.02566852606832981, 
                    0.007888361811637878, 
                    0.00768841989338398, -0.020174292847514153`, 
                    0.005015896167606115, 
                    0.050517596304416656`, -0.004913773387670517, 
                    0.035600144416093826`, 
                    0.027897721156477928`, -0.02947772666811943, \
-0.06321968138217926, -0.02190336212515831, 
                    0.015834970399737358`, -0.037948209792375565`, \
-0.011386329308152199`, 
                    0.0693967416882515, -0.018968231976032257`, \
-0.03388725966215134, 0.01592412032186985, 0.07821791619062424, 
                    0.027486491948366165`, -0.050912775099277496`, 
                    0.010005420073866844`, -0.0558578260242939, \
-0.05703551694750786, -0.020478304475545883`, 
                    0.04841870814561844, -0.07406235486268997, \
-0.046156883239746094`, 
                    0.0008722493657842278, -0.04354304447770119, \
-0.05869932845234871, -0.056632790714502335`, 
                    0.005374884232878685, -0.01678434945642948, 
                    0.05742594227194786, 0.020954566076397896`, 
                    0.01320735178887844}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2k0l9/XxlEhmVKhiZS5EKHyvfcumkgyNoiSRhqURqn8UCKaZIhmM4WI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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.009891084395349026, -0.008443131111562252, \
-0.0068639107048511505`, -0.05372297763824463, 
                    0.006526361219584942, -0.07837386429309845, \
-0.07597493380308151, -0.03086196258664131, -0.016484497115015984`, \
-0.007670375518500805, -0.04047499969601631, 
                    0.08303557336330414, -0.1242675930261612, \
-0.0701264813542366, 0.02948564849793911, -0.03008078597486019, 
                    0.043726518750190735`, 0.0011865983251482248`, 
                    0.07057671248912811, 
                    0.022301936522126198`, -0.04050970450043678, \
-0.05267686769366264, 0.01217070035636425, 0.04361044615507126, 
                    0.02906634286046028, -0.04564826935529709, 
                    0.02579423226416111, 0.03549005836248398, 
                    0.01865006424486637, -0.02944515086710453, \
-0.03659499064087868, -0.020699113607406616`, -0.06529347598552704, 
                    0.08491809666156769, -0.009248421527445316, 
                    0.04077012091875076, -0.007326836232095957, 
                    0.012492760084569454`, -0.02962423302233219, 
                    0.00777521962299943, 0.027424464002251625`, 
                    0.03445154428482056, 
                    0.01601177267730236, -0.008930923417210579, \
-0.005790228024125099, -0.048015888780355453`, 0.021314257755875587`, 
                    0.01734360307455063, 0.0206943079829216, 
                    0.017653243616223335`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwt13lQz//zAPBOJaVSqVQ6SRI5Qr1fuwrRRVLO3ESSo0LO0qlCiFCSikRJ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                    "], "Biases" -> 
                    RawArray["Real32",{0.013737847097218037`, 
                    0.0355021208524704, 0.025545544922351837`, 
                    0.034602198749780655`, -0.025999929755926132`, \
-0.022035622969269753`, 
                    0.010578414425253868`, -0.007706207223236561, \
-0.009573533199727535, -0.013989542610943317`, 0.024632085114717484`, 
                    0.023981940001249313`, -0.004403021186590195, 
                    0.028522275388240814`, -0.01369780208915472, \
-0.02665182575583458, -0.037204205989837646`, 0.026568211615085602`, 
                    0.006731722969561815, 
                    0.03309699520468712, -0.05317658185958862, 
                    0.002270422177389264, -0.00583480903878808, \
-0.002728908322751522, 
                    0.015425438061356544`, -0.01938367635011673, \
-0.025033090263605118`, 0.023471591994166374`, -0.0031824305187910795`, 
                    0.0036696880124509335`, -0.034691642969846725`, \
-0.004399541299790144, -0.02527157962322235, 
                    0.0005799151258543134, -0.016950471326708794`, 
                    0.05800151824951172, 
                    0.009498578496277332, -0.0264907069504261, 
                    0.0020791604183614254`, 0.04545379430055618, 
                    0.04652979224920273, -0.00009725391282700002, 
                    0.026968449354171753`, -0.046874962747097015`, \
-0.006631414406001568, -0.009273575618863106, -0.04552244767546654, 
                    0.025081653147935867`, 0.010855995118618011`, 
                    0.006531747989356518}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{
                    0.15893135964870453`, -0.24173657596111298`, 
                    0.05770900472998619, -0.10920017212629318`, \
-0.07395731657743454, -0.2093004286289215, -0.11611460149288177`, 
                    0.21394391357898712`, -0.05710090696811676, 
                    0.086398184299469, 
                    0.15967172384262085`, -0.09622561186552048, \
-0.1863037347793579, -0.04295175150036812, -0.003428722731769085, 
                    0.33908534049987793`, 0.07147244364023209, 
                    0.11063146591186523`, 
                    0.4190964102745056, -0.08233185112476349, 
                    0.2118542343378067, 
                    0.17567744851112366`, -0.14859752357006073`, \
-0.03133135288953781, -0.07921607792377472, 0.0737842470407486, 
                    0.21676695346832275`, 0.12862452864646912`, 
                    0.1289871633052826, 
                    0.15772946178913116`, -0.04194742813706398, \
-0.25840309262275696`, 0.1322491317987442, 
                    0.019341951236128807`, -0.04641256853938103, \
-0.11759239435195923`, -0.12710364162921906`, -0.058834776282310486`, \
-0.05645911768078804, -0.046251025050878525`, -0.06080444157123566, \
-0.22687575221061707`, -0.1301831305027008, 0.19364036619663239`, 
                    0.1895047277212143, -0.09828906506299973, 
                    0.16091451048851013`, 0.1791723221540451, 
                    0.094310462474823, -0.14603035151958466`}}], "Biases" -> 
                    RawArray["Real32",{-0.00689425365999341}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.8361837267875671}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 4.9821652, "MeanInputsPerSecond" -> 
          51383.282111962086`], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.020365216238246053`, 
                0.021422225410234894`, -0.021461857735783223`, 
                0.06332477648385587, -0.01895581338736612}, 
               "StandardDeviation" -> {1.010491139561799, 0.9867491186600613, 
                1.0082886433434544`, 0.993054690479335, 1.0018355767945006`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8727023657534877748]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[363681], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.38939386471136495`, "PreprocessingTime" -> 
        0.370434`7.020255834720557, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.2614176880322584, 0.17595871664945606`], 
           "StandardDeviation" -> 
           Around[0.31690626263973815`, 0.05611056363675834], 
           "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
           "ModelMemory" -> 99880, "ModelUtility" -> 0.42117083948212874`, 
           "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
           "TrainingMemory" -> 451656, "ExperimentCount" -> 1, 
           "MeanCrossEntropyHistory" -> {
             Around[0.2614176880322584, 0.12442160175171264`]}, 
           "StandardDeviationHistory" -> {
             Around[0.31690626263973815`, 0.03967616004375113]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 222608367185420]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[13.912340116051778`, 1.2810413396044182`], 
                "StandardDeviation" -> 
                Around[1.0904245241586457`, 0.04820167022355769], 
                "EvaluationTime" -> 0.00014118736610602823`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.788548401918414, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.2589254117941673`, "TrainingMemory" -> 
                424920, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[13.912340116051778`, 0.905833018214583]}, 
                "StandardDeviationHistory" -> {
                  Around[1.0904245241586457`, 0.03408372787959533]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[12.42001214369102, 2.199582653151858], 
                "StandardDeviation" -> 
                Around[0.49656187566892807`, 0.039004473883548295`], 
                "EvaluationTime" -> 0.00010731390959453888`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.008719740775955165, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                429144, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[12.42001214369102, 1.5553398098239763`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.49656187566892807`, 0.02758032797967059]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.2614176880322584, 0.17595871664945606`], 
                "StandardDeviation" -> 
                Around[0.31690626263973815`, 0.05611056363675834], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 
                0.42117083948212874`, "TrainingSize" -> 252, "TrainingTime" -> 
                5.011872336272724, "TrainingMemory" -> 451656, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.2614176880322584, 0.12442160175171264`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.31690626263973815`, 0.03967616004375113]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.31690626263973815`, 0.05611056363675834], 
               "TrainingMemory" -> 451656, "TrainingTime" -> 
               7.523765832135071], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[14.193878670928147`, 1.3161009462267577`], 
                "StandardDeviation" -> 
                Around[1.1010443716341343`, 0.04904092140112828], 
                "EvaluationTime" -> 0.00013381451610023818`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.7983070433783572, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.5011872336272722, "TrainingMemory" -> 
                424592, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[14.193878670928147`, 0.930623903802972]}, 
                "StandardDeviationHistory" -> {
                  Around[1.1010443716341343`, 0.03467716807837429]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.8648916324474893`, 0.40568724381420507`], 
                "StandardDeviation" -> 
                Around[0.45024865700877675`, 0.03562201298791052], 
                "EvaluationTime" -> 0.00010533874173871219`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.0890766721078795, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 428688, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.8648916324474893`, 0.28686420114190464`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.45024865700877675`, 0.025188566943266794`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.2991263421849837, 0.1618771969930742], 
                "StandardDeviation" -> 
                Around[0.3270492187249877, 0.05247816697984626], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.39287744495596233`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 451656, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.2991263421849837, 0.11446446371327337`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3270492187249877, 0.03710766773568925]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00031670830396331406`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.3270492187249877, 0.05247816697984626], 
               "TrainingMemory" -> 451656, "TrainingTime" -> 
               1.4940975270326242`], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[11.15958419696197, 1.0260244692383111`], 
                "StandardDeviation" -> 
                Around[1.0832629944511734`, 0.04712041413277852], 
                "EvaluationTime" -> 0.0001444183103262347, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.7818209653086193, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                495456, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[11.15958419696197, 0.725508859861738]}, 
                "StandardDeviationHistory" -> {
                  Around[1.0832629944511734`, 0.03331916436560612]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.3191131169274197`, 0.2815198005344957], 
                "StandardDeviation" -> 
                Around[0.48213001319580845`, 0.03922390178014187], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.020220238857396544`, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 499552, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.3191131169274197`, 0.19906455999622613`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.48213001319580845`, 0.02773548693333341]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.4154072692373616, 0.16078319601616542`], 
                "StandardDeviation" -> 
                Around[0.35865363514804705`, 0.049795103430897394`], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 0.3048275509712072,
                 "TrainingSize" -> 252, "TrainingTime" -> 0.7943282347242815, 
                "TrainingMemory" -> 522848, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.4154072692373616, 0.11369088820387646`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.35865363514804705`, 0.035210455305873065`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.35865363514804705`, 0.049795103430897394`], 
               "TrainingMemory" -> 522848, "TrainingTime" -> 
               1.391017463958849], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 222604072218124]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 8.776123046875`1.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097569402080107`17.333472258039336*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.7255231958858595`, 
            "ElapsedTimes" -> 2.7237122, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 2.8758719931430994`, 
            "ElapsedTimes" -> 2.7426616, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 4.793119988571832, 
            "ElapsedTimes" -> 7.4390986, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 222616957120012]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{5.648243222482892, 3.465491321168917, 
              6.744954758904018, 1., 5.298317366548036}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 13.6073096, 
        "MaxTrainingMemory" -> 961536, "DataMemory" -> 75768, 
        "FunctionMemory" -> 260136, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 49, 0.2409202`7.1344482041883825}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.044040451908517575`, -0.30266467557151727`, 
                    0.3745600176835845, 0.42857142857142855`, 
                    3.890483812593875}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.044040451908517575`, -0.30266467557151727`, 
                    0.3745600176835845, 0.42857142857142855`, 
                    3.890483812593875}, 
                    "StandardDeviation" -> {7.55473131715794, 
                    4.452314590601489, 4.319157626252134, 0.4948716593053935, 
                    1.3936501033256303`}, "Method" -> "NaiveSampler", 
                    "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.2650231448742796, 0.648748789166186, 
                    0.2957877166112913, 0.6421657160391596, 
                    0.09497663440102748}, {0.6002744608613672, 
                    0.28353648909847773`, 
                    0.048298904095504296`, -0.16848220737823072`, 
                    0.727020352292448}, {
                    0.3195150757312347, -0.6153809510669412, 
                    0.06190007549037869, 0.7050084866124975, 
                    
                    0.13545410995260337`}, {-0.52887637211657, \
-0.1045041580095641, -0.636125791960269, 0.1000219391844244, 
                    0.5428703827436484}, {-0.4331664849868004, \
-0.33032897833489533`, 0.7083002188495058, -0.2284635297525968, 
                    0.3864773963728422}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.044040451908517575`, -0.30266467557151727`, 
                    0.3745600176835845, 0.42857142857142855`, 
                    3.890483812593875}, 
                    "StandardDeviation" -> {7.55473131715794, 
                    4.452314590601489, 4.319157626252134, 0.4948716593053935, 
                    1.3936501033256303`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0168188, "MaxTrainingMemory" -> 93032, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 49, 0.2718372`7.186883877352037}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.044040451908517575`, -0.30266467557151727`, 
                0.3745600176835845, 0.42857142857142855`, 3.890483812593875}, 
               "StandardDeviation" -> {7.55473131715794, 4.452314590601489, 
                4.319157626252134, 0.4948716593053935, 1.3936501033256303`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.4860255298757323`}, 
               "StandardDeviation" -> {0.7196183561178964}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.4860255298757323` + 
         0.7196183561178964 #& ), 
        "ProcessorFunction" -> (3.4546444080262484` + 
         1.3896254750846964` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.7379153229142257`, 2.64631298241364}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX04FHYcwC+Oncfo6WG5IlwUQh1J7e5+31/1LD1P2cjrnkU9h7OxUmit
E8VauVpxCs1LpHk5ZCs8Lrnf99dqbPbsedYjxNCSamvNJY+XeUmrPz6f5/k8
H0nMgZB4E4FAkCp6oxDll1tSUpTqUPO3oVLuW++77+30fYPZGzyfW9MHPmoo
OleMm5Mv0xGfF3jYMha0/ZNklfM2rosw4UnGBtzeVMgjXQ9AsnoN/7ktjEY4
HKIoaIIKn3Fydf4i73KX0CNLHLFh+lMo/XMHjOAAHgzTwJOaBRKnuo3W1X0w
sTsM20d7oK/tFltVa8GbZjKhfsyBxho3M21zPXs/dgXd6KqguWU9rFVbgsOd
lvCrdh0WRwup6IUChqwt6fiJR4q5G3b4fXAeGv2wzaI2DoSz29Dtp3qwinUk
AVZVVJH6Lrta+wjjI9zIlejlBse7Yrrmw99xfEkXbL1KICAoCrX/ZRsSNXuw
Xz0Fg24jGN7wHM5cHkZXJwt+N7ORnMioZ/JrNvy3Mm+A6nLW4dUGY4dsaZdT
Oz4s3sTvL36G5PpFtKTeGEFU3Kz2FbaWEtg/zUmjNI/srSuEgustNLzlApTX
eaHKmAQd1zSovGHNN146QVeYptEaSR24ZP1jOFp9HkxbJOD8cjG1C38CAhtb
el41o7h7RyRXCMdYyWwuPKj14H/ZV8LTmXYQBmay0gt98jMT28AQuR5Nvuki
cxEVKPP9gA7HabD0vg6Gyk8RrZ8tK84roj+uM+Fm3hJ45+YdNkCOsXRZvXzZ
ESU/kn2aHT+bTvpPa7BvbRqNmvcE48MFXP1vBdsVfhJCrTxYbmQnHMNODC36
CpcFSyBr3JnEmt2Eg2lCOnkqE2T2A7BULCM5VUNQKW8Ad9FnGJjQTT4JMeOJ
zu5gbMqC9zzceWKQhOtvx2JK/y10yS+BboM7n89QMd+PWg3CYBFbuUvA9xxu
I8Zj6Uyod2ES/3DaKZuBTV6L6fnIAOTmlxTxhYnUb5EMdB75pLeghHWeNaK5
pykvldrBcgcD7p18CjGPe/GxwJxeGLoH0u23DDsNi/hokQH6sjpA19FLOqtP
0QlZjCJ7hxqjXu/H/Jp76KBU06p2MTX91glsZD3YLWYylDdii+krUql+jT56
MXXzTuLSF8lkodeWJ9yWynd/XkT/sE/AQvUq5rc0t3UwOBXKhzKYtU8weHIG
eyumWeswhxj/j/mVv914c6QeNuzcCml5Gr7jnAff8PIVGvWpoH+sQyuFCFZr
fmB3nulIxdwaMpXtgHrTYgwsGzSIgwdxQ2Y+ezKZRNZvOcNFo/7cq3AtTKu/
RmXOST5bVEyjczfT00ebeZDUkePZMFq3Mhq/myjAnMFfYKpqAFO/OE7+Bw0n
8Iw=
                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.05389866232872009, -0.009941489435732365, \
-0.045425403863191605`, 0.02964097633957863, 
                    0.03988877311348915, -0.02842530980706215, \
-0.036987967789173126`, 0.012493210844695568`, -0.01799558289349079, 
                    0.011260785162448883`, 0.06238710880279541, 
                    0.02270382270216942, 0.04823014885187149, 
                    0.01952042430639267, 0.06936443597078323, 
                    0.03803851827979088, 
                    0.11743264645338058`, -0.04200855270028114, 
                    0.031134353950619698`, 
                    0.022264840081334114`, -0.047890860587358475`, \
-0.008261868730187416, -0.08444807678461075, -0.01708541437983513, 
                    0.0053041428327560425`, 0.020245151594281197`, 
                    0.04627489298582077, -0.0403021015226841, \
-0.019782930612564087`, 0.00008200485171983019, -0.061206378042697906`, 
                    0.06299251317977905, 
                    0.052772507071495056`, -0.024916643276810646`, \
-0.06465388089418411, -0.009622981771826744, -0.06116771697998047, \
-0.005221751052886248, -0.029265064746141434`, -0.025933612138032913`, \
-0.02507065236568451, -0.023093469440937042`, -0.0046776700764894485`, 
                    0.02225690335035324, 0.01381981372833252, 
                    0.01870170421898365, 
                    0.030819382518529892`, -0.022532014176249504`, 
                    0.021273544058203697`, -0.02199406549334526}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtV2lUjo/TbtNOiKS02SrJlpSee4ZIkqWIbCEhtFgqEUWbokWkVCptRJu1
op57JmVX1qylEvKTJWvZef3PeT/MnDNn5tM1c67rGiOP9XM85WRkZPyV/6U5
yzfb+vktD3JR/F+xarmPxRif/zXH/H9Yj9OAex7OtC6yQzReNxSnqxJVG7mw
2rFUmwk5n8TmJ/Isb7UArF6HodtYFVxwOpRCPs9FxcRAGuZ8BZqrKuBucCXp
99PEilxnPl3yHjyGNsIDiibnjzHoHfdbNLk+Wch//Q0G1yfQoFh/Hp04HlLV
z4nflruyRtJc0f/DQZjY75hw9cIILCishiCPgbB5f4JYP3M2594UePCI/TTf
sREern4I6nH7aKSMFHwsO+Cz+xJwu7oOrFs88Ys2sNZ0XV6sM11ccFIRYma7
QaXZIXArcwRfpbuC4raJvEQrjr0aj0CF+jwepJggFK7U5el7F9ETRQsc1T4N
VTTPimX2VniqYCB+Xx9Dn+8YYL7ZRnGHe5egUbda+OXfBgluiuj5MpXkTfbA
Mb0PZNCeC9+Vs+DA8XEYUBrFDadPw5D3mlzkf4aML8jz/ONP4ZyTHo28YEnH
Gi7QM319uC4thnmrqqQ2OonQGlEKi+1iKGRmKDsr6aDSImU64LERpmxJgLuq
c9i5bDM+WDULV1keFDaZL8ete+ei4SAFRvUY9r/qKzxUeEtHg8wg01ATndIU
8cTh6dxiIseqeofJwnCodP3d7vhTYwjfOTWa8PMgfKSrzQ/zvxBvnY/Wtbtx
U9BJynuuj3MflsOxKDVcUKMO2cvDeJGGCT8K7YNXu+Qxeu1ratyhyXdb5OjJ
GV22TIuAhMwwcKt0o8prVtII403U0vBW3J5YSsUpSrwqK4b/xh8SQ+LVhVTF
qAq15zl4//pGsLvmAIpJyaBjZCmYlivhYukwadEFXZiuFAt+K+PYuz6AHzn2
o/Dhllz7I46efv5Ir757ssPV+bBuYQQU+taS7DAV3qPeDqH9FnBJdD/x5fBl
/DNDhWMNFPllRaPouCUaT6mNQ8s0PeC8YbRzyxyEgADMa5bDNo904dObsVD/
PIZ9R4Tj/bwkaNr4ln5mJf3DTJYff7st/tgxB6cmBbNB0QG+2WmPn4c4QVdy
DOW9iEEX97d0pv0cffr4TYxuP0uBPw5Rw8IWONozW5w9Ok5a/CaXP8VGCj/r
wun7ykC63KcOeqnI44F6TYwtVEWf7zVgnBXFPhn+9N9oOygdYovOvUrZEB+T
F5hz49t34N60m3NnPBWKPsQK6jJW9NhmG1bfUOHGNB8xVCuahw4upVuXium2
swtPv+guOj15CKoanZQQUgwbM1Lhc/8CcpGPpxiF6eSwokac5+NG3W5+gt1f
fARfFWs8EmTHo7a9BevMj5LBE7/T6HlT2dvNHidWL8X9Hm9I2TkP5w9tFf+7
pcd56a5o5CnDN/quxMrbLhDcqx5yd3pAVUQon+2Mo+RIbd7UqYnbjnrR7Snp
wg2leig+HguhY3yE99cV6OV2Q9rjfRiunffC9F6LUeZhHO8Zuo8OGqWLX71C
6LBjBSkPCBRlF8jD2EFN9PJZGaUV5VPK+VkcvG0J0YJuuHTsNkh77Ujzh23h
ki5DPtm2kd8lVwrR3VdyRYGJYJAkx91rm3HuNFf+o2cNax3+QsTTEdyg/V24
azeE7UvqIT6zUdD85YRbnkh5cfgdynR1Zx1rFRzg81eoWnEe/nxSZo9BIbTT
tIkmb9hFjfsG4m3bSfzEuA9H9JuNdUcVoOi0CGetYrBj7VOYMvs9Hf0vG1bt
s2eXK7XgfD6CdFbU0K++puju9oP6PNNG9X4KbNu9gxyXakHGRxdyVd7HfUq+
UkdFT1xpI9DwPaq4MK4Z8gqH8KJxzyW9tDoF5/JI+jU3R6hcLQjLdshisU8h
TdjzD+sfg/DLh0S4Oc6PdCOTaWqwIU+HJxD4yhveVQ0StSyfoEfQEYE0pnF1
QA2p2FnhbJk5XDWogbv0OujProdQK1mGinm34KLJO/G7vDxKSlVxsNdh2nw/
CncesEO9a4r4Y9M34f2go3B22W48kz2Gtnm+A3mTg0LNaGU2+eoAu04LUvXV
x0Er6ZhQfauZ1ur/oViNLOp+WB5VUu9AsIs82SiboMkNS65qEGlEWgOd/xXJ
U8a2kMEzYyhyuwUL75aKqbuvkdxPP/ZbORduZZ+ENdVnOdrzktBz3ivaas4w
X7EKfHZ1Cd6+YXBF7rHE9+IwCFjsz2X6G4QSa4BX7RNY4dE24fziTlJ5M4R7
+iVTtlm1ZAefE6OW/qWXxjJC6bZaiL5xHd6fV8Yzb44JTaeH4h21rZSg74va
p0zw4vpPdD2mAfyabdhOPZKavpWCuuVzmPHxNhmkddKtw45sGXlDUHULw8qr
+RQtnwE7+JG4vbqAf7gd4mb/OQyaxnzV04Xvjdgv8Q7UI++NoaLBNaBGJxnu
2NsfPxaY8fjWL3h1SBbfn63Oyx/0oh5Fi/nJGicY8D4MNRNSSF9w4LPy7uS2
ejzNLpiEKZ8aBRVtX/wpssQyUYW1Ug9ja2KHNLjGEXVWqwtn5COEndopOD4w
gC+GvxKvtyyAvtmOTG6pEOsXhO3lY7HtlAkPHquGZZm3YWRRFQRFz8Ldm34L
Cn0fg0eZOnZdSOFh3sEwoWk7ma9SIWlrAgyaeg+3j86n8Cmp5O3oSCN1Hgp9
7ZuEhIokifLRtaLqh4Esa63LUw+pc80BIl27vRj8T7umNg6iHPsYeuuiD257
93LglWWigbt35bJBwcKpxhF8X98GhQsdMKV3VuXeuk1ssqBcTOrdD00XaKBe
/134QikFJPr6dKLXUeHw9qX8+j9H0fHrMPRZPJTnDXKBpEMJtLjgGjknjoQJ
uufg8qxcmmOaRtfm2pHTOiPWGv6SXh3eB2PlFJGTO2D7tCDUGrUWrRuceY9t
P34BJ2nWBjNqLdnLtvpjeNUgF/4xci43On8Rzi/vSa9OeYjnfMzQtL6QN5y2
4NX4CMbfmYnuxr5itfQ4289W5NKZ/4Ht51lc7U2U7G/C227dgykbL4JeRBNc
7rDiqj3DoCP+NDUnDeBnF6xx7/tyUB0+EGJHdMGxwUt5j6EdTGxexE4XPlGJ
dZH0pWkMDfS6K6pNjuN0xw+iTMYkdGjNFL4lnoe2Ag3pG0kdJLteoaPNpbBh
eyT2cKkR7i4w5yPn+/Df8btgyt0yyr0xnq3PNFFXRm/cklMurXK24Vqz1WR3
ZyKHxEvw7LVseDR6ICbX3IY/1/vhJbdtVPQ7Vdplf1bS/+E5ztw+HPt52Ypd
H22pxC+Rurn3ZKmaA9el6eLf5UOx7JIP9OxxAI9fbOZIqRcMS10MI7fHir9T
lHBb5gzp3+psal2aCNv/PKGMRncamDoQd5q+Ilc1G4mxYjrZOxjDdkmZ+HXy
J5i9Sw4je82hlkZ9upoWDX+Cu1HzIQE/272BmAkLqXvRJcpVNKKpyq8l8iWT
BZv3XTT2E0FF9gnxk+JFmjpAFB/ti4GV34/RMvtmOFvsQPO2FPDzemf4sb4O
om4YULhLBNzrdge7xRK9PfyA/Dy2YNHbYdLMZwfo5FUlOvOfJvyNyqHXzkNp
Z1stfru5DzzlmwS5MBdYtyUceha/oxy7UbzotQqX+hcKvxJ6oMnYtaz8spPO
ZmZLrBsb6P5/Xljmr0B9G+Q4xrcJdl3vFFX+mFJFaLlQ3WFBLXkO2HvzYmFj
U6LkzaUo0DHV44q+y+H+/kMQfzyC0tItsfVrHdTr34P0jTp0K8wWp8XWUnlD
nqg/8xrZL1/Av6yUoVtPL9Fkxllp3uG7kpRcN34zwZ2L+lrRwx/L2bJWDh/q
XbYZ3adNktbrtzDg3B8YJs5E55dvcMD8cVi2UpmuTTHAr0u78biKWojrHM19
h9WQYvkOiI6SA6vPS3kkWYLGF3sedCiBs6x3w66a35AxswFUmtZTYIURur6p
wvf+Fnyw/3wqXHkHnquacpXZHqg2iqBv9Wb81D2XjpZ146Kvj6B0RTaVtnrz
nz/ZvKN6Ik2uvYT3PVbjvtW+kLwnGr8GjADPejscl+Mt+nxh6mdrz7LLtPDi
gr344v5QjrkxGu5HHYAVvwSW3p0KVXQVqt9fBp1sefyyI4GKs2V5+XuB00LV
2GtGyD8fuZzTZBYKz3YmQVZpDi5IPYQlC3fymsf++GvJKhwSFE0dy94KKf0e
kPKVXXhb0ih5JncbAh7Yicv6XqLiPrkUklUhOoc30NyG86J5uipp9Kui6jxL
Md37AhSCKgfbIOaX60NExmje56UL7R6TePav5dRi3gUlp9bxMQV9HrS6WBCT
Pag62B3tm1TxMp6l3j2bhfzhRbC3mzxPT/NB3zdDsPCtGnl+7ICC95qYdMQF
suUKxD4hz4W7bQq8gF5T4KN6Se32DfjuXS66denzmHn6GFh4gWat0iUb0Y2C
9yqTK8rzoKBv4H//N/gFLeG4YaE4YadUMk1/IixZsYC/t2zDgoRNEFXXTspN
cqzccze6du8is7IXQnGTHj4t8+Mf8dlkYhggmaqtBksNrSF3gokQYmrN6/Tz
Aaoi8ZRZgNRiQzL5R8hTfepTGug3BLN8FdHVf4203+omkKtWlcgodUK1aST0
sE6Fe853aVLyPdrTvEiqUyZLep6jybSqBLpc11H8Hg2IOrYIQ2cl8aNgL27e
aSCM/c6UfyCWeo+5D2ctp2GUuQkFHPZD6957eOXDe7QgOU1KSyR0VNMStwQ4
sNE3EpXTp0iWvpxB5RNfwF/nY1i8LRTOViTCFOdKHtn/OLUemIkFA86JEZoK
WCOZhhuKemFJwVg2unaNxiucQrlvJ+jvVSV8cLoZRrSn8DHnvbDK9RC8sXSH
pMzBXG/QAA//cUmJRR3YeEaBaeBeWLrsBpWUhqKNNB+a9hbjtfFXMBG8YXCC
C5yTHgDnLlvq9LGlNbndhFVpSZLIdUi1l/Kk1h/7CKYaU9B8iES6o72YptwM
5Zn6CrhvVi5slrlFl6v+o5AJA/HyAC+YvzoE7ENiwPBFEr76OACH7vej3dd3
cnxZDq39nUODG/Ro2eVZMCpXAQcavCSHpBioXK0No4NG4sf5u7C9fw/ek2dE
8pMtcFqOLTvMLyc/n49k9VwdzmR746GRGhgszBWD7eaK9nIG3NEsixM7asEd
jWBo6yjaFFAodtmXVrpck+LZ7l6QMvohrTvai7dFjSCtm02w6bUGrLQrwLq8
qTTxZBja628Wvrt7w6Hys8IdHT0wVbQi1XMuYnO3Y+B8tIZeaG4EhdppnLHV
BPI2EbzNCJA8lzbRtZgHsFw6WTJlj7n44nFf/DLyRsXPsOvgr2DLd9ZlC56V
O1Gn0QCWeDWKb1arsmxxB42IdkdY70F5p3vi5XQDuj0jgONk6nhB8woOOVEn
3dx+EvtPugnyFWPYeNJFKX8qEVarHqL144+LiWWPQDBNZQXNGF5VVgMH8oJw
9Ro1XNuxSph+vUAc/VZHetJFllaqbiCLEVbQ7G/HY1Ky4YKmGpgbbhSPSdaw
tflublpljj9No8BKN5R3h+/C4plh/GR2Cr6T18eIjGp8fhr4Sf4FSXxrH7wg
q4k7q8LEXgb21PVLhZ82KbOs41NaeKk7V2pfheY+niTJdcAqP3POSrXhq8/z
6UFOFC/+PopVYhN41LubZHPXGrIXr+MFobeopPUKq7qVwN2yYh4Uf5IOhh4R
1/jOx8qYE3RsYBnF+X8T7vf6Ke6CgRAzZynWjwrFIbol4NyuzNLrP6jjQTgc
/H0Rj1v8oqQrK3lydxmy+qCMFZ5ZZN7jovj5sgs/WbUBxq0czxb+2XSbDbjQ
R58bHuXhctsVfF1DwpFfFKiyxgJG9RgD29xT4PlXdzzv1B9vJGRB/uyJbO4R
jwkbtISfcnHo8vcavFIU6c72wdzrayrJ58jAmMXzseuQKSUs0OI961bwvqQq
aElMpBn2OthzpQ8uGtMA5+rjySm6W1WhbwSGak9l10OOrLLZFO87DuHZ598L
1PmI2ifNxXf9uoQp3XuzxiQTtJqdSbUL/4rT9oVQmsZG8M8OwabRIrQFfqfW
moMw/LQhqu5cL2458xlm2o3C3tmllLOimpY8j4XqZYo0schLWL/zPQxbmCdu
l3Gly/9mzmxKFnvU/KXjjUPxsddPwanoFBy4mfnv1qQCXFxMP1xvgJzMB2rf
FcZu/e04NXkFksoy+taqKso2zeArHbroMWOeMG9nFhZ+C4GWK0b4wrgPKG9T
41eR1VRV05+1IotJ7Z4NlfeL5bcLwvHC5yFod6O3KJjFEW36T1j7HXHwTzni
4+vROX8xxhap8qWQYn5pawD+VrK43qU/O42XUopyH+q+wRhrC1N5zMlSOFho
izEZa6holRqOlZ1Mn2LKMUWfaNnCyXDxhgpsNAvgWwq5oMATqEQ6h/d0/fOu
JwHTXxsLGa/CxJtX5dDgtB22VbbToKVqHP21gaBoIn6VvUBOzxzBqudpoQjb
YPi2nbghbCXE6p0TvS7949hJ7tL90X8l5zSf0IL67SwO7i8MGeZDPa1PQuyD
YBL7aeGk5wdF161lYDD5MlQrXRA9Xlli2RF7XhUqK0rrYvjtvnk0z/OgcM1h
hhB0RUOY8Puz5I9FHP9cPAm+JdfCuIgKOqutxMp3Ram8ih+2zc4T62uH0rvk
HMGWW84FHb8pxkcrodbHYRw9NJpWT/4lzNxQC2e7XxVTH67lOa9Wcv/Wn6Rr
o8RXj7ykwF/WuDA0EbSn9JCGtOpQHc7im3hPXNjugD0H3qXA/DKYmHAQ0pKC
cPj9FnJ6HMc1IYH0KfczHDOZJpiNGEQN7t+FogmG1JKuzHv6jeWg7rKo906B
/9y7LgZMywPTxhaaV9+DVm1Wwec7xoHPCSns37yQPq2YASeL98Fn7UMw4O5w
ejc7lAfEj4KiARbkX7+Pbqh34369/ul+XjnU3jWkn5NGoMcdTzRIqYavxUao
XeIHjlO1+LuPJQcuXYe3cxx5hXU05eiMwcbA/jjVKlmANx7we5YmV17YQ4Xz
HlCP/U7kdXoaCbCXZPpcBuu+LWCZWSX6TjXCKnhLkfaj4fmy99Ra7QRD0ufh
6LHRHJjpRFPmfJaUKuvg0n+PtmfwEek2ChHyB9ixdvRR0WeMJffzyCROyoMR
r25SyfcasaNvI4UbTKB39nkij+tJj0YN54jVw9Bh0lexx6SvdE/7O0163g/N
nzCN2zlbeDx9H/slCwQ/F0OtwmR2+ZiI81eo05sp9aC7TBlHhl+WnJ21C8c9
CqTJD/cLam1T6FnQRLGrtYBOVtqiQTdtWB9XBeOjusMo37CKQyHl0pHrc7h6
oB5f6rVROKI3nPK3mooPs8+IWyYPxJuDcsRnOTE4fks3THxjxIZFo/i/AeGQ
ZxpMxYbl4l5tbWrdXAB9fBPplTBCDPviiNq+CWR8ajXELtmOCYe9cPbh3fje
PAeKB1eDQ/cl7FeiLBjNDxT0HC2g5s5W+PE7SzQWKiBjoAvq/Qd8eFsK/XE9
T6NVLSXf853A2P01Lmuyh/ayUnitcg/mKPfj45cn4Ly8BJr+447gv2K6ZKxv
Kdy75cHzFBbhn2nWrPL+l7jsWxvlRyM7nRmA7/ZkCTPW2TD2VGJD+1qY+9eO
+vfTlQ61XYvSiksUGhdPT2ftlFyK6o3bTioj3gtk2UmuYt1weawp+k323r25
5eIE8ZuLPj86/lRYtXo9tlZtpsyxzqigq4JXFH2l2W/tefeJigrNt26cmask
nWExjAarR6H7lqn8/YxE0IyfThvKz9PBHSrY+kOT/ns3lQN9wuixiTcV6plj
xCV9/vCiAiYMPC0ulJmOHt1SYZK8Bqab9oE/oI7nFI7Tr/+yJLOxCscskueI
XhN4ieltGpDihTM2xKJDRyuYxGhhd2kvXLz5JrpfWCP2nd4Ll3SPI8U72dLu
a3Po69IPQp/42/Sgzgsj1Y3JAtfiY/cRfHlXh/RQuxKX/fq3o6zDwuNVD0l/
txG/OLgBb3yTwS5nJ348zYJd5hmxn329OKtXIm02uwmarSNx0ZLr8Pl9GFWv
/SgmV/RAu/hNOG7HXujpclySemcZtP51hK7twZCyMIiU8z3477CxZJzeLjiW
ZpDT5B78FA+Rp5ot+O7pyXMWH4Mr9Qq0pXw3yCgtoS1KAo+pi4ItGaZo8/UV
lccvEn8e+wvjjB/A873HiaMTwUHjAWQMD6S2KbdwYaEnmqq8ptVLmsRjNT1Z
7myQNOR3ABjunInNI7bTH5IBj0MrsEGrEvR7hyEdTBcX/bwgMfR+Lhz5PVAM
iX9H40q289yYq/R5DNOLa29p1IyfdPzAKDFNJwxv2Hjh+H1xJDybRHdfXgL9
IzMh9vhr+OPpTu59hnL+kULRe/g0Oj9XmYM7dLB1aCucsy6jsvJzJInW4y93
PpPbqzzoXvAY+Et/eOh4kFaPVKGSScMp16oS2qvPs+2+HAgdGw7j+w2UbFk5
WRy0axIvj/BD3cknaGXKGRiemUSWMjngcnUy71Vai8G8m/vH9sLr7/xB6isv
TFY+D6nLAtBb3QTVL2bR984smPprNDy+t4slbeGwv7QXwJM6mDtoCfz6EQXd
/fRwksJQyZuUV6TxwF16YXJ3GNcyFXxc9sDKPkbgaFsm3thwBt11fGFU+GeY
Xn2cTCYqsEtKtFCrMQhCh1pgbqMhCE+zKMdlonDwSBHSgBmw4+MUuqhWSsvH
r0U7nyLy+O2IFbl/YZZxkDggeR1/cddEnfYF7NMVyU3hk/GM4RXx6Dk5rNe6
JqqttcTzQ8+SsaKEly/Mo3DziaR54o7E66Y1BC7cIdgVzMEdydOFO5PCpIvu
W3BkWW/80b0IZcbI48p19YLRlTAMKqyGTWOmo5EyQWiGBt82DsH29CCOHhzJ
hm1ToLnYjrOs5PGtkitnztwqyJ6X5xKzSqrJuAFNU3fx8JL+PGa/I7eM3Yl3
J77iz8b3xVS/WKFK+TgMvNcTdoQcAH+jGKyeaIGPHR6TjJGp1KVwNB8zcMLO
suUgE1cPLyyTcY+/MW67587yc/vTUA1Z/vS3AlzG2/MIP31UCPoo/e3yhkpG
J8OatWa8MSdSDBr0hk4tN8Cx+qqsnhvJI+tu4NiaQL4VZ4ZXviuw080vFPw1
UKywqIFn9bkw4PkQnvRzNkqW1sDlIcvxfOYomvA6VvIn/BKq33THAou1fO1h
k+g6ZSY3L+zBt3dq0uIqOfZ30kGT8vFYc1YLh79GHnVgAqdfuEDFe05AcMs7
YaaWDDbHqtGnzUlQph8jtdzZSsrrNXjF8RjWU2yAvy9sWO5oAi4pHifU/s7h
jnQdnv52G01LMsS6glE4qWknPtxdRW+tOkjeSR4Tt1hzc2S1+GSPlNqmG/CO
xL4wwsQcbbcM5bKmLLre3wdVVtvxA4kyphtvg8xV+rAzYjZE/zAHC0NL1jLR
5RE6xylwgDGcbiuAzi4WvnwNhV/T8tl+vg/qvtMQtjyyFiwX+1Db2pkwMa6b
aPVrKp6UI9qa0FZ59L88Udd1LSgcW8PDuoLAPz4L5OvNxZCr6eJlP0sxa40G
bDhhiK81BvK69/uk5xTLyb65HTBsBD4pOUgHTnykzhGj4bKbAje5WvEz0wa0
8zcRFl9qAc3jE/HQqmES7TnunKKlxjY2OaDoeo0tC9dDaUSBYHf7ADWdceXP
jVeg+bU9D/9bAIkd5yn/Zz6lZOTTmgXV1BDvg5ver8D12oUguzcN1POq4Nzh
SBFbvKDbTw1ecvKtuKQtgyaazAKNbmnCkTtu9LFTKq1MUuDxLwpp/vYtNL/K
jcO8lVBuchu4VyQK7TUFopXVMAp4boQ/2k7D6UDkWRZWcHrCOcwqHslDk35X
lOadgCsja6jTz4R/lJ8QGnpXChLH2XDC0ZJlO1NZfgBy4eMC0Smtu1T34h8x
aW8wXFr3AFWP7+XrqzfzgpFe0Da7xuZwiJYgCD2xX1tPbqnUID+7Mpj5Jhjy
zkSJqw6Mw+WuldJly09Bad0YmND4EgIse/HOSdF8carI9cV70anrLGwakCXp
2BWOP6/Npx3aEq6+MR38PBTQv/UUOZaZ4JGSW6BccwxiP25Fs88pZO9ZxP4r
r4M4Pk/o6j4GL82Oo4h+LYKBg5Su+VfAniX5oGnYiU13Ad1D9XjN1HBqHuBL
KpfmcHreZlDX/hfrBwlVk8347m8vNtabBL02ZMCHmxLhQO8KiEiM54HTHOiS
yhOgbCQzz7fC3xZbir/sjrYformH2nq2PiCLxRonMEtIQPdTOziqLRZ1FefD
xQA5XHv/p1C04y5VfN9Idx02kvSwCvfeYEc/VozjGGUn6jAtFQI9M+ANjhQC
R5yEZ9/jYc0fW7Hnoz/QmdyD363L4ZgEZdxmrkdBtE98s0wFmvdPxNsDjsHl
pAvjvT/eoisZX4XLA8dC955F5NmvUawba45NvZ2E9p2zSJJ4i+7MMMPYTYDT
ZjwDrce7aI6TLMEPe4x7OxY193TDCrPnoL9djrUmhkP47G+4P3oOn8u8QM1R
M7DbGRsaEuFNmnXX6dIsN7p/24q2fxhNbSvm8JBtLawxayFH/LpFmmtc4e2u
T3zqWhp+75mCRn8HosNWQ+zLJpDaGksVDhtx0kxlunJSSvs3NQu6k/vw7Pwx
uLJ8DLrqx4imE1XYc2YmGQbk0pl8Owowa4PsnW7g5rFFLD6/AI53PoU1Y+vg
1GNtYarbMKo/JgNuWlHinLB5UKIdDybPHfhEdTx1tsTRye090MsjgxaOZDKp
u0Clk9WxWnUXcsZwtDjdJtwfPgriFgMmrozF7B1IK3qNpYZiNZrdeJs2St+R
X982Ck50FD/lbCW3/O6guGAJ8b3JfDpOnaOyw9E9URnV5X/AmSPmbNYaRuM3
BEJV1DiOTGsUuh3KEg7k7+AbFqpsrqWLW21M6N2Xz7RPWxl3XJwujrl5FVwv
zWWP+TOEh4mnoPdWHTjve1lIEN3ptVEAHHswFY5cS8Y+j88JV0vD+X5UEOzt
LIO0z3Gwf8UXONTDEGPXLcX0knJSN5iJouou0cN7DL1+PR+zNv0mhW9a7Ok8
nCUFl4T7nnKC1He0dDTshbi5yWj5UwfNh8VVau2eTY+kyVDHOyj/b6TQ8nkZ
yU0bxuS2nW1mqeFcLyl1HvPG2uP7KefuFeH4x7kc/LePVLgfz683RcKX5N2o
pPxUODSkP6g9rBD1Cmshs3QDbB6SA3XRXyC3xpL89p4RAj/q4oE1BmAls1V4
fqEHVRyupF2RPyTl8Um03LKBrBuNsLC8h3he6zpAvhXfvq4kpl35BjKlw8UD
f4ZyceBhcLDsEiZ8U+IPin1J4eFGTvAex/OT38DNQldOUuwBxREiKG2y4BCl
DzDcx1nInaHI5nU5qHdyOW0YNBD7vysW7lg8EhMGHsRPVyLZZKmA1WqT2Sd+
Dil0HRQfq4zD97avJSW3V/OfjH7i40XxVP69O37pHgV9wzywaMlT0X7NNzhj
GUUB+/vz3rt2bJD2hCtn3aF+iVvE/maPwCzFkp+QBifH6+C6sf58yretcqXt
XHzzzpcaQx8L/VX285GjfhT99pTkr+0mYdbKQ8L8ARqo2BGDucopyA4TKSUz
gjwc5Fiz9xub1i8++Pp6uvDoywj2kVNlOccQQWNzGLuGq+CpzEXovjAXRnZ2
Uu+8wbRuvhn+bdCjO92mShJjncm8WYbTLz0kjtSmJ2r7SfrtKt2vdcDgGfVw
0GgpuTUaitG1JXS4ujcFWcfT5B6H4enARGpsOytYbPIn0/prYHYtE58bDeFD
u1fBuN3u6NuOwuLx1nzscR5vMzUT1nl0wFv9vnDQ+RU/6L9T/OowhY3bk3Dh
OH0aZtONPe574efbZ3DaOCNIuyShlD0rQWmwQNG/zXD7+750L2UJOgWchOpO
PTxc8wLW3g0XzDytOPXoJLTqoYss7QWuPdfxH4Vwdt6ozTPa9USdhbXCq8dq
KLtiGj8+ocnde/XncptEyGwNJ5mXIyQ1037Sfk0HSD87gHX/+TiZR73Z5kc6
RWyKQUG3E04n7uHwyHjw2naZ3szVx/DBp2mrdx6dizCil8Ea/Da3VbppagX8
SMrBWV/mCQuD8yVe6zcKFaraXJO+mU+PKqep/l8ElVI7Ycnvmbx6dwuMTfgB
Rd+UICP+LBac1MMPhd34ucSDk14l0MJD6vgrJUIy71c3+jbjBde9K4aFsQ3S
/WcdaHFvI7B6XSZ+uqeByroNoDFqP9xIm4j7hl4nxXM3Ify2SDuyyuC8rS29
vSfD/g0ZMGO/Pv1I3yIZ+WQvFQxfzrsyX4mpJYlg7buImwMs2WT/CFrb7ZjY
QzxH+wN20fSAIPGNUht1ZL6H5++OQ9G6NzC/dQivf1oIhfFpEHDhF3S6ycLs
MQfZ6nOc4HmpGUJVzUC2qF0Uvu+wcd89g3qq9+GiLw0gH9ZLrO15Xtz2oUXS
zZUFKrsC61dVAp1ZS3fMZXHKoyrQPK8rShun8/8B2y8NLA==
                    "], "Biases" -> 
                    RawArray["Real32",{0.0029542415868490934`, 
                    0.015121739357709885`, -0.020800335332751274`, \
-0.015190537087619305`, 0.003949274308979511, 
                    0.04093750938773155, -0.00023632036754861474`, 
                    0.029741575941443443`, -0.051664672791957855`, \
-0.03775079548358917, -0.06287902593612671, 0.02910085953772068, 
                    0.059822339564561844`, -0.003664107993245125, 
                    0.011418547481298447`, 0.0197274312376976, 
                    0.037608519196510315`, -0.01259460486471653, 
                    0.013344591483473778`, -0.002213858999311924, \
-0.0065173800103366375`, -0.0032772354315966368`, -0.03497551009058952, \
-0.031631167978048325`, 
                    0.03181201592087746, -0.03959200531244278, \
-0.013788427226245403`, 0.0035813588183373213`, 0.06025252491235733, 
                    0.04018883407115936, -0.03657475858926773, \
-0.025761697441339493`, -0.02988729253411293, 
                    0.0062470450066030025`, -0.05925098806619644, 
                    0.041830968111753464`, 0.023539472371339798`, 
                    0.033046070486307144`, 0.006280672736465931, 
                    0.01624942570924759, 
                    0.060202281922101974`, -0.07678718864917755, \
-0.012841183692216873`, -0.07189671695232391, -0.004148778971284628, \
-0.06372730433940887, 
                    0.01784650981426239, -0.005183069501072168, \
-0.05865871161222458, 0.013951638713479042`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dUz4/3xwtZKalEU2VUKhIZvV/3ppDslCjKiJbZJ1EyKtp7kaRSohQa
Vnq/7pWZyC57JIRQKDKKn+85vz/uPeeee879547n4+q5b3Dw7CYjI7Ox9z/n
sCLA2s9vxRbHnv8LPFasHWu+9n9J8/83GbcP0LvMH3Kyj/KPsxtw1tYiGLdQ
GQ5sNeQf2YEkl3uBHpj1prb+rdTdwB1vL9gBCSsCeMr56dy+34RVd+fSDK0e
qFufLQx9cJFI9QF1KXWJ6dY3pO7jjXipa3864auFHxXG8v5wZ45caIWrfAKY
l/XA4CGWWPrQnhfqyILDQ1sMKMyGa58jKNwzQRIW9hCOPkoS5s7Pp7rCHljz
Yyq7+G+E4xa5Ys+f1dgwNVvcIa+GH5Rd4WSxDBt2WeGOqmM433oY9XkaCu9/
3xN3j4qhhf36UJpKNNOmZPFxXx/62HkFBh+Zj7r7M8k1OxA7m09IG2r3iSOd
TMHdMECcqJ0p3Js0nJUdBdz4SYWtXvbBGpm9IpYvRdhL3GeZkpVWgixmnjkM
LkbtMOJhPgSdj+TLd305bONVcHBwI4vjw9AxtIiyw7RR88FhfmCSJ86uCQOu
2c9Zz6IFTat74tT31dJdWXfoYtY0+BraB+WP1/CZ3DmUuTuUClyKsP5WruA7
oDssedgkuD+LQZOtE3BilDb7QLU47KcLqS/z515ztM9OW7OInRt6QL2LCczo
L8+nVAzQKaJZkvz+Ip3+dJQLe/8HOk8NWDcokoJ8smmKX28sGztOdNki4XNb
j1Lq1R784OANcvurSuHZtZA4JYPMbRKFkX/M0DPUEpSeqwg5WplYbVHKj553
CDdWjeZ5zqZYm3YPLGb0Q5evD2lLorPwM1kHT5xfZHlaIYk+W8nB9MU3KDcs
TDqt66Qg+2Antl+dAx7qw2D1bFdICdxJ91SRbfUv8raje6Bwxkzcf2K4qGCY
IGl50kVmOrP5otVuHlHiQI8NB2G4SSotse+GkdOt+XFrMLfl7uHXai/E56xO
3+QyaMbXDVjxOgLazuwXx2rVw4se8zhKtgomLbpGZl920WaHIB5w6I+QFPGF
tntO4UAbO350SoOL/EJoh2Ir9HaJEv0kmsJJp1KyMZ2DyrHl9Cm0VUy9d1ka
5p5DfYfO4wl6W/jkqwHQrfgYLi4+KLVQMYHg0lWcLcZS5MBpYs3zBTB81hwu
vvYLDn2yEaOyLDlOaQFenPtbGGi2B//ceUDTDhjz3A27+Mqnt6Rv9Z7SihXx
8scEOMyVMCfoBhnLjuY7K9V5lXYqaDrF44Plx6TGIaqYHzgeFz/ZKzzyT6ex
BwKg4ma2sGWHE751UUG3DFc0d0pD1n4r9UrYTtsOe/EQSaG0YrM17D58D4xX
T0NZm0JyfH+GfKu+SDO+34Y5q9eiee53WmB0UjDV9CeOmopn9Osoyi1OUJ67
ix+0TKCp3hfxWN8zwtA0Z3GN9V1h+QNTtjtTRXmjQrj9hQtea+mJ3j0OwXg/
Xyz20cLcV7ni8inV8HOTCo7a64sTps/gbc8ncuHEdH7a/h50YxaIM1dHsPFY
G2hof0Abb06jMv8ccr1fICTPUGP3VlsanBjHMtqh7HXSRMy7PhiPsR68PnJW
8rl2PI7d3ovWuJ8Rdd/2gD+HN7LcuiTYdDIeTn9uFu8dugunnbMgND4d1eQf
888b3pC/L5+OheQL3dykFODVG3lZoyBOHY9LnkRyw9s8fjpSn+//uUQDd/XB
A8b3hJDo9/DY4xieU76HQevisXDsMh668Av0Su3J7Q80aFDeB/Bs86JVW2aS
nU1ftuwxHX06jkGakiY6z3aG7crV8G1kPC2+2gByBd1RSXG1WLUkCnZ6JlCG
qizLv82gfWffgrW4Gwqz82CIX3f0KVxFqWSDlkqKPGJUFTn8YZLmL+LU6x6C
eL5Wsmp6BUnCVsLV0ouStuQdgr36GLF1vi/r9j1Alz/+oTCV3ZR/KwkXa9ZQ
uWSzkH9iEC4vC+fPzfOhQR/x+QUbDjA7C0+e3uIXT2RhRddY/KFZC5mPvWj3
3OEQvsGMw3ZcAY/B0dSv/xkaGGfCmbWJdIpjeEB2stByYpXlsIZsclnVKLZf
OQzv5Nx4ISmiWWMBWNsrCoc6HWng5ImoEH+B8pOukaPMA5irpSdqzkkRTQ9k
UeO//vQ5ZMXjfpvBomhRqvDxALi6DWD0uAOTX87BLAV1OH1jJj6K7oTe07ph
0/7lFNyxgDw/P6PvjfZodvohjS0qxbwq63/xGNavQ4i75c3fkxJJ4lwnDg0P
YaviErDU6ckXd1wky6xu4GxtQlfaY+D1Tynnl55Gh8J52Izh6FjRLPQ4rUA1
Dr157bBv4rbzavz+ZDexynUD7kjeii0FwRx+awsedHlBxw/mYKR1Gr1zCuU6
p63oMVZPVJR/BXnDeuPTm8b01uk6VJ9J5JLju4R820/ku1ZV6vFZEf3in9GL
okUQ9PkkTw2RA7OJk+EWq3Lw7hqxrloBHxk+pdaoy+LXfZaUrPKDtN5/hc6J
8ZCqd0B4Zyfhgv3duC22UzDxe0WvuzWTpPIpHVsSKXzfOAjOPHsL08XpLPM7
GhuHH6A7y2z+9bk3uoVrSzeqbePLclkk83QAfI+sgfhRlhSyz17svfcpVGfI
CuNse6JWp5agoJyGOyalwgtNf9h9XeDeKdt4SFkeJCmm48TUWeKSdQl4pzGI
nI/J89EiJZ5nnM7qHxXZLbAPWSqb0qA/C7CpTsDRXoeEk9/H8NT6CXDRPgZO
5lTTqeIsMBPi8EhHEVh+FsAzfaK4xfsrybR251knT8MfNRSXSHO4c1EiRVuP
4g8jr7BJfQ6qNSyiXuNrSMPUAlIeBfPJRRb87nI6tPUag+k3GeJc4vD8c11e
cHodGUo/iN0vnQDjaztFmx/6cOdTotBLPAsLrjyl6AU9ccbtYrCaFAmSPU3g
8uYGmOSnU6rGWdD6XSiUdLlWLk4IZ4Ux70FG00LyrbmYB8pLoKe7MsserKJb
O0xgZU0hqI9cQn/u76YV6/rwm8e90M7YAOs2y/FefXMctdOCAoaOwCKHFNwt
lyJIt3yii8+mQb4Xcs74WAjokSnWrO4pPgyz42EVqTx8JUoK3kSIO5TShPyU
91A5vlaUGn2Wtqzri1uVF1GltRneDDPk1PFhVN1DDz9mBbPJ6+48uEc9XStx
R6W3n8HvQD3I3pzHNmMc8bWRHde21QovfRT4yJ8iytsVC7VPL4v+0e7itEo3
0t46DhzL7WBPTy8Y59UTA8esYKP4auFOzjDUfJRa6T14EpuXDmW51TmiXnkr
FKxbzu86q2jqGwN8VAVi4fJA3H7jAhhsuCLVfRcrTrA5C6N1wvm7VTKtH3OG
HieFUcnWdgjWaoCZklvC6gEWQreCIbhvuyF0pBIk9nbGD0bD0LuvDrzYdgNe
xA8WMhvaKbuPDmXVe/KzyGZx2u4+mF30gpLNXaDV6ybF9J0gWL5BTG9/Shdb
yqAs+BmEuJpwmkcFtVe4c/TiOlB+74guQ3Jg/R8rvPBlOlzU9eEBNY5keVxF
Mqf6iOjufAy3dC6DVf/m6cDGOLp4eDOeSd0pabdcDVGho8nNfr+QcLBGdKp5
B/1Odcf/Av6xnNwIuv7eE62uNUDl2F9Co5UJ51wz4kMG84TZ8dZi9YDVFF96
G15+zKK0ATI4rvYbaLtsZ8WnoZijnQOHjVdLxqlOguTo4Rw69hAZT3XEU1/8
uPKzOdee74ZpL0fy4tHXyDNCn4dNZDEh+RWJ7z9IvrtEQXxCLBpYkSD5lQj9
oYh7ngwhzcdMxetyucS7Gf7KNtKBjmaaW2SB+wKMhZXCAv4gtRfsl8VhQdRC
xkdH6YpsT3wQNgQ7jpQIG53XYdf62TxuQRRnjr1JTi8rxOYkez4pFw5LX5wA
+4fKOFmhCE4enEMXXa0o+X6bxNlzDp/VzqO7fYJ4RMAxOL/vk8RYfRUvfrYZ
M2+8Eo4n9meHihWsdNyX9adPoLXma8V9q3Mo3uUJ9T+pwa2qJVBb+oo0b+bD
F1sHTikJQId7WXBafyKMah8kCvWaPLTZET1Kz6LX1PZJLk808dUhXzBO3kaT
R5+g09lW3DnYjIsmbhZq2tfyM70M8nG2gNvzCtEedkGHzRui99fE0bMHSK+4
fRBc9Z7QHfVM9Fs3hFtDllGC7lFMP7WCKi/Vwo9xl0AY+xnm7UG47J1ELr8T
QP3Pv/u4IgS9Ds4QPrA3zp+/AuKruuHuNTG473yp2E33PCWYpdOr3i/g70I5
VImzo4aDs+mWfgIYBodCW0cbfPAuo6ceC3iIvAsnG4fAbQwBYzdTQVOqicdi
34oLoIzf3Bep8rUjXq3eJ97QahLdHoex+WB/KIsbjSnFmrjTpxa2vUvBJVpK
fG9pAZ88Z0xPTypKfs6fj8E+PtwxpB7Uk035i/J1cQeNZbvsInKaX0fGmW/p
cM4bkrg7sZ5dX7767oGo8/cPBPe9Qkv0fkhO1Nqh9s59MLJoFLbm2aCXpFVs
P2bAQz4bgbzmUVK9PJVHu7RCqME+sat0CjjknIKD13YI7TLRls+PnKFPwxNA
88N+yb30Z3DJP5vNtYvEXT8y2HCoD1m+eS75lJWO5wpl6XrbPFRVC6Tbm11J
0ryGsuIqoV9VkJg9NxjXjn4nLBnwWizxmSekeE+nwwlhoBg0nPXWJtKs5Ek8
0skfvvdopfHiIKj4t+PbG7fjuZ9+XLPaCw+OdoXbXw1xma+59FhGATsUK/KG
yxlU2HKJQi5rQXfLaNLFAtowJYyT5urjw+M5WHg1keeNPUx2TcuoKGMmmxZP
4MqL2mzz2oZq7ijia1stjtuSDlXCL/5jYU0lBqtIP6wSOg/nkfUeV/wv4RGk
R43DG90Wk8qeoaJu8mn6oraBI7YPgg6ZcrLomy/9T+84NTbI8rvhhqyT3iK0
3DoNLr5G9Fc1CB3rkyDtrhttsieYpXKb1ggVeHB2JH30+yA5O9meJYvnQ8Da
ELI5PpMDCwYy3uzF9sa7IKwunU+tGcxS0990eUQ+LFy7kPqpLMLWuVnUcUwN
rZqUKe9NPTU8KgCX1h1wfrkbqm0czw5mh2BxgBpPTa4Sz4YOAQODBEy5cp0O
PfoPXL3aqdB2r/Bx/V3BrXQX6L84LYTXngVedRZ0RjwWmxW+wq5UI4nZyhA+
b9UoOdikwo4PG+jQtFF8d56OsG3rPtp8ax/Nbb4pJJybPFF8VcLpOZWV153e
wEOZO8KF7EXk+TpGLJlhIpgU+OFe9WVklCDDlSdV+domF4yKWA/359bg4/i7
dGFXLAVmdiM5x/mwUW80HhziLJiazuJS834c1SeVJ9+9TSrXRbK3jufOx5/I
IDJdvGnfJh4lAd8ln8KuFEM8lrkUSmP90amgjjodc7H0QANkrmwVitbUQehE
Dc4cNB57lg3Gls5C0eJNIb+MvQMfdDdhaPB+LPwcTcEzJkFeiDP4LknA/IzT
tG9Wfyw4PRNuvzGEIR8qhBMDzASPGDXs67qdWH8Aym4Koklf1uGG1Vdoc7eR
8Pe1KE5sGslKIbm8eMst6towmaFfCZy+b8DHN43EaQbD8fG6ebQjJYL2CBKk
vwtgT9U6cVnvtULH5+VY0j1WmPlCjjvnVFHOk0JY8nkFT/qn4a1ux/Fc5HCh
re292LUwnV/a2XDgyD7YMFNK63qoouOuWlq9zwPlFHVx/6LjsHj0Snw6zwGj
5ptTzIBROPRrHWxZ/k4I3nkCP9qdp5yW5ei+vQ3YJ4K0nqTBUn/1f/zVLKw4
HcyaZrXk/Gy3uH5dGBS0SenG2QM0yW8XJBS6s9VrNfyRsZJNjm1BzSRVrBlx
BHqWBsBs78m84usOblhSjN3+SxCGzVwPpywy6M3RGDzaFoG21wKo8cQ4uONl
zdpy3yFnqymryVvC2aWTufHaX7EhJZ8WbbNjrZffYcyXexD8fBmlmsaCxqSn
YkmTEi9UUcX+bgp4YUQ/LHdWAIfnFbxthwz26rhEvYKv4YQeNwltT0g1Hy1l
9fW9+PctfTjaIU9ZQ+dwia2L+Kv4FGt7RwgyluO5fNgF8J5XzQ8zz1Hza19o
f6uIi9NGc9z7SLyclEWut0R2zEyEfX8mgXfOLMb2Dnoy3w4C9h4lV+v+uL+8
Umq03YLaX+6uXKtbgu92PxGu6A8WwxU38PP4Z/BZ/hNJbhSj1fEaaHlrwD2f
I+94Ok/wKC+Ee62bqHg+8q3rCrhf4SUdiDtDpTrTYOqoR2z6XzIr+kaDfPst
ClvrTkFr9vDFb3Jk0nWXFA1eSqeb6uIUuQ+QklsDcet3QYPVN7EPprDO/e2w
92mGcNygNwRaPQaneXmoqTSGxvavwqKtnWJu371sGi3La3f7sfOtB/SHvaWa
I8xxVagq1r/ex8H+zYLiBA9KrHaGD8mBHFkOOKnCmdQyNHBB6iC6uaNF7Kmy
QxD81WBkym0oTf4N9atzIP7KMszV82CdFll8HFsrxDl4oqOOJlcX/4WLj0vQ
aflDuPRWCQ5VjAUL5VHUNqOL6r0GcateECnEeYu2UXto9WY3sWBCF8nNc4SX
T9aC2nBrzJ8bj2G5o9ko6CaabhVpw9avYr9RxmJ0756o+G9Hmy49EFb4WfJc
h2LWPP5U2NrzLDR4GNKjokWcNm0Rl8SZ06sl9wBljPm9xk8oWOgOM6YOgWyT
AWzrH8D+A4Oha0GAOHzGWHjgbwZ+8n+lycqqELdvLAbFOkPOTg3hun0XrFm7
hIP+ca5CzkdwVzaDE1E2cMEwkOdbu2ORsSG+7TDCjMOLRek5c/i62gLru1Lw
wPoIPFr1k3BPISnMkOW5C+xRfmmVYDfbF33vVdHW7hPQUekX+T7X4Cmz64Xt
br1Qei1FuFEwA2dNzcQyk74wsruxaBg9AuUs5+Hic0a4trRIzEjL5SDDfzqw
8Db1MvTG3nFFOEvLmOuMhgD8Vy0ub5anHo35/MZzKy2/EQoWSivFkIWDcVhq
Jh+sWwJdEWX0cb01LLy6C5e1f6PyB/q4actL+OR1jWJm98MrLoqYqGslnF55
kX7RWnTyOiyZ/iBOejF7L8QtGiwaSZxRIVFHnHZdhSs2G/C0vAXwYGWX8K8S
NKuV0bGd98Un2qE0L2OVNNTbDPtfeCvx7aMLkWXKOHtYClT8NRNhnYS/9DpB
6bwPuqXPxDdNdqgXsY71d6Wg54kI2uc+DKunLSdv8SqE9Cqh5BP7OeLICt7E
Uvo1ax83PS6X3Ol8JJSH+vPhoIMQm5AjKV9YSIv8b9HBKBWyM/1LSkvX4NTh
FXT4z0JuXpdG/RovSE4p/2O7/A+CsDiTLizaDs9KE7hbWTrcis0nX+UoCDm1
U7p84X+8L9pBWLrrDsenReCw3cC3fy3C5sEhYBboITiskqHa+EToc+AKvQ7w
h4eB2aAq7YPvGsIoTtYBKie/h8Ud/26jkjbWL0mFffIOlByB4lLbRMnWYxto
f3g5q9xuITpxE06fN8D10hQsAmuqy1Mn1awuoXGIB/u+NsDHz3YK8VY2GBD4
Qzgyvp3UJh5CydAaweNcKM7bMZWmrwoVrLz0MLALOOa8Llj4j6RL3faAUdln
QStSGc82tYnHzuuwRb23aHlOBmu7/aBHD0figYhwMFhgR1oVo+B7zB5yvROC
7hE3yCOpkcaWvoERjmMgceoq+DV0HQxNmodnuAqyx5iA5Qtrse56BIU6lIPz
kenkaKrBo8rseVzxXDJv88EOk2o6+8kVNdf/+9F2PaOt5v1w5od/POAXi41e
a/HdnE2QftoSo9M/C12mH8FRooFXbhnQtZx2eLEyCu7e6xBnX02pFCZGCeb/
5GjeiD1Cn81r8PW5AewSLENH2zOw6Vs8rbEF2Bwsj39d+8Pn1S8p8G8v7rzU
KgyYsBKCVsyh3AmafH6PEw7jVFAYMwXKJRnw0yuCv2XsYFvbEJx88bjgMWAh
dUlW0/cyI1TR2ArXTySKfMAGFol/qfuUQHLw8Re8RUeSOfEN0l6lY5JyX275
9lU0W2rEN3+WQMPZTjHyeIGoO/EXPctShZXbh4KukxE5nNeSOPhehDHKohi5
pwcsGSnLlT0H8v571mih+Q7GDNej9P2LaJtZCmn6KfJOFUMcdv4cPa1sh/d9
28UrGQP5Y6A67bwdA0l/LtPgc9o08UC++PziG9FG8SYsi1BD3TfegrdRGU8P
GsULVumTstxCPJ/lhpfS9XF3L19hRtNN8W1QOWnXXqFjFccgdpmAw/fpYPxT
HVCT//fXRcpw2shKuuBYKRwM2kZXf8mxxeRMGhntx4ZmD0jr1V1wvzKPFucc
4Y9DusHAzV+oPlSRa0sySc5BoGnfIjBfxY/0i5po1q1n4ji5R1DFq2DYx0Z6
m9MomXb6GE1zrKaNSpm0acRIXntHHu33q7LMgDDh4meCHUcfkHdNDFxTWyLo
bfO3/HnpO/1q2UWqnq10MrUKrr80oT2flMU5MZP5SdZFKOt3CUcviuAJp27A
vNv1sErrGP13dC61xSYJU91z4aRjX44JfgQ/pl+h+luKWC03DPVPRQh9C/bC
65pauqJVwQaYSL79Q+HIxyh6Z6PFs8LUULbVkpS0dnKf2BKImbUVfjto0EjD
drJXigPHJbGcHSRh75xwil4/hj20htC5AWUURlqCzc8DzHJLKOb1aF5ffRAn
zHLlr8eqKfUfT3ygcOwYOJhyHrmCg3kTTX63X9ga86JSw6wN1DVn8u0t9jBf
K5UG546DgxPG4Sl3P7TKrwOTRaroEqyOkzMWcV9IElLmR+E6LWOI6ZFKm8d0
5y+vJ3D1AgPM/G2DXXM6xPX62kK1Xx41RPfm3PYLNPnrE2H5wnCqc6qUXrXe
RE0BI0gvSgXH9g0SJ42aB6KOFZenzDn79tczMdljEt4s6s+9o+rpiMSBfnWX
p50fUvmUnhJmavTkDPdfkqJROeil4Y+nripgUp0+Ti17ShYvC/mL5yRO7ZUA
+uPuiNstF/LOuRbcbU29UFwRBkP720LyolgMbwnjT0ddedcled4Yp0Rde22h
eGQOe95tY7OcCxQ/YTxKD/bjN/Z9IfuiPG/haiwaHwjFr0KEzuRC9Ex3JsdH
4RzcPgm2xpuh6e8OuJp4mHJVzCXPYu5S0PZv4Fn+nn54DGa0WAZxW6dj8t8o
0Tc2X+i9xgms53bDb5u9wfiQOn1TGoKl91OEvFIrPFVjyTttbcH7UxakX5qE
x6vU6GTEXMp1ymCLgBKQylry1aeabNWWQmULpUJwZBxZrlHAv390eOz1t1Cx
8xapKqjjnh7PpV4/V6HCtCbBbH8kKBx5QUKBAQYne1tmzbCBWcbHyWJdD361
RJduZR+BPDcv1N7wkvplu+NI/WN45k4E3Gm4z9d9NvGcQHPobArmCIMMurPX
hBvFNB46fCjPN48W5N500oRDCXje2ZVtH32WnlOtpUezU4WfpM9B5cr4SiEd
ZB/Mw/U/UuHrghg+7STLP7/eo359SyTPvl+moeCA5QdLhQ3DlqHO4FDU6xct
qHbTwtthZvxhsDlfuBArNu6v5Oca6/HGyL2wqyMe3aI/iG12H8S+amXCUl0/
vmp8nlTfz6LIjr18MiWN0yvU4NNPV+isHsRmRv3Q69e3f/Oigb6KtXCgqkYy
ZgVQ5oYM3HzISagxfAnHylNFXbtC8UR2fxD62PLVU915St4kWjdoAOfd+X62
Qm442id68CP565ZOQw5xcIkB5xq9hln3+sDWxm+goSjPLeMfCyl3/LG72xr2
jymi+bk7KXjNJ9rzdqP0+KcC1KzxwrErQzlMVIcjxZo48VDHP+6eDhPFYXx3
jT8P/vmKGuTOCVw4hosLFdB2foaQPmwMKTyeAPGlU1nDjZCUp8Ofs4IkpN6S
y513cZFHDJeOUsEWO2MW2qLoz8tQahi6E/b+HMdHWgWc3D4NCk9qUM2Omfw+
oi/V+OhJuyRTsP6aIWR578WUuJl8smqWkLonjKbgDhioeUKilVBPY549E44o
p9JRAxu80iAHy9NLhcLv23i7ST+Oc8wTU/xmC137L9PIvWH4N64GNo8opJpp
RyRZa1+Cv2o22RwLZPvZB8hLR4aHNfbn4gkjhNL5ytg6356f9RrA5z/04sbK
35DiNQLeqaRDXaAlb7H2wSOre+JRu2fiq8HTYdVRQ94QUUMpTyzR6uk2/lYx
hN8r9CGjnCQxVl4D5s7qg29XqpPxCwPBVbcXeA29AkbLwrGxo5Tm3+yBng+b
KfibNbxKzZZMeBYHA9O6SKH/Ruh1XJ0nwXnSkPlP+sp4OZsZpOGBAlVOkllO
znlVfEF9Oqp8641ftQ9CfUem1PdhHrfnN1Gfo4qoP06WT67zRddVBVKXgaOw
RSmUcNF5aJnhKpolJVNLSG+y9zkiRCf14/L5lhJPOyeq8+wlCXScyNOvhoNM
hQNbt72ByekJNHPADSHMvgc/T/MWlu5+Q31H60FnrCEpojJf7tqJbjJ/qV1F
kQNN0ul7kwdfG2KL9bs8QebtIhy/5i+5hBynOrEJFmw7C623xsF2t2r6GB7D
dUWF4Hz/GqkZlIFV+xUYvtQddsfUUENyPfT4HI8bnD/Cpb5S6RYXOa7K3og+
u0fhgmFMna6R/7hnmeTEL01UXo9kvnQp5MFyycCeVXDI/x8zBjVInm8gfJ28
FwLs+vC4+HLxRkgGya48gOMm/oUOBUbJwWuEp5sET21Nfv9lLn0yT2Np9S+Q
2EVA7HRPtowbihUzLkNhwA4sbNNAH4P7EOlkxvU2PpIbddfg2/4BPGDNRnZ2
Glrhc/EOXLbTgfmNDyF5UjFn9FqAZgHp8Ct5EhcpatPLsbrc2HiM1YInSi9/
n4fvsiOwbsZ0VAv+x5wq8jx6405RMWQKbT9khgH6K/B3lQK8UBlBqXdSqWx0
BEdm7OSeXda4ed88vueoAcUmE3nEhE/0TtjA0RJNnn57Ic5RKaz8OlRXLOur
hlaDB4D1tT1knKQjaIuBLDZmkuOhxVS0fBzwy2TwGbxJujRClr+3vINNDwbh
ohzka5l3hddZxYL6mCGw8PIgDPLspCsQygpqCWC1rQX8nX7Du2teXFbWBThS
Hm2xmsap36CTfj2hNckVz9jtx3XWgzi95zL06beL7m/JgJ1BZij5zKLb1CSI
nGxOk2KGcvCPOPRqzINvBorQvyYP3B6+g0qfe3SjbRuYeqhYbr14T7jcTYdP
tCI69T0jKvloc4tDpPC7bDgXW07A1VrnBBNTdV7R/BrKo+aTrEmLpZnqJKFy
ix3uH5ZDZcP64+xwU8z3VGRlrhA+DdHgT87vBHPDI+IbvVXCRj+pwIZvSM+p
FN5fnoQpE8+gbV4upFlpinoJRayjFQfja1LBbkNPrDx7WcxyLheV0osrpvdS
hv9+HKXOX5PQOmEFOH05I5QP2MG7/wuWnvuqiDoT9wAkGYuT/+uo3KyqQFLd
K5I+ixVxWesaNs83wD21Onja4A80q8vg3vBY3hNZAaGjXlF8xlBp5s1lNOaM
Mkwd7cgLrDPg7516aD4yU5zyTIUavn6EOq1DkPJhMiq2F3DjHwPWVe4gA8kj
qhpziIp9X1P17Sx2VYnCzN1GaFeviCMn5EGfxc6Uuy2AqjSm454Vb4Xlua9h
v3ui+OGIE6scXIIOaI75pnPh3qhzpOo1HSS/PXDshe+QNn4KvjidJJTtl0Gz
5lyscQ+lOZvSLPOXauKefn2xc+UIsMhRkCywOo397j8Vm1oGYsyRbDHs5TjR
ybYbTvkyhsfWHhfOHLwFJZuVyffmEYgv6MYvfxeD2kNDaqqTwFy7CZIfTYo8
6EdPGpncG/cdLxV+Tq0UAu8oinXn42kQ7RaKE+XFlX21cOLXo5Aq0w8rU7X5
bc/ZcHvEFqldyFSUH9sORmInGKQNoF0eyiLsW4lrFgZis0YsS4/MElzOFYoX
ssrIS+8sNejYc5e9GWw81J0uvVgIponWkLDpNTXahwlT+qzmpipnHpGoxPKV
w+jegu1s+jCQ75eu4ayPvTDZXw5nfwrmL4NPkldGl1AnePK1Kdkk5pfwXyN7
zCx/TIfCTbkxagtWqncjLVVbFD7683ylfNoenAF19e9w2hQrccRzK34oVJHa
+eVo0yuRwmIt2cQ3gyb1fiD+t1GJ2HUGJZULWBjgQGUekZhkYc4lDeYY7nKV
Tjb9BYMzxfBiwFIcp3Qe3pzOAJbz+8fb2aAVoyPqT2sQe7eO4pXP90hD1HIF
jU2FsGPlY1DatIS76fnzjyHrqCD8tqVq/Ug6ZfpKoO5BNDS6HLfHdUejj2Zi
mm4/YcqJE1Ck/E24/mUqp6hGwHcda76irM/FpSz8eLufnmmfItON5cTLm8Hg
SSAtbVHHJekePKupFXjQZlR/uga2LsmGuNxUXH45ggc76NGlHgwJXT8heugg
SK5pI6lKMf/nvQSPFjrhzF97uLpSj3vIaWPzhTd0ztaM06eagdrdZng/NKPS
4r4RnWmxBlkLE/q7WoT82DOwQtMFy+fvpv8DJC0eeA==
                    "], "Biases" -> 
                    RawArray["Real32",{0.009704483672976494, 
                    0.056859325617551804`, -0.043792180716991425`, 
                    0.03324009105563164, -0.008418030105531216, 
                    0.005239951889961958, -0.021812837570905685`, 
                    0.025893110781908035`, 0.0017104921862483025`, 
                    0.010038008913397789`, 0.014387235045433044`, 
                    0.013284632004797459`, -0.0039796833880245686`, \
-0.05808998644351959, 0.030950943008065224`, -0.07610809057950974, 
                    0.027979454025626183`, 
                    0.002923122840002179, -0.0680886059999466, 
                    0.017712915316224098`, 0.00988957192748785, 
                    0.06564934551715851, -0.014118052087724209`, \
-0.09924537688493729, -0.03298528864979744, -0.03519892692565918, \
-0.024420995265245438`, 0.015187907963991165`, -0.0011835077311843634`, 
                    0.006010790821164846, 0.0131281903013587, 
                    0.021661803126335144`, -0.0007039226475171745, \
-0.01589292101562023, -0.03597236052155495, 
                    0.02574143186211586, -0.02381478063762188, 
                    0.03320986032485962, 
                    0.018296299502253532`, -0.025846347212791443`, \
-0.0011385526740923524`, 0.011574532836675644`, -0.04243078827857971, 
                    0.0024010285269469023`, -0.02589361183345318, 
                    0.003463947447016835, 0.0059913769364356995`, 
                    0.03527264669537544, 
                    0.025626854971051216`, -0.033750761300325394`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3lQz9/3x1uEpMVS0aJFUkmLLfV+nSOkTYmytImEIiprFFIqKhGiXcq+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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.015054807998239994`, -0.0175345316529274, \
-0.019021136686205864`, -0.011364947073161602`, -0.012553416192531586`, \
-0.011390685103833675`, -0.000900415878277272, -0.004311332479119301, \
-0.016976282000541687`, -0.005304166581481695, -0.017072049900889397`, 
                    0.02564823254942894, -0.008257691748440266, \
-0.004299605265259743, -0.025135163217782974`, 
                    0.03229667246341705, -0.014915387146174908`, \
-0.013362673111259937`, -0.020094245672225952`, -0.0024279742501676083`, 
                    0.0027324934490025043`, 0.00766570121049881, 
                    0.0015279523795470595`, -0.016388647258281708`, 
                    0.0036038467660546303`, -0.025940703228116035`, 
                    0.023229267448186874`, -0.014587895944714546`, \
-0.02402653731405735, -0.02236112952232361, 
                    0.00008406602137256414, -0.020727327093482018`, 
                    0.024029694497585297`, -0.013179264031350613`, 
                    0.009765774011611938, 0.00043422298040241003`, 
                    0.039707981050014496`, -0.008026939816772938, \
-0.028690697625279427`, -0.005567724816501141, 0.01326798927038908, 
                    0.02347562089562416, -0.020022975280880928`, 
                    0.002478999085724354, 0.0049027977511286736`, 
                    
                    0.020940329879522324`, -0.005549370776861906, \
-0.027695046737790108`, -0.016261795535683632`, -0.01878495141863823}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{-0.16141724586486816`, 
                    0.0076670474372804165`, 0.060833245515823364`, 
                    0.08142170310020447, 0.05942689999938011, 
                    0.08068984001874924, 
                    0.27214762568473816`, -0.05737468972802162, \
-0.006607470102608204, 
                    0.06006955727934837, -0.020643213763833046`, \
-0.1047857254743576, 0.15522731840610504`, 
                    0.007036078721284866, -0.08192025125026703, \
-0.1258740872144699, -0.23226198554039001`, 
                    0.06638167798519135, -0.09009000658988953, \
-0.14714699983596802`, -0.12083844840526581`, -0.08904696255922318, 
                    0.020836276933550835`, 0.10960105806589127`, 
                    0.242157980799675, -0.20037421584129333`, \
-0.22907137870788574`, -0.32097989320755005`, 0.017773423343896866`, 
                    0.13343511521816254`, -0.10305210947990417`, 
                    0.012775496579706669`, -0.35189828276634216`, 
                    0.12054258584976196`, 0.08222705125808716, 
                    0.0669722706079483, -0.07639043033123016, \
-0.03242964297533035, 0.139220729470253, 
                    0.04354309290647507, -0.09189584106206894, 
                    0.10117704421281815`, -0.029597962275147438`, 
                    0.22142288088798523`, 
                    0.005128646269440651, -0.17017890512943268`, 
                    0.12220870703458786`, 0.07178957760334015, 
                    0.13421964645385742`, 0.22090183198451996`}}], "Biases" -> 
                    RawArray["Real32",{-0.007336978334933519}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.7125377058982849}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 0.5946779, "MeanInputsPerSecond" -> 
          43048.51416203629], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {
                0.001372188822134779, -0.06111779319022274, \
-0.019513791089245506`, 0.023794395593296307`, 0.05612227322622403}, 
               "StandardDeviation" -> {1.0042519493556388`, 
                0.9805484149316025, 1.0008858666702105`, 1.003025365712859, 
                0.9848295670958479}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 4101904463502874336]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 100, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[363793], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3290342684513687, "PreprocessingTime" -> 
        0.3740048`7.024422169493606, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.4321800812383714, 0.2184923582544563], 
           "StandardDeviation" -> 
           Around[0.3712038367196244, 0.07688005772052679], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 99880, 
           "ModelUtility" -> 0.2572373226132504, "TrainingSize" -> 252, 
           "TrainingTime" -> 0.7943282347242815, "TrainingMemory" -> 451592, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.4321800812383714, 0.15449742815916656`]}, 
           "StandardDeviationHistory" -> {
             Around[0.3712038367196244, 0.05436241015219768]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 100, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 267473595559450]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.5996008488536813`, 0.3765116791556969], 
                "StandardDeviation" -> 
                Around[0.5565404200161264, 0.03346829150226679], 
                "EvaluationTime" -> 0.00011402508937382599`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.11911926421842634`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.31622776601683794`, "TrainingMemory" -> 
                424784, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.5996008488536813`, 0.2662339615269269]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5565404200161264, 0.023665655875980948`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.6372846083656225`, 0.3311071088342427], 
                "StandardDeviation" -> 
                Around[0.4056312327134332, 0.028125566693345132`], 
                "EvaluationTime" -> 0.00012135285045061535`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.1953593067514412, "TrainingSize" -> 50, "TrainingTime" -> 
                0.31622776601683794`, "TrainingMemory" -> 428768, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.6372846083656225`, 0.2341280819557652]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4056312327134332, 0.019887778933578844`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.4321800812383714, 0.2184923582544563], 
                "StandardDeviation" -> 
                Around[0.3712038367196244, 0.07688005772052679], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 0.2572373226132504, 
                "TrainingSize" -> 252, "TrainingTime" -> 0.7943282347242815, 
                "TrainingMemory" -> 451592, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.4321800812383714, 0.15449742815916656`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3712038367196244, 0.05436241015219768]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.3712038367196244, 0.07688005772052679], 
               "TrainingMemory" -> 451592, "TrainingTime" -> 
               1.3091380594221897`], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.876115679094854, 0.9544686309582684], 
                "StandardDeviation" -> 
                Around[0.402666173213517, 0.03143888729212968], 
                "EvaluationTime" -> 0.0001351002078275469, "TestSize" -> 265, 
                "ModelMemory" -> 107736, "ModelUtility" -> 0.2009716373168846,
                 "TrainingSize" -> 50, "TrainingTime" -> 1.5848931924611136`, 
                "TrainingMemory" -> 499552, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[4.876115679094854, 0.6749112413804318]}, 
                "StandardDeviationHistory" -> {
                  Around[0.402666173213517, 0.02223065039722447]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.802683673807263, 0.3060931819533899], 
                "StandardDeviation" -> 
                Around[0.5014496480800845, 0.032783045345558856`], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.015919593012634903`, "TrainingSize" -> 
                10, "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495392, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.802683673807263, 0.21644056463420974`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5014496480800845, 0.02318111367179075]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0001603641920883598, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.5014496480800845, 0.032783045345558856`], 
               "TrainingMemory" -> 495392, "TrainingTime" -> 
               6.577306748713622], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[7.394924682718485, 1.4874357040699286`], 
                "StandardDeviation" -> 
                Around[0.42923110266553044`, 0.03613534414707037], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.13588349475185812`, "TrainingSize" -> 50, "TrainingTime" -> 
                1.2589254117941673`, "TrainingMemory" -> 428688, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[7.394924682718485, 1.0517758729268332`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.42923110266553044`, 0.025551546886903077`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.47757549564373175`, 0.231477556342346], 
                "StandardDeviation" -> 
                Around[0.3855139843950209, 0.07790826749824181], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 0.2203758651216422, 
                "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
                "TrainingMemory" -> 451656, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.47757549564373175`, 0.16367934978216397`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3855139843950209, 0.05508946425850228]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.3855139843950209, 0.07790826749824181], 
               "TrainingMemory" -> 451656, "TrainingTime" -> 
               7.523765832135071], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 267469300592154]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 5.9018518518519`3.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.809756953561353`17.33347225956155*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 2.5358985737757735`, 
            "ElapsedTimes" -> 2.2589582, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 4.226497622959622, 
            "ElapsedTimes" -> 3.8174346999999997`, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 7.044162704932703, 
            "ElapsedTimes" -> 6.5724119, "ExperimentCounts" -> 2]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 267482185494042]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{
              3.57197363290299, -4.7777284361151855`, -6.22194990393694, 1., 
              4.605170185988092}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 13.3451464, 
        "MaxTrainingMemory" -> 936288, "DataMemory" -> 75768, 
        "FunctionMemory" -> 256056, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 49, 13.5872815`8.885707526869476}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.6638256634160772, 0.3366792813637681, 
                    0.2717564646035177, 0.473015873015873, 3.897085214313493},
                     "Method" -> "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.6638256634160772, 0.3366792813637681, 
                    0.2717564646035177, 0.473015873015873, 3.897085214313493},
                     "StandardDeviation" -> {6.74836457186137, 
                    4.406017724515529, 4.270680771106079, 0.4992713259249969, 
                    1.3866049149278572`}, "Method" -> "NaiveSampler", 
                    "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{0.4692359247009251, -0.5469291001624851, 
                    0.15816331494441557`, 0.4647077952865894, 
                    0.48960926989916514`}, {0.42594321909204763`, 
                    0.5775566692118885, 
                    0.3261668140868004, -0.3751902121539704, 
                    0.4876968136564957}, {-0.027164652839622005`, \
-0.5795479166791658, 
                    0.4201921255681977, -0.6902368951607722, \
-0.10197009403858867`}, {-0.24880165053257522`, 0.1698399465059589, 
                    0.8318575310298048, 
                    0.4071243660466186, -0.22696900648162485`}, {
                    0.7319493434712138, 0.05074897130007173, 
                    0.007155478582024979, 
                    0.033192602092826415`, -0.6786175290961864}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.6638256634160772, 0.3366792813637681, 
                    0.2717564646035177, 0.473015873015873, 3.897085214313493},
                     "StandardDeviation" -> {6.74836457186137, 
                    4.406017724515529, 4.270680771106079, 0.4992713259249969, 
                    1.3866049149278572`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0142858, "MaxTrainingMemory" -> 94072, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 49, 13.6162058`8.886631060567792}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.6638256634160772, 0.3366792813637681, 
                0.2717564646035177, 0.473015873015873, 3.897085214313493}, 
               "StandardDeviation" -> {6.74836457186137, 4.406017724515529, 
                4.270680771106079, 0.4992713259249969, 1.3866049149278572`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.3603784017454377`}, 
               "StandardDeviation" -> {0.7261704700177318}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.3603784017454377` + 
         0.7261704700177318 #& ), 
        "ProcessorFunction" -> (3.2504466915155628` + 
         1.3770871183670987` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.886238615492931, 2.372249949399409}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwVkXsw1WkcxtkTJxxxQhIqlGsrxBB+39dlI+uyrsuyO64ntnVp0VrGUDga
7BEq5lBz2OnikljtzGk57/dlVpYsjSRddrWhDtVua1d2Rsnqj88z88znr2ce
s6Ss8CMfqKio5GzeiPDEPO/s7MT8CPX3RZSYfsAp/b102kBtAweXXpTxs5hr
pSMpa+/FAa9S0GnrpJWXlDARcwBt4wzBpiWWGzZ0Zq31e2mQuBV9tfXZbX2l
gr0IhpJ3pkxaF8AEORbs4IUY0vA8iqqafUcC87PwunM1OkfZs7tKKQhmtjLP
pT/R33kTW/G5ACUep2FePos2xXegItIHjZs+xy/LP0JaPNaXOXOJxvnW4OGI
KPIsMht6VpbARoUHqn7JWCcKJ71rA30t2tbcvlVVEjxt6nlyuRDj5AvgdaYH
/tbrR0F5OuPZTUNBO+GaZ3nE5vtJLjpAgKue5znrL7ax+2kyGqN6EY1d+sGz
SJdk9M8pvlZzhuFP/gOl0xCXZ5ijOD7xGEKjU7FvG8eGl3WZnnYy831iQQbE
DkSh7Unf/OoOvibz0Lldg10b24yKqDZIEN9A9Q/NyesTXmypcZT7I8WHnJqt
wM8W9cjYYhexp1Y0usEept/1wKaPJSRrwI16y8Skc7CCJhxu5gxu1lDp7rf4
TTNgm8CdxEqa2Vz1LGdeZ8GdNVfiyugkyFOQPhKpka7YQlbvZgY8HS/kT2qS
tfFd0B1uAoq4Qc8s5RA8fLWbLqgYsac5r2GPaAQ8JBakKvQxqvXIMFFaym6t
JBHD7VYeabybipQjulgqqVJUh2iQ+y0h5Nm9a+jqNsSZ/CwFy081MTdTwpU0
XqTkbgYZParODcVN4eX4/TQtUIFlV0rgQdACffNDOxYavsSMJD4Z19LGdd0S
FvrvOahrM8a8RAf2MJ9hoGUt07kTRlpzhSymX6AQGmnglav76QlTF+I42IT1
a5HMeOt1WqIqIHM9G3sMOug+JmRpRceQzAfTMPlJqJ+RQoevGIPtxEzAf4H+
tnookZdCJjOgpspaFsbXZZNiaxbP10Bh0hnMbCgDUfQpWJuZgibZAHfsqwa0
tDykWJzYxY2m5nImIeacrZUBi0h+xAmNXGmYdwsQqEVh0C/oetUfxp43wQ6t
l6D+mxouC+LhZLEF11BZSrT8OrFKfxlcJ92hYPwvhYbKLRyerWQBD/SYy56N
/2VlwNU0A/BC6fpbCbd34AY923obTOXZdNJqC9uSvg5F9+oxp9eaFTf1wM4O
YCNcNzv0ypAUdHZD6ZMuPOo6iKaONiTrqTGTyKIZydMm0pE2cDbioZ11Al5e
bmOpB08zv98bMXbhPB5f/Qd/jBDiDhNNVD03haLyb1nyT2noML8T/gfpkuUv

                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.06931959837675095, -0.1647183895111084, 
                    0.050673406571149826`, -0.010158805176615715`, 
                    0.05722812935709953, 
                    0.077938973903656, -0.020333170890808105`, 
                    0.028829611837863922`, 
                    0.010721756145358086`, -0.09621252119541168, \
-0.07615243643522263, -0.06967274844646454, -0.022500500082969666`, \
-0.08137574046850204, -0.0504237599670887, -0.08596133440732956, 
                    0.007342304103076458, 
                    0.010734370909631252`, -0.04809826239943504, 
                    0.027703862637281418`, -0.009050027467310429, \
-0.16485200822353363`, -0.026341767981648445`, -0.12375417351722717`, \
-0.04526526480913162, -0.1221545934677124, -0.043545253574848175`, 
                    0.07527543604373932, -0.05905371531844139, \
-0.11903753876686096`, 0.013508928008377552`, -0.13653860986232758`, 
                    0.11114910989999771`, 
                    0.021186048164963722`, -0.11188681423664093`, \
-0.08683869987726212, -0.12112343311309814`, 
                    0.04926177114248276, -0.03638221696019173, 
                    0.023817427456378937`, -0.2325172871351242, \
-0.18463055789470673`, -0.09342845529317856, -0.1181102991104126, 
                    0.03727533295750618, 0.019583575427532196`, 
                    0.040671683847904205`, -0.13254784047603607`, 
                    0.13932976126670837`, -0.02320750616490841}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c41+/3x2WTFSGjKSuhMsL7dU6ShhJKVEpFi4iUJiUhSWlKtFBURgpR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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.10320995002985, -0.028671840205788612`, \
-0.02892393060028553, -0.06625331193208694, 
                    0.011434993706643581`, -0.028576131910085678`, 
                    0.038083724677562714`, -0.05367114022374153, \
-0.011371366679668427`, -0.03228878602385521, -0.008886223658919334, 
                    0.0587446391582489, 
                    0.0822661817073822, -0.016002284362912178`, \
-0.053026918321847916`, -0.1019132062792778, -0.08523622155189514, \
-0.01457471027970314, -0.13796918094158173`, -0.05280124023556709, \
-0.011159582063555717`, -0.15130813419818878`, 0.05888413265347481, 
                    0.004973289091140032, -0.1119682788848877, 
                    0.08277096599340439, -0.042063891887664795`, 
                    0.029224174097180367`, 
                    0.02737741358578205, -0.10560742765665054`, \
-0.05874192714691162, -0.16521912813186646`, -0.11515840142965317`, \
-0.07291208207607269, 0.00593029148876667, -0.11166241019964218`, 
                    0.023535050451755524`, -0.014305331744253635`, \
-0.09638570249080658, -0.15879152715206146`, 0.015093149617314339`, 
                    0.1408771425485611, 
                    0.03481246158480644, -0.04137621819972992, \
-0.07041151821613312, -0.1657535433769226, -0.059645768254995346`, \
-0.044597771018743515`, -0.017014946788549423`, -0.03818860277533531}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dYz+/3x1MpbRENoYjIbtL7dY5VsqKMkGiQSjIqo09JuzQ0lRGJygpl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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.053359247744083405`, -0.04211122542619705, \
-0.06330035626888275, -0.03068341501057148, -0.08795870840549469, \
-0.03238888829946518, -0.084297776222229, -0.07559125125408173, \
-0.05143103003501892, -0.06627655774354935, -0.0683164969086647, 
                    0.01001849863678217, -0.06585738062858582, \
-0.11945456266403198`, 0.019829491153359413`, -0.11686093360185623`, 
                    0.01861380785703659, -0.027642201632261276`, 
                    0.01949606090784073, -0.03534196689724922, \
-0.027528196573257446`, -0.1801479011774063, -0.03556572645902634, \
-0.0799437165260315, -0.03131663799285889, -0.0453539676964283, \
-0.07190072536468506, -0.05882992595434189, 
                    0.006794402841478586, -0.08619631081819534, \
-0.09623170644044876, -0.03834628313779831, -0.024562709033489227`, 
                    0.005086978431791067, -0.12359420955181122`, 
                    0.05020879954099655, -0.021432269364595413`, \
-0.029414214193820953`, -0.04057798534631729, -0.03120427392423153, \
-0.04578289017081261, -0.06734874844551086, -0.01522287167608738, \
-0.06404118984937668, -0.0770423635840416, 
                    0.08197986334562302, -0.05680970102548599, 
                    0.03372901678085327, -0.08100659400224686, \
-0.01879919320344925}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUj4/TxtOinbSqLKVFRWSp6HvPCNlTFElJKiWSCCVJol0ILSJE2YVs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                    "], "Biases" -> 
                    RawArray["Real32",{0.02174912951886654, 
                    0.003018120303750038, -0.02270146831870079, \
-0.0003075774875469506, -0.01768600381910801, 0.019708998501300812`, 
                    0.02252398431301117, 
                    0.004267522599548101, -0.030822740867733955`, 
                    0.013829373754560947`, -0.007986824959516525, 
                    0.02035702019929886, 0.010173304937779903`, 
                    0.04057012125849724, 0.022310329601168633`, 
                    0.011577533558011055`, 0.0183795765042305, 
                    0.028896767646074295`, 
                    0.008485480211675167, -0.04533493518829346, \
-0.00906145665794611, -0.0030360149685293436`, 0.04015912860631943, 
                    0.039381638169288635`, -0.03455013781785965, 
                    0.04175839200615883, -0.022394901141524315`, 
                    0.007201673462986946, 0.0009969749953597784, 
                    0.018611043691635132`, -0.034161802381277084`, 
                    0.03046632930636406, 
                    0.011538113467395306`, -0.0858381912112236, 
                    0.022762607783079147`, 0.056059446185827255`, 
                    0.023807467892766, -0.010249733924865723`, \
-0.00004485930912778713, -0.04139554128050804, 
                    0.027292681857943535`, -0.024859650060534477`, 
                    0.03989725932478905, 0.010119467973709106`, 
                    0.09666770696640015, -0.018424710258841515`, \
-0.007217803969979286, -0.021215684711933136`, 
                    0.057528991252183914`, -0.016930287703871727`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray[
                    "Real32",{{-0.17477929592132568`, -0.06010597571730614, 
                    0.09820427745580673, 0.14914077520370483`, 
                    0.048136211931705475`, -0.2207774966955185, \
-0.21769998967647552`, -0.17663373053073883`, -0.12202179431915283`, 
                    0.05858105048537254, -0.042811937630176544`, \
-0.14694011211395264`, -0.15117186307907104`, 
                    0.11449628323316574`, -0.04443299025297165, \
-0.22478489577770233`, -0.060491885989904404`, -0.08666378259658813, 
                    0.08352132886648178, -0.22318539023399353`, \
-0.015375403687357903`, -0.12143643200397491`, 
                    0.18757519125938416`, -0.18421268463134766`, \
-0.001399879576638341, 
                    0.055340979248285294`, -0.02177255041897297, \
-0.24237070977687836`, 0.12611599266529083`, 0.02483856864273548, 
                    0.08390510827302933, -0.1160455122590065, \
-0.15706253051757812`, -0.12031963467597961`, -0.3429006040096283, 
                    0.2953999936580658, 
                    0.15426398813724518`, -0.2689703702926636, \
-0.04620101675391197, -0.10710129886865616`, -0.10678552091121674`, \
-0.19233007729053497`, 0.13685156404972076`, -0.20284047722816467`, 
                    0.09788971394300461, -0.18422341346740723`, 
                    0.15470582246780396`, -0.09813106060028076, 
                    0.21330568194389343`, -0.15497645735740662`}}], "Biases" -> 
                    RawArray["Real32",{0.01913776807487011}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-1.0734978914260864`}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.3684105, "MeanInputsPerSecond" -> 
          47686.36824624346], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.05124942330391601, 0.001838025749308541, 
                0.004806730992135444, -0.041442273562846584`, 
                0.0015537058327323226`}, 
               "StandardDeviation" -> {0.9850898752341287, 0.9901086166493429,
                 0.9729480328063138, 0.997167827034542, 0.9981693047111911}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 6309918465742811838]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[363905], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3199704845332755, "PreprocessingTime" -> 
        0.3699399`7.019676168323984, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.5338360916450294, 0.3512206098174233], 
           "StandardDeviation" -> 
           Around[0.36036986267875415`, 0.06659432020227427], 
           "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
           "ModelMemory" -> 107736, "ModelUtility" -> 0.29115075322152584`, 
           "TrainingSize" -> 252, "TrainingTime" -> 6.309573444801933, 
           "TrainingMemory" -> 522456, "ExperimentCount" -> 1, 
           "MeanCrossEntropyHistory" -> {
             Around[0.5338360916450294, 0.2483504748943745]}, 
           "StandardDeviationHistory" -> {
             Around[0.36036986267875415`, 0.04708929540353643]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 291821765160487]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.019492647786454, 0.5055180414334078], 
                "StandardDeviation" -> 
                Around[0.669080245554206, 0.0362651742295634], 
                "EvaluationTime" -> 0.00011402508937382599`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.30210993649006546`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                424720, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.019492647786454, 0.3574552351097048]}, 
                "StandardDeviationHistory" -> {
                  Around[0.669080245554206, 0.02564335061863591]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[3.5287739803098437`, 0.6500911761511099], 
                "StandardDeviation" -> 
                Around[0.4822486282367483, 0.035272810431156945`], 
                "EvaluationTime" -> 0.00012135285045061535`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.021593710623310614`, "TrainingSize" -> 50, "TrainingTime" -> 
                0.31622776601683794`, "TrainingMemory" -> 428688, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.5287739803098437`, 0.4596838790459882]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4822486282367483, 0.024941643447378665`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.6017043013586887, 0.2474160891824744], 
                "StandardDeviation" -> 
                Around[0.4120930610467817, 0.06673459852540774], 
                "EvaluationTime" -> 0.00019982943044351853`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.16145206834650094`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 451720, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.6017043013586887, 0.17494959443558325`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4120930610467817, 0.04718848715707758]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00019982943044351853`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.4120930610467817, 0.06673459852540774], 
               "TrainingMemory" -> 451720, "TrainingTime" -> 
               1.391017463958849], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.060825562712602, 0.37426850426020253`], 
                "StandardDeviation" -> 
                Around[0.48530840176078266`, 0.03410005547748037], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.0158344948377398, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 499568, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.060825562712602, 0.26464779734693544`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.48530840176078266`, 0.024112380466963842`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.620379248254559, 0.19674896215749246`], 
                "StandardDeviation" -> 
                Around[0.4206534013100346, 0.05694092640394802], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.14605222087241632`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 522520, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.620379248254559, 0.13912252533297834`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4206534013100346, 0.04026331518727577]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00025157034800970054`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4206534013100346, 0.05694092640394802], 
               "TrainingMemory" -> 522520, "TrainingTime" -> 
               1.391017463958849], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.02639950170448, 0.4804624578762282], 
                "StandardDeviation" -> 
                Around[0.6713262878417899, 0.03498253534816628], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.3050491123847713, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495456, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.02639950170448, 0.33973826206983687`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6713262878417899, 0.024736387967786478`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[9.428891612591565, 1.535125004701293], 
                "StandardDeviation" -> 
                Around[0.5483110276480593, 0.03935650183007168], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.1065219895613636, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499680, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[9.428891612591565, 1.0854973007933149`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5483110276480593, 0.02782924932782445]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5338360916450294, 0.3512206098174233], 
                "StandardDeviation" -> 
                Around[0.36036986267875415`, 0.06659432020227427], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.29115075322152584`, "TrainingSize" -> 252, "TrainingTime" -> 
                6.309573444801933, "TrainingMemory" -> 522456, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5338360916450294, 0.2483504748943745]}, 
                "StandardDeviationHistory" -> {
                  Around[0.36036986267875415`, 0.04708929540353643]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.36036986267875415`, 0.06659432020227427], 
               "TrainingMemory" -> 522456, "TrainingTime" -> 
               9.471859998463529], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 291817470193191]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.00001666865234375`3., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097569673137604`17.333472261129263*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.7090710658026622`, 
            "ElapsedTimes" -> 2.3856176, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 2.8484517763377712`, 
            "ElapsedTimes" -> 2.730693, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 4.747419627229618, 
            "ElapsedTimes" -> 7.9317675, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 291830355095079]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{-0.34086637869685965`, -4.729865545752679, 
              0.6430090199245856, 0., 1.6094379124341003`}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 13.751977, 
        "MaxTrainingMemory" -> 979256, "DataMemory" -> 75768, 
        "FunctionMemory" -> 265944, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 49, 27.3406886`9.18938436398599}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {
                    0.3030360249758807, -0.29394511273599155`, \
-0.19120767594769125`, 0.5238095238095238, 3.856693121208698}, "Method" -> 
                    "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.3030360249758807, -0.29394511273599155`, \
-0.19120767594769125`, 0.5238095238095238, 3.856693121208698}, 
                    "StandardDeviation" -> {6.703650103549064, 
                    4.407929233677658, 4.239971109962409, 0.4994327848429293, 
                    1.3470283762044197`}, "Method" -> "NaiveSampler", 
                    "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.0610917187473681, 0.4858139894961021, 
                    0.7963342528006838, 
                    0.30139924221422437`, -0.18778398259554024`}, {
                    0.6650644268058605, -0.19488759839441636`, 
                    0.16931923425180612`, -0.3694196870316509, \
-0.5954563157237214}, {0.3927338129518761, 
                    0.6041904193041865, -0.0421323693250829, \
-0.46181606560609445`, 0.5154268855894832}, {0.344920924824037, 
                    0.42548047836784875`, -0.5221900209551578, 
                    0.594673803022256, -0.271434279633755}, {
                    0.529855468859855, -0.42417436432537464`, 
                    0.25044999540560026`, 0.45362603670124874`, 
                    0.5204109043789535}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.3030360249758807, -0.29394511273599155`, \
-0.19120767594769125`, 0.5238095238095238, 3.856693121208698}, 
                    "StandardDeviation" -> {6.703650103549064, 
                    4.407929233677658, 4.239971109962409, 0.4994327848429293, 
                    1.3470283762044197`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.010882, "MaxTrainingMemory" -> 94072, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 49, 27.3656229`9.189780253577265}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {
                0.3030360249758807, -0.29394511273599155`, \
-0.19120767594769125`, 0.5238095238095238, 3.856693121208698}, 
               "StandardDeviation" -> {6.703650103549064, 4.407929233677658, 
                4.239971109962409, 0.4994327848429293, 1.3470283762044197`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.388689978467681}, 
               "StandardDeviation" -> {0.7678238300258111}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.388689978467681 + 
         0.7678238300258111 #& ), 
        "ProcessorFunction" -> (3.1109870325167988` + 
         1.3023820841382119` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.6927917504254615`, 2.280431225243807}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX1Q03UcgOeSuQ2NKbBEpjtQQnSKTOaJuM83ipmWHegOEnxjBBN0AiHI
maeZEoiOALfxIgjsZk6hNJXShN/nk4jDzHy7hBRznEieQieKyETA9I/nuXvu
8UtMX6nn83i8LcI3WqnLicjM1G3TCt5Gss4wX2l4O5VvcHuDYl8gzszOhelX
BWB7EE0vnIvY/kQN2icpAI7VQKDtCPbNzACT3Nz4srBaDbWDUHKpCwP1k9lh
VzGbEtWkVk75Jrz+SR14pcnYvM4kbihoMkk3ly6uTVFChMPOxUbb4YsFXuy9
K2b09LBAzB4fqnJ+iV38GGgTdavdRi+Cae9u6EnyorYBM16PL4FdJ49iq2Eb
uu5UoCq9gE1ljbh702wW1ODOnN4jKNvrjun+NVxZigN5tnMg4B/gUgvDWEdf
i1royKMoXxntybmpVm08i6FZ13DsGDcyeu5i1qo09qNezO5VzKaO255gHq4n
SW8zrpklpuVnWnDasJB15/ZiW5wW+gN0GHx7EKoXNsC+9+VYs4rHbTlRjFUe
BnJ/boDgNetojuuMGkLqmkKj+exn52Ou0+MyjlYKOHO7AQ8leKNg+1/4z5Lf
4KchG/bLstThOx7BnPsicPtPSmn1q8h/RjkuufwOK4ttQbE9Sl1heISmU9mk
0t7AiauteFw1iZryH6Ai2wbhn4fT+qUOsEht6GyxY2lPPh0oi2AHHQ0oqW6G
+xd3ctm6fm7oqoSMHWdAEpYDeYcauB9U4yhDMZ8+6FjJUp/rQT8spKkpq8Ft
wYC65VsLhsT7so/kvuwX8Q6wrreid00WtK51YuLG/RDfvgovZ34Kxe3/Yu6K
LdjgX4RFKbfAcWUSaXZKKWOtkd1snkc6LzEp+QPcn5ea8bUxgCKL5lJ//nL2
qzKTnQoVsaBWH+qNdqL4CEM/k4AdNHmT6FAI5D3twc/SwoBKpHSsIxnbfLrx
eSCP3RURdMeUq2fd0UJfZRv3uPwu/i4Zz2R/T6dI40Qm1n2PmnevoeKrhbTu
3HGsNZVBxqiURlxGuBA3gSTXfVm7YBMq4v1wbH8dyFI3U7emcvGGZ6dx/ZMp
bLBkPJV23YLzGhG2fyhcfEMvpcoEMfXlvQKHpJWbdd6TuYLvYencRMxrdSJe
DwXNNAUFHwsELC9kw89OwNOdB/CuMZ3yzsbTi81msIU+QW1kBeSniWHDSC/3
R3Up8sdFL7I0TmQj273p6sutaB9oxoSHFvDK8aAed5H6u6RzKN+6Ar9+XYX5
n4yhV3Vq0IzRsI/jAuhkNVDBCXfiyZOwQnsYI44WUMZDG8xYto5SNyVASqy1
SZVkgQkBNi5DuACsIRea5LlL6LRFTK4uKzYuXUbpcZ14xzOZ+x8Q3fRy
                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.00733212660998106, -0.19393573701381683`, \
-0.20054788887500763`, 0.05616932734847069, 
                    0.020682180300354958`, -0.03773908689618111, \
-0.09493255615234375, -0.0098956860601902, 0.08917839825153351, 
                    0.020576689392328262`, -0.06949535012245178, \
-0.015610458329319954`, -0.056123364716768265`, 
                    0.1653716266155243, -0.08775054663419724, \
-0.01672455482184887, -0.055023714900016785`, 
                    0.03921095281839371, -0.08374163508415222, 
                    0.09309140592813492, 0.008200420066714287, 
                    
                    0.13938024640083313`, -0.08225324749946594, \
-0.029188791289925575`, 
                    0.11753017455339432`, -0.007066369988024235, \
-0.13259385526180267`, 0.05488968268036842, 0.057006265968084335`, 
                    0.0414772666990757, -0.11115077883005142`, \
-0.06287882477045059, -0.011625606566667557`, -0.12115173041820526`, 
                    0.13257063925266266`, 
                    0.08401788026094437, -0.059392768889665604`, \
-0.08739561587572098, -0.01667766645550728, 
                    0.08578738570213318, -0.032009247690439224`, \
-0.13435876369476318`, -0.02042793668806553, 
                    0.04614022374153137, -0.08741544187068939, \
-0.14012712240219116`, 0.062418632209300995`, 0.1194266602396965, 
                    0.10157240927219391`, 0.06740245968103409}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c014/3x8keoY2mhIwWWt6ve8soKlKIUpJK0lIy0kTITGVGRimRIiWJ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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.003318133531138301, -0.0502924881875515, \
-0.17558510601520538`, -0.05046132579445839, -0.017574287950992584`, \
-0.008907537907361984, -0.1496618241071701, -0.013898785226047039`, 
                    0.0025995520409196615`, -0.05688486620783806, \
-0.10802324116230011`, -0.09984429180622101, -0.08470235764980316, 
                    0.010158591903746128`, -0.02033217065036297, \
-0.09448238462209702, -0.07951405644416809, 
                    0.0980161726474762, -0.06334488838911057, \
-0.04102523252367973, -0.020986057817935944`, 0.07539289444684982, 
                    0.1727306991815567, -0.07375029474496841, \
-0.07687126100063324, -0.25381407141685486`, -0.0597715750336647, \
-0.01010950282216072, 0.0065986523404717445`, -0.04199228063225746, 
                    0.0138648496940732, -0.07724858820438385, 
                    0.03457314521074295, -0.0416596420109272, \
-0.12291121482849121`, 0.05521697551012039, -0.002783858682960272, 
                    0.0003043806063942611, -0.013952427543699741`, \
-0.12129843235015869`, 0.05466266721487045, 
                    0.01928817667067051, -0.026761038228869438`, \
-0.11806681007146835`, -0.0063552698120474815`, -0.037147726863622665`, \
-0.08318684995174408, 0.002032605465501547, -0.010941686108708382`, 
                    0.06200069189071655}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtmXc419/7x2WEIsmKlDJDCWl5v+4bZSQySkPREO2lovUpm4oUUaLMdolU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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.08703915774822235, -0.05109267681837082, \
-0.015877628698945045`, -0.016967028379440308`, -0.030615393072366714`, \
-0.029520366340875626`, 
                    0.005749169271439314, -0.08096387982368469, \
-0.06282778084278107, -0.1008480116724968, -0.007536361459642649, \
-0.1049714982509613, 
                    0.017266131937503815`, -0.08413776755332947, \
-0.004032339435070753, -0.03676736354827881, -0.052540428936481476`, 
                    0.008819900453090668, -0.1082565113902092, 
                    0.008824463002383709, 0.03822898864746094, 
                    0.0033892726060003042`, -0.01525654923170805, \
-0.06652297079563141, -0.054521411657333374`, -0.04514113441109657, \
-0.05749388411641121, 0.08772626519203186, -0.08759201318025589, 
                    0.01727914810180664, -0.05178311839699745, \
-0.0238160602748394, -0.10889256000518799`, 0.026370178908109665`, 
                    0.08038972318172455, 
                    0.00744139077141881, -0.05625941604375839, \
-0.10327109694480896`, -0.17117156088352203`, -0.0958482176065445, \
-0.09019867330789566, -0.012585744261741638`, 
                    0.04093515872955322, -0.1388792097568512, 
                    0.06923564523458481, -0.12736286222934723`, \
-0.0779220312833786, -0.04247964546084404, -0.08574662357568741, \
-0.05303899198770523}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2k0l43TxxGyJVtZEkJS2bkLv2smKina9yxt2rXJUloktBAlKncJUbKX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                    "], "Biases" -> 
                    RawArray["Real32",{0.07232077419757843, 
                    0.05529510974884033, -0.020417746156454086`, 
                    0.007918382994830608, -0.029682697728276253`, \
-0.02248275652527809, -0.044267572462558746`, -0.11189811676740646`, 
                    0.002055190270766616, -0.059520967304706573`, 
                    0.03503906726837158, 
                    0.03192026540637016, -0.006490395870059729, \
-0.05739764869213104, -0.053832415491342545`, 
                    0.07612945139408112, -0.02400180511176586, 
                    0.00976269319653511, 0.021719375625252724`, 
                    0.039030950516462326`, -0.029658397659659386`, 
                    0.018276503309607506`, -0.04140593484044075, \
-0.0017639354337006807`, 0.018060125410556793`, 0.029460350051522255`, 
                    0.04600955545902252, 0.09879261255264282, 
                    0.03778975456953049, 
                    0.003021605545654893, -0.07060087472200394, \
-0.0812424048781395, -0.03911348804831505, 0.015874626114964485`, 
                    0.015621998347342014`, 
                    0.011695410124957561`, -0.017595645040273666`, 
                    0.031727489084005356`, -0.06049623712897301, 
                    0.06289520859718323, 0.03661266714334488, 
                    0.07445059716701508, -0.06288862228393555, \
-0.02595091611146927, 0.01591269113123417, 0.030445532873272896`, 
                    0.012729000300168991`, 
                    0.0027775487396866083`, -0.042082883417606354`, 
                    0.0711536630988121}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray[
                    "Real32",{{-0.16079416871070862`, -0.22846350073814392`, 
                    0.11150884628295898`, 0.307363361120224, 
                    0.16014178097248077`, 0.20426276326179504`, 
                    0.09064548462629318, 0.08936883509159088, 
                    0.2159746289253235, 
                    0.19786427915096283`, -0.27003222703933716`, \
-0.018502837046980858`, 0.1645830124616623, 0.1925484538078308, 
                    0.0904836356639862, -0.041573408991098404`, 
                    0.2284930795431137, -0.15166164934635162`, 
                    0.011915876530110836`, -0.08133247494697571, 
                    0.1035580188035965, -0.06322579830884933, 
                    0.0006813898216933012, -0.11335314065217972`, \
-0.02837809920310974, -0.1381528377532959, -0.11485125124454498`, \
-0.09334894269704819, -0.17875242233276367`, -0.21479995548725128`, 
                    0.10945142805576324`, 0.0949854627251625, 
                    0.1278410255908966, -0.13470697402954102`, \
-0.03240179270505905, 0.0033170729875564575`, 0.19060879945755005`, 
                    0.29598748683929443`, 
                    0.1635867804288864, -0.2406807392835617, \
-0.04536858946084976, -0.10767798870801926`, 0.01580309122800827, 
                    0.2098841369152069, -0.1386438012123108, \
-0.07939530909061432, -0.04053553193807602, -0.17918674647808075`, 
                    0.06669215112924576, -0.13765670359134674`}}], "Biases" -> 
                    RawArray["Real32",{-0.03880060091614723}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.9360164403915405}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 1.6903342, "MeanInputsPerSecond" -> 
          45434.80218290561], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.020606742945976895`, -0.0033534645822365667`, \
-0.03862784819389218, -0.01623195276991694, 0.05825634037083773}, 
               "StandardDeviation" -> {0.9949591655086734, 0.9984076599326168,
                 0.9713296718955386, 1.000061087169472, 0.9753427578670485}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2469198600951705382]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 300, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[364017], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.2641949601351384, "PreprocessingTime" -> 
        0.3960543`7.049299726324781, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.6543773553638379, 0.32022372110889363`], 
           "StandardDeviation" -> 
           Around[0.4153467878853936, 0.07429465351298836], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 107736, 
           "ModelUtility" -> 0.150310419049688, "TrainingSize" -> 252, 
           "TrainingTime" -> 1.9952623149688797`, "TrainingMemory" -> 522456, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.6543773553638379, 0.22643236469288844`]}, 
           "StandardDeviationHistory" -> {
             Around[0.4153467878853936, 0.05253425330493902]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 300, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 213760734555702]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.062269727963346, 0.5603572813849453], 
                "StandardDeviation" -> 
                Around[0.7729248727974202, 0.0456129747742249], 
                "EvaluationTime" -> 0.0001299709711359511, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.4473412417583359, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                495976, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.062269727963346, 0.3962324335545531]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7729248727974202, 0.032253243772945354`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[8.411556224519174, 1.1901034723674222`], 
                "StandardDeviation" -> 
                Around[0.5933354666475835, 0.03668031468049992], 
                "EvaluationTime" -> 0.00013978572969008897`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.18347405775320424`, "TrainingSize" -> 50,
                 "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                499944, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[8.411556224519174, 0.8415302356246612]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5933354666475835, 0.025936899246637963`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.6543773553638379, 0.32022372110889363`], 
                "StandardDeviation" -> 
                Around[0.4153467878853936, 0.07429465351298836], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 0.150310419049688, 
                "TrainingSize" -> 252, "TrainingTime" -> 1.9952623149688797`, 
                "TrainingMemory" -> 522456, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.6543773553638379, 0.22643236469288844`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4153467878853936, 0.05253425330493902]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4153467878853936, 0.07429465351298836], 
               "TrainingMemory" -> 522456, "TrainingTime" -> 
               3.125035238191293], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[5.63427871276519, 0.7262379876146521], 
                "StandardDeviation" -> 
                Around[0.8243579624524839, 0.04791764098945456], 
                "EvaluationTime" -> 0.00014342569646407457`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.5115872317442335, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                424592, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[5.63427871276519, 0.5135278057975924]}, 
                "StandardDeviationHistory" -> {
                  Around[0.8243579624524839, 0.033882888882105784`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[14.966696948930863`, 2.1975483144935306`], 
                "StandardDeviation" -> 
                Around[0.6097676540263793, 0.040925895535177594`], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.21183611856547846`, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                428752, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[14.966696948930863`, 1.5539013151634433`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6097676540263793, 0.028938978259056322`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.735457762626333, 0.2919193214190972], 
                "StandardDeviation" -> 
                Around[0.43764996191838534`, 0.06855635871858626], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.10230792445248493`, "TrainingSize" -> 252, "TrainingTime" -> 
                5.011872336272724, "TrainingMemory" -> 451592, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.735457762626333, 0.206418131734819]}, 
                "StandardDeviationHistory" -> {
                  Around[0.43764996191838534`, 0.048476666143369825`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00025157034800970054`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.43764996191838534`, 0.06855635871858626], 
               "TrainingMemory" -> 451592, "TrainingTime" -> 
               7.849733612802018], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[10.418307087626166`, 1.5069718736499562`], 
                "StandardDeviation" -> 
                Around[0.5904468605758986, 0.03829616561802529], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.17919213823884272`, "TrainingSize" -> 50,
                 "TrainingTime" -> 0.31622776601683794`, "TrainingMemory" -> 
                428752, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[10.418307087626166`, 1.065590030915281]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5904468605758986, 0.027079478401948794`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.6177218488582514, 0.20537958600858044`], 
                "StandardDeviation" -> 
                Around[0.42307896582335586`, 0.060905683862623516`], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 
                0.13863196837401293`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 451592, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.6177218488582514, 0.145225297983953]}, 
                "StandardDeviationHistory" -> {
                  Around[0.42307896582335586`, 0.043066822072065164`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.42307896582335586`, 0.060905683862623516`], 
               "TrainingMemory" -> 451592, "TrainingTime" -> 
               1.3091380594221897`], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 213756439588406]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.000010612646484375`1., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097569822345416`17.33347226283016*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.8478954355998505`, 
            "ElapsedTimes" -> 2.5152709, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 3.079825725999751, 
            "ElapsedTimes" -> 2.9630701999999998`, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 5.133042876666251, 
            "ElapsedTimes" -> 8.726646299999999, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 213769324490294]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{
              4.0761771390251065`, -2.9054512418166403`, -1.8868765186398941`,
               0., 3.912023005428146}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 14.9211331, 
        "MaxTrainingMemory" -> 942192, "DataMemory" -> 75768, 
        "FunctionMemory" -> 265944, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 49, 42.2624684`9.378529733652053}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.28860906714519285`, 
                    0.4667213463727009, -0.07100941339246523, 
                    0.5365079365079365, 3.799706844654074}, "Method" -> 
                    "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.28860906714519285`, 
                    0.4667213463727009, -0.07100941339246523, 
                    0.5365079365079365, 3.799706844654074}, 
                    "StandardDeviation" -> {7.37010987554904, 
                    4.310714349893842, 4.288206779290442, 
                    0.49866538938644267`, 1.4192864886188339`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{0.11218337032006352`, 0.4657778470780642, 
                    0.8417397058856791, -0.15656310962688694`, \
-0.1934635594482985}, {0.5580470719945186, 
                    0.032435982721566996`, -0.14247498684336946`, \
-0.7278319744292077, 0.37080030688457294`}, {
                    0.26403776801159634`, -0.8059139747733467, 
                    0.2920023935133559, -0.10895686616827162`, \
-0.4285437268537953}, {-0.5672629618271006, 
                    0.08230438719715595, -0.19794941289959353`, \
-0.6357928057560748, -0.47751676208146954`}, {-0.5333808639842417, \
-0.35458081915035394`, 0.3830480097515838, -0.17217583792753208`, 
                    0.6429673395168609}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.28860906714519285`, 
                    0.4667213463727009, -0.07100941339246523, 
                    0.5365079365079365, 3.799706844654074}, 
                    "StandardDeviation" -> {7.37010987554904, 
                    4.310714349893842, 4.288206779290442, 
                    0.49866538938644267`, 1.4192864886188339`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0135468, "MaxTrainingMemory" -> 93112, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 49, 42.2923873`9.37883707528511}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.28860906714519285`, 
                0.4667213463727009, -0.07100941339246523, 0.5365079365079365, 
                3.799706844654074}, 
               "StandardDeviation" -> {7.37010987554904, 4.310714349893842, 
                4.288206779290442, 0.49866538938644267`, 1.4192864886188339`},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.324715427746567}, 
               "StandardDeviation" -> {0.7022271790411673}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.324715427746567 + 
         0.7022271790411673 #& ), 
        "ProcessorFunction" -> (3.310489108269452 + 1.424040580949055 #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-3.035433958715715, 2.482138755194212}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViXswFHgcwG2IM9SyWi3Vydwt0tm7XU5pf98fmsj2OI9M0muIGqrLI4+u
B9GFnUPuIdnu0LEcd3lcOnezv+/P6Y6QyZ6OWiOkYxgkdamrzNUfn8/MZz6r
o46FHFxkZGSUZP5GIZGpvomJkSdCF7+NmMgjCvmRt1P+BtM3fGW6m7pZKfDX
Zge+xlsNMRn1PCXCge73VWPZgiVlrlLy0qGYFdjt4BHFZSgO1LO5kGvY+Poi
rrOaZFPbF+uEM3lcGCjm3o9CdX76+0gqvoDLzhO/SfQX8PVKOS5zsAA/rzDq
Mb+GDRwX88iOPbzQvwebo3P4RLwPzdzmC9Om/rpHc1nwcb4c1yZPsHuLU3na
00FWtN2LB0sZiNJVzFflg/aSJ2z9COOfXlUQG+fLmPe6ARPW6MHn7mYQjSth
/dge2vr4OhiXpKDEqI8kBZrzpw/L0WDqAKts9FCz0KFLN76uzF+UgfUNFdjk
+SXGrpfQuZun6Y4OBTbG/0WWLjHHzd/5Qe2NFbxd0657NSYgle8/R/0OMcXW
ILwQ6Ed7/A5B6+ZbaBJQCAund4LmkxQQCPshZlpIQ2xawEOuIQdjrSj3L0Z1
wjll73wGzQmYI5UGGYi2RKK034hGnKnC3acUOPJOAD1qWIHKjBo2NOxG0qpr
yIvOpdi5QQVa+yasWGIGowZ3mjCzjOv7W0h4eAE2iNdCxcPzWHljL6zU1kOJ
cQFaBnYz2YITqvRyro59glIdYUnz02if+DPs35kJogNa/GhZNstp3MALvz+B
m4LtsOOBLe1zUlHBrBZm9rrwrH4z3dFua1YU1MLyJFKiK/UHz8qNVHsXqJnh
Q4z1HyJ1Hlu5zHJU97vmFsY538FM20FwjY7GkujVfKBnmj1rM5ADFpUg/smO
nH15CVeFLUX3U5a89No5mDo1RyYX3UOleie3SR/E5nNXsPakM6571QFJeZQG
vTiP1eIGLP+mHTqFG6HIKw2N3XJhQGOKPmZ1KPhAxa/G2eiylS3g67AFJs1y
wSOrCdV+K7nPnlS+vNSCn/7jBLWqU9Lyk45Qc0nAfykuI9J6V/Ke9lv07M4i
US5nILLCknvL+0jo57m8KzOXrUgeZhePFSqVZb0k3t2OQrYM645Xgdh1GOab
b7JnCT+grKUaO+e3ofm7GmwLnwHtrn/Ji8cCfnbSmyrGSqArbhef2iog7bae
ONq7nL5KZmjbOgvZzBrD7MaY/YgbFKXOw50HJrTL4jo5e/IwEbX1kdRUR2oy
XM1mc8QwlH+Ix+0bI/smXGDc4mvyn74Wwj+z5pUxf+PhsWG4rwmmzz2v8KhN
CDEuTqB3vE2VWjG/HSGif8rGsfbHQJSEyWiVexQN8dEQC40Qqv5pw/8Bkr3q
Ig==
                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.007405394222587347, -0.03482181578874588, 
                    0.02823498100042343, -0.02075297199189663, 
                    0.02742883749306202, 0.025596752762794495`, 
                    0.07276477664709091, 
                    0.04105871543288231, -0.026160337030887604`, \
-0.009688446298241615, -0.03357561305165291, 
                    0.014800813980400562`, -0.0734693855047226, \
-0.018284454941749573`, -0.03088223747909069, -0.022626228630542755`, \
-0.02602606825530529, 0.012790096923708916`, -0.007302245125174522, 
                    0.04528961703181267, -0.027452966198325157`, 
                    0.04032023251056671, -0.04019463062286377, 
                    0.0004533848259598017, 0.01569453440606594, 
                    0.04314462095499039, -0.01738460548222065, \
-0.0037142662331461906`, 0.03898265212774277, 
                    0.003629910061135888, -0.04318380728363991, 
                    0.0427992008626461, -0.04078466072678566, 
                    0.009966257959604263, -0.07785649597644806, \
-0.014148097485303879`, -0.04743579402565956, -0.03220440819859505, \
-0.034653253853321075`, 0.051791001111269, 0.02763424813747406, 
                    0.02961042895913124, 
                    0.07986349612474442, -0.024246158078312874`, 
                    0.04038222134113312, -0.032852571457624435`, \
-0.028279993683099747`, -0.004430863074958324, 
                    0.05990849435329437, -0.02853270433843136}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dYz9/7xxsaGiJKQokGpVRCeb/uO2UrkoxSRpGVrIysj/YSLRoiK2mZ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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.01935076341032982, -0.051607612520456314`, \
-0.06442621350288391, 0.08115998655557632, -0.0013698396505787969`, 
                    0.04143504798412323, 
                    0.035710714757442474`, -0.02019769884645939, 
                    0.00798102281987667, -0.030366381630301476`, \
-0.040545713156461716`, 
                    0.008365962654352188, -0.0033140077721327543`, \
-0.009058108553290367, -0.042331162840127945`, -0.0062817661091685295`, \
-0.06064656749367714, 0.02145751193165779, -0.0028546652756631374`, 
                    0.019998928532004356`, 
                    0.017146408557891846`, -0.008308873511850834, \
-0.019649028778076172`, -0.04273153096437454, 
                    0.052580758929252625`, -0.000659666140563786, 
                    0.008304261602461338, -0.035899654030799866`, \
-0.03754599019885063, -0.004533933475613594, -0.003479252103716135, 
                    0.05564320087432861, 0.04540593922138214, 
                    0.04496327415108681, -0.004590150434523821, 
                    0.03416871652007103, -0.04795103147625923, \
-0.030199700966477394`, 
                    0.029575463384389877`, -0.06295643746852875, \
-0.04723469540476799, -0.04120054841041565, 
                    0.015383468009531498`, -0.0191650353372097, \
-0.03072957508265972, 0.00292522762902081, -0.03664612025022507, 
                    0.03329826146364212, -0.0069030942395329475`, 
                    0.000677333096973598}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c41+/3xyVZIaRCSimlpYyE9+scRYkGCu1EiXaJijSMIqKBEElkpULb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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.03976508602499962, -0.0019116929033771157`, \
-0.04522448405623436, -0.005110098514705896, 0.012081824243068695`, 
                    0.0020954760257154703`, -0.04294901713728905, 
                    0.0006272325990721583, 0.08028348535299301, 
                    0.038214780390262604`, 
                    0.03310931473970413, -0.04807214438915253, \
-0.03374655917286873, -0.0007086900295689702, -0.032114770263433456`, \
-0.007869018241763115, 0.018673125654459, 0.015526968985795975`, 
                    0.026071326807141304`, 0.011605845764279366`, 
                    0.0038480297662317753`, -0.03878936171531677, \
-0.05772046744823456, -0.025132717564702034`, 0.004957234021276236, 
                    0.008414353244006634, 0.03629157692193985, 
                    0.01682940311729908, 
                    0.050761137157678604`, -0.03756433725357056, \
-0.03084505721926689, 0.013263190165162086`, 
                    0.0028953170403838158`, -0.01927836611866951, 
                    0.027263395488262177`, 
                    0.007427390664815903, -0.045157454907894135`, 
                    0.028242409229278564`, -0.010467369109392166`, 
                    0.011159992776811123`, -0.02855239249765873, \
-0.036097750067710876`, -0.0025968600530177355`, -0.012830117717385292`, 
                    0.010456130839884281`, -0.04534737765789032, 
                    0.05946222320199013, -0.002753549488261342, 
                    0.029706276953220367`, -0.02251964993774891}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwt13dYz9/7B/D2QEMk2lFUKmnX+3XfVNKgokhEJEIyCg1Ei9KUShkpLUq0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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.004253351595252752, -0.0069291722029447556`, 
                    0.030750010162591934`, -0.021120283752679825`, 
                    0.00905576627701521, 0.022008344531059265`, 
                    0.03515554219484329, -0.007174713537096977, \
-0.02100921981036663, -0.006419103126972914, -0.004958587232977152, \
-0.03723772242665291, 0.00009090412640944123, 
                    0.016257094219326973`, -0.012545442208647728`, \
-0.01901647076010704, -0.03650951758027077, 
                    0.013722984120249748`, -0.00719818938523531, \
-0.007733056787401438, -0.013783210888504982`, -0.012746643275022507`, \
-0.017216449603438377`, 0.0003776533412747085, 
                    0.027897832915186882`, -0.006989081855863333, \
-0.017784714698791504`, -0.006885610520839691, -0.0037868500221520662`, \
-0.03608393296599388, -0.008752300404012203, 0.015352417714893818`, 
                    0.008717149496078491, 0.004137806594371796, 
                    0.0005161563749425113, 0.0024722954258322716`, 
                    0.001458917511627078, -0.032992441207170486`, \
-0.004996230825781822, 0.008675162680447102, -0.0010676448000594974`, 
                    0.007213040255010128, 
                    0.026187075302004814`, -0.025093087926506996`, \
-0.0166276004165411, 
                    0.01116433646529913, -0.013957219198346138`, \
-0.05355295166373253, 0.021184632554650307`, 0.011263151653110981`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{
                    0.14430661499500275`, -0.19336265325546265`, \
-0.002563027199357748, -0.0946924015879631, -0.04920661449432373, \
-0.15090805292129517`, -0.08198713511228561, 
                    0.207945317029953, -0.03640269488096237, 
                    0.08581434935331345, 
                    0.15309466421604156`, -0.07591794431209564, \
-0.18414750695228577`, -0.00963524915277958, 0.030812017619609833`, 
                    0.2784806191921234, 0.06857695430517197, 
                    0.09169772267341614, 
                    0.4110656678676605, -0.07353932410478592, 
                    0.2058090716600418, 
                    0.16432927548885345`, -0.16346284747123718`, \
-0.03278983384370804, -0.05523093417286873, 0.0499713309109211, 
                    0.22743169963359833`, 0.08532506227493286, 
                    0.14432914555072784`, 
                    0.14053118228912354`, -0.012437074445188046`, \
-0.229949951171875, 0.12234088778495789`, 
                    0.03906743600964546, -0.007546738721430302, \
-0.09309718757867813, -0.05975910276174545, -0.0640362799167633, \
-0.07132501900196075, -0.014922033064067364`, -0.0617312528192997, \
-0.22020810842514038`, -0.12005037069320679`, 0.17255687713623047`, 
                    0.14307855069637299`, -0.11764901876449585`, 
                    0.13339389860630035`, 0.17464345693588257`, 
                    0.05788341537117958, -0.11296116560697556`}}], "Biases" -> 
                    RawArray["Real32",{-0.012930454686284065`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.44023871421813965`}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 4.9861202, "MeanInputsPerSecond" -> 
          51342.52479513029], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {
                0.02374068706252393, -0.03590043418702494, \
-0.02427238476577632, -0.0413790967702001, 0.018766396868989198`}, 
               "StandardDeviation" -> {0.9769849214234392, 
                1.0051177347952263`, 0.9967652352051408, 1.0019790783811695`, 
                0.989805261564779}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 9187939170700945274]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[364129], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.35349831044121033`, "PreprocessingTime" -> 
        0.3845823`7.03653428590696, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.5198964016376366, 0.1260936101958699], 
           "StandardDeviation" -> 
           Around[0.39390318188208473`, 0.06767113594694132], 
           "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63, 
           "ModelMemory" -> 99880, "ModelUtility" -> 0.2046885194164373, 
           "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
           "TrainingMemory" -> 451656, "ExperimentCount" -> 1, 
           "MeanCrossEntropyHistory" -> {
             Around[0.5198964016376366, 0.08916164683379278]}, 
           "StandardDeviationHistory" -> {
             Around[0.39390318188208473`, 0.04785071911867894]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 222677086662211]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[6.294537189455991, 0.7824913784979404], 
                "StandardDeviation" -> 
                Around[0.7850759389518357, 0.04394755323300241], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 99880, "ModelUtility" -> -0.4623379886697476,
                 "TrainingSize" -> 10, "TrainingTime" -> 1.5848931924611136`, 
                "TrainingMemory" -> 424736, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[6.294537189455991, 0.553304959955903]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7850759389518357, 0.031075612907612783`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[10.517482828549683`, 1.7909358805996891`], 
                "StandardDeviation" -> 
                Around[0.4780697688866561, 0.03565450436980563], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.03001345989352988, "TrainingSize" -> 50, "TrainingTime" -> 
                1.5848931924611136`, "TrainingMemory" -> 428688, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[10.517482828549683`, 1.266382905842341]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4780697688866561, 0.02521154181973495]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5198964016376366, 0.1260936101958699], 
                "StandardDeviation" -> 
                Around[0.39390318188208473`, 0.06767113594694132], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 0.2046885194164373,
                 "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
                "TrainingMemory" -> 451656, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.5198964016376366, 0.08916164683379278]}, 
                "StandardDeviationHistory" -> {
                  Around[0.39390318188208473`, 0.04785071911867894]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00031670830396331406`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.39390318188208473`, 0.06767113594694132], 
               "TrainingMemory" -> 451656, "TrainingTime" -> 
               7.849733612802018], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.730814229834371, 0.6644315360559968], 
                "StandardDeviation" -> 
                Around[0.4789502863837102, 0.0342217477902802], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.028790062031876396`, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 428624, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.730814229834371, 0.4698240447793893]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4789502863837102, 0.024198429926562876`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5198964016376366, 0.1260936101958699], 
                "StandardDeviation" -> 
                Around[0.39390318188208473`, 0.06767113594694132], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 
                0.20468843741260923`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 451656, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5198964016376366, 0.08916164683379278]}, 
                "StandardDeviationHistory" -> {
                  Around[0.39390318188208473`, 0.04785071911867894]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.39390318188208473`, 0.06767113594694132], 
               "TrainingMemory" -> 451656, "TrainingTime" -> 
               1.391017463958849], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.0036790114126095`, 0.480612660260362], 
                "StandardDeviation" -> 
                Around[0.7328531538663136, 0.039189422681791736`], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.3930094159681967, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                495648, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.0036790114126095`, 0.33984447119420824`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7328531538663136, 0.027711106529080827`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[2.364428359623134, 0.4097123472275992], 
                "StandardDeviation" -> 
                Around[0.49829319174019876`, 0.03390577580874588], 
                "EvaluationTime" -> 0.00009501323862597485, "TestSize" -> 265,
                 "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.010131404520360432`, "TrainingSize" -> 
                50, "TrainingTime" -> 0.5011872336272722, "TrainingMemory" -> 
                499552, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.364428359623134, 0.28971037906049274`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.49829319174019876`, 0.023975003995755008`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5439321285079068, 0.10227962100539056`], 
                "StandardDeviation" -> 
                Around[0.40201939136290576`, 0.058314267300812246`], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 0.1894757772625273,
                 "TrainingSize" -> 252, "TrainingTime" -> 0.7943282347242815, 
                "TrainingMemory" -> 522664, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.5439321285079068, 0.07232261359010171]}, 
                "StandardDeviationHistory" -> {
                  Around[0.40201939136290576`, 0.041234413848329286`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.40201939136290576`, 0.058314267300812246`], 
               "TrainingMemory" -> 522664, "TrainingTime" -> 
               1.391017463958849], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 222672791694915]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 7.458642578125`1.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097569954079528`17.33347226433187*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.7168386044535426`, 
            "ElapsedTimes" -> 2.1572307, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 2.861397674089238, 
            "ElapsedTimes" -> 2.8423925, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 4.768996123482062, 
            "ElapsedTimes" -> 7.4600356, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 222685676596803]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{1.4281067184743153`, 
              5.165011933852659, -1.2213463494536325`, 0., 
              3.912023005428146}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 13.175307, 
        "MaxTrainingMemory" -> 979048, "DataMemory" -> 75768, 
        "FunctionMemory" -> 258088, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 49, 55.4388704`9.496389211831026}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.5270527794643848, 
                    0.04950559650729257, -0.21680088349582682`, 
                    0.44761904761904764`, 3.933558893482868}, "Method" -> 
                    "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.5270527794643848, 
                    0.04950559650729257, -0.21680088349582682`, 
                    0.44761904761904764`, 3.933558893482868}, 
                    "StandardDeviation" -> {6.978065175482919, 
                    4.493149943164474, 4.018470265336081, 
                    0.49724866598882334`, 1.3325086008509384`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{0.10678836015776906`, 0.42103754276969446`, 
                    0.7462117714031733, 
                    0.4903622261833219, -0.11847579105094408`}, {
                    0.6625079935299646, -0.02595644118475228, \
-0.29185599396896894`, 
                    0.16014210469789755`, -0.670510258502609}, \
{-0.7006590087802477, -0.030593025546561018`, 
                    
                    0.027543427989569887`, -0.03495325343201819, \
-0.7114496818834688}, {0.08434251314452196, 
                    0.7573193046995838, -0.031605703715723736`, \
-0.641147216097068, -0.08535301980257327}, {
                    0.2272502993073105, -0.49757932860673254`, 
                    0.5968504922264377, -0.5671048499183907, \
-0.1514387411995688}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.5270527794643848, 
                    0.04950559650729257, -0.21680088349582682`, 
                    0.44761904761904764`, 3.933558893482868}, 
                    "StandardDeviation" -> {6.978065175482919, 
                    4.493149943164474, 4.018470265336081, 
                    0.49724866598882334`, 1.3325086008509384`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.010443, "MaxTrainingMemory" -> 93112, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 49, 55.4658002`9.496600122042569}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.5270527794643848, 
                0.04950559650729257, -0.21680088349582682`, 
                0.44761904761904764`, 3.933558893482868}, 
               "StandardDeviation" -> {6.978065175482919, 4.493149943164474, 
                4.018470265336081, 0.49724866598882334`, 1.3325086008509384`},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.43247190705631}, 
               "StandardDeviation" -> {0.7615013190566706}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.43247190705631 + 
         0.7615013190566706 #& ), 
        "ProcessorFunction" -> (3.1943108254488615` + 
         1.3131953615507532` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.6576549456171668`, 2.356859169054463}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViXs01nccgJ03TCocl9edNU4cek0uc3u/n697y1Z4Nfe1Y2LNbDZl1FgJ
xxtD03lLiLwMa14s7aT5/T7fZGgubclamWwMzeW4zIk0l+mP5znnOc/u95Mk
8QIlJaXjaluSxKR6JSfHnAxRfRlxMYmODokvp8MWKltse76d7na9CCmyC6gX
LKfq8SpM3X2KjK9agre/DzvwTIvNl7WiGl/MEj84B6XowR7WRdHHxgl0V2gJ
nHhDGbzeKWXORVb0mL4RHiyPhnv6/pDWPIzpUAF7PtWECcterMwdhmsPX8GS
/D8h1sINP/dUZz1hYXDF3JySOT9ecIfj+/vt6ZOPPemRW7m8hk086oStENl0
IK692QnZ4AYdWoY0uogXvz26xttKSjFuZQf2uQRB5z5n1KwZhE17ISm0racG
Fjl8zh1NJp8vJCprA5zXpAXlVmdw1WESelPcIdk0BFfoEe52+hnsqdtJBV+s
YFjjMhharqPsph5TUx8n1bqXecsZJ5bQkg18wDT//Nky+B13ouGqKygzc2cL
2T9je3U9NjqdRutjweyinyYjkTOENlCwZZrQlI0wU9ZPmysLoNrFHH28FSAZ
zsC9C3OovvAVPbSeRL90awOB3evc9X4ODBY1oEthTKszVKl2jw4VdLiQ9huU
7OiZ44fKZBDp4MPkMcVwOusGpI3Ocg4PXhVnXvEE0dFwzC/0AWnKGI4diqeS
7ksobakF0rJBFM5+/FLo9zTUdx0/OZMOg/9lc4n32nnPrDpObSybNQwaix9f
6yeH/epxtiSPpvz7D4lK38U2lU2RMzwJw2beZNuLWfC3vI9udW/h/bsuUCFv
FH9zogOCUk2oZsJZ8IgZBTO7OKI+/gCg7GuwGDiL/U82yPRvSiwnWBXcwwqg
p2oP081yZqP7AlC+2YetM81QP2/FzC2tSZDIlxc7ing8tYRX/ZVh+rYDF5i6
n8u9fpgOxW6AhtyUDgqLMWTcmIycT6BWsZ+Bav0AiZbroFftFCr0p7AoUgNw
+zS6VyrRpfyfcPKWBm2dm4SM39s9bGuM2KRkCHK0yqFq80NS3l1A2y79Is4X
XUD75tfwqcUU9i5LqbWeNu1qEkK9gMM+0VHiZXQTD878TWzSDNgSZ0cdc9PZ
oy4FkbpqMfneH/i45Ura9tFV5A8YYbHbsli5tgh25l3mFY9WSPcog84IIUb8
NQFJnjHMU2jDCk81QPh+K4gILGVVy+ZM3r2IGx3eMNahQF3XTCKSRvEBbk2E
ltuQBm0TbGyR40Tur3xl5DQuylL4mpQBEtaax6RmvszkW2cYYTLMNDvP+qq/
o4tCPZrT/iO7q2PKBl+8R5+GCFCpawQrOv8AyUAbtr4bSv4HVDXzRA==
                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.00481094466522336, -0.08661725372076035, \
-0.07831700891256332, 0.021545886993408203`, 0.03022003546357155, 
                    0.0034266887232661247`, -0.0734739601612091, 
                    0.09134145081043243, -0.035673774778842926`, 
                    0.05244440212845802, -0.07908646762371063, 
                    0.04838676005601883, 
                    0.04306940734386444, -0.05710617080330849, 
                    0.025376586243510246`, -0.037941861897706985`, 
                    0.08116372674703598, 0.14127378165721893`, 
                    0.10157471895217896`, -0.019784947857260704`, \
-0.027377134189009666`, 
                    0.013975672423839569`, -0.07743429392576218, \
-0.07282538712024689, -0.0021463448647409678`, 
                    0.022474119439721107`, -0.05301946401596069, 
                    0.02676329016685486, -0.0340665802359581, \
-0.16840335726737976`, -0.15801569819450378`, 
                    0.03428633511066437, -0.0778643861413002, 
                    0.03238856419920921, -0.016028715297579765`, \
-0.009225348010659218, -0.03207701817154884, 
                    0.062301479279994965`, -0.0613541342318058, 
                    0.005985170602798462, -0.14607511460781097`, \
-0.07586432248353958, -0.0008705336949788034, -0.010413531213998795`, 
                    0.014322938397526741`, 
                    0.03934451565146446, -0.01008059922605753, 
                    0.0024722779635339975`, 
                    0.0003670428995974362, -0.06477165222167969}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c41+/3xxGZWQkls1I0JJV4v85RMlKShsZHg4aWKE2VkJkkKkRJaBAZ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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.013873306103050709`, -0.09502584487199783, \
-0.09469890594482422, -0.004533994942903519, -0.006517923902720213, \
-0.07877509295940399, -0.00989027414470911, 
                    0.027748368680477142`, -0.006151597015559673, \
-0.047539543360471725`, -0.002313236240297556, -0.06712274998426437, \
-0.03839945048093796, -0.05562964826822281, -0.033506300300359726`, 
                    0.062079593539237976`, 0.05717689171433449, 
                    0.04760867729783058, 
                    0.07620187848806381, -0.009449600242078304, \
-0.014139373786747456`, -0.009086485020816326, -0.06992314010858536, 
                    0.02773500792682171, 
                    0.07260692119598389, -0.08474480360746384, \
-0.022487923502922058`, 
                    0.0005346673424355686, -0.06679049879312515, \
-0.07340740412473679, -0.08029824495315552, -0.08680955320596695, \
-0.0000553912395844236, -0.09901902079582214, -0.11632104963064194`, 
                    0.05641121789813042, 
                    0.003983454313129187, -0.004873910918831825, \
-0.10789409279823303`, -0.03668952360749245, 
                    0.09708604216575623, -0.06829724460840225, 
                    0.029046261683106422`, -0.07725325226783752, \
-0.08373431861400604, -0.002073919866234064, 
                    0.01334400661289692, -0.045501988381147385`, 
                    0.015610335394740105`, 0.045337118208408356`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwt13dYz9/7B/B2SSWj0qBBGlYyovfrvkWp7FQq2aQQRUUUbUJKSyrKqFQ0
yer9um9EfOw9MlKUlYjILD/f6/r9cc51nev8c65zzn1fj6fxkkBXXzkZGZlg
lX+T6+LQCUFBize6Kf1vsWzxqpHWq/63af3/w9FnKdi6TQajSQf46PJY/Dx1
AmScUqDLyy7TljJtelhRThP6HaZXZ16Qg04w9hq5C6pj5nN4QTi3qfXhxCk3
6PDO4Zil2Z2mBxmwgrYjNd1xpltJWUKtuTEv3GEiVVMxQlnj9yTrq8Tys1fj
e6VFHLWyN27JG4oFXfPYyGcuuQVYYkVpHMh7N4kbDmtT3/T7UHP8LpypHkh2
FqrY2m8qaztsFTq0jtEQw5v43mO7OMNMDh/3/i7cG6TLfTusUTn1Kt7ZqsBa
M8dBZPcSQetgOnXCD3qxMYjf/9Shl2NdxS2SAXim9yEYGSfD28M34vwWPcjx
qJPWDU4Bw5nNYqDKBUi+F04zGvujpZYTRW0hKGiJJhmtuegx7xobX/mLS1Qq
YMv+emjRGiWpvpsLNtbITzcWss+gc/Au8qTksz7gDcO55BtxBnr2i+Y15RHi
kWcrUTWghD1+pYOX8ijg654wuJc1f9NLBNdIR5ytfYxNhyoJYwJXUcfbchw+
Mg1C7H1g4ep2wcsjGOO03TC56xVR0zmSL8in0CXBnD7vt8QkaAO3pqTC/kNJ
MKbEgg0/DUfbuQ2SLUsuUsSCTLZ/VAabE+T5ooMiLw/5KO5b1wevqSZLXDKM
+HnlS4nSEE2+fV+H+9x/J35Y1CSJ/qLNPm+mCB0RQ/Cv9DD4JS0X1ilno8yT
4xy7yVccfX4id388CH9lZoNHz9OCuV8dRbVaiuczZTHSyJ9Kk9U5yGe9sDjH
hO/M0IcHb2JFN8cY1Ew9LKhUvRcnuz8AH7aCNP0D3O3SKX6eXgXpjcMxf+Bs
2uskK1Yn7KOYgJWcN3cvy47vxn5f2uBBngWZafXArx/qSXVEGlevTWCLWG1K
eJlAZWGvyaFwF+raOItN12T5/dvzMKvDl8806UvuxL8Tz5t+oUGBC1hvsDcU
7OnG8jPt+cGGVSw4bSG9xgbyH6CGCaNX0YiPc6Q2RmZc7huBDa+v0WUPG2oD
dVLWukpuDq5sYJ3Iyp2HBOvLZXhGkiLqvomC29VWbO2lyL0Wd4lT5+fDlzeu
bNfcCYOj51Q7v/pKp+us0NSup7BBOwhHqF0k58LL9N4xnsMS4knOVpcdra3Q
62S7kGVDYH6+ltr2GnNj2GKuPKgk1PhkY4f3MyF0aQ4sNHoO3UpYUG70pE0b
euHz+VnSkZOd0XT9VuiRGI1efWJw9PjuwpjpaWSe686pTkk0bEw4PM53hzCH
bth86g7F9FHi2AXO4vLMNJhcHINeN7Jp6U55WP7HlT6q+WN7jRHXvLwgJPQK
Yy2fQtoYdQuTj5WLLoN70FmDJlFuyBR+rHqdfFtDOSRoAlofOwnxu+sgrVc8
etd2QVXFJtFihBKKlxogwsYWQ2tc+FigH/vmxXO3kiIwksiL408J/OT3C8HG
vjdH3dAlGbUE6vxlB/H7+/KC5pkSVXEfW1gsY3OplsSsVh91cRIY1JKg8Bpw
VM8+0lSrNvFk322SjO27uXvAaagdnwpGIefFrebr4LdFKYRZHcQCuyz+ZRwM
Fu4LSS7okqDTrsFyckMxKHI9lamNQp/IDJauzeaMRBPO0XxOQ/EmOC7bRNU+
huh1Lhz/W/gelerXoUldDM+xrYSNv7tzD6l89aZL9fDBLpa6j74mfAwuoRmC
B26Zlyrpu+M3dPRZB8LWbvjKM5Z6GFZJpw+1w91f4oRGpQuwxi+VCn/so1c5
n+myTgPsaFbG08HaeP2INg5ynwJ6i2vgfWMzSaxF8i5cQ6uHbOXeU4bSy6Ea
dOXyBfKMNYX2GC/R2+KLhPPW0g7/Obx2xw/KLyGas/wIdRuThz8cuvHruAra
uXc5nhgZyXsjYkD3rR769PXg2ddlsM7+DjdNipYkzO2BA710Ucv8u9iQnACz
3OX5yT4D6K+pT4/rW6jWV4uPlavzXattPO2pEQxdvlKURg2lD6AvObxeFtP8
V7FFP0v0MS4FRaVyoUbzC0UNnYdyJiLpKh2jxDsHodmlxDbryD3x+Ig5dHei
JvYzHcZrHLeLkQ+HitLwF5CZYcJrJ/bCxfZO+LhYHTxlp+L3m/1ReYAiJru4
0Kyny6l1xlsqlBrhLFGJnxbVYhcnUpP1GP45/AYcDgvl+2G76YfPD1HZZgc/
rPOA0kZH3m0py5ZNp4UfTimUaPSfcGDNf2z/r49OuOKKLSV+qFrzR/iYMpXO
31dnk83zKE/ZiDcMVBG22nuic/NavCMXzaPXOaP67gYaOvgQzpgpIc/5Lqxw
ORG7K8+H6SYMmStaQFElhPyX3AZ1/RQOBjNQ6GvOia/VaWnoMZifm0bpTxbA
0utH2LB7ihjT+Fa4/XkIN0m604SHlvh0RzPFUB+ar2lJ0/8q85ykZhgb9xr2
PfwpZn6YzO/GttGDXCfRoF6ZHTxU+VQUk/viJMHdyEpsaiyGpzlz2CswBRvS
T1ExWHPNzWa4+V1NHDQzmu8Ez6PSey+E4cZlcHvGCWLFQWKtdw2MOn29uvRR
H/yQpiFA9xT0WHwUQkzKwc3Vjse9DGPd6H3QeDkJL6yYKk5fmIhYIMuVGybw
1LrBbBWbxOJaFdYpOUSbWovExpaZeMfGAOPeh0ONjQtXazsLKltHwNP45xR6
ygumKO9CMawXvrbxhF2bvoh2l514iksndcWegKpv2vTVr4gPKhqwX8gArh1Y
y/pLy3DqUAvqtr6MFselg6/SJnb5NYrF2nKQKozExrNN0L41DXes0eSsnBeU
eHQMfVx9Ej4m/xSft8nC7rwCac/1j6F5QHeO9HkKVyxy4bJCBMzanwhpXpVw
6EAdqaZlg8asjdBc3B2eRobyJp08CF2XLFxOyOehl7eA0vtB/ML+ENkMeCIc
Xx4Ou0r601gbT7r87S8ZdX8JL0yc0XPjFep5Yhbe3j2BMreZYpdqFB5JchYC
I5ka9wwBy1//3q41G+ryPGj8cl/hQNZUbmvJ5GzVFnH1GUOxp0yWUBSjjCsm
9KKh9l8Fgz2vIUvjOrUu+ueifs/Ix8iaLixUxRyZLbz4oxn3VikQXddPwOg/
r2GOfBFM0X9Eea2LMaE0iMsybwqFn7T4975kcs+TCs4jFEGn9Yo4JzeUyqMH
YH3OAZCVOQX7T72D/UoFTHumShpMzZDrvcUHZ6ayLm3lXj2nVKsVeGLut178
9oQK+zzshmGH54g7dy3Gwp/XoV9LsLCleofoV3AY+g3tw0+yY8Qx++R5bP/5
vHniQJw3WgW/X2kRxzUeE94FDcPPx1LhdEMBnEtfirPfmKOpRRVcS50Dk6xC
Jc1y2+gQ59IrjwyWuazMOU2msL2wQdzyeAJcyVjKZr/cYNyPADw8rYFWuS9B
0w9DBeO9M/n2JzM2qfZi+e8jIV7NFDdW6eG7lKXo93EIHLcq/Nejbot/vROF
jmv7ybnIBZtWGbKR/z68G/+bvHTD0bG6Qmw9MQRO1KjQj44gYfcSog93H4Hk
jDqOsErDqNwC6mkShUvklWFqa5WkfvMYBg2Bp9rEiRV1x0jdzZFWfqiGCg8J
uTUNAb/Wq+Dbdw+bXdiCVuWjYZIkVLSylodJI4dwuo4y2T72w8W1Ltxj6wB2
Tb4ASummvLDoAL2ynM/mfr4kfXaKrDJOwbvoKuh2bD6+UQ0TH/faAnpJZfyh
ewZd7dGbz+/ZxdlF/dFqbn9+1f0TjT8/GIPsZ4likRNP79gCu/MJrwqDuH+7
ESd7aMJJpQahQHsfzLvbATXuGjz8RhbbiGH0qcVd8nhcEmdWlsDLmRUQMNcJ
xbyZgtL5ekH4VCLtXBcG96+N4Y31uVSxIpYX1UaAgaw8FJSGcueDTfjCZRsU
uE7iBeed+IDOKj5Q5yAaXBHEkh82dOebBgerzuODdhWw9P5oGln6B/q8G8iu
i/yx1vIueO0dB5cydwmfNP3ZPnI4WoulePyLtlRLTwE96yzg8K2D4o83vbm5
ZyFBVxPFfrgBTwMNOdzvASXduSUEBB9B95y18EScw0OtevO5jgGYUzZWckpV
lj/5pWLD2b68qVWeWrP3YN1PGeqYqIcFw6zQYf0gNBxTJTxKUeQSvQiQ1VrM
D7ScMEBNQ9IXXkGRE8FEeUt01M7C6UPKhBS7eNrRIqGxgU9AxaRE2FrlRmd0
nou1kQE0Ny5OuL6uGqoGTqB7bVZ8eLU9F4cUwdEvU+CCvQK8tkWcX7Od4j3z
+EbcRXrr4YAKJw8Lw+qm0YGJSzjrn29PST3x+6De6DkiBf7T2oHHlC+SsnIK
b2m3pBjdVYJHKuBK47HcLfU12O9T5ZR1SnCn7D3JTc4jqw3XaOrKBtrs+JmS
x/vxo/NmrPvHiEZmn4ZZQ6ZT7x01wodlcfjqX52F6umibLUKzhu2g2pvKvO6
Yadh/FNN6n96A2vu18PGsHdCwOs0uDxHGaa9SRbcSg6OSyuV5c/V8eAZoADi
40kwTvsAe4dfEeUexHBcUB5VGsaJQ1RSceynIxJv+dUYpLeTXFa4U5lSFoV2
vgLTAd+kcQbrsUPHXzhssk+yLVRd7GPRRn2VA6Er0ph/jOtLByOHssSoWgj7
bclfY9fCy+HrsblBglC6ikMclmKOZiqsztLEq/vjBIfEDDZbcoMUrj6gerSh
US8KYKTxFNIoeUyzh6XzbKOBeKZxP7o5x3BP3RDKlgulGq/BvCPGnDPemHFb
pzHtavoFnlMM+EbwSwieJnN2V4Q8zdcbRbt/W8CF9lSSPl+DP+sM8HOxgPNh
L8ntjhZ47DqK+h7E3Wa+F/KU79Lh8E1nmibK87scVV4Xp8MLBrqBjP0VkLm0
nczyluF/5uZQsfsA/dZj8A69QgHnC3D9h2gaH31cqmIwi6O9ZaFYfS59TLRl
LLbkHepddGrwZAn9SufdMerseUmXH7YPhdyElZT53Rg930SSRg8zfLF7EuWb
ZtMXmzS4b30Haq4txylnBX7tXAbvVyty0DBnmmGXCZtK4zDDoJBm3ckHe7eH
9FH+inC087ogCUmBHvJSSdjOk6BTmgRDRvcU88e1wyhpkVj0ehMvuxAgGXfY
hKPOtJFRsB6H2aCksfoxjSheRFsUlUDb5Y+ga1zBL8PlhfPp38Dhn8vaNm6l
WsMU8inuLc719MGugcaUd6kba4Vo8nLzOahn9As2nBfx/vmftOV2NHUf60DF
Sc+EjxWWOHfJbyH9wEz+49CP26bv5rH1NVT83Z0mH09lI8MBvHdWmejXbAS+
2vFY01mKiWlGGPv6Fkhd0nHMqHLSvxyGiw2dYXlWD1yneAPGbXhIUwZ3x4Dp
hmj21xS+/o3mnOBSkK/0wZ2aGzDycwddK0yCwTeuwYG7kXg+VIYvvNJD05xu
MMQmClzemlJ+oKYYqD0c7PJHCb1e/QfTLy+jXu198NbzGyL2zBG9DM1o+ZMW
StWK5mMB6hQu/5+4T9MZbvou58h7mTArowPe/VCCaT+PknU3U4w4rga9C7Rp
/v1aydKvvujsqCO0ycqwx4p8qrdaC1Nfr+TNvxbiiKdS1HSXk+r00KGEA3vZ
bcFqfj5PDfNfV1Gq7Ud4PjWP3s70wP0be+Fb02ZQ+2esGrOlGP8gXgyLGoqK
pa9hRo4LLDU6hrNevKVDs+biTrUj0P/RQVK6vA1eBw4Sgs8vgx7bF3LHtSiq
3xBLfRPuQ0znD+pvXECezwaCzOkRnFTYB6N/RbPVCDfsHfEN+lvmwhK75n93
uZ13/fLnlpO3cNAeQ+Hm9VwKfNadxzwqQK/Rp1FliAqlqyuKTltms/ohNyzP
VuL74U9h3lgzlklXheC/rpQyxIXzf/SG7bF1sHaRJpm7jyBMPCTeCvPh5Hty
aPvRAb+/csQjyuqg4XucLXccBI8790lzwVFcF9efFur1E0oXn+AD94zZ+JkD
HlpzXAhr9P93Bkvy2JzCrzSOw777D8i00Rc+d1xnuy31ZOFQBe6qc/BLYwsF
67mi+NyPPqc+5JNfHEDRPRFeBnmwtdslWnvmqDDe/gdFVH4GhQEhEou7j2nJ
H0+SKTuFe5++FzPMcsSlhSWccKoczENS6VlyAU5eVw5vPMbxw7M2fGr3Y/Ho
q0pYM0uBj/qs5owSJXDuL8NPDRR51ao0EMZc4CWPx/OWs6Nh85V35KhnTua6
Bznn1hPymTCJS0LeilPqr8CVvGfQZFoGH//OgsG2I+ml0ybWXFYEF+WPQt/u
g4XSAdHwflsu2tePpJXuF3GSoT8tOp/Jp0Pl+apBDG8YXE+P2uKFMyv74I+6
LjAfnM3Pn68Wn92fJ/YIT4Vgy2C+ceMryDstptk5nVDTZkNNqx3oQIoR2AcW
gknvfDB8qIydNeOgpFIf/WRn8c2Ww9DzgLJQ6xKLCxbpc/0tM6wYsBcrnVbA
qQojKF45G2rOTaF3tW/I/VA3XmA5nHresafPc5aJQrYJOU8byKULLEDwThAu
rAIsfZqKtqHXaeGzBpx9UoczIxaKTRGBlJxvgC7P0sk4drzQOiieN2wq56qO
bZD3JwcKZwr0syGLS0cKXLEqj5apWeG3jYP5Uu096Hx5AeYu/ykURaTS6ub5
XP0vX3qcGUWyT+Lhr+tyyHi5k365GgvjT49A83M10BlzEZLGTUL/UgPW2n+J
lGtU8PSbIng9IFvw7SzmFrnFeMtuENq8VkKFe7rjGvYPBFtvOzQoisUy36M4
fOxTcdhTPfLevJp3DFqGF+YsgzsxQWjCsqxhrYFyTt24+qorf2p9IZ2w7hes
nPdD2r7UDQfJ52DYHQOIm2dKaRYLsPKeC5Z/csDq3Emi5edcbj6hwSbfC+nF
6ADMnZyBT71UuVorQxi/J51K6tLFsx153HDRnyz2O0PyzuHk6DoDM85V8skn
OdDi/M/OkUWwuHMHGqz9RF0HWmF4li5KPc7SxaVq+N7jI0S7xUuDbrZRd+lq
tB9VImTvkYE+4wIhLj1S3Lw+BNUXPBLXnKkhs5bJ7Kq2Q3J+WgNEbtKHSfvV
uX96Ih16HUP9Jj2uVn0xG2Vjqii0KhDG7orFn+HqyHhA3PogmYsOKPHt+hbY
4o44fP9ZKDgWzz2O7sGoyQ/J7GgvlHt9jQZ1jZac+s+Mi4yz2KN1F6f+AfHR
wQQ+kx1HG3bbwGHTEF58/AboRkWQ7lozXn9xOE9fUUkVa3aQZ/tENLktkIml
Cwfs3EuBHqa03WEDJJyZKxhekooN/s5w+HEwL+6YBDftvWi37ATw6KdAs94v
4s4NpcLH7GeskbwFf2w15fx3ozC7fzKMbroqCfiiREZuB+BkSQsNqt4lzCsr
gNUrzNHqgwvdPpgKaX+aIPCfk9o99dB+11b4Kr+KhvZ8WK3tTeJlq7M006+Y
7dwqqb3lCdx3fwy/V6RipLa/OH78KbFklRxcGhDIWSYGqPVmIMQvAJx3xBJ0
m5/Ru3vlmH5woe3xVzvRtWMtdWxpqC6erI+RV604q0EOyn22ixLns2DbfyMc
9BuKGRt0xBfFA1ijz3XxSudX0Orsx78qx2Fq2U4Ykf+fqP8jCiorK6nj0lp8
5BhDtmXtFBx5Bq50hMDLqtXQ3W4sLI5dhpuXPYKqjXfB8/gJidJvqRjSsx72
pulQ16J+fHDdVuYQf7qs4Y0BGo30X8B8dFq2UligJNLo2QPQfHY5Ne3ZibU9
Q/C0pjZMWKKHn4RDQnq1LPad+w1OeyaSm8FTsC53gg+XB9LWCVrQz41EhW8j
+BRowO4/67DVx5rNklPIIXYbekzOpc1TGoUJ179A5+Y0+J7VTjunq3NJzUqJ
gZMSvDkylY5P1uLJmQLa/fuvv4eIkPv8DBjgWj44IpwrgpLwxSANULWQkOns
bbQxXA+rZtTCCX8zYd/XOPBI+0DrTIgMin9IAiqGUEWFBvb4lIrPimT596J1
4lIna97/4xCsOB4rJosq0lthT6lmyF5o1ZgH3Sum08rIY+L+OgU8smGj6OrT
ExQ0DHl69Ef6PXEuWtW2wcRh7rQy3ZQmyc8ijtLlZS390bDqA81U7ItT8o6K
858pc8hBZdK9lQZO4f/RQO9SsSu3L41vNKQ1Z/dA84JfMMXqjGTf5qOs04W8
57kBmZ92xdFtXqg6Ww8/T78lzXQ2JMMBn6l59DHqunUEXsRboKdaO0y9GQZq
jRPx/MgbZPmpkub5K8LK79tIe901Ki3bTXN6RXHcn7t0fdpVqIlSoaafZdw2
8zI05Lwgl9VGfOyGIb2O2Co2xoTguMcLaPfUEC77EyDoy32GgNEB4KhuwM+u
bRe8tDLFO9+DaMXLnvQjQYWjJ01HcZQSF+xdKbqmPATZu3dp5c7FcP+QiVBk
NIVe/SfP93xTqXyZIaf93nbm5JcTVL/ul3TzzES2uzQQRz8+hjaZq3meVQL0
vhsL3fs+ojcru0Fx5F9hnV2q9EPtX1r67S281z5FZ1vaQC92FF57rAmN/Y2w
XtKDbPqf4tU6d8kpMxtMZ3bRnf7/bKHzCF7oVtG2VVEs+2aZba8q7+ryk8uF
U9lt5OaTA5OLd/H0L324cspf+nojgMeskOU+AZfJqkUH/Q4lccX+J7YDXxvx
UxcpHnwZyirnPomvIwRu/TITY0vq6O6SDLjbuoi6ZpUJrz4OB6eTrVBfk0JH
5j+FDdVZomZgOuxb8S8/FvbCeXcrYbbVH9j2YRAaqXnx/G368P3FWHz+rj8o
BomU/oPI+4E97z05FlM3uOHu2IvSzon/ST5G7KFjcxNJkp0mth49AX3NFUit
/93q360+tPWJDbU/HIiDvs4WF/pqwwvJTLYcHSVMk7kjenzvg+2X20nG/pkY
Y1ZK/jIHaGVnLK/wlcVLLx6RntFWiYN7BnYJm3C/5Sj0q/vnZOljqhpfxQ+S
l/Dx3qkwyqY7fdneg53kRnGjaxRkNewX5JbIwyCnNIx/n8JXv0bxhyfqfFEz
X7jjpA9etzJYKVzxbP17Bc5VPwKPpNpcczsc7Ev68KDNJfj3hKpYNWsHDD1c
g5eOXKSAMn++NOOccE9pGqp4lkPHzyVUXTdYdHpiwjuLYsAsdwxb7x3PcvnB
MMfYBuObpVQVOwN6ft8H/rcU0DBwDtD749TkYIxLOt9U30zTwJtmdnzbcht8
0YyGcSn9sMQ7mXwWAa2xTGdVX2Wccc6Ol9/15XWvIsg1c4/tt7xi8vPohvLZ
E7k29ATkTQ4ivfmn4M17Q8rp5YXBisHQd0cbzNnfl00WyOPChEohfP8tiHit
xxum2rFosEr6VyMRvsfa4BS7b+RMG7DjZiFmu2TB7II69lZYytu65YOKtRMv
vizLys8dOHfDNva/4Mjzk+Vg7XUT/jw0Did4mvGa4J3iy8Ywmnj2n4n1hvIn
Cw1svFUF/Q8HY9DElYK662YOdjDglUXFZO80HHK7JlL9RQmeNswE23nOOHjj
FvyyVxtqQyZjx8shHPdqGP8sc6C7O4k1g12wpHQePLsSjefXKtG6zTMp4akC
XZofwB+PniCV5j7c5HWAewaF8q+TxjBtqS1sH/MvJ9sqYteNP1xo2AlCZgis
H/tX/Om1XVTQysek9bIQN6AvanaNAv/aQeTp4wWHpw9jr5WKbDHQkba59ubn
b7TAWmco3l07hxf5vxNula/m8Rf7sFuzEWqvWgN+GhUw2uUqWS34Lh0+JBr1
TmzmrpuZpHNvD71MUeXi/kUS75p0PNgxGzv3prDTj0vw2tgS34SoYuEwGTit
aMZ6F6az0uM60j36RmgvmsW1JeUw8cFVyeGhr8WGI3rgfduD39pXYd8gJ6Gw
Z7WQXzKI01Qi+QGH8qTZ2uhyAriK1PlG7+fill6p4PdzGiekjUHbMC3QaMih
5a0O/DnUjKbHqtNMOTXkskPiy+UJOP3OGG6VK5P0WXiVwl94CIF75ahqSge1
5+0UhGvHySJUA+9XgDCjzhRWVIXw283faFuOLwkrfcVxmjvpzfYoPOv+EkpL
n9CgderiEc8TUKCVQIPHL+WvH26QQqoSn7jSTi90mqRtX99Cbizwkxx1jt3Z
RSMdVPBYxECodHwtjLlmwjg7DqdVWuE0AxdKKnSAA+1WnGp8jfQ1LPCddCnT
0v48eOVEGnvaThyRUS/EO+6DCflXRGnbWHDW+SOk5DZBj675KHdtvhjpL4sn
e+yigRe/Ck+PBQtrG2WhbL0yq1lOhPft7bQ5ejhReMq4lBkurH08CTullXQr
KpHU9Co5+UIvPP7oMhh2y4ZLtzOkKvoH2ebrF4pUH45Q0Y0n2q9GXw17cWWZ
NQ6riaZBvxuhOOOo+OxqLNG85dI1czTBcGAjbbu4T1g40Ymcrf2EqN9TOFg7
EjI0h7H51Sp4p11MhYt/CtmF+RR1SQ3ixpvw6QUL4Pi5ueLReYrsvmkF6t7U
4NFqXymwTJNOFi3hqMtOWH8sEeri56CljhY3RydT1HV5TCivAJ0z9cKHBaoc
6LKeN9luhBebIihL/zY0bL4CQff1oev6E4qza4Hrwm4MPPQWPtTVifrKj2im
42b0VNXEXFOmXqe3gsKii5IzkwejR/4y0nDyh0kps4V7RXI4UesgBeclnplu
dgn35YdA/vyntDsoSTzdxvR5RhHOGCOLTYcvYOuQdPr+sackVNaIS9fF0ZCK
SDYV9XCMTDnIOU7l6J7q2DqvBk5vTsYdbSbY7fsNUJlgytm/b0qXHm+DS+fk
uMFzHqtbasPW23vh79ZrQmLTedjTcZDHTH4FmjNbxMSp5jyxJZbyzwvsKBZw
yiUteJYyEK88OYRBLjPQ/Vd69eHRrXRPf5FwSrmc3G6a4/gPwWjtpg11DlvE
/JT/KPPTDt56YiEXRJni+McS9k0Phy3syPbaW0jzuT/rf68l/8f9cWKRKZz0
miWeqDRF7z0+YpTuavFLQ4DwZYAj1xy9RIlxqrRvriw8+5ULBXEOwollHfTH
8RhM+toDJYtdWSnQFj77Z4kP006D3DQV9Dd9STAymDdbxMEiTTXU/qKBVWvG
8aNDsqjdRxV9/Noon3aTrqoR6Pedjt3VAjHgyFTu+rMQP/vF0/A7R6DnnVCU
/+VHSWYJ0GlTJuUDU1g7bDue1JgCDWO9oX/WHihvDcRFiU6i5K4GmSg8EORl
lEQ9F3V233wfBumPERNDjFnNPAhs2k3YNGQ4Vg/JgbQaLZ41uRw+9pwm+q/K
AZ9ztoL6kuFo3vpDNEzoh2sfCBh/y5j7e8TAwt4GbIv9hO3P94uLn0yH6Ptb
hTfaslwp3oR7juaYVCPiqgWxcMKPxdqQNNa7poU2Dv9B8rt30Hxvv/ji0i5x
QqGtdGGxAQTs/OebpGHYq9cuOOcQD48muvI+/Sxho+I3kI1VBH9XI/pdoCP0
iVSgD33vCOPCLsAhcQlXjDDHM60W2JbXDAmBilhYnMhnvJXB72MrnZ7WD8KT
dWjTkZPw+9l83mG9ByJOdsH6CUmQ9CRB6haaDku+fwK92gkYnvecpZ+8eMVk
IjIX6WxxJCkd/UoBt3I5fFMSTvy0FnueHoIXtXRwbe9i6czaAjHcWw0nbp0J
7aO/wT67KdTjqz9HhOujtks1WAfehnc6Eyj+633YLb8Yg21WwyrFRTh0y1Dp
Qe838FstE5+27hDkJdG0pH0cdhPc8b63CpYG7hZudzuHqxIcqGX6B7j03Fks
f7lDMHunhB9alNiwPEG49b4Znm88IS3/UQj39lZQ7itLGPnHltZOzBWK3lqC
d9wlMpgTIoab3obyWRaCUbo9pEU707d4pDcNjyTaUSni0/G2aLi1DtbWfQbj
Wi3OcsmD5cF5Ehc9Y0zPVMCj2/+AwZIoCvn67ozd0lhsfhGJdTGxPMd6jzi6
bhIZ3OmigyVMPpPs+HL9bJDaB1H3jlEQ9mcvmJW+pEptdXA94MvOiUu4NtWR
1+pnUY8Afx5vGsvZG7y5fWMf7Cr7Cz/lI7g6v4TGK+pD88IV/OVtmhgRncrR
D2ai74M6us7V5Htsx7/6PEljf87GuIK5vPJdl2j8eSw4tb9CyZWe5JN8lY5I
1tP6NwPRfL07TT8/mx32BdCv4x/FRb+rJUqrYqTTbezxy54EQQ7ycPLbv2TZ
QxuLT89nFX0ZzNEww5epLtjwOQcG5zoI6Vo7cAxI4ar6fHg5P5/ql+tyRkqj
SJUjBY8/RXBcpQ8mjY5meYVd/CypQ0watVXQS88Q/A0J9p1YQS/tMzFmtSGu
OPufGN/pKAmoV8MIi1fC0sI1bL5tN/QZNpBnXjPj7BkPBcU7a+j4jXralz9Z
LEwfjY/cxlDluD9w88pENo/QxslL7XHWqQBQ7z4Eeiasxwl5wUwRTUJM5y8I
H6iD7m45gu79u5T88RafdZ2Ondl2uKvVj8esnMSRhX3Qd0oMnchuoSN552GI
fwrY/Jkr3e3xiIoXvRIMto2k8YlaSGGDMG+XN8rfukP/B0w+9vY=
                    "], "Biases" -> 
                    RawArray["Real32",{0.05713987722992897, 
                    0.007160727400332689, -0.06549590826034546, \
-0.011695710942149162`, 
                    0.045251715928316116`, -0.03446283936500549, \
-0.021528685465455055`, -0.03948695585131645, 0.09480579197406769, 
                    0.09795712679624557, 
                    0.012807822786271572`, -0.08425548672676086, \
-0.09671558439731598, 
                    0.022512590512633324`, -0.00023247592616826296`, \
-0.015886623412370682`, -0.00047507122508250177`, 0.034599754959344864`, 
                    0.0012906704796478152`, -0.0168132446706295, \
-0.05318213626742363, -0.0032656334806233644`, -0.0717267096042633, \
-0.18032275140285492`, -0.030703162774443626`, -0.055394768714904785`, \
-0.08505198359489441, -0.044088102877140045`, -0.01368147786706686, \
-0.01527318637818098, 0.006027206312865019, -0.04849513620138168, 
                    0.0009236789774149656, -0.049826353788375854`, \
-0.029756665229797363`, -0.04494065046310425, 
                    0.0035168395843356848`, -0.053916264325380325`, \
-0.031223975121974945`, -0.029478179290890694`, -0.006408130284398794, 
                    0.010198202915489674`, -0.0748128890991211, 
                    0.008994514122605324, -0.03350634500384331, \
-0.014217984862625599`, -0.08395683765411377, 
                    0.018368199467658997`, -0.036334410309791565`, \
-0.0636354312300682}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dUz+/7x5OmdpEy0lAKDVGq9+u6NAiRtKRIhOgjyUoZRVRSUZpESkZD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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.04013016074895859, -0.04581547528505325, \
-0.046757809817790985`, -0.04847332462668419, -0.053572848439216614`, \
-0.009910729713737965, -0.04915214329957962, 0.002295419806614518, 
                    0.08039984852075577, -0.021025236696004868`, \
-0.009394202381372452, 0.0032108179293572903`, -0.03892610967159271, 
                    0.054114170372486115`, -0.009018711745738983, 
                    0.07431171089410782, 
                    0.0035359743051230907`, -0.03519749641418457, 
                    0.022487765178084373`, -0.004195836838334799, 
                    0.020694203674793243`, 
                    0.019966833293437958`, -0.054933302104473114`, \
-0.045894987881183624`, -0.024775845929980278`, 0.015629272907972336`, 
                    0.041594140231609344`, 
                    0.0010542996460571885`, -0.05538778752088547, \
-0.0056127565912902355`, 0.013893462717533112`, -0.003796621225774288, 
                    0.04346667602658272, -0.02372543141245842, 
                    0.016184989362955093`, -0.043536052107810974`, 
                    0.0010338409338146448`, -0.01635744608938694, \
-0.03787531703710556, -0.03711977228522301, 
                    0.07025685906410217, -0.04612201452255249, \
-0.04001905769109726, 0.03382868319749832, 0.057203684002161026`, 
                    0.030855262652039528`, 
                    0.0010028800461441278`, -0.07375457882881165, \
-0.054815616458654404`, -0.04718495532870293}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray[
                    "Real32",{{-0.13054196536540985`, -0.0021828478202223778`,
                     0.04420134797692299, 0.11376725137233734`, 
                    0.032295111566782, 0.061380188912153244`, 
                    0.2372267097234726, -0.037890203297138214`, \
-0.025989310815930367`, 0.06889494508504868, 
                    0.002308262512087822, -0.09366293996572495, 
                    0.17135971784591675`, -0.05997880548238754, \
-0.05880345031619072, -0.11908342689275742`, -0.20970876514911652`, 
                    0.05971313267946243, -0.14404802024364471`, \
-0.12020713090896606`, -0.10617309808731079`, -0.09520994126796722, 
                    0.03861357271671295, 0.09174890071153641, 
                    0.18056394159793854`, -0.18952184915542603`, \
-0.1274263709783554, -0.29350951313972473`, 0.041032012552022934`, 
                    0.1315816193819046, -0.07438205182552338, 
                    0.03236746788024902, -0.3187474012374878, 
                    0.07899439334869385, 0.04244326427578926, 
                    0.031589075922966, -0.04654191806912422, 
                    0.0006104953354224563, 0.08882920444011688, 
                    0.04434530809521675, -0.10327748954296112`, 
                    0.053271692246198654`, 0.04945158213376999, 
                    0.2033531367778778, -0.03104333207011223, \
-0.17623449862003326`, 0.09693078696727753, 0.07086125761270523, 
                    0.10812433063983917`, 0.15466001629829407`}}], "Biases" -> 
                    RawArray["Real32",{-0.03100804053246975}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.6803402304649353}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.343203, "MeanInputsPerSecond" -> 
          47911.33707628177], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.03167329679222021, 
                0.007660418371645697, -0.010431722990510858`, \
-0.014798685046635706`, 0.028859016718078646`}, 
               "StandardDeviation" -> {1.0270405217921146`, 1.013218957068351,
                 0.9901133077208596, 0.9988340446401656, 0.9925079998028361}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 5688579868242986017]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[364241], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.27246337446631885`, "PreprocessingTime" -> 
        0.3751629`7.02576487778208, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.40293510460632553`, 0.17347459341182292`], 
           "StandardDeviation" -> 
           Around[0.3606025994867405, 0.0772462245795577], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 107736, 
           "ModelUtility" -> 0.2848469126268236, "TrainingSize" -> 252, 
           "TrainingTime" -> 5.011872336272724, "TrainingMemory" -> 522648, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.40293510460632553`, 0.12266506136507917`]}, 
           "StandardDeviationHistory" -> {
             Around[0.3606025994867405, 0.05462132922126421]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 267542315036241]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.988644305663453, 0.6281500291328417], 
                "StandardDeviation" -> 
                Around[0.765010505936131, 0.04310388068390871], 
                "EvaluationTime" -> 0.00011984538276992662`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.4365193417886072, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                424800, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.988644305663453, 0.44416914520235967`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.765010505936131, 0.030479046327047687`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[2.3673088305361873`, 0.4001084832916414], 
                "StandardDeviation" -> 
                Around[0.48492195232158686`, 0.03194119718132373], 
                "EvaluationTime" -> 0.00014857252870619073`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.01750032638942156, "TrainingSize" -> 50, "TrainingTime" -> 
                0.31622776601683794`, "TrainingMemory" -> 429016, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.3673088305361873`, 0.28291942174578405`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.48492195232158686`, 0.022585837126130645`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5108128992349813, 0.18829875140308192`], 
                "StandardDeviation" -> 
                Around[0.3963451031901336, 0.09182687763036249], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 0.1869951245609024, 
                "TrainingSize" -> 252, "TrainingTime" -> 0.7943282347242815, 
                "TrainingMemory" -> 451608, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.5108128992349813, 0.13314732400607915`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3963451031901336, 0.0649314078676166]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.3963451031901336, 0.09182687763036249], 
               "TrainingMemory" -> 451608, "TrainingTime" -> 
               1.391017463958849], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.9937673823619184`, 0.3585720129609058], 
                "StandardDeviation" -> 
                Around[0.6597602047785934, 0.0443254138270838], 
                "EvaluationTime" -> 0.00012461454850499739`, "TestSize" -> 
                305, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.2906495902452808, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495456, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.9937673823619184`, 0.2535487019083671]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6597602047785934, 0.03134280069603091]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[8.708589978992993, 1.617065530664767], 
                "StandardDeviation" -> 
                Around[0.5269144331726718, 0.04248532685442225], 
                "EvaluationTime" -> 0.0001196145805631029, "TestSize" -> 265, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.06846139774443649, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499616, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[8.708589978992993, 1.1434380023560797`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5269144331726718, 0.030041662719688906`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.40293510460632553`, 0.17347459341182292`], 
                "StandardDeviation" -> 
                Around[0.3606025994867405, 0.0772462245795577], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 0.2848469126268236,
                 "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
                "TrainingMemory" -> 522648, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.40293510460632553`, 0.12266506136507917`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3606025994867405, 0.05462132922126421]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.3606025994867405, 0.0772462245795577], 
               "TrainingMemory" -> 522648, "TrainingTime" -> 
               7.849733612802018], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[6.9961194625762, 1.1007331137033773`], 
                "StandardDeviation" -> 
                Around[0.5061339343550566, 0.03424432019077176], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.025666297115255143`, "TrainingSize" -> 
                50, "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                428688, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[6.9961194625762, 0.7783358489762411]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5061339343550566, 0.02421439102401812]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00014229478653976401`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.5061339343550566, 0.03424432019077176], 
               "TrainingMemory" -> 428688, "TrainingTime" -> 
               6.577306748713622], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 267538020068945]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 8.7055371900826`3.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.809757009013184`17.333472265882804*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 2.6254485787568504`, 
            "ElapsedTimes" -> 2.2928683000000003`, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 4.375747631261418, 
            "ElapsedTimes" -> 3.8676477, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 7.292912718769028, 
            "ElapsedTimes" -> 6.7269997, "ExperimentCounts" -> 2]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 267550904970833]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{
              4.0761771390251065`, -2.9054512418166403`, -1.8868765186398941`,
               0., 3.912023005428146}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 13.6156631, 
        "MaxTrainingMemory" -> 955936, "DataMemory" -> 75768, 
        "FunctionMemory" -> 263384, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 50, 9.0560682`8.709514649080512}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {-0.2332265104045125, 0.08725459238388025, 
                    0.31805830879171776`, 0.5015873015873016, 
                    3.913754688324012}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.2332265104045125, 0.08725459238388025, 
                    0.31805830879171776`, 0.5015873015873016, 
                    3.913754688324012}, 
                    "StandardDeviation" -> {7.422086073467229, 
                    4.395205000371473, 4.3545061271762835`, 
                    0.4999974804673229, 1.3194541563980298`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{0.37888186121130835`, 0.7496723655139507, 
                    0.15083077518513308`, -0.0449012005386942, 
                    0.5193012989363768}, {0.4634156385650303, 
                    0.0552270969256847, -0.47067259816936907`, \
-0.6677097440088179, -0.33886120578594037`}, {0.5674786074692866, 
                    0.015648865375850852`, 0.5153940439334291, 
                    0.3155504314442307, -0.5590349253584023}, \
{-0.44356713565360534`, 0.6543714357768161, -0.22695780204911611`, 
                    0.18007387267843245`, -0.539545898580529}, \
{-0.35058623391570287`, 0.08058814554086322, 
                    0.6622510990225144, -0.6481889427781183, \
-0.10894686636496392`}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.2332265104045125, 0.08725459238388025, 
                    0.31805830879171776`, 0.5015873015873016, 
                    3.913754688324012}, 
                    "StandardDeviation" -> {7.422086073467229, 
                    4.395205000371473, 4.3545061271762835`, 
                    0.4999974804673229, 1.3194541563980298`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0145756, "MaxTrainingMemory" -> 93112, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 50, 9.0859881`8.710947128291792}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.2332265104045125, 0.08725459238388025, 
                0.31805830879171776`, 0.5015873015873016, 3.913754688324012}, 
               "StandardDeviation" -> {7.422086073467229, 4.395205000371473, 
                4.3545061271762835`, 0.4999974804673229, 1.3194541563980298`},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.4266106086398995`}, 
               "StandardDeviation" -> {0.6931537913438393}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.4266106086398995` + 
         0.6931537913438393 #& ), 
        "ProcessorFunction" -> (3.50082570267033 + 1.4426812815396541` #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-2.9281655390882064`, 2.5807982153299536`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX0w23ccgFOXrNRLKW5ra9N4Ker1gl4z+X2+igumrMRLuq7TlODIjcZM
/DNv89Yqk2PaocOyjnamGrrS/D7fKsYM7dTNmNjc0Dul1xU7zsr0j+e5e+7h
X0iPSjLgcDiZhruKkmWfVCplOZI3XodcpvAWKF5PwS68XfRlv+OZEj7ouEMw
Oc/qGuaE8PjMJOT+5UxFC4U0XDyFb2r2EHWqHuduZdHjRRNgl56D4ZH2JOwd
OWniNUPyzCbEPDIGzocUuTCE7t5l0BJ0Ed2WDMk1+cdko+wR9N37HtmhWZD6
/IprF0aZZ3kWzFLFuE4bdwdd/CtR52JExOtL4Hk9jQjfN4euX4zJlUM+1Mm/
Da52K+FpyV5av1WEL6tE1EN5E1yH29DG0pg6PW8CZfkUJHJDURBTjY2aSeSe
4tISsUaUn+oFDasaMi2cRlk/gu/KMZo1exutNz4HnlMMyVrfYDzHD9I7CcUw
53iPtXv1GfY5lOpalT3w8LAjKXyqEvUEbzCTLRpIiy3QhanPUQuXaXjimScK
KCmAnsVA3JR14FlrDmoqToJHeB0rcL2B1gcqyN6st3HwIzUaF/wIfvvdabhV
JGlRnIeyHE8aPeqIWq0Ic81rSOlwKvFoV5NnzW9BVqceQyYqIWXAhO6rlZDW
9n6MCP5ZdL0mjaxAKBxZNiBJ8RLmnFAFGdpY6njQCjL5ebQ8o4qpF8hIW2sz
pEe7MTc3WjBEJEWvCXuQxKpxz/xDPHVeA6e/CieP9WuQXTuFmrReNAkSYaJq
FD2KjFE8UAOTKduMW+5vrJ27CzC8aSyI7UJB8X285D+CA429bMl3H8AIx4Ax
SucTy5YFJiaORy4G2tNB9QJTV2lOepWfUFVMCv7QPK4r2rIiq2ZLePc/F8r/
yYy063wIVzMIvdxLuJP2Ar/J72FzAvRwtOlPED4/QXwNclhTI43O1D6BBlgX
kgZnGyrzk7K434F8zbEly7xqyC3LxpA/JDCbOgwPNhch0ZmH3X8fpq2lxvBq
ZgPCFSbUNGCU2de/w3Rbu4smX8yzYVqKgtC7mLmGePyfSCDLfije1mLRfQvI
6DCBb088AI63mmkrZsFJzIEbChmNjKggtmMZuqCzOxjtr4LLtTb00zEp2Txq
gds+geR0vQO5LBSQFZt4cK56iTKLDMj2MiQRI6vwZIKQQ/ah7NaXFaKdDkPq
NRyJjfG3sO5fPb7XNswIO23J2AFn4rrqSImpHouTPaGzMYkJjmwHUu6GyUcq
SKNiFILliyi/HceooqpB0hwKZk1iIuyzZK96SalhgjlTTQPoo6YivOZkRvLy
ueC7akPe5dTC4mIXLkr72XzlFzATX8Acc5TTIP468z8xo95e
                    "], "Biases" -> 
                    RawArray["Real32",{0.04801580682396889, 
                    0.022682474926114082`, -0.10096153616905212`, \
-0.0032632537186145782`, -0.0939515233039856, -0.010531008243560791`, 
                    0.01670827902853489, 0.04046220704913139, 
                    0.01937839575111866, 
                    0.007229277398437262, -0.005012100096791983, \
-0.02804054506123066, -0.0866241455078125, -0.009310884401202202, \
-0.03179842606186867, 0.05210532248020172, 0.043261025100946426`, 
                    0.02488553524017334, -0.01741417497396469, \
-0.09002988785505295, -0.01534702442586422, -0.005653287284076214, \
-0.044047173112630844`, -0.03393067046999931, -0.06222767382860184, \
-0.04043674096465111, -0.1264464110136032, -0.022968878969550133`, 
                    0.005642972886562347, 
                    0.029332399368286133`, -0.02608303353190422, 
                    0.013989191502332687`, 0.1014075055718422, 
                    0.00229254481382668, 0.02725834771990776, 
                    0.026118764653801918`, 
                    0.08391261845827103, -0.017015641555190086`, \
-0.03173992782831192, -0.00479164021089673, -0.019978683441877365`, 
                    0.048091206699609756`, -0.04087575525045395, \
-0.016233589500188828`, -0.08851097524166107, 0.037421904504299164`, 
                    0.06057053804397583, 
                    0.026817435398697853`, -0.003973234910517931, 
                    0.040991369634866714`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c014/3x1GUbFFomKFECMn7dW9EQ2kn2VQU2lqkspXMtBSiIak0qbxf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                    "], "Biases" -> 
                    RawArray["Real32",{0.05015435442328453, 
                    0.08849678188562393, -0.04404490441083908, \
-0.009946133010089397, -0.0020284918136894703`, 
                    0.0027345987036824226`, -0.03480668365955353, \
-0.046201933175325394`, 0.014004131779074669`, 
                    0.006644559092819691, -0.01960138976573944, 
                    0.05694969370961189, 
                    0.003890883643180132, -0.011220404878258705`, 
                    0.06845938414335251, 
                    0.03808150067925453, -0.022321850061416626`, \
-0.02851131744682789, 0.08903801441192627, -0.01552007906138897, 
                    0.09694285690784454, 0.013189900666475296`, 
                    0.007242470979690552, -0.0005091545172035694, 
                    0.03621450066566467, 0.007746819406747818, 
                    0.010559449903666973`, -0.008019911125302315, 
                    0.039238978177309036`, 0.012659620493650436`, 
                    0.01858660951256752, 0.04061436653137207, 
                    0.03492236137390137, -0.012889250181615353`, \
-0.019227521494030952`, 0.005748116876929998, 0.03747696802020073, 
                    0.007314437534660101, 0.06104820966720581, 
                    0.007274916861206293, 0.05978928506374359, 
                    0.010272779501974583`, -0.027732301503419876`, 
                    0.01709066703915596, 0.014833655208349228`, 
                    0.007416182663291693, 
                    0.03946274146437645, -0.02783740684390068, \
-0.024149782955646515`, 0.035235632210969925`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUj+/XxUsaNFARShkalKSBEn3vcxQVGTJExqIkMpSQOc1JSRqIBspU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                    "], "Biases" -> 
                    RawArray["Real32",{-0.08563092350959778, 
                    0.02735513262450695, 
                    0.0010254258522763848`, -0.04893248900771141, \
-0.0018923087045550346`, 0.042206648737192154`, 
                    0.03640419617295265, -0.01711144670844078, 
                    0.042956169694662094`, -0.009128632955253124, \
-0.010351172648370266`, 0.04582417011260986, -0.007814878597855568, 
                    0.02558179199695587, -0.053757209330797195`, \
-0.007735958322882652, 0.0050694881938397884`, 
                    0.02223183400928974, -0.018967676907777786`, 
                    0.018454866483807564`, 0.027361257001757622`, 
                    0.04581091180443764, 
                    0.03337796404957771, -0.011236671358346939`, 
                    0.008791928179562092, 
                    0.01705450937151909, -0.031619030982255936`, \
-0.06669393926858902, 0.024233918637037277`, 0.015261692926287651`, 
                    0.027423502877354622`, 
                    0.013994831591844559`, -0.03161038085818291, \
-0.004866786766797304, -0.004522041417658329, 0.09314759820699692, 
                    0.008933737874031067, 
                    
                    0.0015823612920939922`, -0.011763115413486958`, \
-0.021899696439504623`, -0.013034677132964134`, 
                    0.0007367389043793082, -0.025896240025758743`, \
-0.12081731855869293`, 0.10223319381475449`, 
                    0.01858196221292019, -0.037825848907232285`, \
-0.03989238664507866, -0.06582335382699966, -0.034354206174612045`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtV2lUj43TTtoVWpVsIbJmSdTvnlEqUfasLdZKlkIl9CTai4p2Cu0lSaul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                    "], "Biases" -> 
                    RawArray["Real32",{0.007438485510647297, 
                    0.02318739704787731, 0.03347255662083626, 
                    0.04010973125696182, -0.0003799761179834604, \
-0.0019300857093185186`, -0.013401275500655174`, -0.027148498222231865`, \
-0.026995452120900154`, 0.010063381865620613`, 
                    0.0026860241778194904`, -0.015639718621969223`, \
-0.02784062549471855, -0.06012953817844391, -0.039531584829092026`, 
                    0.049911390990018845`, 
                    0.03293078392744064, -0.012048359960317612`, \
-0.06351722031831741, -0.011151154525578022`, 0.03935606777667999, 
                    0.03988049924373627, 0.0010162213584408164`, 
                    0.0417567603290081, 
                    0.05600978434085846, -0.017622580751776695`, 
                    0.020563099533319473`, 0.03522488847374916, 
                    0.015576045960187912`, -0.021863307803869247`, \
-0.08397458493709564, -0.01947733759880066, -0.014857742004096508`, 
                    0.022514162585139275`, -0.014134530909359455`, \
-0.021295323967933655`, 0.003970150835812092, 0.03564707189798355, 
                    0.027124103158712387`, 
                    0.008956707082688808, -0.019483275711536407`, 
                    0.0011138019617646933`, 0.024929629638791084`, 
                    0.02349199540913105, -0.0034428052604198456`, \
-0.06734935194253922, 0.020274756476283073`, 0.023356309160590172`, 
                    0.0020782656501978636`, 0.014117669314146042`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{-0.10449700802564621`, 
                    0.1234944760799408, -0.10835301876068115`, \
-0.028829796239733696`, 
                    0.18627505004405975`, -0.011182717978954315`, \
-0.3481675982475281, -0.10159101337194443`, 0.1261906623840332, 
                    0.09643779695034027, -0.12417621910572052`, \
-0.29026737809181213`, -0.17817281186580658`, 
                    0.18537718057632446`, -0.17369820177555084`, 
                    0.09745791554450989, 
                    0.3259640634059906, -0.1305847316980362, \
-0.043972503393888474`, 0.20577800273895264`, 0.24256134033203125`, 
                    0.054326798766851425`, 0.14836528897285461`, 
                    0.10502161830663681`, -0.10794548690319061`, 
                    0.06610976159572601, -0.1972714364528656, 
                    0.2286006361246109, -0.20103499293327332`, \
-0.23512303829193115`, -0.11924652755260468`, -0.2247687727212906, \
-0.23012834787368774`, 
                    0.0902547836303711, -0.20623637735843658`, \
-0.14040793478488922`, -0.22242577373981476`, 
                    0.07198899984359741, -0.20709171891212463`, \
-0.12226468324661255`, -0.009829679504036903, 
                    0.23048876225948334`, -0.20186470448970795`, \
-0.24719290435314178`, -0.1386900693178177, -0.03243662789463997, 
                    0.08953121304512024, -0.07476703077554703, 
                    0.07018029689788818, -0.32335227727890015`}}], "Biases" -> 
                    RawArray["Real32",{-0.0001863076613517478}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.4811568558216095}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.1311459, "MeanInputsPerSecond" -> 
          49891.38975759781], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.04789292259568498, 0.02338138199537739, 
                0.006336467089034028, -0.019529176118533182`, 
                0.026070047839378753`}, 
               "StandardDeviation" -> {0.9803793798807869, 1.012888237122776, 
                1.005443639516244, 1.0001112364264946`, 0.9809800732799604}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 5088644467333114782]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[364353], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3665033832820043, "PreprocessingTime" -> 
        0.3512615`6.997175545070417, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.29282244608402735`, 0.07828348437968966], 
           "StandardDeviation" -> 
           Around[0.28185378338897776`, 0.059807955008255066`], 
           "EvaluationTime" -> 0.00019982943044351853`, "TestSize" -> 63, 
           "ModelMemory" -> 99880, "ModelUtility" -> 0.5316243690697254, 
           "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
           "TrainingMemory" -> 451720, "ExperimentCount" -> 1, 
           "MeanCrossEntropyHistory" -> {
             Around[0.29282244608402735`, 0.05535478265978972]}, 
           "StandardDeviationHistory" -> {
             Around[0.28185378338897776`, 0.04229061055523709]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 34076482760288]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.3401419537175943`, 0.529575880135646], 
                "StandardDeviation" -> 
                Around[0.8044678625468166, 0.050615562894999], 
                "EvaluationTime" -> 0.00013409930775366567`, "TestSize" -> 
                305, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.48811191875329807`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                495776, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.3401419537175943`, 0.3744666959967496]}, 
                "StandardDeviationHistory" -> {
                  Around[0.8044678625468166, 0.03579060775662799]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[4.8508400669248335`, 0.8793108698013555], 
                "StandardDeviation" -> 
                Around[0.5122146422663126, 0.03787970017210922], 
                "EvaluationTime" -> 0.00013683847771505932`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.03885180935697996, "TrainingSize" -> 50, 
                "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                499760, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.8508400669248335`, 0.6217666788075799]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5122146422663126, 0.02678499286101166]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.3760360919644254, 0.06857729290678294], 
                "StandardDeviation" -> 
                Around[0.31387619160281127`, 0.05226858141945587], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.4328127829261731, "TrainingSize" -> 252, "TrainingTime" -> 
                1.9952623149688797`, "TrainingMemory" -> 522584, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.3760360919644254, 0.04849146884980234]}, 
                "StandardDeviationHistory" -> {
                  Around[0.31387619160281127`, 0.03695946836469842]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00031670830396331406`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.31387619160281127`, 0.05226858141945587], 
               "TrainingMemory" -> 522584, "TrainingTime" -> 
               3.125035238191293], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[5.624169456992134, 0.8784763130173091], 
                "StandardDeviation" -> 
                Around[0.4862339931442247, 0.03163704246586384], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.01495689220245533, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 428752, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[5.624169456992134, 0.6211765580462953]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4862339931442247, 0.022370767264299093`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.3539564849204078, 0.08149144460344304], 
                "StandardDeviation" -> 
                Around[0.2953590463026866, 0.06404005824596007], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.48393381212771025`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 451656, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.3539564849204078, 0.05762315308778245]}, 
                "StandardDeviationHistory" -> {
                  Around[0.2953590463026866, 0.045283159453299845`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00031670830396331406`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.2953590463026866, 0.06404005824596007], 
               "TrainingMemory" -> 451656, "TrainingTime" -> 
               1.391017463958849], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[12.692362561830148`, 1.8153203291469433`], 
                "StandardDeviation" -> 
                Around[0.5151974288359047, 0.03296847871478685], 
                "EvaluationTime" -> 0.0001351002078275469, "TestSize" -> 265, 
                "ModelMemory" -> 99880, "ModelUtility" -> -0.0426913377050081,
                 "TrainingSize" -> 50, "TrainingTime" -> 1.2589254117941673`, 
                "TrainingMemory" -> 428768, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[12.692362561830148`, 1.283625314765599]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5151974288359047, 0.023312234864630133`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[8.323471313635785, 1.0278471664313162`], 
                "StandardDeviation" -> 
                Around[0.9731987759426401, 0.05153418512240576], 
                "EvaluationTime" -> 0.00014342569646407457`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.6765473276596385, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                424592, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[8.323471313635785, 0.7267977014069615]}, 
                "StandardDeviationHistory" -> {
                  Around[0.9731987759426401, 0.036440171762976]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.29282244608402735`, 0.07828348437968966], 
                "StandardDeviation" -> 
                Around[0.28185378338897776`, 0.059807955008255066`], 
                "EvaluationTime" -> 0.00019982943044351853`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 0.5316243690697254,
                 "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
                "TrainingMemory" -> 451720, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.29282244608402735`, 0.05535478265978972]}, 
                "StandardDeviationHistory" -> {
                  Around[0.28185378338897776`, 0.04229061055523709]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00019982943044351853`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.28185378338897776`, 0.059807955008255066`], 
               "TrainingMemory" -> 451720, "TrainingTime" -> 
               7.523765832135071], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 34072187792992]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 6.382666015625`2.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097570238054891`17.333472267569057*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.8480371350265647`, 
            "ElapsedTimes" -> 2.6000436000000002`, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 3.080061891710941, 
            "ElapsedTimes" -> 2.8663257, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 5.133436486184902, 
            "ElapsedTimes" -> 8.6279193, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 34085072694880]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{-10.000487623375335`, 0.812499798921313, 
              2.634461233836259, 0., 1.6094379124341003`}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 14.7877711, 
        "MaxTrainingMemory" -> 942024, "DataMemory" -> 75768, 
        "FunctionMemory" -> 258104, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 50, 23.844385`9.129961051915432}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.4026824002902974, 0.05759150625484832, 
                    0.20378653551485318`, 0.4793650793650794, 
                    3.8246203765190696`}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.4026824002902974, 0.05759150625484832, 
                    0.20378653551485318`, 0.4793650793650794, 
                    3.8246203765190696`}, 
                    "StandardDeviation" -> {7.262560334602431, 
                    4.589301011623757, 4.224369450133401, 
                    0.49957401859022904`, 1.4183334941448837`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.3286241722434752, 0.6073951730184691, 
                    0.2292503540582421, -0.6791377792673057, 
                    0.09640232957349941}, {0.27102023638008704`, 
                    0.6607334532712688, -0.1920153209071136, 
                    0.4641747003554563, 
                    0.487494922319778}, {-0.5209332610057559, 
                    0.32414445383081225`, -0.3786854778489864, 
                    0.3274602135783641, -0.610676696802924}, \
{-0.5110745109021332, -0.2886134185331344, -0.5642408318003524, \
-0.12066901218401527`, 
                    0.5679581077654788}, {-0.5347761838132165, \
-0.07832672095415691, 0.6699283426581083, 0.4489125998939444, 
                    0.23990175357959015`}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.4026824002902974, 0.05759150625484832, 
                    0.20378653551485318`, 0.4793650793650794, 
                    3.8246203765190696`}, 
                    "StandardDeviation" -> {7.262560334602431, 
                    4.589301011623757, 4.224369450133401, 
                    0.49957401859022904`, 1.4183334941448837`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0173873, "MaxTrainingMemory" -> 92936, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 50, 23.8762986`9.130541928021902}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.4026824002902974, 0.05759150625484832, 
                0.20378653551485318`, 0.4793650793650794, 
                3.8246203765190696`}, 
               "StandardDeviation" -> {7.262560334602431, 4.589301011623757, 
                4.224369450133401, 0.49957401859022904`, 1.4183334941448837`},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.372180681608611}, 
               "StandardDeviation" -> {0.7297956814333084}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.372180681608611 + 
         0.7297956814333084 #& ), 
        "ProcessorFunction" -> (3.2504723472050174` + 
         1.3702465298725997` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.8557293844758234`, 2.3766379888842692`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViXkw3GcYgB2hyQqhTTTb0cpGNFJJnUHT/b0fErIl1UYmiKNGFBlFhK4g
XQQr1tBiVkTVMZHDEambdvd7v9CkIceUaVipI6Sb7s50osYSKqmp/PE8M888
gpOnA2MN9PT0UjeuKzDqrFdKSlTGMePXEROV4OKc8Ho6r2O0zrd9mxnbU06D
jilw5J4bQnwrLtslgYOgHgsOdKHXwBmMBiuUBvFgfuAmeTtslt6fOQQtzUnc
zgwzNvehHhHxxvDrFxWQ7Yxs0LcYLm65hXvjAtHA6RcI1M+iQ4feYLNDQBYl
oyA4tZtdsawmXHQl1a4FEJV4mrYvJTPpcQWXHXYHRDt8ScFyLgak+nIBzulo
XfsmSXvZwalHBpVt7REY1/cnDtUMwvi9bpiKrYcm72bMmmyAmX+TFfu39nBl
6kcYnpIDrfIybqHIltXr7Fn4/ZfQHhxEeT1G7MY7BkRS6AH7rJthjfnAGA1g
X447MrOoHqyI45PPzxkxzUk1/Z4vBZmfBT26dBGkETvwwUETlhqdD/I1CZ20
IXjXoQ9L5Sncp/xeboj/CStNV9H/cJDuYklk1KqaPIxpUxbaHyZdmutMttan
nLAr4YZVj6HptoI2Rj7By1W9So9MHuG5+bCjngLyys6QGC3cwumRUpCG2OOi
oz3G7+pXJLfPcLYd55F3zRAFrkEkVGzIdKm9RM/SFXq7W6AuVIQGHfWgjc0m
lu+twsM7aWAjNEVPeT162UvJsLgBDOO0XHqzQKk6N8hZiAtRotnCSp7U0bAE
fca4TuroZMyirpvjyIEbmPnUBcJbr2AYfxIKal6BrXMld02kz9KyzzOF116a
73IBnX7soncbNVCjMCcT2e+SkOCb8MORPMwW1kIe4WFjrQ+ubnoLPX+fojFx
au6LWoC0ZELkC73onfYUFms2w+Wf/NHst0zy6LNL9DtXa4h6HkSq3cUwflWH
ORkaKh3wIh4bHqNINEF/LbEk3m71NEFjRByUOYqEvGISofkLTPXVMCcEumHF
hn4QKqZ5zT+jQiYhfVot3cPfiOb9z7jp7nCUtxDwiSwDg9gKZM/alLGRo7gi
qcLE6Q6wKzNh4qTTRJZszVR/31YO5QuY14lKpA37YD5rK7V1FJHVlQdUVhTC
cufHads2fYiXNYJfvxY/Lm4AWWgOjFkUs0tnhoXTVeVgqi7ilocPs6/c3icx
rBG2+wsx50IslF31Z1MVGthf2UlD/QQg1loRF90UeMyngo/kONP5RBL33BxO
92IV/rH0FtbMF7DEndvZ7mARMQl0w8RTPJKRq8VvNpVzql5L4LXk0+dNZ1nZ
kTkwTlUS7xE9cqJjG1vqqgG1eyekWAlh9iMrJv3DnWuoS8T/AaMK97g=
                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.014639019034802914`, -0.029732808470726013`, \
-0.07044381648302078, -0.09935785830020905, 0.04156200960278511, 
                    0.04475228860974312, -0.0436866469681263, 
                    0.0014753106515854597`, 
                    0.03398572653532028, -0.01617596112191677, 
                    0.013005533255636692`, 
                    0.03387503698468208, -0.0075302221812307835`, \
-0.004505831748247147, -0.02785906009376049, -0.004681797232478857, 
                    0.0029421818908303976`, -0.024066265672445297`, \
-0.0020812060683965683`, 0.0024461615830659866`, 
                    0.009763793088495731, -0.032126929610967636`, \
-0.01746494695544243, 0.033663176000118256`, -0.06118873134255409, 
                    0.024846291169524193`, -0.01140243373811245, 
                    0.00698114326223731, 
                    0.020806390792131424`, -0.0018508911598473787`, 
                    0.04850959777832031, 0.025348246097564697`, 
                    0.02104894071817398, -0.02228405885398388, 
                    0.08047665655612946, 0.07312244921922684, 
                    0.038857121020555496`, 0.04650433734059334, 
                    0.0018666075775399804`, 0.028306709602475166`, 
                    0.04302322492003441, -0.028314262628555298`, 
                    0.006271573714911938, -0.016775939613580704`, \
-0.03211793676018715, 
                    0.030804134905338287`, -0.00907748844474554, \
-0.02342013269662857, 0.0037024489138275385`, 0.0282913688570261}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtV3c01//3l02RmVmkUJJEIu/XvSVtGaUlNJCUKNHQkhGZGdkjkkoKlSTv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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.049082279205322266`, -0.028465736657381058`, \
-0.06093369051814079, -0.01085385587066412, -0.01646564155817032, 
                    0.0033542506862431765`, 0.0002519835252314806, 
                    0.007605535443872213, -0.03404125198721886, \
-0.007084155920892954, 
                    0.023501081392169, -0.0031398397404700518`, \
-0.03423277288675308, -0.02904588356614113, -0.04855666309595108, 
                    0.018857641145586967`, -0.04218045249581337, \
-0.043263476341962814`, 0.036816637963056564`, -0.0242677740752697, 
                    0.06370855867862701, 
                    0.018557261675596237`, -0.003844561753794551, 
                    0.005723334848880768, 
                    0.051580823957920074`, -0.016030801460146904`, 
                    0.024483099579811096`, -0.004262667614966631, \
-0.006691208574920893, 
                    0.00476208608597517, -0.004624120891094208, \
-0.04008198156952858, 0.01112530380487442, -0.014239481650292873`, 
                    0.01402552705258131, 
                    0.02053888514637947, -0.06502838432788849, \
-0.0546124130487442, -0.052590373903512955`, 
                    0.011764224618673325`, -0.01105963159352541, \
-0.0223686583340168, 0.021107444539666176`, 
                    0.027001524344086647`, -0.011661273427307606`, 
                    0.01484321802854538, 
                    0.011652914807200432`, -0.010023882612586021`, 
                    0.003398261498659849, -0.03146077319979668}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c01//3wDMiK5EGRYpCVkaK9+veyqpoKGnqU2nQjoaGREUku4TSUKgU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                    "], "Biases" -> 
                    RawArray["Real32",{0.04195485636591911, 
                    0.007377347908914089, -0.04808538034558296, \
-0.006728561595082283, -0.004853066988289356, -0.018541213124990463`, 
                    0.012744697742164135`, -0.0021281158551573753`, \
-0.008779818192124367, 0.006948516704142094, 0.008066922426223755, 
                    0.030014105141162872`, -0.027822019532322884`, \
-0.0011258223094046116`, -0.028982801362872124`, 
                    0.012462199665606022`, -0.020274247974157333`, 
                    0.03066842630505562, 0.01487570721656084, 
                    0.005613483022898436, -0.0027844985015690327`, \
-0.03263607621192932, 
                    0.059194114059209824`, -0.013714545406401157`, \
-0.0031118737533688545`, -0.013885381631553173`, -0.009133481420576572, \
-0.0217537060379982, 0.006642801687121391, 0.006879589520394802, 
                    0.013040440157055855`, -0.02501048892736435, 
                    0.0364227257668972, 
                    0.013299747370183468`, -0.009611304849386215, \
-0.036681048572063446`, -0.0016421283362433314`, -0.007926242426037788, \
-0.0075118630193173885`, 0.03206988051533699, -0.0005522441351786256, 
                    0.021747354418039322`, -0.015559045597910881`, \
-0.034277286380529404`, 0.006477242801338434, 
                    0.017067935317754745`, -0.0028689797036349773`, \
-0.0016505980165675282`, -0.007789930794388056, -0.020922482013702393`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dYz+/3xxuKFk20kESFSlO9X+ckikhSmRkpWYWsrPpok1GaSCINUigp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                    "], "Biases" -> 
                    RawArray["Real32",{-0.018966378644108772`, 
                    0.0307008046656847, -0.007950147613883018, \
-0.0045434581115841866`, 0.006567694246768951, -0.002265770686790347, 
                    0.021752024069428444`, -0.002873251913115382, 
                    0.023365864530205727`, 
                    0.024403870105743408`, -0.04260041192173958, \
-0.005429441574960947, -0.00612772349268198, 
                    0.02062053419649601, -0.04035516083240509, 
                    0.00678479578346014, 0.006425436120480299, 
                    0.016931796446442604`, 
                    0.023685624822974205`, -0.03511669486761093, \
-0.008175374008715153, 0.010459602810442448`, 0.011397290974855423`, 
                    0.005923809017986059, -0.03481335937976837, 
                    0.002127339830622077, -0.0012634004233404994`, 
                    0.003053261898458004, 
                    0.009037953801453114, -0.008302831090986729, \
-0.01528866682201624, 0.004389787092804909, 0.007080956362187862, 
                    0.009500853717327118, -0.0049186949618160725`, \
-0.008505354635417461, -0.000299496459774673, -0.011591826565563679`, 
                    0.02899790368974209, 
                    0.016307750716805458`, -0.009225771762430668, \
-0.003740309039130807, 0.0187027920037508, -0.017035387456417084`, 
                    0.01904147118330002, -0.011419679038226604`, 
                    0.019837195053696632`, -0.015138371847569942`, \
-0.0010943907545879483`, 0.0169085580855608}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{
                    0.13263042271137238`, -0.1751396805047989, 
                    0.17117783427238464`, 0.17254087328910828`, 
                    0.09797990322113037, 
                    0.15653981268405914`, -0.08064373582601547, 
                    0.15976351499557495`, -0.31339728832244873`, \
-0.028016483411192894`, 0.04238954931497574, 0.1941792219877243, 
                    0.12976092100143433`, -0.25703155994415283`, \
-0.05888252332806587, 
                    0.21242831647396088`, -0.055079396814107895`, \
-0.06736589968204498, 0.19417297840118408`, 0.006934543140232563, 
                    0.13878637552261353`, 0.06092865765094757, 
                    0.0523739717900753, -0.22852091491222382`, 
                    0.06047600880265236, 0.048317890614271164`, 
                    0.06300622969865799, 
                    0.09717143326997757, -0.17467932403087616`, 
                    0.09619168192148209, 0.1876993477344513, 
                    0.13170601427555084`, -0.24534009397029877`, 
                    0.20978115499019623`, 
                    0.0612298958003521, -0.057238757610321045`, \
-0.17114676535129547`, -0.15012884140014648`, -0.18833592534065247`, \
-0.1280374974012375, -0.10388420522212982`, -0.15696071088314056`, \
-0.14814843237400055`, 0.13507865369319916`, 0.06110198795795441, 
                    0.02075074426829815, 0.06324383616447449, 
                    0.11375496536493301`, 0.08650311082601547, 
                    0.04032483696937561}}], "Biases" -> 
                    RawArray["Real32",{-0.00306045007891953}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.5507226586341858}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 0.5360308, "MeanInputsPerSecond" -> 
          47758.44970102464], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.019368448424148196`, 
                0.004849858921813492, -0.01842777301018929, \
-0.006311900598287717, 0.024426587493336156`}, 
               "StandardDeviation" -> {1.025808798516083, 1.0253490481828627`,
                 1.0232395800272491`, 0.9999596817991986, 
                1.0010789189452254`}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8100446370136657837]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 100, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[364465], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3149906724633046, "PreprocessingTime" -> 
        0.4358847`7.09091661859948, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.5020589896297265, 0.1306532577334183], 
           "StandardDeviation" -> 
           Around[0.39357423887527127`, 0.06300326987278207], 
           "EvaluationTime" -> 0.00019982943044351853`, "TestSize" -> 63, 
           "ModelMemory" -> 99880, "ModelUtility" -> 0.2077921144327628, 
           "TrainingSize" -> 252, "TrainingTime" -> 0.7943282347242815, 
           "TrainingMemory" -> 451656, "ExperimentCount" -> 1, 
           "MeanCrossEntropyHistory" -> {
             Around[0.5020589896297265, 0.09238580452741381]}, 
           "StandardDeviationHistory" -> {
             Around[0.39357423887527127`, 0.044550039363970305`]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 100, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 193892215844462]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[6.896054944274304, 0.9765914487432837], 
                "StandardDeviation" -> 
                Around[0.8455617642342509, 0.05475523844300407], 
                "EvaluationTime" -> 0.00010869404378619128`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.5382932331335154, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                424784, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[6.896054944274304, 0.6905544358551705]}, 
                "StandardDeviationHistory" -> {
                  Around[0.8455617642342509, 0.03871780040853451]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[3.905954592919756, 0.7371659098801253], 
                "StandardDeviation" -> 
                Around[0.4811188181748481, 0.035511550115943744`], 
                "EvaluationTime" -> 0.00015633372739584048`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.02380756056787059, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 428752, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.905954592919756, 0.521255013735788]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4811188181748481, 0.025110457897429748`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5020589896297265, 0.1306532577334183], 
                "StandardDeviation" -> 
                Around[0.39357423887527127`, 0.06300326987278207], 
                "EvaluationTime" -> 0.00019982943044351853`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 0.2077921144327628,
                 "TrainingSize" -> 252, "TrainingTime" -> 0.7943282347242815, 
                "TrainingMemory" -> 451656, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.5020589896297265, 0.09238580452741381]}, 
                "StandardDeviationHistory" -> {
                  Around[0.39357423887527127`, 0.044550039363970305`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00019982943044351853`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.39357423887527127`, 0.06300326987278207], 
               "TrainingMemory" -> 451656, "TrainingTime" -> 
               1.391017463958849], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.390255435611572, 0.46435911174378103`], 
                "StandardDeviation" -> 
                Around[0.4935889679800776, 0.03665517191864328], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.001872212656834904, "TrainingSize" -> 50,
                 "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                499760, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.390255435611572, 0.3283514768197893]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4935889679800776, 0.025919120629231372`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5016410250685007, 0.12537304559370546`], 
                "StandardDeviation" -> 
                Around[0.3948894019100624, 0.05830156379485287], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.2068677850304308, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 522648, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5016410250685007, 0.08865213071731932]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3948894019100624, 0.04122543111312057]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00031670830396331406`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.3948894019100624, 0.05830156379485287], 
               "TrainingMemory" -> 522648, "TrainingTime" -> 
               1.391017463958849], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[7.687783681845256, 1.2889356287288551`], 
                "StandardDeviation" -> 
                Around[0.5403724734481492, 0.038758289554300954`], 
                "EvaluationTime" -> 0.00013252401628338037`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.09192758834193282, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499552, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[7.687783681845256, 0.9114151235871195]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5403724734481492, 0.027406249371037934`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[5.118426394130815, 0.7202531505616898], 
                "StandardDeviation" -> 
                Around[0.7509185452291123, 0.04718951708713962], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.41921317251267376`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495536, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[5.118426394130815, 0.5092958869331462]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7509185452291123, 0.03336802753323488]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5420594894188727, 0.1344431971179259], 
                "StandardDeviation" -> 
                Around[0.4109764657712896, 0.05803672861198537], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.16818612632165053`, "TrainingSize" -> 252, "TrainingTime" -> 
                5.011872336272724, "TrainingMemory" -> 522648, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5420594894188727, 0.09506569636648511]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4109764657712896, 0.04103816435941818]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4109764657712896, 0.05803672861198537], 
               "TrainingMemory" -> 522648, "TrainingTime" -> 
               7.849733612802018], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 193887920877166]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.0000154213985278654`2., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097570375586889`17.333472269136852*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.7168386044535426`, 
            "ElapsedTimes" -> 2.3546994000000003`, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 2.8613976740892384`, 
            "ElapsedTimes" -> 2.7267045, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 4.768996123482062, 
            "ElapsedTimes" -> 7.872936, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 193900805779054]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{
              2.5909365816875582`, -2.020853005809032, -6.711775236845678, 1.,
               3.912023005428146}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 13.7388295, 
        "MaxTrainingMemory" -> 956600, "DataMemory" -> 75768, 
        "FunctionMemory" -> 258088, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 50, 37.5846172`9.327585019548911}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.6874610441284447, -0.30262885226318004`, 
                    0.06482792563953058, 0.5111111111111111, 
                    3.973092013239888}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.6874610441284447, -0.30262885226318004`, 
                    0.06482792563953058, 0.5111111111111111, 
                    3.973092013239888}, 
                    "StandardDeviation" -> {6.871741015051197, 
                    4.478829505048547, 4.471145567666201, 0.499876527964533, 
                    1.3191369323693722`}, "Method" -> "NaiveSampler", 
                    "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{0.6030604836363651, 
                    0.36385320091014267`, -0.11837320879138884`, \
-0.4283940660234738, 0.5535297723700349}, {
                    0.48463538993515515`, -0.5365457735384311, \
-0.28419729051587994`, -0.36129005794866326`, -0.5157020126112858}, {
                    0.42456841815499047`, -0.5189151889436946, 
                    0.30433141434544103`, 0.5612337074559236, 
                    0.37797857194116374`}, {0.2292342468908212, 
                    0.31553794890359377`, -0.6901912923866614, 
                    0.5915509347483563, -0.1469385394172935}, \
{-0.41065789929872404`, -0.45923012811740976`, -0.5798603742798747, \
-0.14502494763643917`, 0.5130277673536567}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.6874610441284447, -0.30262885226318004`, 
                    0.06482792563953058, 0.5111111111111111, 
                    3.973092013239888}, 
                    "StandardDeviation" -> {6.871741015051197, 
                    4.478829505048547, 4.471145567666201, 0.499876527964533, 
                    1.3191369323693722`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0144334, "MaxTrainingMemory" -> 93000, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 50, 37.6135388`9.327919083376413}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.6874610441284447, -0.30262885226318004`, 
                0.06482792563953058, 0.5111111111111111, 3.973092013239888}, 
               "StandardDeviation" -> {6.871741015051197, 4.478829505048547, 
                4.471145567666201, 0.499876527964533, 1.3191369323693722`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.404412309736364}, 
               "StandardDeviation" -> {0.7283175652034527}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.404412309736364 + 
         0.7283175652034527 #& ), 
        "ProcessorFunction" -> (3.3013240715465937` + 1.373027437173857 #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-2.8172701607597803`, 2.425716271517243}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViXlQ1GUYgEFFoRAL5RKJ5SYC1OWogf29HyA2BoYcikhIrByDKw6HLssp
AS4eHGLgIFfRcB8qiRjgfu+HIwUSiBwDEiRHRbilVnIIooR/PM/MM4/BsUjv
sHUKCgqnlNfkLZQ4x8QI4302vo1QYYQNP+Lt5K+htIbYkcfcQ9qpLjxB9cZE
/LSuF5eSDsGoZgVuya5B3ecZKB4wQ8dNdVxn8E1y388Jq8zeByOtau7NrBLj
rcxDeK4CC7TMBvOJH1nMYgzUDndg8WE//Ek0BAU3B2iqizFr1nEgS0t90PDH
LjaXWESEMwFUzdSDGO2zpldqo9kvoovc0xIEpatfEp86ii97+h2XppuRiA2J
fq0BnL+xjoZOn8UoToEtrCiSqc3lELmLQhUtwRzVCqgM/Fmm2+7EPRLex92a
YliUi7kybwtmmW3PxEpyWMXsO68bNzCZhyrpn/wQjlqNQu8LJ6gSejBP230s
wfEWVhx4h4yIV/HhNT2c+rcO/JraZSK3UNgfrIWS7WpsY9RXMONzSWYbqIhJ
H3RgQECXYFxnEx0VeLPLzxwwunKQ3stLId3VDaS1LUuguOhJsk0amGW7jM50
eXGP46YhSVMZC09P4395u6mnqzYxe2bFuGIbUj+rRKbSq9ExKAtqpZbI8Vxx
ryhWVtDVzWkqSlGnfICe4AlI2vg/KLjQSXKT48C1/Bs4cygW939fAoZHLhK5
pyKJ0i2GxLsEayLTMLxGSg44NUBQDg/md3TSmWgNWF9YiSbUhPHNtHHUfj3L
O7JKf3XWYFf2zNPW5D9xrCkWvjucgwOtQ6A3JoejfBXonTJmau5SZqyqT3t/
y8LQUUMcd1Ehdxp0SEa8OYk73g/b9OrxoNEtyHUboGa/e2EL46FkrxFmDG2D
lEfBkBDiRNKNSlCi2w0qO87AoqY3Fi5LyO1BA+7ewgin5yskp/tqwT9mCk9W
/U2rHh4k1yMG0diwgS7PqpCRrmSudLM2SVfL5Fy9LhO3V3JYkc9BXbEDl2k7
QZvlN2iBbw/ulJwjzrEymijJp8HKxnCu8Rgm6/Dh7vIlOPmiDL+90CZ4yZ/A
oMci/HqsFPzm7RlkRZIHwzz2cYI6nUv7iM1Yl+Nkiz9o5NS3WUYDuTqqj70p
IlYaUk2p/1Yw7JmE1vxJNLU6C5mlReDuk8PsOFU6J8gDu4puQbyzO9sapku0
vdph+L1P0GdPOGTlfMEUAp+AUq42NY+Phe1FpiT3/Bs4Hh8OvZ+FsZ0TKWRy
YUXw7jU5DC82CeZ9pcx1cBVPpduRLfxUTLYwIK+bnmL+qwzuxA/usBpsQ59r
JbMiiz7QlnYQNecNpGXCmv3lVwQlg9fhwZgFuNzms9TP1WVllZH4PxOL9oc=

                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.0449196882545948, -0.09242907911539078, \
-0.0367252379655838, -0.023996371775865555`, 
                    0.04728036746382713, -0.005173527169972658, 
                    0.02012120559811592, -0.12977375090122223`, \
-0.02666713111102581, -0.010072039440274239`, -0.02378033846616745, 
                    0.036276303231716156`, 0.0357966311275959, 
                    0.06626567244529724, -0.09774741530418396, 
                    0.0782032385468483, 
                    0.012970900163054466`, -0.03844079002737999, \
-0.021083904430270195`, -0.05032583326101303, -0.016865113750100136`, \
-0.07894062250852585, 0.06465747952461243, -0.040190812200307846`, 
                    0.02578352950513363, -0.03380567580461502, 
                    0.011783544905483723`, -0.037434667348861694`, 
                    0.011894670315086842`, -0.009104317054152489, 
                    0.01022327970713377, 0.038726020604372025`, 
                    
                    0.09107544273138046, -0.035331569612026215`, \
-0.021274594590067863`, -0.00845517497509718, -0.034786369651556015`, \
-0.06637149304151535, -0.022679157555103302`, 
                    0.04247622564435005, -0.025850681588053703`, 
                    0.025477217510342598`, -0.011665471829473972`, \
-0.012539650313556194`, 0.016100464388728142`, -0.06331765651702881, 
                    0.0907539501786232, -0.02376711554825306, \
-0.03690451383590698, -0.056413184851408005`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3lQz+/XxqNF0UqlRSKhQiqF+rzPQUn2ErKUki2EEgopbVIqW4tU30qU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                    "], "Biases" -> 
                    RawArray["Real32",{0.12028557062149048`, 
                    0.025596143677830696`, -0.039319850504398346`, \
-0.06163327395915985, -0.024821924045681953`, -0.03935284540057182, \
-0.03808339312672615, 0.039051078259944916`, 
                    0.04141960293054581, -0.03759470582008362, \
-0.06877881288528442, -0.026143625378608704`, -0.07726991921663284, \
-0.028811486437916756`, -0.02769448421895504, -0.05240245908498764, \
-0.10187814384698868`, -0.03035307116806507, 0.056110676378011703`, 
                    0.006293749902397394, -0.027449654415249825`, 
                    0.010909322649240494`, 0.025239301845431328`, 
                    0.031982921063899994`, 
                    0.01829458400607109, -0.03178086876869202, 
                    0.006011350080370903, -0.0000720591633580625, \
-0.06048984453082085, 
                    0.046241942793130875`, -0.02835344895720482, \
-0.07502073794603348, -0.0235906969755888, -0.050846755504608154`, \
-0.03083052672445774, -0.009258699603378773, 
                    0.016540132462978363`, -0.012139169499278069`, \
-0.058792706578969955`, 0.026460401713848114`, 0.03908880054950714, 
                    0.012467531487345695`, 
                    0.015889650210738182`, -0.018694235011935234`, \
-0.050172109156847, 0.016300106421113014`, 
                    0.027732959017157555`, -0.11413316428661346`, 
                    0.002428842941299081, -0.0048660049214959145`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dUz+/7x5s0KFGUBi0qEi3q/bquyghllUjKzJ4pZURK0lSUSFpkZRQR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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.0487152524292469, -0.004522049333900213, \
-0.013680876232683659`, -0.034756649285554886`, -0.025438982993364334`, \
-0.009408222511410713, -0.008960689418017864, 
                    0.004634222015738487, -0.0413479283452034, \
-0.06736456602811813, -0.01511042844504118, 
                    0.02253608964383602, -0.016933735460042953`, \
-0.032279107719659805`, 
                    0.016411717981100082`, -0.016245737671852112`, \
-0.014178382232785225`, -0.02023456245660782, -0.017099466174840927`, \
-0.02279547229409218, -0.07317348569631577, 0.037772487848997116`, 
                    0.0035057421773672104`, -0.039572782814502716`, \
-0.014753395691514015`, -0.04795576632022858, -0.035276226699352264`, 
                    0.010019291192293167`, -0.02514064498245716, \
-0.007871821522712708, -0.005138468462973833, -0.011465915478765965`, 
                    0.006458303425461054, 
                    0.04503566399216652, -0.05275973677635193, 
                    0.008531940169632435, -0.023897774517536163`, 
                    0.01745256409049034, 
                    0.06733407825231552, -0.08868351578712463, \
-0.020519401878118515`, -0.020012520253658295`, -0.014564444310963154`, \
-0.11391814053058624`, -0.06025952473282814, -0.0658242478966713, \
-0.009828832931816578, -0.023684754967689514`, 
                    0.0033743069507181644`, -0.036476895213127136`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtVnc814/zlyQ7KREpIxJFGsL7dYcKKSJa0kTaKmkv2YVElAgVaZAyK+/X
nbQHokWKqLSTSkvr9/k+Hr8/7h53j/vn7h6P5zDwW+UVKCsjI7NW4b/ktXCD
Y3Dwwk3e8v9rFi1cMWrkiv8NR/5/VCj8FSw/zKKBX8Zg5a92unojBvrVdQft
hHDQLbckk6ZciFubAtJBnVRj40B97zfBhE5TGvF5MGY5rMZuB2RIfUGmMOa0
FY17FSbZ0/MF3bAYw04+E6ny1xg8Ouyq+Gzzc+Frrz/k/qFDrLcvIdkjTP+G
RfHtT4mUcqoE7v3uxh6SQejg2JcXuVVSVJ8A6QOnM+yqlUuSMlUh26wP9j01
CHLKsvDGui3QcSoFu+nOp35/Z/DaFH1MqC0mhZ6jKdVRA+eaTcZxJbv4e85I
1kkZJaSLSnht+mS+tLSJdEt60cIbpTj8sxyPrZjGo36O4mG3amiomiWdWmfJ
XVvWkbuJFfdteFs+QiGDcx0Sya3zNXi5erPNyKFUZK9BR9+ooKi2FrOUt/D2
yuugtbOU81U1KabgPGmceQcD/s1nxde/pJvvlJKSpQuGeu4XikO1WFuvD1p7
ZMDIBQW0dJ06eFVZ4NPRA7C0SRVbl5fx9PY9bGXhxgHpAfTy+BaO2TxSfHL4
Ew1dlgQjttUIJZFPye3wYFTvoQ22klR4evGd8LosFRTv3IWgU3o8vESNPeOr
SW+bn/h5NdPG332478fPxHk5UK4pB8Eqg7n2iqqk5Kc1eupv5B8164XDY4hl
eIbw5Js/17oOECJfoOTKQHU8WV0J5/e3UPfzY8jf6CkdD12OV3wv0fPEVBqe
clponCjD56vesouPDOX7L0A9zb58qumouG/qLhhX1gS6XQfo1vV6YcXyXTRs
zS78ZqrCy07/EbSP/xAyFleIhdvHYKl/ADReGYbW7gW85+QTevaskCymS4W2
jYlcEnqemtc9BrdkVaGs+wS8VdOfz1SHoMyp52Jez29QUDsSH8va4pQGIwy4
7YuXTPzgdVE462VF8DRZSzhUcQxOLUkTjQcY86qSCHFZ8GiqXLFHPDemUBrc
Nw9irc7RnBAn/JQ3CQr6dwi3Htwkr8HpuLPmhpid2EWN07140AYjCr9lis1q
GRSQ4la+wtuDlHf+FJvuHYOm04o8NmgR+zYG483SkeIboRi+N0Vh+cQyHNRS
x6Uu+0DBLwGK7RTFhp4ipAyy4uiN2qz8qBPi16WBgo0ZKkvnQuzqXNp9OppM
9A7CpbXd4PHF0ZAZOo3FVGXO0rHj4CYlYUPsAVHWvJB+3LrIJeN9qc8UO4gp
tuKoAf3YXsaUJvonUWnaffB4nQ6fww/iAeNHkkce/TChL1P/kBvQN9oYzhRZ
cO8vz8QVQ0Lx3iBj/rI1G8Idknj313zamBRHq9R+Qe+r2mTVGMe6fIN0f2WS
HbyntZJUYbWqER53kOXXOcFsUzWCP7wQqSSpH67uqqf9FSrs4GiCsOy38DE4
kaWPf0JnrgK4aERLNmfm0fDaZWy3Mlv0Fj9jcJwHDTYdzdmn1uDZDiPedtME
GywuQMPDB3QkeRpVKM7n+V/uiAb39XFKuhOvHddEySu+wmQNb3o2uhUuPEjj
nHM7yezfcbI+9xFSl8wRMuoa6XhYGNs5mzI6mgLtfgjN4y7aGU/VByrpLr2j
WiSuW7cC37Y9gMKjLTTkPz5prZxImWtOUf0kKRn5xVDZr2kwa9xK6eJMRVI6
cZlm5euyk+l6Lsmoo41Hu6Od3k5BIaudnIMGwPTesnxZfh+NTUxgt+a/8G5g
f859etc274sOX/8+nu867KfsCW78a+Xt8jNlCTgmJwttlMxRb/V48cjDHTj2
cBY8z+0QXZfdFZZUhcOSemOQzVQQFsTU0c3B3XhkSaJE9VgG3k53o8LpPlRZ
o8091FokoROWQsCdBdjHYxHVNw3gHOMX4pd5y7nSVx8tKmzQSCaAT5vcJcN1
e7H34fG4bK4dq/iEk4NLf7ixyI4boqw4a/YZjPawhAsDw+jI5DeUc/0QzHtQ
S+vT7Xi09X7+AMZCdX2GdESourj89FZoTM6BDWvSYWNNCbz0cBImbtbheaVS
4PpaoXOwC/ubDeMM/1fi/ioDXt48kFkpkjOvSyFsk5Gw1qiQ+27vKbYsUIcz
tidEn9lvhStLb4rqV8yg7mUvDgv1FfC7yD3H72JZi50cEu2EV11385m0DjG+
ewXFHT4uJquHS0rd3EQzOW3+VSbLgUk6PMTvG/FHdf49PYSWvFETuycfFUI/
xNPIkXbQtT9RcPJNEBd+Ow1fVo+BT1VHhL8Hl2HT7nBh1teXdDZvME626caL
ozVIIdMUXx5fAgXH8/jHhZEo53pW/KNyiOXdLpKMSx7lDFfA+EMm+PWHAfU0
6wsqnrvx7cpcGnLVjX9kWLBL3m5e49UA30ZeEizbneC6ezXwvH5C72xPTErb
CifSzklavZeylsEuXC89jjKt6vjFajZlBEXDs9HpoOt3kzw170rXvE+hpP4a
KL8qmbsqF6NPiD6WjRiPhdVzeJmFHq9RuwqFCXVwLmId+6X5c0jbOtz+zpMm
f9qKldWtFKRsQ7tXFcDS738hcPcNmOzdD1VadFnuijtwlyWtGNMEc0YtEO7a
nmJsns9j1/XGL+0k7Pumis9nqqHSvsscuWQB+0yT4JKQiejYuhhv3HAjmcTY
8u16l4QRQjSvMhgGY6+INHRnfzKPUaCr9aF4zr5KWHFRmfsGDueNn2vF1iDg
RyvjaFpkFs2NSeClFMFpE56Q3+bNdPvRG/DMiIQTf6YIxWWj8enEVOit4Erd
ZmzEiefSxb7/ekiXfZyFvXLV+cbbFkgvjeOB0RZkX+dGftOnotLcaMmJKQfI
3D1NuI0R/GVAGTTL58OOnjHo7KCKN7MEbruRAV7r5SG06Lt0ae1OUC71pZ+y
paDUfBZkFK/w+vg2oc/Zs4Df+8IRYTKa9nNH95cSutaWKvo7HgcTiSEmvayC
K+PSqKPttcQyZhXFYX8wf6vHSkqZ/Lp/NqnNuCmqyErw+TdN9Db1hPXX8iDQ
fynmvd3Dy1xccd54NVE+eiwuKp+KB4KLyWmKKu8b2ItH+RVRlNFlMk3ox71v
H6SGMzVUH/WQosx16L1VLMu3vYGIdSKdeZZDdmIGnN+8k6OProE1eztB57In
Z93Po3tXXWjv1g+0d7kva2t4UmbjWHrdUCXEiMrCxps9SXb3Ojj8bgY8m40Y
nzEcFj3fTe+t88A94JZ02nwrajVRlx57c0dUvD+HF+YpiQ/CR4Oy018apz5O
cuhbMLvUSlAmN5ZMkx7j0eearFEn4WMKl8A2WBsMXYPRxgf40noppKltEnMb
3gm7fUxofoYWuqxUhpvBjcKAzwOxp6Espy2bTBr/Yexv3n685nVQ+ubtc3D/
dw2PqUegqlwO5XhLwcg5A1/46wj3B3ZAu0qlpLr1MOwwvAqd16fglGxjPpDq
TK0tavxotw03R6hzyScjPOnwmlL98/DJjGiOcAR2UlsOrpl2kqYUQ25Praag
SS30J86AV4+TgagtkRSvuoSdHe15+/pPUoMlxyjHRY9me+WT0qeH4JIeRWUh
Wtg5R1oekrgYluuNwG/zx/OBPech4IiiaDliGHblB9EP5Vw+fLxEmGulw713
OdEtTBO9Xo2i5e2rhaOvzVgMVOFT56/T/IMHaYpbGCilu9Kspk34ZVuExHZR
KGma6nEp64CyuR6O1hxO4d5b0HT9Bn7xRJ8jQjvEOwetBb9f3ZhV1vL+YRGs
Ofwktk9zol9VkXQxYQ8F9lGh3XH2WNFZL+6jQPg7TQWbTb6B4djPUHfNCL8t
rYHVts1C/8fXKfJihej56xpdrm0Qxs2eypI+RqhiZo3XzoUKLc292F1hBfR0
shajb+wCu/AMnrFNlqtORIJRwkr4vcWYLm/QwL0zlPnGIxvhwNdy6YsUZcy+
7Mo/x7QSfImEwbmuuOe1FkfvFSDMTFEMvvMM/tQ+Fjs7+qGjhw72ej1JONY2
k75c/UiXfPIhZFax0D88Fxbaf4CnAQ68JD4NBJkerGcdyeVNBzFzRTeed18e
/2Y6CnbmyULaJz1xzdCBPOuXnfhx3hEWZuzDV6b/4PHhaHwbZMm2P2LxwNHe
wnePhZAVb4RTTr0VXn0+wKdbCsnMrgfda78Ga0ab8ZHzB8SR2Z8F/bw4UGqa
z1PrD7DnZF3sd3Au1iuFgqm/itB/jS0O7ayCul3dePB4W95bPY17Xk7l72W5
FLjVjy0+n4GfR36JJY1bpGcTzVH7WCw9SJqMxZ7edH9pPyB9d54f5Yy1fxby
e/9Uejtgp9DMK2l7qBIPGDkJxm0Yy7bel+HtymQwSr4p6G05II7LmQvTpmjg
AjcZ/ufrSfqlTrSt1hjSf+wXdveNhfUat6ElPRKz74+C7ed/05GNfwgPmWL5
xztk9MZOSJDRFO9q2/HPS4NgwvtpKDsll0y90sHUeAF2C3gtXPoSRzW1ulSY
2I/NKcOu5uxkdJmWRe6as+Dqe38cejueJywv5m+KihhXcwZOKKYLc62JbhXH
CvfXDIfUDDmsVbRh8nElg+4Docbspeh6YR1EjYrDRYn74dntjXRmpT6eEcql
ozqsuPRrO+gWdgnhd6thfmMRuFub4f3hEWRR54WTBg6l7/UXYXqQqjT1zjSM
EiU85b/91KaZiUV3msHPKgsfXtYXN23Ng2PTCjj2ZgEN33wPsmNkcHyMAed8
k2EZw2j+uUWDWfexGOtcICnRGgXlOc586V44zB+fRUe3r6W4nLm82U2HeuQ5
Q9XWbeLpMfPZT/sm3LTUEVd6JKP2xyxaknSUrQ+dhMXBFuDwazIWPjbAndiz
wmFTGt3aMZH0DvpgoMow3Om8B9uCTLH17BSc3asO9pIIqvnDyP9AGS26ZoC6
vhFi9OUhuH2hhOtGbMdz49U4bnoq7o9EjFHfJRpayOGJxArqtn85xzhLRb/x
5YLBbQXcfm0wDzaPgYH120GpcwY+jxpHv270wENhQ0Rf50XiKdvxWH4ukLpt
DKSW4Aa6iqclN7WeQpd3snBbx5DmRbZAYMkI7i6XLXStdUG5bTXiwy+DeKnG
VGyoul2uHvxX9H0hg6EPx+DLKWF0dscEvvxVS9hsV0IWDt/Iqj0Nv5rF0Gb1
GsnnOeo8YsRLcZBuAn7/MAuKb5qT3HpjXFMRDwWfbksUK3IIv2Rh4cNciV5w
L+HZPi1c8d+NZ5Mu4TTrZJDdFkkKum/J3mCXdGjqC1FTpxJ7zJwNtv7GzJEn
OE15LxTQ1/KzY+K48b4uPx0fSlsOKUNCR6QoXkjFrspzMNXeQOw+yBRVpovw
wOiiJMFyFjhbh/PwugK410uZxVMr0PXfX5I8raKfdgXSP1IfzNhsi3Wr5uLk
hvcU0uILSqEJ4q3fHyhuhgg9FOOFbp8jsVLfDCpndeND46eR2f099NguC7wN
JpJ2VSjLDR/AA66VQN0MQ3zV64qobaPAcTVj8U3gPjLwMMKZh4xJAnlUsmUg
K4ztAlfP+2Kf4+foW+wEfPGjiwZEnxSi5fxgnKIljQ2WsNz1naLr0CIO3ObE
Hfk6OKY0HSxyCsuFKTPBbUgmPTaeyq8S5dDLZyx8PTsKFxqbscxsM8hRmMAL
D2qiRW4RuXeNoOQ4Rfzk4ow1Wp5Q0lUpjBk6DV52dyK9itUsSU7CO8qv4F7T
JOwx0h0vXCqk+NZ7BMsHsXvbANyyMogOSU7+pxUlKD/KTbyZz1ILg8NU+3QA
j4yZwwEvz5LJyC+0te82yYx3hXzFzoHvFS2i/go3JSnyUnHGXgW0MlnFk58F
Uuu45bi+ciN2f6qCTZ2tZKSuzyfLisWM1n1UWz+YB/5KEQMedYju4am0orcS
bXY8L170SwJ7LVm8J7dXWGMShhrTtHh6oDHWXc2WBJ2egAlrDck6LpjyrMMw
M0yH/tj70vlJ3lTQeyJcdB4CNX2N4LH/fDAvGkgBgUvhcUI+eG+OgwubP4Br
zHXqpXoQvx7OhCHdP4D12zgy6acmvD1bBTzRkiJHr+JPfsN53Kw9PLzDDPpb
fKTySRdAt2UUjz3cToNe58CVtDhJfsFLSj9hBinu5eKDoNtCgMNUWtpfCY3C
q/hASik1dJgLTc9eiZLtgVzjmCuUCfGiXvFJgNX6dPeHDzo2z8HErY+EqRZJ
/O1MEKo5GEuvp2TQrKjkCwU2k9nLagR2Trflv1UyQlPrXjjU5xeVXVkARV8l
nDc6md7nuuOGNxG8cokCzVTSx99DDLn11m6QVmeScrgnbgmeyBnlN4RFkyuE
j0rZHOH7F6adeCFccwzCOces6M39TZS/Jx5fvJjEAUYdgudpGb7RtgSK2kzB
wqA3NWXPESKjY/h6nTx2Pp/EVXufQOzvcGrcd4me9Lwp/MicwAH5a+ndoPc0
veKp1PNaPnYe3y2u8fMQmmYZoI1bCs1NeiJNeWrFed7VpH/6HyQetsLj29oh
0DUbHNVKSNHnq2BV4QB/fX6Q72YlrFcIJJcNw+n+hJvlio2T6MChNJFSF0Gp
hxwUP/XCl5tkoKWfKjpL5tCLKUoQur4n1f2RoTm6l8i9zQ3Xa+wmzx47obPW
W9wUYkLeVW+h1xgjXv63gvoekOWLfWNAmjiBFvtr88TYBVj2sxV+jhdgvXEu
yU4pgSWZ3fDM2TS0jUqD6rwifJ8+Ey7s6M3tp2+CRmyNdF6tjHRn7yjhqoY6
jnm8F2Wvq+KMSYOFnEmhOPDBMsmdOxao8sRJ2Dcmh4ofzKW92z9Rks15uGZf
CdqVmXBl9PnyQ59j+YhsBfsvCcXju6Pp3fRRXFN2jc7UZKPT88H8ZJUuvhhi
xtvChmK9zVjautocfSPPY7x6KMfNWYMaBca8QL5NNInLhqOHnNl54ipKsIjC
BE0lmrByNz3wHsQ71Tx48QxtvLhiPSr7K7Cj/hdhxrp9tGhDKG/GXrjuznjc
7hvLlyutec84Z2lY7hH6npUBzQdbYLrFWswevxLv39aiLjNdbMutETa23YS8
v9/pqmetZKjUkRZ7zsKTGT1Yx+aGMPK3Kvj0KhK9w3/CPbMUie3bCulXDRXe
MjWS309VIrUcXd6YeUn4qHNOvLfAUDrzsRZEXz8Kc1e5Umy5Pknv+ENP8yhy
qvaBwOYlcFzfgvuOPUwz5UsA1Csp3sOLfH69llr3PkeZ6QbQcvGpMNb3Lcwa
MIkDQy0x1S0E7Ddu4GFzM7BX1wFOyPUSgwpO8sshv0h/nRyejVlGSR63QO+f
NhpMPUbDFyXAmSHrcPAJZcFFIwz/KQ/AhlUx1Flxivqq3RJfS+Mw/tkxmpGw
kUJKX4FVCLDbBjXebOkMQeObJSVP9gCbl8AN4wrwemTCBTf38yzt6zR3Yl90
uxLDE1XLaUW+J3zrjMGr7rvYIm44mp9spGfhUeK86kQOHZEL4+MaSeVZAX3R
04fuV/eSnN9dMfm1B2hkO8DQMSb83XAmRGSmwPH7d8BLJRky7UKp9lO79KLe
H3GYaylJ3UaA9vAILKypFD/U14A6FdEyw/1co94KUaW5rHP0HrhM30+N5XVg
mBQDo6zaaOeFU2Lrqj/QFdgodVvfBrFJbuLTumNCcshOzpH349U5vYXC1Yn4
/VQ8pL8bzb4z3alhYYuo2tkPfbudJ5PNkXDzlgvLaQ+mXjtfCTNnekCUj5mt
ZbsBnnv4TJjzyRQUU0/Ru4dp1OezEW7zuAxfJ34Gh72hvNutJy+6/EFU7LQR
Q77ZwN8pVTR7XwBErYmG9C2NdCJJhJOdB4XJyqri3W5z6Fm1HGoaTOenq9XY
b6cudzZYsEXEJdr7N5qVA2dR1ZIEPHmnjXSMDCRyiw3B7GEH3N2khLveJNKo
4nPgcVmWZR9+pxe9koTsGVmQWqnJb0Y58cIgdZ5baQcpH1LZ3nEFFU3bRMsy
3gg3Jw9g9+VVRE5/hYbRHmy7fhd91H4GY2Z64rjbpvzd4ip1pLijQqUO7z27
GZ1+DsRWy+E8db5UVMjoxxFzY0A7rUGq7hrFBmNCcOS6UjhooIa5dj7oNHc+
Gevtg154gzqjn4uJWvLU00INnsa4wpk6RZx8LwBnbtlALyxv0+EkG7ByOSSV
vVgnqM3Mp1GyZwRwk+PTNhkw9NB4fmteyGaLYiA4oh9v/LMTfXKmiJ531bhl
syIeCbtkZxlURemaBvz7XBwn91TA2fsnYlTawv9qM7w9wlAa7qFO4wemw/sQ
Q9APiKOGjG7C2nn74cOgANp4RpEf3j9AtpnzyFHPmDNuq+PhdiUc6RCLuhtu
w6G9SjhBrweHGd+SNqmnwaPUIpAuJcr+Zs7fv8fC6n7BJL9dgoEGqdAoexlO
hqhz8NRlQs9Dl8jadSsU6x4G47gymNpgzp+LZbil8Qv9XXmJ2kanUPO8qzTT
8Sjbx9QKf+R98Z2eDJe/3ITf/8iC4fyBsPTNOAyoHoirxySQwncZNEh2pYbT
oXRh9H6ubpzA178vgM3harh1sRrNnr36P3PdLh7afxpubEAKOSIF5T5TYW1K
HJx1fifcN4sjVWsXnDXAj420O0D50hfoWD4X52w4T7J+XvD3pDI+SDSkNkEB
1wcfJusPT+DK5+90O/Wj6PvMngb3HEcv5r6ks3tisP3xEzFm/nrJhk4VLnul
hRV/u4taP4ppxZ2n8P6PgDkazrDWwY8N0zfZTl/SBD+TronVOafIO/sXva9y
oQ2RqnhzYDNU9/DmH94BottlSzBXjQDf75dhasw4eGUfymbpYYKVy070frSA
lR9toOHtsqyUPozsZFUxozWSfbY4ouyNDbwxazTHlJUAufTgU3pePL6rlly/
XsesOUUw/fENoajghbTw0zFYoO+BYn837rXoIR1eshN1/tPFbuMUsfDRCmHg
11g6tloXc5/YC60TjbAiQ54P2u8S6isioOfMBRja89p/nncyq1zQIiobwUWV
wDeH7MJ3w6rE7t3UIW3DaFq40ovCrsfhj4cG1O1XDzTKk2ctnRrSUnHFzs4v
YDohE9a9DsA9Vv0xf2o41ipl4q39ByEsNF4Y1XCHZ7Zs5VPDqihGSZnWNcWT
zMaFuKipDu/6FLNmYzTeMZbnR4P+wb5xBF5ZH+Hofk2ObXOCF3dnsMqkSdBV
NgRs4Ll4QVxCqzXvQc2088KqE+uxaPZ6fN8oiy2u2egaMIPONhRT1a8iOP9t
OIcfuytcXToZ48RI6pd2myZ+H4Z7Ey1BrW2R2GLak4W0cqq51R3WXJ2Gl17r
0cEjcWBorsfeBk00yDWZUuLsOCFQlwtcXtGzM+fJ6PIqqDh3nAx/RNDbZQ0w
JtwL/8Yq8M9oY5zd8xZlaTvyrVNTJDsae7NL5zqO9v5MdlvP0O+/ZVSgYoqa
pMFxfZRw44NmcTFeoOfRB6WbFyxATz2RmruqYY1NN25dHwXUPxVnbpcnp861
/FDlLFzx06MgDyvxeeIhCH81iqeGypH+7yBOeHkanDVGYVbTTomakR8mTf0s
zMnWw2tX5uDahDCYPmABTx/VTPNct0ns4pNFu6t9eIFbLzw79x14pS+HgMjL
kDB3DR/WjgXZ3tPFJf/9cu1qd/7d/wfoJ/XmScVnYd7MpWRYkggTF6yDRX0K
wWqko7D2txLuPDqQGr8InPaiD57WLQatnnK4+lkW2E/JpIU23igX9J7CQ3xp
xbR8eJl7E0c3BsEu87Pwdtt9yq9WlWjuiObQ+jaYc2UjhNdPwIHbd9H7uBxB
JTwWN7e1CJW9zXji0keQk9INUhR/gc/bHXxP5gWlZqzj9B/rpZt7tMCem2Mk
HmcTcGrCXuGY/0EoEg/zgB3BfKTmIP7Tc+WFu7OAKoNQvV6by+qTykv9n8KU
CW6S8HXz+EnOPtgXCVAQoMbybo12B3vvYbXycXRkgQnH+l0Tfq2YiSsOPwD3
/R4ouzsE/7lmUtK1GPB8FI0dfdoFk9HKPLv7CVq2SA7XPlyD6oW76KjMWRqQ
nk8T78rRFK8/NCXDAjcFxIPts5V8v86N9x0ZjD91msQJv+tp3s/z4sOtOWDc
Sw2N1xeDntFI8Y3vN9o2rxYc5HpDl4Ip/OkZhTUPj4kq036CgdpQGry4Whip
oM+zHt2C941ZYu3pMiGob5cQqZNLr8M+0frfBvjHyxDfuG6n/EExtK1zBart
kSMMNyCtoXY4wilUquq6kZWTY7DtRbOoof2JdMzM+aXOHlD4aSc1NhkqPi47
DMsmhxP0+C6x+3xOej/bkSc8+w0OOWZ8t34mVc/voNmnbSQYsgQPzh+Ps4/t
g9UT5Lno32VSDbQG2VYXvGEih6WOW3Drf5g8Y/ePrE2f0DAfDcoryqeV4T9p
Ve9DqGHymMySJ2PjkjiavaJBCPPdQKHto3FTQZek8sUKyZdhbmQ4whrnLKoV
a1KRphjvoY6Fe8ku6gQlPXNH/1sWYPgR+PyLfDSXDaPUDz+l3e83wPzHFaLL
sY1Y8jYDd+cMphTRgrcesBRf/RsHtuuegnb2UdTcF0WK1YPRlidw1Ct36ZED
lvA7MZIGRCJ3z4uAEdfmsY2/DrvrD+e7018JD9+EcqedHRfTfA58q45vdJi+
1fejkv94NSz/GPpkTIB61SpxwQ55Suq5DZpeu7LZ8Uq4d0RX7JHmyntPK1HO
7gnChgFqmCgm01brogua8wexl3swmtn2576SKE6rno9/NbVxiajPP82raUFI
niikq6Be+yOoftuDetwthZl38jGuyJK9/+VQuiywzJooehDyQNDx64YP0kOI
3bvzlktSuv9tHs14cAB7O3lAdkULaOoOApmBWyiwM4tSvPqx/tQ+3GC0lxZe
KML6tMdC6IhhYlaPGG44/55ySJf/BKdDvwf3JQGnXVi2n5500PR42n31FOrM
9gSX0Nf05q4+z5HegCK1l6S5SUG4/qMfuBwJFIq652PFYGusdk6BGf210fNN
M/mWKtPCTBceJ05HWnQRatUPUkKykhCl3BcnWsTT/eivkHzlH8wYqofexbPo
SbEJj582kz8kOtOtDFl8LW8Bl8bHwuNFy7F72GyhJdEET7T508GORjqjkYrn
Z7tjath9Gl6/nSS2D2jy2lGsfqYfNiz4Ilh/+w5aaiXgeFmFn8x0wXlaoWDx
0I7tdx0gkx+y3HbnM3S7oM5f9uyXZqc8FPrGIQ+0sOBW/y7a47YTxDfJ/3Hz
Qo6cYIgyscfE1oN/xALHPhzkYS+Kf01IKinEi8+02CthOE6+3Q13xIbxEB1v
4d7l6Rz4t41e6/5DmRcjMFvzKKWeWiWMenEB/eClMMepCPqvPQd173V5WHk1
pXxw44BtdvjaZz92le4X/4QY48ZkL1xTtFc4sd6Hj2/aSY82DxLebk0H+dJC
OpSTQxekA9DupISHFsZK92rPBL9lfWFLxWQ4bWUlDVo0Ai5mLseH5epQ6L+U
7F9r4NiwajF4Xhq4PdblUa6T4fGJEAg1J5q1axBrpzVDfQWSz5tdNF9rJlU5
xqGBTBdZrjGhPq7H+E7uLvqj8BEK3MbCrtxzQofbVHxstUxUm7VL1PwdBhee
n5AenxQL+gPj6elJC7YM2kA2rc7ssUTCeNkMX4Y5ixoFtiAo2GBE2Gj0Ot4I
7TOGcsSLVcDt9WAoKQL75gQYYujLcz5Y8vG/WkJGLzMccXUVPG76J1ho3oGG
4n+gLxQI598/J9umQt6kF8cRr1PF+KdERy4m442NBjSsNVfcE7ibfl9XE5bl
q+JpJXX+MHcPVxTpcf/WE6LmWjNxsW8afFnSHXc4aIK9EWJ77X8YdLsGa64n
4wPpZ8F61iLM7ndPkFxUxHWVRrzk00iO1tCmjs5k3OFcKtpsVCVVw0Pw8HkE
Zu2aIO4zTRLUFazx+eIK4O0n8d2/V9CuUEnDzI1RXrFDmtYrBn6pueGJMk9+
GvaVWi42SyQfE9gk4zutso3kuc99BT7TCR2rn4NMWBK8nWFFV5744nnxomCn
tAn2RF8Fmdl13KNsLM5deoqsHL5CtY8fFs0fitk7BvEMBR84JrMUIjul4HBb
Aec5DeVVoX1YxX43Z3aYU/88A9LZoQV1Y1VoxaUv4lvQxquiFib9egnvR8nx
XPkV/PjVe6l9TzWuvurEz4bLwFItFzp0WZFJRg/TEo7w7GWKVBy7m59b2dOI
59VgWmOPzSHv6c47R+pyfw5FQ/qTXt4wPDVeD+e+FmFURRxY97WktFVHOWVB
G7yPURSudzpCf/l2OHHlkRDr4EgTHOT4Q4QSx04hIUjMkoQ6GHPJsgGYsT2J
3sd/In70hp7b7CCD0a/EDV3h9PPQTNa+PESQ6TxHaStbxFOzj4vzF5fChsyh
XKX4G/wnzobne8/D6dzP0HLRVMjN78Z8Yi6LParg8nVLMFYpu9BOy7jYYL/w
5/EkUXrdCpSFVzCvPomu1HWjXsWltmF/jlB0sz1UWG7nC8vPwoFtZ2Dy8/tQ
83EsFkZriI+eqMPZbWlc89SAfSLyeaiaA/rHLgaHHxr8fwoTDdo=
                    "], "Biases" -> 
                    RawArray["Real32",{-0.02849709615111351, 
                    0.03761879727244377, 
                    0.001269683358259499, -0.0064943768084049225`, 
                    0.0009266017004847527, 0.0270082987844944, 
                    0.012589925900101662`, 0.014713848009705544`, 
                    0.0003440017462708056, -0.021800285205245018`, \
-0.01884634606540203, -0.037741754204034805`, 0.003352400613948703, 
                    0.012641912326216698`, 0.010242569260299206`, 
                    0.0011696877190843225`, 
                    0.0025303619913756847`, -0.009286703541874886, \
-0.006287264637649059, -0.023795809596776962`, -0.004666425753384829, \
-0.00988029781728983, -0.01399359479546547, -0.006841118913143873, \
-0.015632517635822296`, 0.03488926962018013, -0.01079341396689415, 
                    
                    0.023612769320607185`, -0.008820242248475552, \
-0.008728353306651115, 0.004070917144417763, 0.015177170746028423`, 
                    0.008467250503599644, -0.01741935685276985, \
-0.019364679232239723`, -0.027758263051509857`, -0.011588772758841515`, \
-0.0016178230289369822`, 0.010002369061112404`, 0.013965073972940445`, 
                    0.00044628523755818605`, 0.0233633853495121, 
                    0.00775315472856164, 0.0017881604144349694`, 
                    0.01475678849965334, -0.01886761747300625, \
-0.017572779208421707`, -0.029765207320451736`, -0.0353531613945961, 
                    0.0029349783435463905`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{
                    0.13293059170246124`, -0.14577820897102356`, 
                    0.10791470855474472`, 0.1793874204158783, 
                    0.0862574577331543, 
                    0.11608128994703293`, -0.018531445413827896`, 
                    0.12052532285451889`, -0.24175430834293365`, \
-0.01787237823009491, 0.04698579013347626, 0.1574658900499344, 
                    0.09385150671005249, -0.2041858285665512, \
-0.053321849554777145`, 
                    0.19442446529865265`, -0.043240468949079514`, \
-0.057980045676231384`, 0.17315985262393951`, 0.004546276293694973, 
                    0.10856304317712784`, 0.05331481248140335, 
                    0.05113749951124191, -0.18877868354320526`, 
                    0.04914041608572006, 0.04345608875155449, 
                    0.07770536839962006, 
                    0.08685795217752457, -0.14699867367744446`, 
                    0.03426523879170418, 0.16576650738716125`, 
                    0.10952483862638474`, -0.2551117241382599, 
                    0.18001560866832733`, 
                    0.05341504141688347, -0.06339339166879654, \
-0.16281071305274963`, -0.09449336677789688, -0.12776099145412445`, \
-0.10991136729717255`, -0.119136281311512, -0.12235555797815323`, \
-0.08402234315872192, 0.13612523674964905`, 0.03671944886445999, 
                    0.00968710333108902, 0.04560365900397301, 
                    0.10548814386129379`, 0.0998905748128891, 
                    0.022322017699480057`}}], "Biases" -> 
                    RawArray["Real32",{-0.002417216543108225}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.7275869846343994}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.7575675, "MeanInputsPerSecond" -> 
          44463.221664357385`], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.013423594492896884`, 
                0.0020522014246405844`, -0.02574871017000337, 
                0.04121377715501629, -0.018202384129459126`}, 
               "StandardDeviation" -> {1.031400811850008, 0.9687618519382117, 
                0.9815824623286493, 0.998368453871281, 1.0302750007918087`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 626476178797837095]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[364577], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.31701810996115576`, "PreprocessingTime" -> 
        0.3743441`7.024815986141981, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.47874637815261606`, 0.17511670947763455`], 
           "StandardDeviation" -> 
           Around[0.3861416205330914, 0.06156392912732522], "EvaluationTime" -> 
           0.00031670830396331406`, "TestSize" -> 63, "ModelMemory" -> 107736,
            "ModelUtility" -> 0.22698092870246922`, "TrainingSize" -> 252, 
           "TrainingTime" -> 6.309573444801933, "TrainingMemory" -> 522912, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.47874637815261606`, 0.12382621277070993`]}, 
           "StandardDeviationHistory" -> {
             Around[0.3861416205330914, 0.04353227176241967]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 193909395713660]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.451196298150971, 0.3375587261248987], 
                "StandardDeviation" -> 
                Around[0.5426087276468636, 0.03027330140893187], 
                "EvaluationTime" -> 0.0001497747329571884, "TestSize" -> 305, 
                "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.09290911343711417, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                424928, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.451196298150971, 0.23869006429160844`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5426087276468636, 0.021406456715159988`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[4.887959871094671, 0.865875091966436], 
                "StandardDeviation" -> 
                Around[0.5521581805316733, 0.04080997705084678], 
                "EvaluationTime" -> 0.0001430034169695532, "TestSize" -> 265, 
                "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.11393235304332372`, "TrainingSize" -> 50,
                 "TrainingTime" -> 0.31622776601683794`, "TrainingMemory" -> 
                428752, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.887959871094671, 0.6122661491899923]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5521581805316733, 0.02885701151272114]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5050839600335336, 0.17874916643137154`], 
                "StandardDeviation" -> 
                Around[0.39364512847378774`, 0.06060858944244288], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 
                0.20879702974595016`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 452048, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5050839600335336, 0.1263947477150656]}, 
                "StandardDeviationHistory" -> {
                  Around[0.39364512847378774`, 0.04285674459290275]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.39364512847378774`, 0.06060858944244288], 
               "TrainingMemory" -> 452048, "TrainingTime" -> 
               1.391017463958849], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.1650780185632184`, 0.35264117665191513`], 
                "StandardDeviation" -> 
                Around[0.5182510357588346, 0.03343111556276509], 
                "EvaluationTime" -> 0.00015633372739584048`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.048704580929762153`, "TrainingSize" -> 
                50, "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                499616, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.1650780185632184`, 0.24935496733617238`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5182510357588346, 0.023639368517062314`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5415822034661183, 0.2038287209412793], 
                "StandardDeviation" -> 
                Around[0.402945753940541, 0.06403910488873348], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 0.1844812084731493,
                 "TrainingSize" -> 252, "TrainingTime" -> 1., 
                "TrainingMemory" -> 522600, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.5415822034661183, 0.14412867077815902`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.402945753940541, 0.04528248532794003]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.402945753940541, 0.06403910488873348], 
               "TrainingMemory" -> 522600, "TrainingTime" -> 
               1.648107170553497], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.8976160591102287`, 0.27726438242491136`], 
                "StandardDeviation" -> 
                Around[0.5039738168875277, 0.02887397139063789], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.01934352133246231, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495712, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.8976160591102287`, 0.19605552499415502`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5039738168875277, 0.020416980970106417`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[11.42935192852115, 1.859959379235765], 
                "StandardDeviation" -> 
                Around[0.5601014994484529, 0.040750520984976425`], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.12799010315837012`, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499760, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[11.42935192852115, 1.3151898897891308`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5601014994484529, 0.028814969725361534`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.47874637815261606`, 0.17511670947763455`], 
                "StandardDeviation" -> 
                Around[0.3861416205330914, 0.06156392912732522], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.22698092870246922`, "TrainingSize" -> 252, "TrainingTime" -> 
                6.309573444801933, "TrainingMemory" -> 522912, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.47874637815261606`, 0.12382621277070993`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3861416205330914, 0.04353227176241967]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00031670830396331406`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.3861416205330914, 0.06156392912732522], 
               "TrainingMemory" -> 522912, "TrainingTime" -> 
               9.471859998463529], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 193905100746364]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.0000140364355231144`1., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097570518482965`17.333472270765803*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.9316899305093955`, 
            "ElapsedTimes" -> 2.4993096, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 3.21948321751566, 
            "ElapsedTimes" -> 2.7636051, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 5.365805362526098, 
            "ElapsedTimes" -> 8.33071, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 193917985648252]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{9.965673017368527, -2.5014136237752815`, 
              4.287008219560214, 0., 5.298317366548036}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 14.2957747, 
        "MaxTrainingMemory" -> 968648, "DataMemory" -> 75768, 
        "FunctionMemory" -> 265960, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 50, 51.8812098`9.467584944748989}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {
                    0.2478273654230271, -0.049823069496447825`, \
-0.03908609805496223, 0.43174603174603177`, 3.8610940556884437`}, "Method" -> 
                    "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.2478273654230271, -0.049823069496447825`, \
-0.03908609805496223, 0.43174603174603177`, 3.8610940556884437`}, 
                    "StandardDeviation" -> {7.209950475732185, 
                    4.524730724985776, 4.0634341083550165`, 
                    0.49531948863091013`, 1.3607200404137665`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.7251424930301632, 0.18356559888621532`, 
                    0.11741958310316487`, 
                    0.009221557225879485, -0.6531459561949026}, \
{-0.25537111018713793`, -0.3871873299261353, -0.5084763189528217, 
                    0.7194378372248073, 0.09344837644356839}, {
                    0.29337646059489075`, -0.7747263505884217, 
                    0.12571630809016493`, -0.15601366239328984`, \
-0.5230530385148068}, {-0.39140752659563033`, -0.3649369480378437, 
                    0.7016178388350515, 0.10085536776300018`, 
                    0.4595451828742596}, {0.411927616671781, 
                    0.2881141234146381, 0.4686067569686529, 
                    0.6691876367594102, -0.28266854201307745`}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.2478273654230271, -0.049823069496447825`, \
-0.03908609805496223, 0.43174603174603177`, 3.8610940556884437`}, 
                    "StandardDeviation" -> {7.209950475732185, 
                    4.524730724985776, 4.0634341083550165`, 
                    0.49531948863091013`, 1.3607200404137665`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0198028, "MaxTrainingMemory" -> 93232, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 50, 51.9171123`9.467885378473598}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {
                0.2478273654230271, -0.049823069496447825`, \
-0.03908609805496223, 0.43174603174603177`, 3.8610940556884437`}, 
               "StandardDeviation" -> {7.209950475732185, 4.524730724985776, 
                4.0634341083550165`, 0.49531948863091013`, 
                1.3607200404137665`}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.442691431615144}, 
               "StandardDeviation" -> {0.7393964180949834}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.442691431615144 + 
         0.7393964180949834 #& ), 
        "ProcessorFunction" -> (3.3036289760621402` + 
         1.3524544825040514` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.537295218783484, 2.5169195500191046`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX841HccwE84omMZVhqFthaXJDTdfd6fycIMt7DDRuvohHPylGd+1UL1
lCHzox1hWZ5htnKytLjv+2NMnrRhhnLUbml+j3rkqT09PVZ/vF7P83pe9jGH
Q+JW8Xi8o8YvFSJL8z5yRJYRyn8VclnSTrekV9PtJYYvUWTPco5tQVx2Lp/a
+fwA83Xfo2D7OJR5tsPZrmOAys9ZcsUgkf5aDPKPKsSzD+uIe9QMp368gLpP
Y8nqse2wlBKAjuFvU1/bfi4N7dn1Dimt5ruwqkk32luzAIrAFrhfvYzwrEuz
b7cROdeTDxZvymmB/gRxT82HbYZGrLz6EDaHPyUp73eyDx6kg7/HH7h1w0m0
jDwj1uJh7uN1vZyL+hYk9JrRwDYzqip/Hco01Vg2vAr6c1Ih4Mgi+keZUF1Y
u7h7NILEBaixKFtI1/SdxdGZHgTvHVScWYz0RCWRiprwomUtNj0U4a6Dj8T0
gBHXOJvGOTRYMJNBA3apXI7q4U6MKrFhHb9ZQqJyNe0NeYA+RVJ6s8sR7nn2
wb1mG5yS7yXeEYb0yofLmuoTJ+lmlRTC1/CxJH8I63sdSPp3CViyx5il9x/H
5UFvCB3KAdsOPhaqHpPgJ9NcZmcjmnc1g6plBYN3PCX/NIiYXt8NNM/JwhBV
KG4WXcIbK3pMtlZAJ04MgX/WOlC0jmCKfQLcqSqj88l1YrNYPQjruICnJjOw
qMmKSfbpsNHnJgnVHScuLhpwPgc4VeNH3UPUWDP5Av9sHSMtHjliWcVhkupY
w7XbWLJDpbnAjVrQ06l2uNHFjM1lWnNKZx7TqY+1eW2JJu90q1FxqxL3j7aB
bH2KWLStDvMsn0DcggDzfAuggPsRdNolcnmXM85f3cmEffXo9csIrFK40heB
anB6rk8fjgygb66QxiwjbjX1pZvsp4BIrKikS8J9UbGBacfMmXOiEjTjZnQ6
xo+Y/tUKlUabqDJuO3pbnGaFBsN4n2XRab4Juxaxh2WsF1CDb+xhr+sBmhYb
jcFJDKVqV6zaGI+RogOgbU2ilX45nOt7x6g2/RGZa54kK4k/k2JxPAZdTiYO
X/2H3zoZsL4JAb1i/QaLizwNru+eona8JlFYloCW6aQ0/JNOqB36GrdYvcXm
RAasRJ/His7HIrULRI8bR6EeW1DSY03t/55B6xItMZ5/jjFOepxfvAHtUZhy
QbV5sG3/CJ7/zAcES0KMPnkRe9ol9GBRNt5WWoDt/Dh5Vi3HBa0GVaGGnCxV
imNuQlY+dZXdNL8LP/3+L5yqLabBykK2gKVE3bCI13yv48DdKhTd9qKhr50h
u/03sKoLpTj4pSfwF+9gQv4yWWsyg92WJmzOJhgHYs+Ki4Xu9H8aZ+v1
                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.08470120280981064, -0.0050467876717448235`, 
                    0.02417302131652832, -0.03410644084215164, \
-0.01566355861723423, -0.047728851437568665`, 
                    0.0018717524362728, -0.13878029584884644`, 
                    0.044230204075574875`, -0.041262321174144745`, \
-0.128509059548378, 
                    0.06982129067182541, -0.06167077645659447, \
-0.06336931139230728, 
                    0.08029687404632568, -0.019059419631958008`, \
-0.09167537838220596, -0.0036687010433524847`, -0.014663977548480034`, \
-0.002248183125630021, 
                    0.05544966086745262, -0.10392586886882782`, \
-0.03721334785223007, -0.04194028675556183, -0.01385694369673729, \
-0.0014232649700716138`, -0.030275730416178703`, -0.003319829935207963, \
-0.02216266095638275, 
                    0.016133343800902367`, -0.05829039588570595, \
-0.05198560282588005, 
                    0.02400761842727661, -0.04453335702419281, \
-0.00030473823426291347`, -0.13671939074993134`, -0.007793314289301634, \
-0.03141988068819046, 0.02664533443748951, -0.01023128628730774, 
                    0.009233967401087284, -0.012261119671165943`, 
                    0.022106656804680824`, -0.06470394134521484, \
-0.03565192595124245, -0.01926097460091114, -0.0529651865363121, \
-0.003721359884366393, 0.07020286470651627, -0.036925606429576874`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2k0kN3XhylESEQioZSxgZDp3tuUilIiSlJpTvVQNEsIFSJJKolQUk8y
lIp771KJUHpUGkUaNUhzGfL2X+v9cM5aZ51vv733Odc1fFGQ57I+EhISIbJ/
N8+AjY7r1gVs9pL532FpwGrz8av/dzn+/1flpzNwaMZgGpVmyadTrlLqLU/6
MsCJVeGDmGJjiqnSLnyjVAMKbCqFx0m53Da9gGW9pPA+uoiHtQLEXCrH7xQi
QMh8cXixFL0PyeX8CmO8VP9AdFu6VYw4TfQkdy8aSyoKFvsSsSmjG+isDT6O
+A0fvybAf5Os+ZP3AJxRUgcLfrvDmZA4KtOOQQ24RwtDboLhFDd2NIuF2fn9
6GB6JQVsvQL6exWgJXeOaF6aLtRH3iA390xB216Li8pLYfoIXTzzzxHh3oYO
iO+cDxW3jHnREE9y760FfBUhvlv3nnz+2LOjzwzeesem/KBDIv5o/wWlYcMg
UH0bBd/uDw7TO8B4/0Oar39e7FjbSOuCfopyL5PE6g9xWKWfTdcidpW/VeqD
9kopOGFrFn88ugKcrZ8I/bx3g6s60fwNxzhM6oK4e4QThs/PRY8Xh6jbeTX/
+DCP/2xP5u66ceBmGgV98wxpW2wllMt+BtXahyCzYTxvs8ikrU+PwlEnBcgu
Xcs/bh1h5VU9goqcNU4ZZokJ7Z2XUqp0ubrVTLTWVcOuc+Fi58b1uNRkGFxY
fQtq+vfnFJl/yMbckh/NvgOaRRL4eCZylpss7HboIfv32VQ8fDZP8/UkK61X
NFPqMaUpZYHjc00YerwElycr0zuLHThsSwxd2qgg5MJk8My1EHdZ2/GGi40E
Qr6I9afY0ncPv57cDVM9R6Hl0mPUO/A+9er5CQXrRSEX97BE5yW47zsepbbJ
cF5gCfVR9APZHYfZyeskHc3PZkN7CeyclkdPp/bjh/8egrOBQ0nV/SidrdOj
5G5jHNf9WKiOKoGIljho2VhFfkfm8oLWEMxK+XRxwPaSsvgSAXoLvpOt2S2I
jEwD09U2rDW8SLjmuJ8OLv4Ftvqp5K93gLYOjcfJS3dgj6I82rkcK1uopIib
9uhjeI8BN+b/hrZxd0E1yoDrHJ3ZxfcLqaqdF7ryh6DnoXRc/DyXPl6Uwj/m
tXTkijGc/PVSlNpSAn7lMtB+aga/3XkXlT1daIX3eq79KAEqWl/BN3Etz1By
50fhhuj+fjx6Wk2iwqMT+C7KU2jODVTqB5Rw+A697ZDESe/2QFnLMY6LzSXV
Pzm4zOsEB9USrM+bhnlyGhhuagwX3HUoxqm1/JCbOj+W7yU/e1Oa8DAJevYq
UvSa04KsVwLtNlXjy2aB2GVnDfsvDMPFHu+p6rIs/laayAYTVrDJgaVkdHoE
uifOwNSo6ai0dhEbW2lhk0wqlBr4cErNdgDPORwiowenXFR4w3sNvCn/Sny8
by8cfPUeXo26Sh+K7wnaqfsxw7xbHHPKl+Xmq/Ou1a6i1scg/m9JPPY77Avf
a5fRKiM3NCtNAol7g2jKpxiaZ2wgdj3ajQsq2yDiTw5VWb0Xd+3twxVmy7Ez
LN+uwWUh5JSIqDMzkDsOx4uTB4bDjjGWnK3GwtX639Snx5MvGCxj8w/7cHBE
NBtO2cUDnqcLU5dawuwn+lSYnitsn3OMhPffaaOVCuWu1ODGFk87d81gcV2S
DOxPrIIn1/qRWu1IHl0eAdpB/XDehUz+WK5A+SuCKXAs0foJtwXV3qVQgIOp
gzzYonoAD127Fc5PiuLPG8fi4yQltDVR4j4FaSSzuS9Z+J4V2lIGck9IJsnK
9UeJKYlsPSwHfAfIYqd3HGrOL4DopwYon34MIk5qYOUzHzT4/omySz/D4apa
cVdiEy/6M5Bz/mb9zFOa5Tv7g1RMDyy6qI5fPzjC0o/a7LDbDO+a6qJ1ejo8
WeFBLz/0ll2d74Nfptjg4RuLhSY7eUFN1YRbRsjjqNcf6OjUixC/fx62JA9l
85bHQmv4j3KHNUe4MGUPPJHvi302l3CxkT0m+52j7iWpEP92MOfMvUPyLbq8
dlYWFU+NZlm7b/T0yxjYWLIeGqLfwAM5LxodPAwh4zRGrkuHuwNSMOKAId54
d5beRLtwbdhgXlRuC22DLbjRwrO8qjCRtN7mCu/sWsTmaiP88+GF8M1/Ba69
/1G4bzaRdxa2QGKWNiou6odfDCdR2vJA8fvNg+wS6kqR88zRsV6TSvRO0rDx
0/G5qjLfPvaMuu4NYZ8fCVjeMQ7Xb2uHU1qysPXkXlFj4AzIcPsX6wd2wZkB
ChhxTY7d5eNZ+f4iwXmiNPrsvgoDzd/B6/Z6UXaGa/l/3v9gytY9eCnoKN7V
qqO9G6MpquMtZI7qpa0BpeKu4V9JS/mm8FFjLF32LrM5Ev2dHrRNwsAzc1H7
ViKcuZAs8lBNGq/zASwPZMCrcVl0Vq2Vgmgz7fIwwYemA/FO6mM4l7mQw9XC
sPJXjLBXfRIohAXgmeQTgk5kFSentUPN8DDYJGkFxRVF4jh9ReFwZw7Oe+0G
FjXOKDtVSnjR4sDFvx3YKv2UMD5UF9be/Ea1XVV08HI/rk014vrLf/NceVi4
W6eIOPUAFLzZh0nLQvlxWykUhp9FGz8FiO+R5hgnN56MzhxV1SgMHC5jN/SL
OknLGcLEaYL4U24Sn63y46J1HmjSnsZW2RG2kyMGc8A6Odxzygj8pBPJ4+lO
cNQ0F07/86R8ufcMKL6nAwqvs2CRVwT1fF1AiTlzUM92AU1ffZuuX4rkf4/3
kM3wHHFd5R7MaBsnSMvL0uoGPUqTyRGbX07iipImemaxpsx0QRhFlfnytbQ4
EKd1iKuUNgshHf3Ze+Q2mndSCS/MvincPpAHvn1WitJrw8BgcBQ5qSuKKQ6z
aOu4AayZk0rp3hac4cAwz3AKzN6uj8bpyB0OI7nojycYFR0TpPIKxatG3wUr
CRM4/eeW+HVBkbg3/4BQ828M1+hFko/9LVHLV4e+JJ2k04luLL/NkwxmEskV
HMSGikdin4tuWH12P6xLdMb7tXG2UmnDKcupWJR2mQsNksfBdtk+UF7hT3Wq
EzCszZq/FI3Fs+vHc9SOYbwjvg4mx4iAYcNxFHeKq8a9pPVDmwXtSDWWvzwD
JjTH4lP/DdDjViy8uLGHvh/6KCzZpQqGmjt4rTAK1zr8EkvlcoXgAfco2G4e
N+bJYWPdU2hQ+kk9B9aButxIlLjTAnWzVolGpIbj3vVFfdsOikq7Bk62trjA
YxHsPlYM95oH8fvxD2hz+igYrr6M93msFg2WXxF++fZFdETmiUvxyV4zTFqz
AvqsSoEAx3Xs0OlHTW9VuTDcCd0OlqPFhL2C6998TxxuF4tWLeC06Vr0rteR
i6aawLKaSRhwORG+DDgkFOd48MY/juQ3FfGR3Sl69VkLXP7sYwc7GTIPaqb5
swbjWZVxrBV8SuiZGcIvszTJ/oEtZS57CTH1Tmj74IztjxPLUbrBneZ7SeLT
3hAcPclMyDmYTfGqM7lUWE4SzRXCC73ZDCmFPK/GHQyilXjUIYGWmv3D8VqL
qdSkm2Jettl6uA3l9/ov6GacKgldJ7gj6pPoscFOGJC/GUKqLRFaF7Hjju+0
5LgKbs3yFarXKeIaxXIcFP1LfBOyhs+f6cdPDtbAnKbZHPvGWKx+dAoiQoso
7q0UxvkF0bmSHOrZfhq2X/gEDlcH8Ry3QpDZbGr3sGcozlsj4IT6d5DzPF/o
VzJNCEkW8EJCFz219QHl73I4cZ9b2UJZZON8Jy4TO+ng33okW9lA86UkweKG
uzDDsV0EmQukXBFC76xXwYPpajD7ygtsrbJgf3c9bvHawQ5rM8BiiBe0LFSl
19I7YX2bGo4InAxXfmykIss2qmj/TNfq4qn8F9IEhU12VxzHo/NCRzHycyAX
d2QL8wOUKfrTDFabqS+2n9yLK7fYQ/ea/eUhjfq4+tIZCpSJhutlGqhRfE+8
F1Nll7F4IoYWreVb7ZV2gwoLyL0GsMXiFllF3oPEwT62VhZauHjhCuwKDeGS
udOpbOAvOmL3CbzwBNw/0Qntra64ILeErvqU0Py1a6DA2ZQ9u1zJ0vIgt7/K
FjStp1LC8pFQddGRHur6Y7q8DPerdcO2CXNw1nlPaPY9QVaB92BW2WJqCw2G
TUe3I5o3kF1cvNBTl0kvhozEdzt0WPq9Fl6RXcOPH6mDaWYDTGmStV12SZU3
NK0FxHLyPlBJt3XN+WLpC0jeeAa0P02HhtoEsXToeMFBKkZ4bBAIni+k8bV/
LHfOUKcBsSP5er4Fns/3JanwA3TwxyPaPFMP3xqroc712eLG59do598e+K5w
CVYHPqaVe7V46nYrPKzwFt74K3CQcTUM6ckBoz8a6Dh9G2g6mEJq5GB+9n0j
rirP4ML8I+Qamkwho46KSw5n0erGsfzF75w4zD6O4+Jy4ElbABQ8awWjoI1U
IX9fDNtqhIf7h4k9SqrYkCaJC23VL31R1eIh+6Rp1LlDYPJ6If5o0KSZw+Nx
R30m6LyUJPWlbcK+deqsMqtICLOJoadvjOBFqTPXb3flNQYeNOLNZNLNzSa5
tr8Gd0YGZx2MxSNBfTlg0Q8a4nmAE19Iigcfn8Ddsr/INngwn4zaR1M+N9HV
UeFkOLsRVlVY8t6FKaB+N4AHyyXypMaPtGBkND2SkOQnz1bwqnWqIKkzh5Yl
VgkzP5/kxGWL4Z9fxfCocgwccJThvonRoLQ9hHcUzASN6haKl0oCDd8Xl3z/
8+dBF/4Vore/xEkfzDG1cCBYnXaAaxHpnL3nPG1aoYChudGC0kOBP26o4sPZ
q7BirR3fTszBmC5FuDfdgvsnapQp7g7nTQW7QXnxIeq3ulKckqBLX6sLwTc9
VVxjn0/BS124+WYszfHQhjtX70JJ+Gz2yc0HB0lNfjBnBMacfEEm152hXmOD
MP3kVbh6fRb23yqH4dmDUK+3kWynqAoO1c58xytaaP63F6YXfhb3qUbZPT3/
ASSVd4lJEw6Iu718BJ8qf3SK1BYzlg3mqdFJcLzKmlUlzTnoRio0uD4AKfhI
u+xDecW1IHTe0kKvX8hy54KLnJLfRR7bv4nWpX/ocCxR/7Qgyn2oBHoWBhy3
cQfFT/Mjne4V8KZ1ANV/tee0kn2wctBoOmPuJwQv97EbNsqVG36Zc+8BRzYe
MoKNAv6ln1dHgd2VRPa3KqMukzEoJdsjBHjpYdAKazF+VAEErOyGbe2DWGp0
At1Ovy7WeRUJTd7GnNyWj9tW7sHph9sFRYN4nCqxi9w9C2Bu8wLIPKbEVd3F
wuCBUaAcbIC74ty5We+P2NZ7A0Il7kOme1+MCVsr7up+SDZDn9EHCxecavOb
3lo9EKZ9KaZ+C65Q1oQCYY+/H7rqv0Dd+9Wwuv8MijqyGk1DntD9tg2k9v45
FEto8YiQvbj4aDFK2y6k1rEZ4CeVDAb9d8Fd9U7x8vfqi5Y1YeW07POl4iBf
yj6bzO67XKH8lO5f7ttJZ564Y1kRwOKdB3HBbANsMErDgsAMrpzVB9en1dFR
1ya4HNqP3xeo45eEv3Ues51b6tTQpEcRje1rOOdYJBl6NUBSxUpu3lYKFzYc
wxKn80KEpCp/cpzPk0aPxFijJKibvB+OW0mg0ZFCIWRWIU188R+EVihhaHcy
290fQaszHHnycGMase4IHJE7gofyJ3JXfKpgtfIlhCzUYOPQC4RewZQ2wYvP
f/oMq1atL5/TnAsBhwzEmVqWvDn8F827LPBmqbfg+8sPQrN38My4KegdJM3w
OJsKKxsw0uUM/qjdgqfnVsKJivEMU6Uw21cNA7ekQvr6epg1qZYijF+R/3Nd
VGyNpNHPFEFfbySu41rRwvumaFN1CnaqyoHz11U4Xfs5+HcvRrX1q/BPlQEb
l3wjFeP5uONnHL1q2kDfVpwBT4WL7DrbSty66aBwyPmG6GgSiWc9+opunjuE
8IVFoPjImz4ub+KOBAl08nbnL1Mk8Nv1S9Cz1YSVwz+SeuNx3JYk8tZNHjjk
uw/X52tgfaMcTtD6jV+uxfDct6/A3zKNHTbbY03mJnZOaOSe1Bcg8dyUZ2yX
Q2+lDSAduJH/2dxf7GNoBX4zpITFm/eLxUFSeHp2P7s2zZGcPX8r5ybKwKRy
zfJtRSqsO2KsaFp6kUoWiHx7X5owSsGHt386Rxc3O6FJXCps9/DH2LESPF5j
KN/ymU/7k134zvX5eCnTEsOdLKl78BH6+iqAqqcEwp+YcLum+gZS2TOHKvc3
g6p/PiQVXwHTVS4o27WNVat38IR7JmQXUgMZZR7g/7oO1h9UJkstDw6T0Ufp
Dj0KvWqKvieO2F102UeLOI9HSJ2nJTOr6OWRG7hy6FKWeSDFa06Z4yaNelG5
6SO+Tw9iB6Oz5DVoEyY1zcGoVCd0jD7ECSZDOM+mAT1yPdlV2pQjdN+JYvc5
cN34BCQuH6WlK99ByzwdvLxHg4+e2CEMnnoPIt+TGL5zGP/eu5oXPyVQUZ1A
/4ky+E5KBW7+GoXWcjqY62YmnHzqjjEZ4Xjpiir+OrCFzB/ZCiuVtrCGxiP4
XZqEeZcVcI3xLgi7fgIH/aUA+Q4lNLsaSUHeAfTx/c2yjH9iKXJag1i7yZHH
bZPk6PZ2NigYhA/uDaIN/sa8XycBAkIPiEcbhlH8MXM0bw+mhB/5wpdjmhgh
P5gdHhtg/7ClsNq4UaiPVBBOKxyCxLUbaHlwGIQn3aauZbP472Dixr6dhBml
wqYqlb8eGE96utNpjXY0H7i/x8Y6KpuWP7fhRq0eWn22Pz+XBYy2eUqjV8wV
SozW05bYi2VZT6YKn9yk2CYzgQdXT4DtEVfhfPoj8IkzozHe1nh1xn/gEGWP
pbXRos22WBoz9wC+OX1OaBp5Cg4+E0R333/4rKECvP00CF9kSeGzDcnkNfUn
nZ94kj7L6vCE0apoejwEOrMfkomULubrPYU3dfGwIq9eDLaKJXV7Rew+rQZn
kwqp9dVKOuc2kQOnWWGdKkKzfCoflNuC+8oVaeG6l8KJTxPEPP3VrDayF65u
GI5pKzvBve9rKvFLoItLLPDQEDt+V3GcZ+/6LZjF+JY7ByUKveeu0vZGQ7i2
yRsfxyqimeY8jkwxAP05kbA/sYwC/4wUG153kU22L8y9Ui0O6t0HbeXzcFDH
bVisWyIoD9FDFVVvKmgxJM28sShmTuBjNVnUULmSsTpJ6Ii1xbjAb6CEPtwa
fBQKrxZBRvdo7tFGPlSTTM9Pnuf5LpNRP0GKMcGZ/W+YYZqxMn6KGw5ZEX/7
13MyF2+8A6ZrRdFlrgrP+pCDSw3eUf9h6eTvcYhedPcIpyIXc0q8FK9r6YOK
xQGwNCUHaoqaqc9jWX5mNpNbVRPgzQ+9v2yaT+9Tl3OfRBX2qFVkMe00LWq2
R/UxXUxLIqHo4RQUMuI5y8eCv3l008Kvhrz33CwwM4mHmxk9gs9EB/z1IwqH
HmiFhstN4Ns3iPUnj4T85deF18F1cKzhH1ondZIGy+6kO+HG+Oy5Gk2cdho+
dIeIzi1M7ducsejIAxrzzYRfladQnsMwLNXyB4V538hY56jQf4kMx04fYudd
sRJVYv6l2bedabe0HzSFJsHz3lah2/QymOXHiouGHsTxXQrQz6sVzHsGc2uC
onD1Rga5ZUnxHUM7nD9yAm8evYv77zESzqVfE017TtLcKbq49WAWGKI39Taf
FYqPe/FyzwM0zy8TFTd+psa2NLyyIEuc2xFZ/rbRkKSSJ/Ga5x5wrzsYv5hW
wIYHvRR/uY7lrsSWT4srJvntevjfUnUKXrYLsDYaV92pBa2qXXA4KQmandJw
kthDW5fIo/ZHNbC7/oEKDFQgTdKC47rl+UJZFjS5x3DDvX680mgHHpIywVST
BhjZXC4Ma2wQvmxKhdxnX+Dc6G4KKJyOa15p86DvCbijdQ2aedmUn5b1hsXN
yWi6bjlMWXyd/lw3xW9JeTyn8QW9W5KI6uqGXH7iCdjHnaXOFnke5T8AJt8u
wsxzrpjxSQVvLu8QpE9qwki7yXxocTR8vXoW+635AT/bczms5+97PkQRd75N
FKTvhoJ6IHIfFx9KZD/oHn/bbthJHQxYkoPVEbGg61oIDvBEoMP2HBP8QQjx
GgKBcbnQoTMbrTedh2THBvKyFjmqZi8Y3JZlzyZH1HgjS/Gj9oNF0Tb+Za4P
p16FYL2jIy3OGo03HUxYu1GOTjWHgLbJF7EpwVtUPW/BF5Veik+HJcJnq3x8
6bcKj1nWw6A3gPGVa2n+k2t04DKIyrNToDThHy4yj2XpFhdWn/qDiub546jK
cNbZPJ4tYhhad9rQoocxuH7GMFw0vJGsV49B6HTE5VnWdGr3v3DM2wCPdRwU
r7vEg9m7eB5SfUbUVqni77LeuKg0BjeLl6H/wmIy/leP1+tpY5wT4tigCBpt
sAgao0RwsPfFsUa6fMnlMryRnA5GoybSuf7jKDG8AfSavtCj2AD8+JLBNTwE
9iuPxcrSTBxZswDvefnQxeRDpOjymvbMsIK8dSc4/HYY36gxx++aD+CPwmie
OycBPilHi0hX4MROF/7QmML2G5XY7rkXJZrvh5Fb1tJYp70wy/sL9K7aTkN3
9UC/rsmcqGoPZcECXt0gjxOb5Xl7ni+vMdNmSUM5NjL1geMJxcIOcIGi8wmi
tupZ0utbDy5HDnHM+/NkOVSlXC79ODx+k2mrE5ELx0/L8YyB/dn3mDcMOeKF
qaokDvh0lHZu1YWxdtKos244PStfg0XJ2cLpFC3SKIimLBURf17X4YxDEtzQ
PZMFmctUfyaNPyi2Csust0PnOXvuHlpM8ft3c109snXXckyu/Acn2Gvx4GOH
hRPXb9D4idMgd/9qXittjBELF2Po1enwrKhJLApOQNmPe+nXBU0MGXeUHzyI
hu4tewVxbI/wPs6Di/2Y971Jpq13/7K49DiM//NN6Pqv0+46XKaA6zpove6h
XYS2AKG7gEeMLua3yzdRp9IdyH2zAxa9qim3u54HuWN+wgOLWbC0+reg1/aK
7sa108MlQzGygoQz0ZYsOTAVRz46iO4rnsAgn51CdXUr5FZq8iF7X7ArK6RF
TsNRYUtG2QhlOfS9MY1B7QNELW6De/PjafgEf96Tf1YckrkGN7w7IFz4nSr2
iVkPo1wms9vncThpXx6Nmd+Xb0e9gPUxMiw/ubJ8wrsI6N1mz703FtPdzfYc
0G3HDr9f/vXctbzz8Qq+tXkItmRFsWJlBF2vccR02zJRytkbzywzxdjAvrzH
63HZvXPuDOOelh/Oy8c0vU7hV5kexdT6g1g9jXR1XuC6kGwhy/cKPJzwHH5R
Ofb/MoOG5uwSsxIkWZhqxT+OrOEn546gzcG3NLwin3LHhcPA3uNQr5cMhWdv
Uj/H9eDz+KYg6FjwmMQh2HpKkae/1OI708bQ3be9MO3dQDJZoMnrrodS5JIH
onMM8MCcafzZ65h4/pwhDhwaD38WbhMPlb6lAZWG6P6mi56bzMbXfQQafncW
+zyzRpnVXmCyUcD0UW00ur85RacdJSNtY7zdeY52e9wrL1/7TJQcLM2SM7Sw
5JI5Zn82QS04T45nXWmK20DIt5yE0zWHQnJKEq9o34AbJvcVJNWeQ0bdLfpX
Kwsqxx1ih5QNBGaRlH8sF5YenoZtj4aBpr0/rljhBBEebjx4/5Uyn7xGqgiN
EJ6MPkuuJy5SH/t4mLLND2/dvEUfNX8IKzUm49UpjA4vKmBv5U6IyrxP6rnZ
FO70nEYNqQcxulS4O86RzP2uUOmmKihw7KKjR7/SJreTkDAjD3IG/6Rd7UZi
p3CQ1sf7QMadAViiU0xBzyz4QfFGerVkGi/cdAokvRrK1aLUsP3CbcH5TgwN
HOgMbQ7TSDn8ihj7VJkrVprjdtelUHPeBNKOS+DUj9+pOT4NtD7G0ZS8QIo3
CkX/Owpw2W4/uQ5wo+O/ZPitqzc8CGykld1x8FZmCiUr91BJ1b+o6hAFh/Yr
oGT7DXHynmg+Pr8ClsUsEHx3zyEzielQmr1bvHBElQy9ZSgipJX8eiVEG/2+
3PzfBqwpHo2ZRmXgkaHG/9YOEeaoOghXLnlhlZUOnGvdjuMSAJzWfIUlie9F
lf3HKXnECBhZL4M3tn8D1/em4FWgK3qMdwJYOA2DZyqi9jwVvteRSFebXlJJ
0ghuVdQSZ7uehUsHHvLA3mqxudYXr2up2mnPCkTlVbM5s2E319dHoexKB+xs
teR+J0OFMzmxNDxvEEQ8U8Erm8aicuU3Gh3fQdE/HoiWj/pgnoUzt7e0Qeoe
E0oO6hZehSRQ9gt7rpHuz13rQylldid1bb0Cd082weRTWbT/xiLBylVDXPBh
P1TNSIdjWnWcpJaEOYqjBWr9TokxHbRpZsElKZOzQkPYGjbwGsfHIvPRQmIn
jA5I4H4Ze3BW0TRW6Uqg8x078NviSlihGco3ZzaARkit+LC4QNj6oR/JHnfF
rBw59t9yE8bE5winZkrz+/nV8P76R6r7LcFS+x6S/IDHpGSXI34ao4Kni+5Q
2yVtfvx4MFu+8sdlK0vp3og9sHniJDb957P41KYQtiRYY5ebPA+J3EHB1ExF
M5ejeOIXSd2YK5pNSsOv+7xh5vVAHFprgpk53fRy0GPoO+szZH2qER7/PCfq
rbosPjFRhPOb7pJn1CrUxSRyuqMsth9YAfeUI3DlwWWkByvh/dFMzkx6J9zx
jP/r8+2Cc9QK0vilCHtdxkCIVSS+a3UFBdsyOlzzUhzVqEiPtBR4XKkpjtg7
XQiJNUTWV8FfftEQ2+XDi1emYHzrElbum4xazVKk79xIdqeNWKIplqQ+jmep
fu1kfl6VXwRLcGLbS1i6rQxy/R2x46glWG2YiH2eOODXtxvJ+GI66m/zoS+x
j+Bmn7F80E6Jzl/5KIbY1dAwWUseKTkME9GI8xN0+YTdcK7os46Tr7jgxq58
0Jy6ixJe74N7U6LRXumbUP16BarrPIK9NpGsW1sHiyqUULfGG+/M1SdZOx2a
YnYC2u/5c8K2Ol7+cA/PfXxalNK/DRYBsRhzPobO2f9DLarp9DH+j91LqRja
l6aJNWE1woGo0L8en0ENrpKcph3G+T/Hi1vhkvCjTJY8PvWlR61OsGD7alRy
WML7y4pIwrseCn/Gku3Zfii3bjTGHh8F0o+eiBB/jbIq1rJL7Q6e1+nEJY/+
0CWVm7DScifHBS7jxKdD+cyHEdS7NJt1nipxcIQ1PO03nhxi/3L0Jjssf2KJ
Xv+8ES97/Oaflp3CBilpHKG/TGysTYFOVMAxb/ShLqwCJsn/tSUNM5py5jLI
zbWH3z8rqS7bjGq3qsGCpnoyGVJJj56q4kIxGM8tV4ZPez/CnvuSNIMMsepB
lJ3P7b6w6rYMP1eN5OpmG/KYbYbHSwfj5eYkmHznA2WER4FqoD9Gzc3mmSN3
ovY+L9A90UTa7Udg/AIJrP6DsG/BEEZDfbw93YQlw0PZbNZ/4pWCFPQsfUZ5
mt9s9T4W8d6UMA5KrQbbb17olVAOT+erQP5GW85ttcKI3ptCZn6VoN4zike8
ducj129yatAc7F8RBAdMd4g7dyVhyJ8J4v6wkVj0nylq+Xth/0f1lGP7Byye
T4QArVsw0W4zqs68Vf7fjzzSnH+apEQFvL5PhQrsFaHjlx2lFTrB84cnyWLD
UHGEsbP446sjvW9z5qBDSiA11B+/7X0AifOfiglXPsFSR3+M9LpGujtWYYml
Crxe4k4DQidimMJz+ne0Ov3gVOpVAdqSvx5PDgq8tAUuw/S0eEjWNKOU9tkY
dUGXfngFw5g749BzjQ3WWy/gEyOTSMtzKHf8Gc9Jr7eAD/eFSQ5fxbzfDTDW
XF7sGTSWSxe9EovnZ3JU32LKmPIN+pdGo6GVJOsMmo+F7qO50yZc0H0lT25H
ZgnHvjnjpLotlOztwDauR+mr/Al69NYIdx3UECwvFFJ81xwMcJ0G4fpBvL1o
Drt/NUW1FmvaLcZS0ttEqvrTl0+9rYHDm4JZ3tSJUV+JO+91CiVVzULtif7C
sytBrLyiRRgSvZATd6/gA90bYcf7WWiyeSRN1umB/EWLcFP2YVh+rxzul3eR
fs4RMUDnHMVYb4AP61bzZsub4qSci6CRW0U75hnw63411C2fQHAihiT7pNud
DpLnrhMaGPbDmGRi7EimdhCGOD+hC//VQsWNXtr4vIY6XiryLIkRdFDrlqBz
YAAsPjKK/TJm84lbfaj/7Erw0dkGW0ZrcJ7lT3Ca3Bd7fKPFX4PSSfFhjXj6
778498ExLkmNp/J5MiC/aQsfu7ab1h8xxJMOpmjaNhbbhhSBPuYJu2ov0Q3Z
L6BcPRyPlo7kguu9VL5ZBq0WRrPki06YO+686LtlIma/C6HTaZZ41zAWTHPT
6O5RDdbN9IKxTxqg+VAzecYC1mlfBnvlVLHRpwlWQSP9KOy1PWRaKowyGsQ/
pt2EipV2KGz2p/8DZYIB2g==
                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.05188700556755066, -0.012964822351932526`, \
-0.08500837534666061, -0.016288019716739655`, 
                    0.0601920410990715, -0.008449006825685501, \
-0.05061934143304825, -0.03993301838636398, 
                    0.03194562718272209, -0.0163937509059906, 
                    0.032893918454647064`, 0.0758521631360054, 
                    0.003493112977594137, -0.00472523458302021, 
                    0.01184166967868805, -0.014973372220993042`, \
-0.005650565959513187, -0.061554063111543655`, -0.060621872544288635`, \
-0.01624704711139202, 0.015551816672086716`, -0.0625731572508812, 
                    0.020008889958262444`, -0.023659570142626762`, 
                    0.02593090385198593, -0.10793158411979675`, \
-0.005824992898851633, -0.019449913874268532`, 0.055188681930303574`, 
                    0.033379506319761276`, 
                    0.014815929345786572`, -0.043953292071819305`, \
-0.001970017794519663, -0.07461933046579361, 
                    0.0047330171801149845`, -0.044792018830776215`, 
                    0.0018482623854652047`, -0.019943421706557274`, \
-0.041565898805856705`, -0.015724921599030495`, -0.06847350299358368, 
                    0.03797978535294533, -0.007913258858025074, \
-0.018708333373069763`, 0.03209633752703667, 0.008733455091714859, 
                    
                    0.011846802197396755`, -0.04293498024344444, \
-0.05420650169253349, -0.010861513204872608`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dUz4/3x1MKpUGkNHxaomG16P26V4qMNKgIGRUyEpJdGqKUltKUUklC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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.07285068929195404, -0.027293231338262558`, \
-0.04321644827723503, -0.04937264323234558, -0.04546893760561943, 
                    0.013071202673017979`, -0.03463941812515259, 
                    0.006800499279052019, -0.012120070867240429`, 
                    0.054220523685216904`, -0.07262459397315979, \
-0.030887655913829803`, -0.014965941198170185`, 0.004744399338960648, 
                    0.00766668701544404, -0.021403949707746506`, \
-0.019846711307764053`, 0.010466521605849266`, 
                    0.02146589197218418, -0.06801160424947739, 
                    0.03736766427755356, 
                    0.01623838022351265, -0.03803618997335434, 
                    0.02058066986501217, 
                    0.06337274610996246, -0.025985276326537132`, \
-0.07645463198423386, -0.022281864657998085`, 
                    0.0637972503900528, -0.006116055883467197, \
-0.07808104902505875, 0.03643691912293434, -0.014075148850679398`, 
                    0.02453780546784401, 0.02742738276720047, 
                    0.03629031404852867, -0.10476342588663101`, \
-0.048924654722213745`, 0.023742014542222023`, 0.01528850756585598, 
                    0.0020924671553075314`, 0.005697442684322596, 
                    0.029371630400419235`, -0.005154581740498543, 
                    0.030263612046837807`, 
                    0.0030620028264820576`, -0.025856249034404755`, \
-0.018241064622998238`, 0.009778818115592003, 0.009606657549738884}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2c41//3x+0VslWUlJFRIhSf9zlo0rCaNIxKpaGhHRmhzMqqEEqZpUXx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                    "], "Biases" -> 
                    RawArray["Real32",{0.000818145927041769, 
                    0.02447950467467308, -0.01106187142431736, 
                    0.023475974798202515`, -0.0439378097653389, \
-0.02557755634188652, -0.0015006348257884383`, -0.09429129958152771, 
                    0.01828974299132824, -0.031440675258636475`, \
-0.02821897156536579, 
                    0.023312553763389587`, -0.015577432699501514`, \
-0.019184444099664688`, -0.07450070977210999, -0.01807933673262596, \
-0.03789251670241356, 0.037231236696243286`, 
                    0.017623670399188995`, -0.033134862780570984`, \
-0.0422690287232399, -0.015541517175734043`, 
                    0.0622594840824604, -0.05153306946158409, \
-0.04630328714847565, -0.025871945545077324`, 
                    0.01066332496702671, -0.010631413199007511`, 
                    0.013388755731284618`, -0.018007205799221992`, \
-0.009236622601747513, -0.001433095894753933, 
                    0.004119307734072208, -0.024152174592018127`, 
                    0.019785631448030472`, 
                    0.021390635520219803`, -0.005238785874098539, 
                    0.021143736317753792`, 
                    0.02099192515015602, -0.015321972779929638`, 
                    0.010469513945281506`, 
                    0.05162075161933899, -0.018146023154258728`, 
                    0.0042555071413517, 0.052645668387413025`, 
                    0.05315101891756058, 0.04217229411005974, 
                    0.035689499229192734`, 0.03198647499084473, 
                    0.016533905640244484`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray[
                    "Real32",{{-0.04809097200632095, -0.06619758903980255, 
                    0.18344098329544067`, -0.43981993198394775`, 
                    0.25722306966781616`, 
                    0.06549123674631119, -0.1635257452726364, 
                    0.02948574535548687, -0.060175828635692596`, 
                    0.10501134395599365`, 
                    0.3362386226654053, -0.0898195281624794, 
                    0.07634793221950531, 0.17905983328819275`, 
                    0.20972788333892822`, 0.1186046153306961, 
                    0.0877169743180275, -0.10386399179697037`, 
                    0.1029181107878685, 0.09030476212501526, 
                    0.004224465228617191, 
                    0.1030086949467659, -0.13752323389053345`, 
                    0.013605858199298382`, 0.14370697736740112`, 
                    0.11125189810991287`, -0.07250893115997314, 
                    0.008711881004273891, -0.06012982875108719, 
                    0.06364061683416367, 0.110772505402565, 
                    0.005277593620121479, -0.08144079893827438, 
                    0.054469671100378036`, -0.0009495971025899053, \
-0.08799749612808228, 
                    0.12155728787183762`, -0.3744087517261505, \
-0.018008306622505188`, 
                    0.06475518643856049, -0.0968855768442154, \
-0.10430314391851425`, 0.2185443788766861, 
                    0.044714730232954025`, -0.19531238079071045`, \
-0.08196185529232025, -0.16716089844703674`, -0.03183754161000252, \
-0.1846475601196289, -0.06559179723262787}}], "Biases" -> 
                    RawArray["Real32",{-0.026820845901966095`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.8649173974990845}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 0.6874126, "MeanInputsPerSecond" -> 
          46551.372494481475`], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.0003145059730577686, -0.00024389862347338939`, 
                0.0007066503926780335, -0.0002325879733872891, \
-0.0002161158624126499}, 
               "StandardDeviation" -> {0.9994229926970353, 0.9998966189861109,
                 1.0000382305277749`, 0.9999984213472487, 0.9997881312867569},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 5287015175410666490]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 100, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.1523809523809524, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[364705], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.30192107683136726`, "PreprocessingTime" -> 
        0.4707386`7.12432480488878, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.5165024475909943, 0.12639810280352917`], 
           "StandardDeviation" -> 
           Around[0.4002916518023228, 0.06042230191960101], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 107736, 
           "ModelUtility" -> 0.19263809732941495`, "TrainingSize" -> 252, 
           "TrainingTime" -> 1., "TrainingMemory" -> 522520, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.5165024475909943, 0.08937695562148984]}, 
           "StandardDeviationHistory" -> {
             Around[0.4002916518023228, 0.04272501942225082]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 100, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}, 
           "FinalTrainingSize" -> 315], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration", "FinalTrainingSize"}, {
           TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}], 
            TypeSystem`Atom[Integer]}], 
          Association["ID" -> 195743346749074]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[6.092213484579202, 0.6660693475661732], 
                "StandardDeviation" -> 
                Around[0.8385689789418302, 0.04203803827136802], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.5270988892774898, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495792, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[6.092213484579202, 0.4709821524045405]}, 
                "StandardDeviationHistory" -> {
                  Around[0.8385689789418302, 0.02972538192946393]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[7.814156879551435, 1.303693033042893], 
                "StandardDeviation" -> 
                Around[0.5065684065042608, 0.036173307128220665`], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.027265875398325812`, "TrainingSize" -> 
                50, "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499824, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[7.814156879551435, 0.9218501842502874]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5065684065042608, 0.025578390768308507`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5165024475909943, 0.12639810280352917`], 
                "StandardDeviation" -> 
                Around[0.4002916518023228, 0.06042230191960101], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.19263809732941495`, "TrainingSize" -> 252, "TrainingTime" -> 
                6.309573444801933, "TrainingMemory" -> 522520, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5165024475909943, 0.08937695562148984]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4002916518023228, 0.04272501942225082]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4002916518023228, 0.06042230191960101], 
               "TrainingMemory" -> 522520, "TrainingTime" -> 
               9.471859998463529], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.410236642098897, 0.18672612380518894`], 
                "StandardDeviation" -> 
                Around[0.5296372421377473, 0.02927903198861835], 
                "EvaluationTime" -> 0.00015459545750832804`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.06861374052636904, "TrainingSize" -> 50, 
                "TrainingTime" -> 0.5011872336272722, "TrainingMemory" -> 
                499616, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.410236642098897, 0.1320353083673279]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5296372421377473, 0.02070340206572988]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5165024475909943, 0.12639810280352917`], 
                "StandardDeviation" -> 
                Around[0.4002916518023228, 0.06042230191960101], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.19263809732941495`, "TrainingSize" -> 252, "TrainingTime" -> 
                1., "TrainingMemory" -> 522520, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.5165024475909943, 0.08937695562148984]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4002916518023228, 0.04272501942225082]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[5.794917661785722, 0.6737202685125513], 
                "StandardDeviation" -> 
                Around[0.8374405589003688, 0.04415887583258574], 
                "EvaluationTime" -> 0.0001299709711359511, "TestSize" -> 305, 
                "ModelMemory" -> 107736, "ModelUtility" -> -0.526267023043439,
                 "TrainingSize" -> 10, "TrainingTime" -> 0.3981071705534972, 
                "TrainingMemory" -> 495848, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[5.794917661785722, 0.4763921704880466]}, 
                "StandardDeviationHistory" -> {
                  Around[0.8374405589003688, 0.03122504055079612]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0001299709711359511, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.8374405589003688, 0.04415887583258574], 
               "TrainingMemory" -> 495848, "TrainingTime" -> 
               1.7552248208707883`], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.5024082870881874`, 0.3730033443091592], 
                "StandardDeviation" -> 
                Around[0.5432273358071232, 0.033177410249008145`], 
                "EvaluationTime" -> 0.0001351002078275469, "TestSize" -> 265, 
                "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.09509280840699952, "TrainingSize" -> 50, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                428752, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.5024082870881874`, 0.2637531941662671]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5432273358071232, 0.023459971769281718`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5900346023041442, 0.1571457982916386], 
                "StandardDeviation" -> 
                Around[0.4298901592482009, 0.07138149052795348], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.11837643889896299`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 451720, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5900346023041442, 0.11111885960699103`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4298901592482009, 0.050474336003519214`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[7.481761960410332, 0.8566760741480679], 
                "StandardDeviation" -> 
                Around[0.8952363760969725, 0.047182603645853985`], 
                "EvaluationTime" -> 0.00013806927383312083`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.592997424732371, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                424656, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[7.481761960410332, 0.6057614613103683]}, 
                "StandardDeviationHistory" -> {
                  Around[0.8952363760969725, 0.03336313899202047]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00013806927383312083`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.8952363760969725, 0.047182603645853985`], 
               "TrainingMemory" -> 424656, "TrainingTime" -> 
               1.6521447577970134`], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[14.129229385572957`, 2.220507784241601], 
                "StandardDeviation" -> 
                Around[0.5762421225200927, 0.041139898270446944`], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.1561296190546393, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                428768, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[14.129229385572957`, 1.570136111914751]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5762421225200927, 0.02909030104435775]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[7.027702788092377, 0.8051216567082962], 
                "StandardDeviation" -> 
                Around[0.8694143125562378, 0.0456569729156063], 
                "EvaluationTime" -> 0.00010323961206782055`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.563691886399007, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                424464, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[7.027702788092377, 0.5693069831385837]}, 
                "StandardDeviationHistory" -> {
                  Around[0.8694143125562378, 0.03228435515707575]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00010323961206782055`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.8694143125562378, 0.0456569729156063], 
               "TrainingMemory" -> 424464, "TrainingTime" -> 
               6.577306748713622], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[12.77765602315695, 1.9579596863883317`], 
                "StandardDeviation" -> 
                Around[0.5920455326591647, 0.04111466484752069], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.18280096892694353`, "TrainingSize" -> 50,
                 "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                428752, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[12.77765602315695, 1.3844865715350752`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5920455326591647, 0.029072458319894044`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00012279953685898285`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.5920455326591647, 0.04111466484752069], 
               "TrainingMemory" -> 428752, "TrainingTime" -> 
               2.618472979592802], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 195739051781778]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.0000153658519553073`2., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097570729557569`17.333472273171957*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 3.087381559062487, 
            "ElapsedTimes" -> 4.6306115, "ExperimentCounts" -> 4], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 5.145635931770814, 
            "ElapsedTimes" -> 5.9829827, "ExperimentCounts" -> 5], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 8.576059886284687, 
            "ElapsedTimes" -> 9.1432985, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 195751936683666]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{-2.245104345849121, -7.59940581983865, \
-5.849196524803394, 1., 3.912023005428146}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 22.0466771, 
        "MaxTrainingMemory" -> 962416, "DataMemory" -> 75768, 
        "FunctionMemory" -> 274216, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 51, 13.9301508`8.896530771579968}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {
                    0.5186761127340378, -0.05654553703591192, \
-0.11425261256334132`, 0.4666666666666667, 3.6811827759436997`}, "Method" -> 
                    "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.5186761127340378, -0.05654553703591192, \
-0.11425261256334132`, 0.4666666666666667, 3.6811827759436997`}, 
                    "StandardDeviation" -> {6.985564721139147, 
                    4.3348215960623655`, 4.2891060508028795`, 
                    0.49888765156985887`, 1.4520909127502026`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{
                    0.5727223633413101, -0.0824548875915385, \
-0.1548067595493231, 0.6360877386211462, 
                    0.48643349187189566`}, {-0.36123199294107894`, \
-0.24403462540247606`, -0.7519743298550783, 
                    0.36537649181460835`, -0.3331563827225061}, {
                    
                    0.32337881152551023`, -0.4153881438300411, \
-0.4610356077863361, -0.6621827259412665, 0.26802805830707144`}, {
                    0.21787366714106254`, -0.7662102768852824, 
                    0.4004272277969885, 
                    0.133023275293988, -0.4329153730589417}, {
                    0.6240655023532502, 
                    0.4171603944261153, -0.19409708402947745`, \
-0.07557283705233936, -0.6270044037851311}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.5186761127340378, -0.05654553703591192, \
-0.11425261256334132`, 0.4666666666666667, 3.6811827759436997`}, 
                    "StandardDeviation" -> {6.985564721139147, 
                    4.3348215960623655`, 4.2891060508028795`, 
                    0.49888765156985887`, 1.4520909127502026`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0233137, "MaxTrainingMemory" -> 94064, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 51, 13.9840058`8.898206549120216}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {
                0.5186761127340378, -0.05654553703591192, \
-0.11425261256334132`, 0.4666666666666667, 3.6811827759436997`}, 
               "StandardDeviation" -> {6.985564721139147, 4.3348215960623655`,
                 4.2891060508028795`, 0.49888765156985887`, 
                1.4520909127502026`}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.3404900641306363`}, 
               "StandardDeviation" -> {0.7220608282845569}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.3404900641306363` + 
         0.7220608282845569 #& ), 
        "ProcessorFunction" -> (3.2414029018733483` + 
         1.3849248717393516` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.9302096260189576`, 2.4358057708397527`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX0w1HkcgJG3S2gsdl2pURY1qfXasX6fn5dbx50Ywlx1yiZdhLCbJV2j
vEwryV3skdM6bzHpdJe7lP19vt5fJm9X6FA4LpyXiGuG47arP55n5pnH7OS5
gNNqKioqIu33ChBK3OLjhUmHNT9EuDDKzjbqw7R9j8Z7bjZ9isl6e+FQ72fQ
b+BKOPMH6cL2fqbSwQpMfCvgqrkM0/88DuZjD5l1Sz/qlI46zfXPRVMbI9pJ
KqGPS21AnMmj3t12As4mNp3W2U9lluuQxIAmF8a2iVrWymeWag5AQ68xrf+u
HOWpWyG7ZR5tmJPY7eUB0T07IZmdDT9WX4St364i70EObl8Phy5NPtYdzcBg
ze8xTD2aXp4oQf+aLfQN8SQ4Ng+jPIKDM/mvmK5fi5FbXAWuLalUZ/se2mVg
hVp0SCGCJBaRPHNT6PTl4hfiRlQfXML10vP0racCeofOCmQtfEJWrVKphzN3
SO/sPnykWMd05XN0/2ECBGcW0LLaCDzU2GiiPQElefVgn9XGCEfHFbkyb2z3
9CO1ekWQMONN+Il21O3HPGakYQ5ckzoYw9xyTLjWzBhOe+ALRxlOrciwNL0Z
WpSxWKY64zIi7Aa+UIdyj9En/RF2JC48B2t/aoO14k7cbTVPLaguYak8iIxy
1UhwXSbW9BkQ+wt1aNR0FUIi95Ihz2KY7LiLdfnnkLiICFiY0w0J9ShtHYAj
nI9QWmiN+5RGZMrzHpipe4CIpUedLdcjU6pehPuGRwsiuPDY8jVOh2VD9yNb
2B4ci7dMN9PioJegYPuAZUkJxtiJwSZlDq0nrkD3UA8z0usNW07/gVZHq/H3
0EJk5XWAd9Vm8ouNCUkvS6E1iT7hj8zigCye4ZxvQleROSkAZzL11X76bdQx
2ryiHHiWXAKtrfi6CKgcjXkYUxqQ4t1p1MATCS468yGrwZC8OnAJdfPXcBd/
GJqFyRDU9SWEafjC59/9xzw/9Ay7Fhph8GtTcmFxGER6eThsKsfFiyzi5FOE
19PkIMk2JrNyIRzxnUZ8sY0e23DGLpkVakmTwK0giIxrF1D3ByVY9oZFrziu
4kJIHzTfq1KwHCIZlRkN8nZwA6MdJyHj4DeMn5cmHSpowxO1aTj3VzmerZyg
OC8/JpJBQ7i7K5QODEC4eew6Bu6IIevsSCKOfkpFZszhNl4xGM6ZQqaWLipD
4rAyxJ1aydWmn7jNYnpqNv62Pw4vt2XChkiJZ+JcFAXMMJIre5i/J7PQAvvR
//IJsFz2oRsXWQQn2SRR05iM33HDBy738cbaKeJ1qRUSKg4TqbMJBP58jRFn
iKA+Rh2te3RBzdFCESvjkw37Udz0bzsW7HQgAs8h/IdrxvwPTCAAwg==
                    "], "Biases" -> 
                    RawArray["Real32",{0.009823484346270561, 
                    0.028382789343595505`, 
                    0.02561095915734768, -0.023213019594550133`, 
                    0.005619267467409372, -0.027566496282815933`, \
-0.011463671922683716`, 0.0585540235042572, -0.022601425647735596`, 
                    0.03524307534098625, 
                    0.03841551020741463, -0.008497687987983227, \
-0.04634975641965866, 0.054089393466711044`, 
                    0.0023266724310815334`, -0.013743825256824493`, \
-0.005956823937594891, -0.0072071850299835205`, -0.012619748711585999`, \
-0.02332649938762188, 
                    0.031046831980347633`, -0.0008084066212177277, \
-0.06480704247951508, -0.03324750438332558, -0.028427833691239357`, 
                    0.006190837826579809, -0.0186079740524292, 
                    0.03996038809418678, 
                    0.005534498021006584, -0.0009628275292925537, \
-0.03372930735349655, 0.0376972034573555, 
                    0.026302484795451164`, -0.03544184938073158, \
-0.06921026110649109, -0.02390929125249386, 0.018928971141576767`, 
                    0.0527925118803978, 
                    0.010965363122522831`, -0.04241103678941727, 
                    0.008683747611939907, -0.03162415698170662, \
-0.07187560945749283, -0.006033460609614849, -0.06130565330386162, 
                    0.07431979477405548, 
                    0.02878754585981369, -0.06811002641916275, \
-0.023803267627954483`, -0.07022029906511307}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtmGk0l43TxxGyJFuyJGQLLUgkv2sGpZKKUEmlUiktREmkoqJICdmKiPYS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                    "], "Biases" -> 
                    RawArray["Real32",{0.007586234714835882, 
                    0.039391424506902695`, -0.020243806764483452`, \
-0.0346267931163311, 0.030337391421198845`, 0.04266529157757759, 
                    0.009922627359628677, 0.027352746576070786`, 
                    0.015037628822028637`, 
                    0.0018645174568518996`, -0.005107145290821791, 
                    0.004093309864401817, -0.00017228677461389452`, \
-0.015061253681778908`, 0.005185962654650211, -0.014214341528713703`, 
                    0.02868959866464138, 0.014175576157867908`, 
                    0.014489062130451202`, 
                    0.023256180807948112`, -0.03819790109992027, 
                    0.037548672407865524`, 0.014491820707917213`, 
                    0.054538555443286896`, -0.018386507406830788`, 
                    0.013254229910671711`, 0.014693516306579113`, 
                    0.048798780888319016`, -0.06329760700464249, \
-0.005562484730035067, 0.017633382230997086`, 
                    0.019905341789126396`, -0.015000695362687111`, \
-0.02083563059568405, 0.01801007054746151, 0.01705704629421234, 
                    0.003532374044880271, 0.01399940624833107, 
                    0.02138012833893299, 
                    0.04377143085002899, -0.013794636353850365`, \
-0.04973447695374489, 
                    0.008865983225405216, -0.043938107788562775`, \
-0.002023976296186447, -0.032357871532440186`, -0.0677594244480133, \
-0.01606883481144905, 0.027399525046348572`, 0.014377503655850887`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dUz4/3x9MQSSUNWhSpjDToo96ve5WGEdGgITsJaSGZaZEKKaIiScNW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                    "], "Biases" -> 
                    RawArray["Real32",{0.0065707433968782425`, 
                    0.016028644517064095`, 0.00047819907194934785`, 
                    0.020855814218521118`, 
                    0.020847024396061897`, -0.005661739036440849, \
-0.010715102776885033`, 0.005377117078751326, -0.011662301607429981`, 
                    0.006724693812429905, 
                    0.022151432931423187`, -0.016432754695415497`, \
-0.015749720856547356`, 
                    0.009623494930565357, -0.011058897711336613`, \
-0.005531634669750929, -0.002791011705994606, -0.05013037845492363, \
-0.035970333963632584`, 0.01347159780561924, 
                    0.007848476059734821, -0.019413767382502556`, 
                    0.036604441702365875`, -0.008494107984006405, \
-0.02216290310025215, 0.015070829540491104`, 
                    0.040210265666246414`, -0.013520768843591213`, \
-0.005216018762439489, -0.004195114132016897, -0.0581827349960804, \
-0.00983554869890213, -0.02427184022963047, 0.03861748054623604, 
                    0.01920946314930916, -0.017976971343159676`, \
-0.003914163913577795, -0.016397245228290558`, 
                    0.04358626902103424, -0.0022866190411150455`, 
                    0.022234035655856133`, 
                    0.008526913821697235, -0.005335257854312658, 
                    0.0070495218969881535`, -0.0020510631147772074`, 
                    0.011972114443778992`, 
                    0.010861612856388092`, -0.016396325081586838`, \
-0.020200714468955994`, 0.035784583538770676`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUjo/Tx0nRolCKUNGmpEVZ0n3NFCklsqUiSyKSyBKVNSWk0l6yRKUk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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.004506872501224279, -0.013174557127058506`, \
-0.016423547640442848`, 0.007636896800249815, -0.01466132327914238, 
                    0.03090221807360649, 0.0061853062361478806`, 
                    0.02724352665245533, -0.00873370561748743, 
                    0.008970588445663452, 
                    0.02357490547001362, -0.01157170906662941, \
-0.0265644621104002, -0.0012860748684033751`, 
                    0.003002363722771406, -0.0017554974183440208`, \
-0.015946250408887863`, -0.0016497921897098422`, -0.042070209980010986`, 
                    0.010126378387212753`, -0.026495372876524925`, 
                    0.02629389986395836, -0.014315380714833736`, 
                    0.027318475767970085`, -0.009423634968698025, \
-0.01283616665750742, 
                    0.01013453770428896, -0.007096432149410248, \
-0.013743565417826176`, 
                    0.026744060218334198`, -0.013301541097462177`, \
-0.002015559235587716, 0.02563733235001564, 0.010490065440535545`, 
                    0.0006495733396150172, -0.023185571655631065`, 
                    0.004654372110962868, 
                    0.0005150548531673849, -0.00018756865756586194`, 
                    0.011591179296374321`, 0.012727521359920502`, 
                    0.0463084802031517, -0.010063585825264454`, \
-0.012102543376386166`, -0.004404416307806969, -0.009454166516661644, \
-0.004546316806226969, 0.004208469297736883, -0.0365903303027153, 
                    0.012881751172244549`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray[
                    "Real32",{{-0.19337326288223267`, -0.22840936481952667`, 
                    0.07904986292123795, 0.3354961574077606, 
                    0.17914257943630219`, 0.21595929563045502`, 
                    0.09881407022476196, 0.0916374996304512, 
                    0.26161038875579834`, 
                    0.21449175477027893`, -0.3243938088417053, \
-0.008337534964084625, 0.2014879733324051, 0.19859135150909424`, 
                    0.06413615494966507, -0.03149817883968353, 
                    0.24592049419879913`, -0.17246150970458984`, 
                    0.01344692800194025, -0.07788550108671188, 
                    0.05920175835490227, -0.03789390251040459, 
                    0.020834168419241905`, -0.08357079327106476, \
-0.02216448076069355, -0.13833050429821014`, -0.09803784638643265, \
-0.10045593231916428`, -0.2260219007730484, -0.2274845987558365, 
                    0.13662853837013245`, 0.11293046921491623`, 
                    0.17641301453113556`, -0.062284573912620544`, \
-0.04645085334777832, -0.040628157556056976`, 0.22256456315517426`, 
                    0.3095824718475342, 
                    0.12950082123279572`, -0.2949845492839813, \
-0.04567059502005577, -0.11730366200208664`, 0.004490496590733528, 
                    0.20459912717342377`, -0.1501823514699936, \
-0.10972099006175995`, -0.04402969032526016, -0.2035246193408966, 
                    0.040654294192790985`, -0.1375751793384552}}], "Biases" -> 
                    RawArray["Real32",{-0.016334302723407745`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.3342325687408447}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 0.6247955, "MeanInputsPerSecond" -> 
          40973.406498606346`], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.017852640167262, 0.004196044234214371, 
                0.029746505021140415`, 
                0.01895372699169022, -0.01431530322164417}, 
               "StandardDeviation" -> {0.9994957865013525, 0.9861300016175952,
                 1.0031572501533597`, 1.0008832954376197`, 0.982213823096666},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 6074018774571329539]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 100, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[364817], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.32564589393651533`, "PreprocessingTime" -> 
        0.3999747`7.053577514829206, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.5855761061478973, 0.08879315539689572], 
           "StandardDeviation" -> 
           Around[0.40734342215636693`, 0.06087551782942396], 
           "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
           "ModelMemory" -> 99880, "ModelUtility" -> 0.1754680737277109, 
           "TrainingSize" -> 252, "TrainingTime" -> 1., "TrainingMemory" -> 
           451768, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.5855761061478973, 0.06278624230409585]}, 
           "StandardDeviationHistory" -> {
             Around[0.40734342215636693`, 0.04304549146542826]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 100, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 213880993640101]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.8837405792491766`, 0.32813502122618027`], 
                "StandardDeviation" -> 
                Around[0.6056546423255171, 0.028983850706782482`], 
                "EvaluationTime" -> 0.0001497747329571884, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.20126131574573602`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                495840, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.8837405792491766`, 0.23202649865382374`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6056546423255171, 0.0204946773796644]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[7.197882621318806, 1.1589726027017018`], 
                "StandardDeviation" -> 
                Around[0.5204072886607205, 0.03530407384541617], 
                "EvaluationTime" -> 0.00017208999361214625`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.053514238490213195`, "TrainingSize" -> 
                50, "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                500120, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[7.197882621318806, 0.8195173865797957]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5204072886607205, 0.024963750019604408`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.571078854531039, 0.09269622005748482], 
                "StandardDeviation" -> 
                Around[0.4120317993194494, 0.05605426412079725], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.16662827067395525`, "TrainingSize" -> 252, "TrainingTime" -> 
                2.51188643150958, "TrainingMemory" -> 522760, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.571078854531039, 0.06554612579300798]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4120317993194494, 0.039636350274237515`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4120317993194494, 0.05605426412079725], 
               "TrainingMemory" -> 522760, "TrainingTime" -> 
               3.7708153838671685`], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.16119935482958, 0.3777646391271793], 
                "StandardDeviation" -> 
                Around[0.6217226921445164, 0.03086295498571803], 
                "EvaluationTime" -> 0.00015075301172452342`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.2277973979200808, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                424576, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.16119935482958, 0.26711993801931744`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6217226921445164, 0.021823404757856383`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[15.492325688221525`, 2.1694448312588333`], 
                "StandardDeviation" -> 
                Around[0.5890302188060925, 0.03739452170583205], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.17651849987602364`, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                428800, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[15.492325688221525`, 1.534029151593226]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5890302188060925, 0.026441919877421387`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5861408509154151, 0.09590387114129352], 
                "StandardDeviation" -> 
                Around[0.4121049829619516, 0.06223439975328789], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 
                0.16354158768990867`, "TrainingSize" -> 252, "TrainingTime" -> 
                6.309573444801933, "TrainingMemory" -> 451704, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5861408509154151, 0.06781427762604948]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4121049829619516, 0.044006366088624266`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.4121049829619516, 0.06223439975328789], 
               "TrainingMemory" -> 451704, "TrainingTime" -> 
               9.471859998463529], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[7.969846681070953, 1.144386199023808], 
                "StandardDeviation" -> 
                Around[0.5581509897426932, 0.03501049705124433], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.12252063218509002`, "TrainingSize" -> 50,
                 "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                428800, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[7.969846681070953, 0.8092032416260325]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5581509897426932, 0.02475615987764649]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5855761061478973, 0.08879315539689572], 
                "StandardDeviation" -> 
                Around[0.40734342215636693`, 0.06087551782942396], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 0.1754680737277109, 
                "TrainingSize" -> 252, "TrainingTime" -> 1., "TrainingMemory" -> 
                451768, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5855761061478973, 0.06278624230409585]}, 
                "StandardDeviationHistory" -> {
                  Around[0.40734342215636693`, 0.04304549146542826]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[3.5186829054471636`, 0.41484356965573355`], 
                "StandardDeviation" -> 
                Around[0.6494992848473385, 0.032357690761911924`], 
                "EvaluationTime" -> 0.00013806927383312083`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.2715402900819961, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                424720, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.5186829054471636`, 0.29333870123520306`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6494992848473385, 0.02288034256128522]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00013806927383312083`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.6494992848473385, 0.032357690761911924`], 
               "TrainingMemory" -> 424720, "TrainingTime" -> 
               1.6521447577970134`], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[8.467540155288441, 1.459568404882754], 
                "StandardDeviation" -> 
                Around[0.5202695103547392, 0.03859765198344755], 
                "EvaluationTime" -> 0.00015459545750832804`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.05450135224358854, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499600, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[8.467540155288441, 1.0320707166982277`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5202695103547392, 0.027292661455374158`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00015459545750832804`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.5202695103547392, 0.03859765198344755], 
               "TrainingMemory" -> 499600, "TrainingTime" -> 
               6.577306748713622], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 213876698672805]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 8.2887404580153`1.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097570924790975`17.333472275397526*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 2.8821087473264497`, 
            "ElapsedTimes" -> 3.0508018, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 4.803514578877415, 
            "ElapsedTimes" -> 5.0833976, "ExperimentCounts" -> 4], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 8.005857631462359, 
            "ElapsedTimes" -> 10.054095799999999`, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 213889583574693]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{5.61306622871624, 2.3961737427316545`, 
              6.222154108557685, 0., 1.6094379124341003`}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 19.0257239, 
        "MaxTrainingMemory" -> 968256, "DataMemory" -> 75768, 
        "FunctionMemory" -> 262712, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 51, 32.9568194`9.270520193991425}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {
                    0.7733246627480023, -0.582088891006676, \
-0.18733779389347258`, 0.5396825396825397, 3.8786977936074263`}, "Method" -> 
                    "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.7733246627480023, -0.582088891006676, \
-0.18733779389347258`, 0.5396825396825397, 3.8786977936074263`}, 
                    "StandardDeviation" -> {6.721701254735527, 
                    4.400202478643077, 4.0674140664291105`, 
                    0.4984228085113518, 1.367971194331637}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.6334421030413756, -0.09197749817546835, \
-0.2667658671171105, -0.3485080244408547, 0.6306103162536196}, {
                    0.2390262206338013, 
                    0.4211247751152693, -0.8307249193671113, \
-0.21617456093477297`, -0.1693666353825323}, {-0.5065981080875475, \
-0.3683785385050382, -0.38042621790035225`, 
                    0.5240844572265235, -0.4338974345149132}, \
{-0.502553459781297, 0.43754989670302125`, 
                    0.2960692311027123, -0.4142860861033371, \
-0.5447018975664126}, {-0.18004428590768168`, 0.6978835174135891, 
                    0.07969305874444083, 0.6208971224444105, 
                    0.29778923916527955`}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.7733246627480023, -0.582088891006676, \
-0.18733779389347258`, 0.5396825396825397, 3.8786977936074263`}, 
                    "StandardDeviation" -> {6.721701254735527, 
                    4.400202478643077, 4.0674140664291105`, 
                    0.4984228085113518, 1.367971194331637}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0242642, "MaxTrainingMemory" -> 93160, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 51, 33.0146642`9.271281783470522}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {
                0.7733246627480023, -0.582088891006676, -0.18733779389347258`,
                 0.5396825396825397, 3.8786977936074263`}, 
               "StandardDeviation" -> {6.721701254735527, 4.400202478643077, 
                4.0674140664291105`, 0.4984228085113518, 1.367971194331637}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.3783730857585663`}, 
               "StandardDeviation" -> {0.6935501897649645}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.3783730857585663` + 
         0.6935501897649645 #& ), 
        "ProcessorFunction" -> (3.429273210298691 + 1.4418567174480732` #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-2.996043543275328, 2.5905593864369916`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX001XccgOl0uaYMsZu7EYYV7ryFNL/Pl9wl5XjNy9hO3o9h3DBXHZZZ
XeMQM+8ZJsochXEJ9/f5DiXLaPMWGq0xhMTJcmzsTH88zznPefRC4rwi9sjJ
ySVwd+UVLHaMjw++4K3wOsKDY6wsY15Py104u/h8G0FWR5tZC5yEqSoFui3L
wAMqWTjqZ4H3RJWYmq1GDok9iE/BSZnEoQj/9mxj8j+ugD5poqzk/AZsq/ay
nrkWVOFFDfL7x3BTIGANP8llJSPe7L7b+STg1CxzN7YQxk1n2dhvahhvuxqo
OJMOBc3WtCQwnCRc1qViSGNqtHMYnZrjZGFL+IHrigHd7+OJloZutPJ6Bcsk
9UCOYwPyt3+Hm3FXWOMlb6IpToIIX5YJrB1hNjM5wPfbiwn+drj1ah/xaKrH
4JENNm/KgdEbCoIM1hx0Hc+S7ovuaN7yWdfymYdde0+r0yrJdXAfLUfw1Wbc
TeWgPdzRnvL9qaHBIOMl/AL4010M5yGXygVrMKkaE+i9CKBiUYzcx2qww+sE
sxdC6icsZm3WfoSZnEBU14mFyn4fGiRwpyW2Axj1ZiAebdXEFO4UTli3M/OD
MmgRzaJ6dQOEz4spmZmHJ2l61OjlD7AtGMaaGCWEOwPgfbUW3u6hcLyITzz0
L9Aq1XwSWy2mdYlfUue7jbId3wZQfzoDTloL2PEyhKymS2H4n6NEQShhtUMz
wSmxjLmoJI8pn0vwztAzyLXlULe3CDt9PhdPWXFom0YeloYHsI26VfigLQIP
lrdDX0M3tP7qhwn3u+FAXp8s2SqBVbxxiNG94QDjLuUoPOIL3IVH4FS3AMnS
ambY6iN4NcAjP3GNmUKtTjTQ96NJ4kzsG1jG1m4zuvq1LUjHRVDt0oQ6/vos
P9QaF2330NZbf2CH9D1q8nQP6Bj/BYKWEUh7fw0yF96R2b9RhIUm90E0x6Hc
yWukYDmG2FU2MAJPXxqXH4QVUnPy55wW0fy0DJ2Sm6hTbBLGx50jZh0q7P6w
FnzwJBxds4thcnoJua0Sskwa8dK8L3Xhh9FjY9ewvLAUbj/To5mrV3C2tott
yfwK5m75w39cHtgs2TDyJZOs83MO7VlXBtd6FbLo/j1wfvsFlk6mo6NdLigV
u9GbUyEQ3czDENEmclfkiWNUP0YPjIChrABWlLOBt95MT9wzgsi1CebqcysS
6XkJ7NWyYM5ch4yllmK9gxTrx77D5pKfQTemCbrAlCoOemHUQjS1Hz1GymzD
IKVO1nmi+BGYKAbSKuVzeHiLR470JpIw/cNkLs4Ze7YPMutGQmr/bwY93atF
58SqxKs5gug/LoOzoavQvhNFP/QMAGlkPGwMdTNZonfp/+cP7pE=
                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.030228443443775177`, -0.018271002918481827`, 
                    0.020013397559523582`, -0.07585728913545609, 
                    0.03315939009189606, 
                    0.07280923426151276, -0.09960287064313889, \
-0.09053535759449005, -0.03502076864242554, -0.017248494550585747`, 
                    0.023168213665485382`, -0.001418719650246203, \
-0.03376811370253563, -0.021242497488856316`, 
                    0.04539789631962776, -0.003429338103160262, \
-0.09025676548480988, -0.03720935434103012, -0.04962087795138359, \
-0.00014343227667268366`, -0.014932170510292053`, -0.0316799096763134, 
                    0.021732326596975327`, 
                    0.00019429036183282733`, -0.009984413161873817, \
-0.08236901462078094, 
                    0.0652906522154808, -0.02570086158812046, \
-0.05079919099807739, 
                    0.0068029616959393024`, -0.06631312519311905, \
-0.01037631742656231, -0.0027989211957901716`, 0.021332697942852974`, 
                    0.05709468573331833, 
                    0.0016751674702391028`, -0.016461867839097977`, 
                    0.08273962140083313, -0.01495339535176754, \
-0.021846238523721695`, -0.03994876891374588, -0.05359102785587311, 
                    0.019429635256528854`, -0.00903358031064272, 
                    0.01818706840276718, 0.03328310698270798, 
                    0.017058400437235832`, -0.03308386728167534, 
                    0.00856876466423273, -0.015730151906609535`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUzv/TgAttVErRQioSadMi1f2daZEtJUupbMlWKGUvhKhoIYmUEBIq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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.02059629000723362, -0.06087097153067589, 
                    0.040364183485507965`, -0.04540518671274185, 
                    0.06251654028892517, 
                    0.003743695328012109, -0.01167383324354887, \
-0.05605635046958923, -0.0655733123421669, -0.02913515456020832, \
-0.005101856309920549, -0.0002565901377238333, -0.025814799591898918`, 
                    0.005819614976644516, -0.018931638449430466`, \
-0.0013645007275044918`, -0.09463178366422653, 0.04021341726183891, 
                    0.028965048491954803`, -0.0725405141711235, \
-0.016878223046660423`, -0.034641820937395096`, -0.03529021143913269, \
-0.015242576599121094`, -0.0027501885779201984`, -0.04993361979722977, 
                    0.01961236074566841, 
                    0.013165947049856186`, -0.05447987839579582, \
-0.0171242356300354, -0.0033926931209862232`, 0.00242859055288136, 
                    0.018554730340838432`, -0.015205010771751404`, \
-0.011619701981544495`, -0.006479507777839899, -0.0006438037380576134, \
-0.014612548984587193`, -0.028172869235277176`, 
                    0.05047677084803581, -0.0018010296626016498`, \
-0.036201734095811844`, -0.05425538122653961, 0.10310997068881989`, 
                    0.006731312721967697, -0.05186944454908371, \
-0.05861411243677139, 
                    0.05167457461357117, -0.02330506592988968, \
-0.0805995911359787}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3lUz+/Th9MiKqGNVEqbKFKR6vOeUSFLUSJJikQIRVHWtCotUkmIRKlk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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.02286159060895443, -0.021512078121304512`, \
-0.020024344325065613`, -0.029909679666161537`, -0.03846173360943794, 
                    0.048279955983161926`, 
                    0.021012376993894577`, -0.04663730040192604, \
-0.01094448659569025, -0.02953140065073967, 
                    0.040322497487068176`, -0.032795459032058716`, 
                    0.052397556602954865`, -0.01470902469009161, \
-0.05719200521707535, 0.01100599579513073, -0.025057580322027206`, 
                    0.014144990593194962`, -0.02089438959956169, \
-0.02791534550487995, -0.05525458604097366, -0.016203684732317924`, \
-0.023811819031834602`, -0.039506956934928894`, -0.0027769869193434715`, \
-0.033883266150951385`, 
                    0.005600168835371733, -0.04691071808338165, \
-0.02715434692800045, -0.020625166594982147`, -0.021711226552724838`, \
-0.021902481094002724`, -0.07097066193819046, 0.0222428310662508, 
                    0.0050771161913871765`, -0.0397210419178009, \
-0.06022914499044418, -0.0014574113301932812`, -0.02369089052081108, \
-0.010012643411755562`, 0.001610495150089264, -0.007586309220641851, 
                    0.03166511654853821, 0.02576288767158985, 
                    0.027780018746852875`, -0.020830558612942696`, 
                    0.018854491412639618`, 
                    0.023948173969984055`, -0.016545526683330536`, \
-0.014377572573721409`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dYz+/3x0tJe5CstqSQ0db7dY6WiEpIISFSIrMkM0l7EBVJJYqkSGT0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                    "], "Biases" -> 
                    RawArray["Real32",{-0.0016349360812455416`, 
                    0.03362027555704117, 
                    0.005622990429401398, -0.04453849419951439, 
                    0.022634232416749, -0.02191680483520031, 
                    0.010435258038341999`, -0.0043594008311629295`, 
                    0.041565947234630585`, 
                    0.004347797948867083, -0.023160025477409363`, \
-0.005221132654696703, 0.02493174560368061, -0.0034030992537736893`, 
                    0.026927199214696884`, -0.035905856639146805`, 
                    0.02824263460934162, 0.011482097208499908`, 
                    0.025320259854197502`, -0.010073596611618996`, \
-0.00042410625610500574`, 0.004725113045424223, 
                    0.010800457559525967`, -0.013679403811693192`, 
                    0.038080841302871704`, -0.013167746365070343`, 
                    0.006791437044739723, 
                    0.0008049733587540686, -0.020695749670267105`, 
                    0.03533722832798958, 0.0007589465822093189, 
                    0.0141965476796031, 0.005903350654989481, 
                    0.01741357520222664, 
                    0.030945857986807823`, -0.0021176915615797043`, 
                    0.02076013572514057, -0.018275195732712746`, 
                    
                    0.005117496941238642, -0.003049761289730668, \
-0.028734054416418076`, 0.025614237412810326`, -0.03733609989285469, 
                    0.014183362945914268`, -0.03700936958193779, 
                    0.004446308594197035, 
                    0.00790904089808464, -0.023391248658299446`, \
-0.05381407216191292, -0.028892729431390762`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{
                    0.12928257882595062`, -0.15404385328292847`, \
-0.0645887702703476, -0.08561962842941284, 
                    0.35397782921791077`, -0.08434179425239563, \
-0.2971241772174835, 0.06980861723423004, 
                    0.12785251438617706`, -0.11563427001237869`, \
-0.2236166149377823, -0.02392427809536457, 0.0268558282405138, 
                    0.16750140488147736`, 0.10851172357797623`, 
                    0.06356120854616165, 0.017522547394037247`, 
                    0.045301903039216995`, 0.04052633047103882, 
                    0.13695290684700012`, -0.0858675017952919, \
-0.18685339391231537`, -0.13710182905197144`, -0.13890129327774048`, 
                    0.19107767939567566`, 0.003006226848810911, 
                    0.18390941619873047`, -0.22513797879219055`, 
                    0.15340054035186768`, 0.11068017035722733`, 
                    0.09618961811065674, -0.034567706286907196`, \
-0.1343613862991333, -0.03923070430755615, 
                    0.0025559428613632917`, -0.09394579380750656, 
                    0.24448810517787933`, 
                    0.12767630815505981`, -0.16585874557495117`, \
-0.20610980689525604`, -0.07056429237127304, -0.13168294727802277`, 
                    0.12702499330043793`, 
                    0.1765650063753128, -0.1973656862974167, 
                    0.05291040614247322, 
                    0.21692563593387604`, -0.050775639712810516`, \
-0.06305715441703796, -0.15542005002498627`}}], "Biases" -> 
                    RawArray["Real32",{0.014101528562605381`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.5828611850738525}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 0.7286807, "MeanInputsPerSecond" -> 
          43914.98224119289], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.0003145059730577404, -0.0002438986234733767, 
                0.0007066503926778446, -0.00023258797338720732`, \
-0.0002161158624127204}, 
               "StandardDeviation" -> {0.9998742283898597, 0.9998817210419974,
                 1.0000926057962556`, 0.9998937362950258, 
                1.0003009690561764`}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 6172390854307906800]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 100, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.1523809523809524, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[364929], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3659316701589117, "PreprocessingTime" -> 
        0.4510711`7.105789996358274, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[1.7418289282496031`, 0.2804302678190974], 
           "StandardDeviation" -> 
           Around[0.448594758382023, 0.02680342377240759], "EvaluationTime" -> 
           0.00015459545750832804`, "TestSize" -> 265, "ModelMemory" -> 
           107736, "ModelUtility" -> 0.09657511621229953, "TrainingSize" -> 
           50, "TrainingTime" -> 0.5011872336272722, "TrainingMemory" -> 
           499792, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[1.7418289282496031`, 0.19829414402484344`]}, 
           "StandardDeviationHistory" -> {
             Around[0.448594758382023, 0.018952882708486118`]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 100, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}, 
           "FinalTrainingSize" -> 315], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration", "FinalTrainingSize"}, {
           TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}], 
            TypeSystem`Atom[Integer]}], 
          Association["ID" -> 47476780723894]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.22130408294401, 0.5903834775908493], 
                "StandardDeviation" -> 
                Around[0.6529024105682583, 0.039077364859911354`], 
                "EvaluationTime" -> 0.00018843183123375387`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.2787509843872399, "TrainingSize" -> 10, 
                "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                424768, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.22130408294401, 0.41746416050498564`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6529024105682583, 0.027631869683344218`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[13.150900805360093`, 1.7756597381104047`], 
                "StandardDeviation" -> 
                Around[0.5205515792388685, 0.031714192431960275`], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.05242417461268334, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.9952623149688797`, "TrainingMemory" -> 
                428880, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[13.150900805360093`, 1.2555810418977962`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5205515792388685, 0.022425320528494195`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.3027196601071056`, 0.6445254029803559], 
                "StandardDeviation" -> 
                Around[0.534911557672639, 0.11002281494585067`], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.10783888574879463`, "TrainingSize" -> 
                252, "TrainingTime" -> 6.309573444801933, "TrainingMemory" -> 
                452224, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.3027196601071056`, 0.45574828309440185`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.534911557672639, 0.07779787853344364]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.534911557672639, 0.11002281494585067`], 
               "TrainingMemory" -> 452224, "TrainingTime" -> 
               9.471859998463529], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[8.127465854094362, 1.27949370726135], 
                "StandardDeviation" -> 
                Around[0.49706082694896875`, 0.03364930350045414], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.007586700659022783, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499792, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[8.127465854094362, 0.9047386768900159]}, 
                "StandardDeviationHistory" -> {
                  Around[0.49706082694896875`, 0.02379365068737535]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00014229478653976401`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.49706082694896875`, 0.03364930350045414], 
               "TrainingMemory" -> 499792, "TrainingTime" -> 
               6.577306748713622], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.703434809451852, 0.6450245074288691], 
                "StandardDeviation" -> 
                Around[0.7144721735850672, 0.04304933251823631], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.36894852669250267`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.5011872336272722, "TrainingMemory" -> 
                495632, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.703434809451852, 0.4561012032344659]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7144721735850672, 0.030440474949199443`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.7418289282496031`, 0.2804302678190974], 
                "StandardDeviation" -> 
                Around[0.448594758382023, 0.02680342377240759], 
                "EvaluationTime" -> 0.00015459545750832804`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.09657511621229953, "TrainingSize" -> 50, "TrainingTime" -> 
                0.5011872336272722, "TrainingMemory" -> 499792, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.7418289282496031`, 0.19829414402484344`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.448594758382023, 0.018952882708486118`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.6948357217378918, 0.27593394609102234`], 
                "StandardDeviation" -> 
                Around[0.44696627494489527`, 0.07809873555999913], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.07774138915517315, "TrainingSize" -> 252, "TrainingTime" -> 
                1., "TrainingMemory" -> 522840, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.6948357217378918, 0.19511476444052514`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.44696627494489527`, 0.05522414551657034]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.44696627494489527`, 0.07809873555999913], 
               "TrainingMemory" -> 522840, "TrainingTime" -> 
               1.7511872336272722`], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 47472485756598]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.0000168172190201729`3., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097571092823547`17.333472277313017*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 2.789140336493701, 
            "ElapsedTimes" -> 2.722714, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 4.648567227489503, 
            "ElapsedTimes" -> 4.6815081, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 7.747612045815837, 
            "ElapsedTimes" -> 8.0305093, "ExperimentCounts" -> 2]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 47485370658486]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{-1.58371347981322, 0.21494728902017465`, 
              6.938379786136243, 0., 4.605170185988092}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 17.3399118, 
        "MaxTrainingMemory" -> 968040, "DataMemory" -> 75768, 
        "FunctionMemory" -> 262936, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 51, 50.2986352`9.454131053880156}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {1.1568513334225228`, -0.32428533617490296`, 
                    0.17662914082710798`, 0.49206349206349204`, 
                    3.9942377122908423`}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {1.1568513334225228`, -0.32428533617490296`, 
                    0.17662914082710798`, 0.49206349206349204`, 
                    3.9942377122908423`}, 
                    "StandardDeviation" -> {7.030813560439557, 
                    4.494442091586921, 4.122978441373256, 
                    0.49993700787376577`, 1.2767366933781785`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.17398367370300455`, 
                    0.8385073375268012, -0.10732476749484844`, 
                    0.33271129521600984`, -0.380025939267813}, {
                    0.3404947744997864, 0.3540383553132133, 
                    0.5402302950944657, -0.6732393066892133, \
-0.1167056797942084}, {0.6253990019279794, 
                    0.31351316125453454`, -0.17362912993596358`, 
                    0.2283969951247491, 
                    0.654425949946471}, {-0.48392761227044384`, 
                    0.2497886942961615, -0.46706692629448154`, \
-0.5600050944059977, 0.4143216804431081}, {-0.4779991049080117, 
                    0.10429474484765382`, 0.6695775042098031, 
                    0.26510589737240353`, 0.49195964360793515`}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {1.1568513334225228`, -0.32428533617490296`, 
                    0.17662914082710798`, 0.49206349206349204`, 
                    3.9942377122908423`}, 
                    "StandardDeviation" -> {7.030813560439557, 
                    4.494442091586921, 4.122978441373256, 
                    0.49993700787376577`, 1.2767366933781785`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0195789, "MaxTrainingMemory" -> 93240, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 51, 50.3504983`9.454578625744007}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {1.1568513334225228`, -0.32428533617490296`, 
                0.17662914082710798`, 0.49206349206349204`, 
                3.9942377122908423`}, 
               "StandardDeviation" -> {7.030813560439557, 4.494442091586921, 
                4.122978441373256, 0.49993700787376577`, 1.2767366933781785`},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.3909731665462584`}, 
               "StandardDeviation" -> {0.6899416786494937}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.3909731665462584` + 
         0.6899416786494937 #& ), 
        "ProcessorFunction" -> (3.465471416694813 + 1.449397870784413 #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-2.2714190440569544`, 2.541160622427657}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX9YzHccwE+ei+oqbsqP8eRUFpWFW+vp+r7fTKmL58rlV6nNnTr6MfWk
KHpCSz8sU/NsHPFIE3uGK2f9WPd9f6RoKq2IHQlP6ZmKm7Rms+5a/ni9nuf1
vCTqZKXGSiAQ7Jo6IaVqz8rUVFVmhPX7iFMlLV+W9H4um0A4QULi33Rz0QPS
FKexstrL3PfXo7io6bf50CRfVnurgL1NDaEsxay6/pYKgsBaeGbbwseYmui8
PBbtC7PJfKGQ9W3nUPzVCbjR2U+PUpS8WH2IvZnbQZOPa/mosNOcS+VRzhQT
iovL5RReWQ3qJbZsraMWwlyv4tuRhWzvtWC+wZAMYSYt/qPNwX3ji5nduy7Y
HCaEBsfj+F13Pfj3RsC68TaIthxkRv92zDbMx8S4Qppad4VEf+aRi/d0mu35
CLImbcCUaQFo7j4Evpki5hr/C6uR9MGC5BDIF9niD8mHZaG+g5yX0Yl9sNmB
68l7Q+fv+sFhoQO3b98GFlMqwD+ip8CjbXIaRi3nct0Vh5/YY6HPUr7CnE+J
uheY5t9GLx7rYGbzEC+YmYCRp0ogvkaEXY2/BUxyEmOtbhHUqDxhTo6UvMcu
UWvshxivOQD5jx9ya/5yRunpSNp/t4pKVknZDLMdKrrvkQrdUSDt51Pd1jH5
eiM3YK3jNy5vgd1bJKzXooJBiYrCL1XTjqhhmWnux1g0FsTOPZkHIUIrUnvH
UU/vRbqnbCbz6DMuJ+gCFFW+pghxBxn1fuzAzhh4FTANpcJBOpZijd6BX5Bp
yTHcEuyGnuUag3PvCNfj7gCWlzmGrJ0FkHFSiTt9HNmNE8txTCFCN2ijQNlC
ZqVppFbtrzT6cAUazVJg3YBz6jfCt8yG7fFpB1m2CV5v8mJxwvXM2S2BnXBi
AVsb5TB29Ra3tQPw3/potv3mFIzIkeJZwRvSx5bRjkghE8fPY7/vjmDF1Tpu
YE44m1Vq4ftCqmjyoIHdKW5FXV4Ftc93wo9MB/nGI+vRr8MZUn/0RfWZTizR
9VCWcChAv7gILgY08jeq94N9hQdzGiir37r0P5C6B7H7QjHkfsKBe0YTGVZM
R3P+HWhI9JEpnR1xpFREj8VJTN/pj+liO77vgYYTPbdAaFEnYNNLGLgTjdue
XuNNTT/T3sQU2nWyHLrMa3hBnZzNL5rEJXCZWD31GY3af81WpxMsG3Lj6tVX
ILwmyHAm5Sl8ruiC5lwZSGZLcPxyOrisLcejigVcW8FmEnt8yk6le+C5LUfQ
oz8XFN+sZDE2m/izGXpOmbCa9Th5MOOrmaxWd5/fJDgL2lxf5veuyhBccpvv
WhVEC1y+pBmfXYRTpXrDbEs5O/68mHR105iXzAZ/EvDwNleD7YmtkDZDS/8D
4Obq8A==
                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.10716865956783295`, -0.22300323843955994`, \
-0.23369088768959045`, 0.02646668069064617, -0.04200686141848564, 
                    0.08905035257339478, -0.2077724039554596, \
-0.03753888979554176, -0.16926392912864685`, -0.27011939883232117`, \
-0.11068323254585266`, 0.16558760404586792`, -0.20768533647060394`, 
                    0.2042863965034485, -0.042173001915216446`, \
-0.24391306936740875`, -0.12721215188503265`, -0.2747951149940491, \
-0.11530885100364685`, 0.11776450276374817`, -0.04997815191745758, 
                    0.22768637537956238`, 
                    0.20585836470127106`, -0.3225376009941101, \
-0.08480793237686157, -0.29328453540802, -0.0794176384806633, 
                    0.03563150018453598, -0.12622693181037903`, \
-0.08324356377124786, -0.09882169216871262, -0.11711673438549042`, \
-0.5929617881774902, 
                    0.14960432052612305`, -0.21299687027931213`, \
-0.4168469309806824, -0.10295593738555908`, -0.06787482649087906, 
                    0.056987494230270386`, -0.34354346990585327`, \
-0.17196092009544373`, -0.1147879809141159, -0.1286517083644867, \
-0.10682351887226105`, -0.18531763553619385`, -0.20717020332813263`, 
                    0.11394670605659485`, -0.0505957156419754, 
                    0.1005108430981636, 0.08154650032520294}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUj4/Th1GULEkqiSwt0kIJpe89E5VIKVtkl6WyFqVFUUm0L4pEKdJC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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.17907337844371796`, -0.12077303230762482`, \
-0.1527586579322815, -0.05900215357542038, -0.20822614431381226`, \
-0.0993632897734642, 
                    0.10426795482635498`, -0.08458183705806732, \
-0.12512652575969696`, 
                    0.03979279100894928, -0.07906938344240189, \
-0.22724057734012604`, -0.08728621900081635, -0.13599777221679688`, \
-0.20013809204101562`, -0.23886670172214508`, -0.34818533062934875`, 
                    0.04787946864962578, -0.22628015279769897`, \
-0.04163718223571777, 
                    0.055051833391189575`, -0.23338548839092255`, \
-0.017050525173544884`, -0.10311321169137955`, 
                    0.29633668065071106`, -0.1300264596939087, \
-0.08593682944774628, -0.09268522262573242, -0.04006583243608475, \
-0.1240357831120491, 
                    0.11850862950086594`, -0.0740726888179779, \
-0.09061527252197266, -0.15557324886322021`, -0.17391973733901978`, \
-0.001887293066829443, -0.13533715903759003`, 
                    0.038486942648887634`, -0.12184648215770721`, \
-0.1727040559053421, -0.1853213608264923, -0.06781432777643204, 
                    0.021845214068889618`, 
                    0.11307477205991745`, -0.12651406228542328`, \
-0.0383947379887104, -0.08131294697523117, -0.2168375700712204, \
-0.35437020659446716`, -0.1176767647266388}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJw1l3dYz9/7gDVQUqGFMlIqDREVvV/P05KGXSSyWkIDJaOM0hQtGoRkJSoi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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.041172973811626434`, -0.09198589622974396, \
-0.09574254602193832, -0.1339084506034851, -0.26368895173072815`, \
-0.10370822995901108`, -0.009068009443581104, -0.1817551553249359, \
-0.07135313749313354, -0.11349557340145111`, -0.13569103181362152`, \
-0.09516165405511856, -0.10703320801258087`, -0.14016380906105042`, \
-0.22915300726890564`, -0.0716855451464653, -0.2078753113746643, 
                    0.039861079305410385`, -0.16593585908412933`, \
-0.2732120156288147, -0.14875605702400208`, -0.05479133129119873, \
-0.21521228551864624`, -0.102572962641716, -0.2681698501110077, \
-0.16583560407161713`, -0.04185641556978226, -0.1426219791173935, 
                    0.06671077013015747, 
                    0.06684961169958115, -0.13498006761074066`, \
-0.06893753260374069, 
                    0.030767690390348434`, -0.1354481726884842, \
-0.14444909989833832`, -0.060859668999910355`, 
                    0.05928666889667511, -0.14254789054393768`, \
-0.028254276141524315`, -0.08848586678504944, 
                    0.024170272052288055`, -0.04732515662908554, \
-0.06605970114469528, -0.014217069372534752`, 
                    0.014884233474731445`, -0.16406631469726562`, \
-0.08114487677812576, -0.11167007684707642`, -0.17523793876171112`, \
-0.17845019698143005`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUj9/Xh0tFqVAqpZJUhgxNMvS99yZKKEmZK6QoISIhNGmgEKVUSFSo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                    "], "Biases" -> 
                    RawArray["Real32",{-0.04046930745244026, 
                    0.027864815667271614`, -0.05402812361717224, 
                    0.015183117240667343`, 
                    0.09303726255893707, -0.03788917139172554, 
                    0.0037455763667821884`, -0.050122328102588654`, 
                    0.07926006615161896, 0.08036559820175171, 
                    0.010908849537372589`, -0.09739837795495987, 
                    0.058635249733924866`, -0.011710605584084988`, 
                    0.03115304559469223, -0.015399515628814697`, 
                    0.05188346281647682, -0.09173857420682907, 
                    
                    0.027723591774702072`, -0.05079308897256851, \
-0.014129303395748138`, 0.10981109738349915`, 
                    0.050314221531152725`, -0.057026516646146774`, \
-0.07704892009496689, 0.019432727247476578`, 
                    0.015873312950134277`, -0.048304371535778046`, 
                    0.05222124978899956, -0.1664692759513855, \
-0.02366882935166359, -0.07337470352649689, -0.0011450010351836681`, \
-0.027240607887506485`, 
                    0.011931933462619781`, -0.10563743859529495`, \
-0.013571024872362614`, -0.05657731741666794, -0.05684756115078926, \
-0.01203223504126072, 
                    0.018712254241108894`, -0.07498873025178909, \
-0.06828027218580246, -0.04390209540724754, 0.0477592907845974, 
                    0.043735746294260025`, -0.0038729908410459757`, 
                    0.0005598224815912545, -0.06453458964824677, 
                    0.043568678200244904`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{0.007904298603534698, 
                    0.15275119245052338`, 
                    0.07805315405130386, -0.03393135592341423, \
-0.20744077861309052`, 0.15118148922920227`, -0.05934664234519005, 
                    0.09642618149518967, -0.20143882930278778`, \
-0.15555621683597565`, 0.10862629860639572`, 0.0063009909354150295`, 
                    0.2190360128879547, -0.0017423112876713276`, 
                    0.10347574204206467`, 
                    0.09528552740812302, -0.12443603575229645`, 
                    0.07583078742027283, -0.11136993020772934`, 
                    0.11950649321079254`, -0.13210535049438477`, \
-0.16353878378868103`, -0.06629067659378052, 0.09109633415937424, 
                    0.058809034526348114`, -0.09604990482330322, \
-0.06207987293601036, 0.02688424475491047, -0.09476805478334427, 
                    0.08512751758098602, 0.09036801755428314, 
                    0.07329898327589035, 0.02659628540277481, 
                    0.13364377617835999`, -0.03775341063737869, \
-0.0007830776739865541, 
                    0.04823066666722298, -0.10089387744665146`, \
-0.0007076856563799083, 0.09124993532896042, -0.17399123311042786`, 
                    0.15622583031654358`, 0.09047413617372513, 
                    0.14949552714824677`, -0.09072854369878769, \
-0.22344104945659637`, 0.1359604001045227, 0.09627306461334229, 
                    0.002718226984143257, -0.11807018518447876`}}], "Biases" -> 
                    RawArray["Real32",{-0.0207933709025383}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-1.6582469940185547`}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.2921009, "MeanInputsPerSecond" -> 
          48373.98319446252], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.014623873127515109`, 0.033276001018979554`, 
                0.05623561422967628, 
                0.03157978306518616, -0.026850348657137948`}, 
               "StandardDeviation" -> {1.0049416096138137`, 
                0.9972920709166949, 0.9910987880395747, 1.0003031075128606`, 
                1.009059961578553}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 7906009762522671289]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[365041], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3711482086595468, "PreprocessingTime" -> 
        0.4273051`7.08228306976423, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.09136649271320253, 0.40052611339561667`], 
           "StandardDeviation" -> 
           Around[0.2333755179769314, 0.05683130034177276], "EvaluationTime" -> 
           0.00019982943044351853`, "TestSize" -> 63, "ModelMemory" -> 107736,
            "ModelUtility" -> 0.7143704394699751, "TrainingSize" -> 252, 
           "TrainingTime" -> 5.011872336272724, "TrainingMemory" -> 522632, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.09136649271320253, 0.28321473082433263`]}, 
           "StandardDeviationHistory" -> {
             Around[0.2333755179769314, 0.04018579785531687]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 154640509726407]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.317984583993578, 0.6533965727583471], 
                "StandardDeviation" -> 
                Around[0.6583737177063693, 0.042690149732410546`], 
                "EvaluationTime" -> 0.0001444183103262347, "TestSize" -> 305, 
                "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.28808171322973297`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                424896, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.317984583993578, 0.46202114740147654`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6583737177063693, 0.030186494365656572`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[16.448303219065554`, 2.541437824314064], 
                "StandardDeviation" -> 
                Around[0.5853870325834183, 0.04102591211882237], 
                "EvaluationTime" -> 0.00015633372739584048`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.17161657723520674`, "TrainingSize" -> 50,
                 "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                428864, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[16.448303219065554`, 1.79706791953646]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5853870325834183, 0.02900970066358266]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.148248507893918, 0.8209384789755203], 
                "StandardDeviation" -> 
                Around[0.28675193314563074`, 0.056973851181849285`], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 0.5169900986764375, 
                "TrainingSize" -> 252, "TrainingTime" -> 1.9952623149688797`, 
                "TrainingMemory" -> 452096, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[1.148248507893918, 0.5804911654205603]}, 
                "StandardDeviationHistory" -> {
                  Around[0.28675193314563074`, 0.04028659652099882]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.28675193314563074`, 0.056973851181849285`], 
               "TrainingMemory" -> 452096, "TrainingTime" -> 
               3.125035238191293], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.6683186312505187`, 0.5178130198557459], 
                "StandardDeviation" -> 
                Around[0.507631360439088, 0.03904201105124336], 
                "EvaluationTime" -> 0.0001351002078275469, "TestSize" -> 265, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.03044625258076461, "TrainingSize" -> 50, 
                "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                499872, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.6683186312505187`, 0.3661490977266823]}, 
                "StandardDeviationHistory" -> {
                  Around[0.507631360439088, 0.027606870765494305`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.3061487764699131`, 0.49746684041829775`], 
                "StandardDeviation" -> 
                Around[0.42669942755760093`, 0.05771616301403418], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 0.1318011525600873,
                 "TrainingSize" -> 252, "TrainingTime" -> 1., 
                "TrainingMemory" -> 523152, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[1.3061487764699131`, 0.3517621762752244]}, 
                "StandardDeviationHistory" -> {
                  Around[0.42669942755760093`, 0.04081149025129177]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.42669942755760093`, 0.05771616301403418], 
               "TrainingMemory" -> 523152, "TrainingTime" -> 
               1.648107170553497], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[17.780684195848472`, 2.788984303153922], 
                "StandardDeviation" -> 
                Around[0.5924363794200849, 0.042684820910789976`], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.18397456645349541`, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                428864, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[17.780684195848472`, 1.972109713382976]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5924363794200849, 0.030182726319752936`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00014229478653976401`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.5924363794200849, 0.042684820910789976`], 
               "TrainingMemory" -> 428864, "TrainingTime" -> 
               6.577306748713622], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.265991218674153, 0.6472658049776957], 
                "StandardDeviation" -> 
                Around[0.6597288235482845, 0.04337040734712093], 
                "EvaluationTime" -> 0.00014342569646407457`, "TestSize" -> 
                305, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.29031695949579395`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                496088, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.265991218674153, 0.457686039929898]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6597288235482845, 0.03066750913797207]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[13.939197596007205`, 2.37024964381545], 
                "StandardDeviation" -> 
                Around[0.5654189630348071, 0.04346232111998053], 
                "EvaluationTime" -> 0.00015459545750832804`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.13824932935155576`, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                499728, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[13.939197596007205`, 1.6760195962469036`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5654189630348071, 0.030732501990045534`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.09136649271320253, 0.40052611339561667`], 
                "StandardDeviation" -> 
                Around[0.2333755179769314, 0.05683130034177276], 
                "EvaluationTime" -> 0.00019982943044351853`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.7143704394699751, "TrainingSize" -> 252, "TrainingTime" -> 
                5.011872336272724, "TrainingMemory" -> 522632, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.09136649271320253, 0.28321473082433263`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.2333755179769314, 0.04018579785531687]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00019982943044351853`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.2333755179769314, 0.05683130034177276], 
               "TrainingMemory" -> 522632, "TrainingTime" -> 
               7.849733612802018], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 154636214759111]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.000011110791015625`1., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097571273175555`17.333472279368944*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 3.063896568985556, 
            "ElapsedTimes" -> 2.5072902, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 5.106494281642593, 
            "ElapsedTimes" -> 4.6415788, "ExperimentCounts" -> 4], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 8.510823802737654, 
            "ElapsedTimes" -> 9.0098925, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 154649099660999]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{1.6738018344904457`, -8.412325310002771, 
              2.341229054839705, 0., 3.912023005428146}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 17.0424867, 
        "MaxTrainingMemory" -> 990680, "DataMemory" -> 75768, 
        "FunctionMemory" -> 268008, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 52, 7.3424886`8.618418250973905}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {
                    0.10729515739317705`, -0.06678824638440758, \
-0.2621786735484515, 0.48253968253968255`, 3.7549891076302226`}, "Method" -> 
                    "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.10729515739317705`, -0.06678824638440758, \
-0.2621786735484515, 0.48253968253968255`, 3.7549891076302226`}, 
                    "StandardDeviation" -> {7.156150232868117, 
                    4.503091044412869, 4.17812287267334, 0.49969504431621586`,
                     1.3922365848199187`}, "Method" -> "NaiveSampler", 
                    "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.31526359964511474`, 0.43017310267905673`, 
                    0.43195880360038075`, 0.7237520541342894, 
                    0.07179499006757374}, {0.33076872623938014`, 
                    0.6083100913008189, 
                    0.4138404702837058, -0.42358645336721634`, \
-0.41214252903905896`}, {-0.5649141261647432, 
                    0.3575040064222756, -0.029913971856165254`, \
-0.4956291428149598, 
                    0.5536423236457295}, {-0.6851507789252347, \
-0.15849972073982832`, -0.0343198297483435, -0.11423396177313222`, \
-0.7008701733753546}, {0.051394091863278674`, 
                    0.5403504959472889, -0.8000468490790538, 
                    0.1950893011682138, -0.16506117865641}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.10729515739317705`, -0.06678824638440758, \
-0.2621786735484515, 0.48253968253968255`, 3.7549891076302226`}, 
                    "StandardDeviation" -> {7.156150232868117, 
                    4.503091044412869, 4.17812287267334, 0.49969504431621586`,
                     1.3922365848199187`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0104794, "MaxTrainingMemory" -> 93240, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 52, 7.3674224`8.619890540252012}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {
                0.10729515739317705`, -0.06678824638440758, \
-0.2621786735484515, 0.48253968253968255`, 3.7549891076302226`}, 
               "StandardDeviation" -> {7.156150232868117, 4.503091044412869, 
                4.17812287267334, 0.49969504431621586`, 1.3922365848199187`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.3525659236779433`}, 
               "StandardDeviation" -> {0.6777778329018955}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.3525659236779433` + 
         0.6777778329018955 #& ), 
        "ProcessorFunction" -> (3.4709986214885014` + 
         1.4754097160695197` #& ), "Name" -> "value", 
        "Quantiles" -> {-3.103839677164278, 2.6127673494398373`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX001XccgC95n673c23U8tJmnCNHOqvj/j5fNuY0DsJUFrkOlrfYFfIS
uTYXW8SOeYucFWphu7WF+H0+XpZ5OaFSCZmZyaQtkSOU6Y/nOec5j1lIrE+4
skAgiNfYlI8kyVkqlST7qr2JMEn0bvvoN9N+E9VNpiI/xJVRQwiiVLC3FVNy
kQMrkG7B9/q9Ya2gGSpLZKjEzkC0Qwo/FZTelmetzdZrz2GFhjrr/iODqfz0
kOsaiuK2fbULCid3sKgGHbAdN6Ijrbvaur0yuFMdUbxfSC6ke5gx+zoXNPIJ
g+aiF2g7UYG3B06D4h9dCK2WQdFELsxmPcYfnEtwXT8dPONycEjiiV8bXsSG
lCh2KaAYX1TrsvC+GRhpWkETrVHesNcCBcsVGH1UAeE2ReKfZ7azY2oT3LRb
JpUJttH4gSdtsYos9EpqQfPaeZw3TmVc3ufsd1EviNx96DNZKdebVkPuitPo
2LmEl6kB9/yqxDSKZ7HUuIdLcTTCs9JZCHjYAuKNbD7+roT3cTPEmtDDtBZx
ASIS/Si4J5Bz9Oxqa3eZh9XgQT7dToEJaQa4FJKFJ8fC0PqOAqs9h+BQXxYW
5g7eSBq4CyqTduLLIkNq9PUlvaZ8LOpdgPzIQTzc6gGphmtYsxFHbcWrOB2S
ih4167hBtzBekgFyMqcFjSaQ5yhQfsYSw/eeokl1EbtWP4xWghGYKtdFCztT
vLBdh2pHKiH2v0Sw3PmSW7Qzpy7d96m44lNWrW8GqfdE5K36G7hP2MHcTSlm
15uysscL0JcdA1ddGjFjtxtYrk/iUthJOJG8BZeV1CDeeRiLfVrRILwODQ7M
wo3zW8lSqEl5JjnsuN47dKjjEeYX6qPgeQ9+l2pNAuDI5Q5jqsrujF+9Da/P
W1B/2jX8yMtcHJeiwvptDUge5sQtvmrBodo60PETUqJDEOaNLeO9/dMQGVEI
7d1/cUdMZABzT/iYTj0KrB6BiHYdGpBoMX+lUlxSQZS9bU7lJu14a64WapTV
6H6MDVgFNmDzVRs2//ExdJpLxH2/lMKllSCqEhPHiZxRJ0qFJRzVpLGqTrj+
6L44bU2T9/5GhyyMtell8TMQuY7yn1iuQuDCTSxKyMfZb+vx37MjnPqf75K2
6ytuzCGTCXY2wOLTE2gOwbQ4HkY7xns4qXARobASxq6Ygon8HC9r3ofyrQ9a
FxzUWYHMhJQPluPs/njUNMiGCovXqP4378iFPMfjGUoYcD0LrXoE5Ln4FnBC
V0YpQjKQCunBsAp9sRGIwp4knErKoarmGXha40/+pZkAocv8s71lkOnvjFol
jVxGnrL4A989tHBxHg929OL3VxwpzYnwS/mP/P/nX/09
                    "], "Biases" -> 
                    RawArray["Real32",{-0.04944506660103798, 
                    0.02686053141951561, 
                    0.02393185719847679, -0.018222857266664505`, 
                    0.009971553459763527, 0.002132316352799535, 
                    0.014393597841262817`, 0.04009097069501877, 
                    0.09372412413358688, -0.029942771419882774`, 
                    0.011835170909762383`, -0.00981539860367775, \
-0.014773858711123466`, -0.019723717123270035`, -0.026531202718615532`, \
-0.0686047375202179, -0.012954681180417538`, -0.09972124546766281, \
-0.08363651484251022, 0.01859164983034134, -0.020366491749882698`, 
                    0.05106349661946297, 0.1021084189414978, 
                    0.02996913343667984, 
                    0.00226750411093235, -0.03296009078621864, 
                    0.004624951630830765, 0.06697477400302887, 
                    0.006881969515234232, -0.03385536000132561, \
-0.009831401519477367, -0.024755069985985756`, -0.018482385203242302`, \
-0.0019395803101360798`, -0.1458330601453781, 
                    0.11801459640264511`, -0.012522182427346706`, \
-0.051284585148096085`, -0.020259272307157516`, 0.02544740028679371, 
                    0.00044954344048164785`, -0.07270844280719757, \
-0.11304184794425964`, 
                    0.017196815460920334`, -0.05534485727548599, \
-0.07443282753229141, 
                    0.10513915121555328`, -0.045089103281497955`, \
-0.03663759306073189, -0.02138621173799038}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3lUz+3zxivtixIpbdIiydqm+rxnJCFRpM1alKxlyU4oUSqUUpKilRAh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                    "], "Biases" -> 
                    RawArray["Real32",{-0.015801746398210526`, 
                    0.045906778424978256`, 
                    0.03781913220882416, -0.05873122438788414, \
-0.0824248343706131, -0.05197128280997276, -0.06716900318861008, \
-0.007786645088344812, -0.027379924431443214`, -0.06246023625135422, 
                    0.004204548895359039, 
                    0.0009602924692444503, -0.003650307422503829, \
-0.046710383147001266`, 0.013317584060132504`, 0.032698675990104675`, 
                    0.062156256288290024`, -0.04087340831756592, 
                    
                    0.04495243355631828, -0.0004492780426517129, \
-0.023225346580147743`, 0.016576169058680534`, 
                    0.09049541503190994, -0.058738067746162415`, \
-0.04050058126449585, -0.005944601260125637, 
                    0.05146707966923714, -0.011744406074285507`, \
-0.024950312450528145`, 0.04510059580206871, 
                    0.05641886219382286, -0.028145037591457367`, \
-0.07397690415382385, -0.016981491819024086`, 0.04442381113767624, 
                    0.05617650970816612, -0.004484675358980894, \
-0.010879571549594402`, -0.11629728227853775`, -0.010274860076606274`, \
-0.0024433876387774944`, 
                    0.03737381473183632, -0.029147587716579437`, \
-0.044995151460170746`, 
                    0.07804916054010391, -0.03022117167711258, \
-0.08127050846815109, 0.0366356335580349, -0.07721897214651108, 
                    0.06395964324474335}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c419/7x5EZIpRRQqFSSWnxft03LUqlMtOkhSIlkhbKCqEiOyVpaWhY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                    "], "Biases" -> 
                    RawArray["Real32",{-0.08399640023708344, 
                    0.008617721498012543, 
                    0.02121633291244507, -0.0065256268717348576`, 
                    0.012115789577364922`, -0.001064217067323625, 
                    0.0031485394574701786`, 0.04673508182168007, 
                    0.012858943082392216`, -0.06740299612283707, \
-0.005863668397068977, 0.049674127250909805`, 
                    0.012764894403517246`, -0.00810942705720663, 
                    0.04862535372376442, 
                    0.03679265081882477, -0.02393023669719696, \
-0.0640413761138916, -0.005882906261831522, 
                    0.017553061246871948`, -0.03176333010196686, \
-0.08102405071258545, -0.06961529701948166, -0.08912957459688187, \
-0.09276706725358963, -0.08234325051307678, 0.04969950392842293, 
                    0.0023458064533770084`, -0.019860008731484413`, \
-0.03506883233785629, -0.03472558781504631, -0.004907242953777313, 
                    0.002952123060822487, 0.02883865125477314, 
                    0.0016004289500415325`, -0.053652361035346985`, \
-0.01143747940659523, 
                    0.02302449196577072, -0.14803588390350342`, \
-0.02020840346813202, -0.04280978441238403, 
                    0.01178471464663744, -0.017358647659420967`, 
                    0.02875419519841671, 0.011866992339491844`, 
                    0.009499707259237766, 
                    0.02582635171711445, -0.03620245307683945, \
-0.00316798547282815, 0.03631310909986496}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dUz//7ximlYSVFU1FSGqT9ft13RUgkq0QIGUnKiKyopCQpLbSUSEUK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                    "], "Biases" -> 
                    RawArray["Real32",{-0.009616878814995289, 
                    0.02154630236327648, -0.006570166442543268, 
                    0.0034841536544263363`, 
                    0.0026499787345528603`, -0.008771911263465881, \
-0.007385102100670338, 0.01773175224661827, 0.03696887940168381, 
                    0.01699894666671753, -0.05734223499894142, 
                    0.0001952692837221548, -0.02702208235859871, \
-0.019411524757742882`, -0.04341667890548706, 0.042991556227207184`, 
                    0.007427742704749107, 
                    0.0025008826050907373`, -0.07843127846717834, 
                    0.03670608252286911, -0.01576254703104496, 
                    0.020911844447255135`, -0.018554145470261574`, 
                    0.018262965604662895`, -0.03982575982809067, 
                    0.0025295757222920656`, 0.04440445825457573, 
                    0.042085666209459305`, -0.01519377063959837, 
                    0.024122633039951324`, -0.07025296241044998, \
-0.05781431496143341, -0.0011789032723754644`, -0.02422346919775009, \
-0.021217701956629753`, -0.025375384837388992`, -0.021876530721783638`, \
-0.010889201425015926`, -0.08973584324121475, 
                    0.012728366069495678`, -0.026681149378418922`, 
                    0.028481626883149147`, -0.06632479280233383, \
-0.05509285628795624, -0.0042260996997356415`, -0.0023344492074102163`, 
                    0.04628628119826317, 
                    0.011803925037384033`, -0.009254256263375282, \
-0.0371147021651268}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray[
                    "Real32",{{-0.22999221086502075`, -0.25456351041793823`, 
                    0.07790614664554596, 0.3457720875740051, 
                    0.20797061920166016`, 0.2545565068721771, 
                    0.1092427521944046, 0.106245256960392, 0.2969173192977905,
                     0.21714815497398376`, -0.32425159215927124`, \
-0.01710301823914051, 0.18987837433815002`, 0.19653332233428955`, 
                    0.07081956416368484, -0.04515516012907028, 
                    0.2805956304073334, -0.19638729095458984`, 
                    0.0321742482483387, -0.08360744267702103, 
                    0.07087402790784836, -0.08645761758089066, 
                    0.06218234449625015, -0.08667748421430588, \
-0.052572570741176605`, -0.16717873513698578`, -0.13268733024597168`, \
-0.11672292649745941`, -0.23230434954166412`, -0.23582473397254944`, 
                    0.16089266538619995`, 0.1262388527393341, 
                    0.1807524710893631, -0.03858880698680878, \
-0.026646317914128304`, -0.05391431972384453, 0.2535269856452942, 
                    0.32715433835983276`, 
                    0.18367622792720795`, -0.35526061058044434`, \
-0.08513887226581573, -0.17994336783885956`, 0.02357426844537258, 
                    0.21712014079093933`, -0.1573423594236374, \
-0.12532106041908264`, -0.07944932579994202, -0.2279338538646698, 
                    0.07914938777685165, -0.1759791374206543}}], "Biases" -> 
                    RawArray["Real32",{-0.025722049176692963`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-1.041874647140503}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.0464109, "MeanInputsPerSecond" -> 
          50729.12314770088], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.006108885170067561, -0.04691812506274433, 
                0.0038280127845562633`, 
                0.0426552842756025, -0.03145063863130073}, 
               "StandardDeviation" -> {0.9944994233817057, 
                1.0042444781227562`, 1.0244636709123283`, 1.0005285299985822`,
                 0.9785887049809324}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 5932863310730318187]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[365153], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3889357248262916, "PreprocessingTime" -> 
        0.3453293`6.98977842179757, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.5261713092159128, 0.35361119411484254`], 
           "StandardDeviation" -> 
           Around[0.3503656300988833, 0.06285449209870059], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 99880, 
           "ModelUtility" -> 0.32034779112876166`, "TrainingSize" -> 252, 
           "TrainingTime" -> 5.011872336272724, "TrainingMemory" -> 451832, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.5261713092159128, 0.25004087326207775`]}, 
           "StandardDeviationHistory" -> {
             Around[0.3503656300988833, 0.04444483759102745]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 213932533247702]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.554867780896983, 0.603142555959185], 
                "StandardDeviation" -> 
                Around[0.7168195122028329, 0.04196396045401893], 
                "EvaluationTime" -> 0.0001497747329571884, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.37189026813656856`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                495776, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.554867780896983, 0.42648619134092636`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7168195122028329, 0.02967300100248089]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[15.258046202922234`, 2.2572310670511375`], 
                "StandardDeviation" -> 
                Around[0.6643217022728387, 0.04505202369570263], 
                "EvaluationTime" -> 0.00013362079043559505`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.29766448694299474`, "TrainingSize" -> 50,
                 "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                499728, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[15.258046202922234`, 1.5961033942168057`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6643217022728387, 0.03185659146140835]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5473122545344674, 0.4080342066291083], 
                "StandardDeviation" -> 
                Around[0.37226324205423383`, 0.0820004577400215], 
                "EvaluationTime" -> 0.00015873015873015873`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.25186066583569044`, "TrainingSize" -> 252, "TrainingTime" -> 
                1.9952623149688797`, "TrainingMemory" -> 522696, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5473122545344674, 0.28852375446351536`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.37226324205423383`, 0.05798307972837012]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00015873015873015873`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.37226324205423383`, 0.0820004577400215], 
               "TrainingMemory" -> 522696, "TrainingTime" -> 
               3.125035238191293], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[5.658795161820361, 0.7513364715937951], 
                "StandardDeviation" -> 
                Around[0.720692043092169, 0.04259439234935614], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 99880, "ModelUtility" -> -0.3773870242626053,
                 "TrainingSize" -> 10, "TrainingTime" -> 1.2589254117941673`, 
                "TrainingMemory" -> 424640, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[5.658795161820361, 0.5312751140167463]}, 
                "StandardDeviationHistory" -> {
                  Around[0.720692043092169, 0.030118783670750125`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[27.00105284237213, 3.947213745264127], 
                "StandardDeviation" -> 
                Around[0.7064188603217968, 0.04881381854025935], 
                "EvaluationTime" -> 0.00013252401628338037`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.35935777591185514`, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.2589254117941673`, "TrainingMemory" -> 
                429192, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[27.00105284237213, 2.7911016060690135`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7064188603217968, 0.034516582105427004`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5261713092159128, 0.35361119411484254`], 
                "StandardDeviation" -> 
                Around[0.3503656300988833, 0.06285449209870059], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 
                0.32034779112876166`, "TrainingSize" -> 252, "TrainingTime" -> 
                5.011872336272724, "TrainingMemory" -> 451832, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5261713092159128, 0.25004087326207775`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3503656300988833, 0.04444483759102745]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.3503656300988833, 0.06285449209870059], 
               "TrainingMemory" -> 451832, "TrainingTime" -> 
               7.523765832135071], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[12.39394212223475, 1.8207415580326332`], 
                "StandardDeviation" -> 
                Around[0.6215252119008262, 0.041459906212662684`], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.23085357421257413`, "TrainingSize" -> 50,
                 "TrainingTime" -> 0.3981071705534972, "TrainingMemory" -> 
                428800, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[12.39394212223475, 1.2874587024730346`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6215252119008262, 0.029316580830332055`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5229309060318272, 0.25343088451053275`], 
                "StandardDeviation" -> 
                Around[0.37170132000329104`, 0.0575112417492691], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 
                0.26600939949970936`, "TrainingSize" -> 252, "TrainingTime" -> 
                1., "TrainingMemory" -> 451704, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.5229309060318272, 0.17920269699950248`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.37170132000329104`, 0.04066658903536706]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.37170132000329104`, 0.0575112417492691], 
               "TrainingMemory" -> 451704, "TrainingTime" -> 
               1.648107170553497], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 213928238280406]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.000010844921875`1., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097571421666772`17.333472281061677*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.942058513438322, 
            "ElapsedTimes" -> 2.4683943999999998`, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 3.2367641890638694`, 
            "ElapsedTimes" -> 2.9391374000000003`, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 5.394606981773116, 
            "ElapsedTimes" -> 8.7106899, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 213941123182294]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{-13.060469205364882`, 2.2505554067043327`, 
              2.3025629375567593`, 1., 3.912023005428146}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 14.8545116, 
        "MaxTrainingMemory" -> 942200, "DataMemory" -> 75768, 
        "FunctionMemory" -> 258088, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 52, 22.19859`9.098900319160489}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {-0.18897217008099257`, -0.17507393997192724`, 
                    0.32805171238825365`, 0.47619047619047616`, 
                    3.8691875324215403`}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.18897217008099257`, -0.17507393997192724`, 
                    0.32805171238825365`, 0.47619047619047616`, 
                    3.8691875324215403`}, 
                    "StandardDeviation" -> {7.303171524698292, 
                    4.8458610608120605`, 4.380254102801408, 
                    0.4994327848429293, 1.3677260613126128`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{0.5600103445970198, 0.04259852083446085, 
                    0.5815033248928239, -0.12546374349725847`, 
                    0.5750534863586937}, {-0.0006344944066671442, 
                    0.7506494373611783, -0.49313250362049305`, \
-0.16447693577968592`, 0.4077900085530588}, {-0.31154496158467104`, 
                    0.5848408258343902, 
                    0.6153397834495125, -0.1579366777582566, \
-0.3966281660088529}, {-0.5070656812598422, -0.30431996899271574`, 
                    0.04254085395712094, -0.7426717169411692, 
                    0.3112920621554942}, {-0.57637847215252, \
-0.007832823353274164, 0.1955030528162697, 0.6170096541696248, 
                    0.498802713222815}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.18897217008099257`, -0.17507393997192724`, 
                    0.32805171238825365`, 0.47619047619047616`, 
                    3.8691875324215403`}, 
                    "StandardDeviation" -> {7.303171524698292, 
                    4.8458610608120605`, 4.380254102801408, 
                    0.4994327848429293, 1.3677260613126128`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0140422, "MaxTrainingMemory" -> 93152, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 52, 22.2285089`9.09948526012943}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.18897217008099257`, -0.17507393997192724`, 
                0.32805171238825365`, 0.47619047619047616`, 
                3.8691875324215403`}, 
               "StandardDeviation" -> {7.303171524698292, 4.8458610608120605`,
                 4.380254102801408, 0.4994327848429293, 1.3677260613126128`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.458820267112628}, 
               "StandardDeviation" -> {0.7235254063409977}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.458820267112628 + 
         0.7235254063409977 #& ), 
        "ProcessorFunction" -> (3.3983882881837397` + 
         1.3821214724956041` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.760731508697341, 2.5944218668254413`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwVjn001Xccxy91cykPMa61Du5EqGVEovv7fJYhy2M4h7RbXVusxca1FptS
TsI8nEv0pHnYHNJcQ1tL9/4+32TkbIsQOovOadfQyZIehDxMf7ze57zO+5+X
JObLsFhdgUCQLFqaMPmR7QqFPDV8xRs5II/f7Br/5nRdQriEOPQ3ymzzYeYX
RexDvVz+9D4jktW9i7bzlnhuUwCcurSGzM98xDlqWiB4eyLEPuyjnmQZFr+y
x8rWFHBDD5baFY3lzjbMxDKfphpyQNgJ+KwljMK3+FH5Lhc8pZhXf7FThru0
/dKOJ9ksapUaFgVD0uU5tfz8jQzw8Zrlk5tz6UFXO5fpfhjV1Z6sUalgJekS
GqsE8g4I4o/RCra4/yo4BkopLl0Pr1npY63jB/z9+6XweXIhhjy5RupP2yG4
lXE/tRQzw8FhKBz9E8r6TnJP67o55YFbMNkeygJ/vyzNOg545pE3hSWuxx13
NuA/2WVkprDiI+UxWDDwnBt7yEFvtA9lHb5Olb7VnLhxhtq6itFqzhR7DTLB
p/8sXzB6gz5Rfs/e/tEYG2I9uMC+DujoVFMt/zPWp0zB5fI5pvEvovj+Kspe
p+TdbuuR9YNGOp1azQx+yIXg8eskzTlJ95oXwCPtOGf1axv3Uvc2HdyRhkXN
8VgRPgcvMiTMzy8fry8FWY9Eol1SA8ljoqHnZAm9decp1GyywenFIFqs8Uad
Ex7cjEQHe/IEuL/WC3d2O2Hj9Ho2I0ZImkxj1sFDMJ0VCc7ZjZz9zATfKLrH
171nTq47moGP3wvmogQqW+eA3FE9nIoyAVmEKTO95YVxyiY4d1mF56slaK+y
RQdXP+4vvecgDFyJ1TUiJky0YAm2/du+00ooMn2EHPNWM7m4nP49Kwcnp2VM
2fE+/WJcAdoJLdVsCkT94za41tmO2V10Z+0aBe+7Ugpj83GoNU1gd1ucyEhY
Km07JGERVetwM+fHXniWQP2VPIwQF0o7j8XxLk0SfEXF5EiP4dLLUbI7NaFZ
HpQJ8hKNxlA/g8ymthI/ro8jFq81+XMDZDDkxkJdQvjcFDVz6JQzw7AC4O5u
wb4peybtToKb0SL4eE8JrvHyZxv+kFGbbhVUPuvV7N4YTIKr+2g45zy7L7sg
tZkvBzjsrPZN/4/7298YtSXA1vLLMPCVAB5vNaHdkguoEvnCIX6QeqqHYdJM
zCICZrd5iko5S2ueRMwfbZZHcvsK9dmA6jVZfS1j34htpV7fZrCv6t7RmBmF
4rGivXhk1gB7vXWYcYwKKlptuYWkVZB6UMj0xjXUJI+DjcK9sLhwU7OnzBMe
HS2iE9EWLGv1AvRUXKG4E/Xg7xvF5kLK4WZlPG/kHgFDqs/IOGmQ/x9d3+hD

                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.1510709971189499, -0.07775840163230896, \
-0.05914611741900444, 0.09943794459104538, -0.1159881129860878, 
                    0.033256255090236664`, -0.13965219259262085`, \
-0.021780384704470634`, -0.010041830129921436`, -0.057006679475307465`, \
-0.0006358043756335974, -0.01356689166277647, -0.0009673949680291116, \
-0.06955254822969437, 0.034203317016363144`, 
                    0.025349507108330727`, -0.06210005283355713, \
-0.08476744592189789, 
                    0.08956259489059448, -0.029062826186418533`, \
-0.1144477054476738, -0.02278268337249756, -0.09623954445123672, \
-0.013512988574802876`, -0.04434807598590851, -0.047971732914447784`, \
-0.19708269834518433`, -0.20140819251537323`, -0.04896358773112297, 
                    0.01301348302513361, 0.08715353161096573, 
                    0.04633041098713875, 0.0062102871015667915`, 
                    0.10873556137084961`, 
                    0.10314296931028366`, -0.007217751815915108, \
-0.052727583795785904`, -0.12076102197170258`, 0.02547481656074524, 
                    0.04672395810484886, -0.0021001985296607018`, 
                    0.03703915327787399, -0.05863751098513603, \
-0.09591540694236755, 
                    0.023594515398144722`, -0.021563006564974785`, \
-0.08599047362804413, -0.03146215155720711, -0.15792568027973175`, \
-0.18364836275577545`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3lUz8/3x4nSro2kRGlXKtnq/bo3iRI+SpaKlLKLouxLSrtCm5IoIWtF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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.13723377883434296`, -0.015155753120779991`, \
-0.0030980552546679974`, 
                    0.00603823596611619, -0.05589085817337036, \
-0.140317901968956, 0.022242140024900436`, -0.04877166077494621, 
                    0.07055444270372391, 
                    0.053618598729372025`, -0.033953722566366196`, \
-0.06738077849149704, -0.04120662808418274, -0.07041921466588974, \
-0.07562383264303207, -0.05852700024843216, -0.09409289807081223, \
-0.011150852777063847`, 
                    0.0183758232742548, -0.06070227548480034, \
-0.07523118704557419, -0.061086505651474, 
                    0.07696858048439026, -0.10184698551893234`, \
-0.0007592748734168708, -0.0584462471306324, -0.10043027997016907`, \
-0.07662522047758102, 
                    0.015595431439578533`, -0.09913947433233261, \
-0.041896168142557144`, -0.04058811813592911, -0.0786786675453186, \
-0.003131329780444503, -0.11473957449197769`, -0.15156753361225128`, \
-0.0020391494035720825`, 0.021728502586483955`, 0.062096353620290756`, 
                    0.010450411587953568`, -0.02568678930401802, \
-0.09029802680015564, -0.016039900481700897`, -0.07445226609706879, \
-0.07592879980802536, -0.017677603289484978`, 0.14817097783088684`, 
                    0.17000660300254822`, -0.07956969738006592, \
-0.05585040897130966}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtV3dcz4/zL0p7EklLRSFSRuP9uitFlBJZRaLsyEgKkfYiJTQUJQoZiVDe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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.028153272345662117`, -0.036478474736213684`, \
-0.04370279610157013, -0.10315335541963577`, -0.008875848725438118, \
-0.056303415447473526`, -0.05672973021864891, -0.03964827582240105, \
-0.03259142115712166, -0.0092740124091506, 
                    0.011460911482572556`, -0.03976524621248245, 
                    0.015437482856214046`, -0.04070300608873367, \
-0.055176567286252975`, 
                    0.021388564258813858`, -0.05225773900747299, \
-0.0010398030281066895`, -0.0037898868322372437`, -0.0846625417470932, \
-0.02517455630004406, -0.0405731201171875, 0.016147935763001442`, 
                    0.03522461652755737, 
                    0.029025880619883537`, -0.07600286602973938, \
-0.0271719042211771, -0.0556059293448925, -0.09646162390708923, \
-0.0874934047460556, 
                    0.045424122363328934`, -0.03467407077550888, \
-0.014724412001669407`, -0.02267424389719963, 
                    0.002917003119364381, -0.0418674610555172, \
-0.13335295021533966`, -0.001506611704826355, -0.004211188293993473, \
-0.016791392117738724`, 
                    0.013041466474533081`, -0.14084920287132263`, \
-0.07563536614179611, -0.000737268419470638, -0.022972863167524338`, 
                    0.004994997289031744, -0.04957902804017067, 
                    0.001412979676388204, 
                    0.0797569677233696, -0.061404116451740265`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dYz+/3xxWVKEoqSUNJhYZdvV/nNCmibElGZa/MZKXSpK1NSQkJUYTe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                    "], "Biases" -> 
                    RawArray["Real32",{-0.034896235913038254`, 
                    0.02363860420882702, 
                    0.09772443771362305, -0.036776043474674225`, \
-0.031542424112558365`, -0.0066595543175935745`, -0.011608656495809555`, 
                    0.004747775848954916, 
                    0.0380357950925827, -0.03490070626139641, \
-0.024859054014086723`, -0.007840823382139206, 
                    0.006880899891257286, -0.03556692227721214, 
                    0.009212130680680275, 0.01803010143339634, 
                    0.006314401514828205, -0.030811112374067307`, 
                    0.022055620327591896`, 
                    0.05078328773379326, -0.0441037192940712, \
-0.016471102833747864`, 0.0463707372546196, -0.004862670786678791, 
                    0.018879471346735954`, 
                    0.08210285007953644, -0.04050382226705551, \
-0.03840543329715729, -0.005101829767227173, 
                    0.019824443385004997`, -0.024826087057590485`, \
-0.02653697319328785, -0.08436933159828186, 0.025714367628097534`, 
                    0.012872477993369102`, 
                    0.015211086720228195`, -0.03614674136042595, \
-0.04863971471786499, 
                    0.02701670676469803, -0.02896794117987156, \
-0.009032228030264378, -0.004985308740288019, -0.003581098048016429, 
                    0.05239780619740486, 0.01946263201534748, 
                    0.029842959716916084`, -0.004132663365453482, 
                    0.03080483339726925, 
                    0.05185535177588463, -0.02200959250330925}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{-0.10983509570360184`, 
                    0.0792948380112648, 
                    0.1132376566529274, -0.11053474247455597`, \
-0.17247000336647034`, -0.1252889633178711, -0.05969996750354767, \
-0.2975841462612152, 
                    0.052615463733673096`, -0.056796081364154816`, \
-0.02127143181860447, 
                    0.1741936057806015, -0.2744290232658386, \
-0.048549070954322815`, 0.08926041424274445, 0.10874145478010178`, 
                    0.13790933787822723`, -0.24666054546833038`, 
                    0.08638303726911545, 
                    0.1589154601097107, -0.21931114792823792`, 
                    0.14229394495487213`, 0.12783707678318024`, 
                    0.10847771912813187`, 0.04069121927022934, 
                    0.11004369705915451`, -0.08472302556037903, \
-0.05662889778614044, -0.1812478005886078, 
                    0.15040823817253113`, -0.18070870637893677`, \
-0.04686632379889488, -0.13728347420692444`, 
                    0.03891093283891678, -0.1397169977426529, \
-0.14025750756263733`, -0.03538027033209801, -0.14497187733650208`, 
                    0.08277716487646103, -0.06940076500177383, 
                    0.08214998245239258, -0.13641685247421265`, \
-0.04975707456469536, 0.08573897927999496, -0.03336721658706665, 
                    0.13306106626987457`, -0.11231992393732071`, 
                    0.1932545155286789, 
                    0.06973631680011749, -0.14234709739685059`}}], "Biases" -> 
                    RawArray["Real32",{0.022550033405423164`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-1.2419770956039429`}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.2251762, "MeanInputsPerSecond" -> 
          48993.56312615831], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.003457765307167061, 
                0.036027549399334204`, -0.02332993622862701, \
-0.06363079656422238, -0.05720618152050389}, 
               "StandardDeviation" -> {0.9516345978942046, 
                1.0463432507998085`, 0.9979923250830507, 0.9951974132131631, 
                1.0071473617795572`}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8023476431259091446]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[365265], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.32361961764463426`, "PreprocessingTime" -> 
        0.3747197`7.0252515191929055, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.7139183673682132, 0.4636084852351057], 
           "StandardDeviation" -> 
           Around[0.355599211498439, 0.06422098491790244], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 107736, 
           "ModelUtility" -> 0.305286801781283, "TrainingSize" -> 252, 
           "TrainingTime" -> 5.011872336272724, "TrainingMemory" -> 523088, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.7139183673682132, 0.32782070372536665`]}, 
           "StandardDeviationHistory" -> {
             Around[0.355599211498439, 0.04541109392992781]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 195829246095076]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.7728553842400039`, 0.3200439494811571], 
                "StandardDeviation" -> 
                Around[0.5147039202287245, 0.03447627849760019], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.042325263394278445`, "TrainingSize" -> 
                10, "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495824, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.7728553842400039`, 0.226305246955851]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5147039202287245, 0.02437841031572905]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[4.026828267907799, 0.6719667937674221], 
                "StandardDeviation" -> 
                Around[0.40628300387855987`, 0.026930263110186432`], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.19435441975242707`, "TrainingSize" -> 50, "TrainingTime" -> 
                1.5848931924611136`, "TrainingMemory" -> 499792, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.026828267907799, 0.47515227660512643`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.40628300387855987`, 0.01904257166435075]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.7139183673682132, 0.4636084852351057], 
                "StandardDeviation" -> 
                Around[0.355599211498439, 0.06422098491790244], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 0.305286801781283, 
                "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
                "TrainingMemory" -> 523088, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.7139183673682132, 0.32782070372536665`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.355599211498439, 0.04541109392992781]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.355599211498439, 0.06422098491790244], 
               "TrainingMemory" -> 523088, "TrainingTime" -> 
               7.849733612802018], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[0.7599358317266053, 0.13126587979901413`], 
                "StandardDeviation" -> 
                Around[0.40946115062940436`, 0.025153199661230013`], 
                "EvaluationTime" -> 0.00009754313933815523, "TestSize" -> 265,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.1875210614079591, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 499728, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.7599358317266053, 0.09281899374430114]}, 
                "StandardDeviationHistory" -> {
                  Around[0.40946115062940436`, 0.01778599804899491]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.6348246025189752, 0.2859389505486556], 
                "StandardDeviation" -> 
                Around[0.40927843194919855`, 0.06745166422416216], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.16774870187607538`, "TrainingSize" -> 252, "TrainingTime" -> 
                1., "TrainingMemory" -> 522696, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.6348246025189752, 0.20218937093831924`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.40927843194919855`, 0.0476955291752231]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00025157034800970054`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.40927843194919855`, 0.06745166422416216], 
               "TrainingMemory" -> 522696, "TrainingTime" -> 
               1.648107170553497], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.39440139228581, 0.4452768943943654], 
                "StandardDeviation" -> 
                Around[0.5693887982896384, 0.041338800642323696`], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 99880, "ModelUtility" -> -0.1444035060414438,
                 "TrainingSize" -> 10, "TrainingTime" -> 0.3981071705534972, 
                "TrainingMemory" -> 424848, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[2.39440139228581, 0.31485831153194194`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5693887982896384, 0.02923094626030589]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[1.4823185179508498`, 0.2512407112836612], 
                "StandardDeviation" -> 
                Around[0.41527661017794437`, 0.025342497174061143`], 
                "EvaluationTime" -> 0.00015633372739584048`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.1734999370432001, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 428800, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.4823185179508498`, 0.17765401065880837`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.41527661017794437`, 0.01791985160397955]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.8138542326855479, 0.44430098153177355`], 
                "StandardDeviation" -> 
                Around[0.3916505920832314, 0.06731485618815114], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.21040847417384922`, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 451832, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.8138542326855479, 0.31416823692895607`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.3916505920832314, 0.0475987912852389]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00025157034800970054`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.3916505920832314, 0.06731485618815114], 
               "TrainingMemory" -> 451832, "TrainingTime" -> 
               1.391017463958849], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 195824951127780]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 0.0000102899224806202`2., 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097571556632684`17.333472282600223*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.7685503625800085`, 
            "ElapsedTimes" -> 2.0604857, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 2.9475839376333477`, 
            "ElapsedTimes" -> 2.8613393, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 4.91263989605558, 
            "ElapsedTimes" -> 7.7961409, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 195837836029668]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{7.062708447633639, 4.813353001058087, 
              5.280333637534039, 1., 3.912023005428146}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 13.4905239, 
        "MaxTrainingMemory" -> 962240, "DataMemory" -> 75768, 
        "FunctionMemory" -> 265960, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 52, 35.6901949`9.305123813290164}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {
                    0.41593800050903124`, -0.060983903090257155`, \
-0.026386830467606613`, 0.5015873015873016, 3.7760595161204873`}, "Method" -> 
                    "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.41593800050903124`, -0.060983903090257155`, \
-0.026386830467606613`, 0.5015873015873016, 3.7760595161204873`}, 
                    "StandardDeviation" -> {6.6281748705184365`, 
                    4.572131716686459, 4.261365899076322, 0.4999974804673229, 
                    1.3241641660386154`}, "Method" -> "NaiveSampler", 
                    "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.42565417147075213`, 0.4256654502963584, 
                    0.2183272019485191, -0.7320796323146663, 
                    0.23242223553890018`}, {-0.5706546420802878, \
-0.47298043775785653`, -0.0029719776087966613`, 0.2532701201984655, 
                    0.6216817502021053}, {-0.6484023839987813, 
                    0.18019348080263578`, 0.23203572844950415`, 
                    0.3594054449101447, -0.6034002028444935}, {
                    0.04113627824090828, 
                    0.7500155310285223, -0.16876116857994164`, 
                    0.49120676250676626`, 0.4074556347329669}, {
                    0.2665594883303715, -0.010268525435486292`, 
                    0.9327397755756233, 0.17163129318757941`, 
                    0.17140538738419672`}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {
                    0.41593800050903124`, -0.060983903090257155`, \
-0.026386830467606613`, 0.5015873015873016, 3.7760595161204873`}, 
                    "StandardDeviation" -> {6.6281748705184365`, 
                    4.572131716686459, 4.261365899076322, 0.4999974804673229, 
                    1.3241641660386154`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0196283, "MaxTrainingMemory" -> 93360, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 52, 35.7241024`9.305536219259514}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {
                0.41593800050903124`, -0.060983903090257155`, \
-0.026386830467606613`, 0.5015873015873016, 3.7760595161204873`}, 
               "StandardDeviation" -> {6.6281748705184365`, 4.572131716686459,
                 4.261365899076322, 0.4999974804673229, 1.3241641660386154`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> 
                 Association["Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.3885294480440598`}, 
               "StandardDeviation" -> {0.7373353239124003}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.3885294480440598` + 
         0.7373353239124003 #& ), 
        "ProcessorFunction" -> (3.2394073233467258` + 
         1.3562350365826306` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.8043552758674934`, 2.450498786303831}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwVknkw3HcYh9WVFVqMVBFxTSTTWFEkRO3v/aZpB23HtY5EEBZRSWRthWbX
MeqoowZNkXRU0o2pukkHGdb+3q8jjtIQ18YmE1IJ200yBqWJSZpU/ng+M595
/n1sY5L48ZoaGhoXONvDF1z8JDlZIAnSfXtOCxJdXRLfSpdtdLYp19OhPoVR
sMkZhc5YtXxxjQeVxWqwXiHUT6ucdpeM4dcb/0HEqX9wOVtEb+SpIXIwDmV3
HUh7TzQ54yoGj1AjMvAjF2S9DSiUzuJwhRj4YcVoIzAlKQ1xxO34CAw+v4H3
Tf8GhWoM585aMpNPxcxwZyc7P92EfS1X8ZSvPiFFG7CQGUryR7PBLXQRNlyD
aO7LfBA3pcHHMRvIMiI8W+tPx6v64FxXN/77wTvURHIZsEAFt70SMS8hALlV
y7jurEvnHa/wKqO5cFz9KxG4D2Ftay+8MHKiT9q78akwG8ZyY0iL3Bw+v2ND
U4AHgukcVtSZg0mtlfLZNBaGupzIVEI+myXcCR5BTSB7Y86OBp2gfc96wDB1
ioHgNlgZMcfAmRF03NLGpcKT8KKjmt3pUYniqWLS88oOWyfS8JrZKARXedIB
yVfkpbAE3Bu59FGABTpZfIRTfYXkUH8m2WXzPXlQqGRycsaRWFaD6TqH1liH
kIfjMwirVjyTkUjio4iBh1aapMS7gKeXnw2Fhnx66fdwmLqSSxeOGsuvr0lI
m2UTxDom87jaXViqV4QT6yrmQGkVGh9W4u65q5BnF0p0z/8FfZFSNM2axRTh
MLuZ9ggvLO7D1LYSuJT5IfjXNLJmHQycgXnsuoxYxL+FC83t+OR0NqvU8ob1
gwflucfsSd6rW4zGvTcwt25JxZZGsPKHDrH/MoWKXgdghzKXZ2hmS24qDKiD
vxvNmtAi7r/tIaIqCj/3JGG/gTatt37Gxnu3Q4TLLOzxciP6Vrls6PVSdrsX
6pdeTBLS36cclwxWrnIkg0pj4rFRA1YrRehcdwiEz/+E1OoBEPoa4dpuNYZH
XARV4CZ4BhvQa/GvGT83LlSk+MhWtdbYhbtl+CC4Hi24UiyXpUN/ZjTOKVlM
r3CErKUJpsNzGDz31zN2cikAKYNj3hLaL/2WVJuYsR5+i/hTqi842O2i6qhw
8nhsL4Z1fUoiyqyITcdRckRIIM91FTMi46FyaQtctjucnPuMBCgs2OjALXnc
0Hu0yb4AB0aaMYtzD6f5tUyNrQXRFduTc/f30/7RGVxVLTGLmSOMkt8Ldzh7
UdpcQiCqGR4rdlC32z/IZvpDoCYuBOK93An/Ow5bt3ye6sd+w7ybwKeHWyV4
8oALUSQpmckTtuSLfS0gutmAdTJnzGj8BUQGPcz0kTC6Y0MT/ged0/mh
                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.010836305096745491`, -0.012768835760653019`, \
-0.005590992979705334, -0.02530570514500141, -0.07613379508256912, 
                    0.033224012702703476`, 
                    0.046526093035936356`, -0.045242343097925186`, \
-0.05780612677335739, 
                    0.03214878588914871, -0.016076484695076942`, \
-0.011553255841135979`, -0.09524316340684891, -0.00007732425001449883, \
-0.02221756801009178, 
                    0.034826457500457764`, -0.0361807644367218, \
-0.055934611707925797`, 0.006195788271725178, -0.005714491009712219, 
                    0.09026210010051727, 0.02784680761396885, 
                    0.05117463320493698, -0.008733258582651615, \
-0.027233237400650978`, -0.07182085514068604, -0.1032494530081749, \
-0.03870455175638199, 0.003712821053341031, 
                    0.035970594733953476`, -0.09132788330316544, \
-0.032191358506679535`, 
                    0.07576894760131836, -0.006522060371935368, \
-0.04141182452440262, 0.07958538085222244, 0.03402920067310333, 
                    0.014811104163527489`, 0.0006128298118710518, 
                    0.05822135880589485, -0.02209143526852131, \
-0.022945581004023552`, -0.09171388298273087, 0.015058300457894802`, 
                    0.03759025037288666, -0.013552190735936165`, 
                    0.013625485822558403`, -0.1375575065612793, 
                    0.014385366812348366`, 0.029857873916625977`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtV3lQj4/zp0OlUuhQUihFJd3S+9mNypUjOpQjV44kFBJCEVKJEio5Kp1U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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.012630201876163483`, -0.006769832223653793, 
                    0.07701500505208969, 
                    0.004296676255762577, -0.08798419684171677, 
                    0.057135336101055145`, -0.008678214624524117, \
-0.018028652295470238`, 
                    0.03727182373404503, -0.010604383423924446`, \
-0.03779294341802597, -0.0033715299796313047`, -0.006845169235020876, 
                    0.009935109876096249, -0.007368444465100765, 
                    0.021659888327121735`, 
                    0.08702576905488968, -0.024171210825443268`, 
                    0.08644320070743561, -0.029842205345630646`, \
-0.0017226131167262793`, 0.014359522610902786`, 0.015431133098900318`, 
                    0.02342246286571026, 0.018218591809272766`, 
                    0.02641718089580536, -0.01913801021873951, \
-0.003993868827819824, 0.04577108845114708, 0.047058794647455215`, 
                    0.03114970028400421, -0.042903728783130646`, \
-0.08894601464271545, -0.004974852316081524, -0.04818639159202576, \
-0.0014289747923612595`, 0.013620777986943722`, 0.00017669814405962825`, 
                    0.026398738846182823`, -0.0067553832195699215`, 
                    0.02043173834681511, -0.021949904039502144`, 
                    0.00619996665045619, 
                    0.026756877079606056`, -0.01810281164944172, 
                    0.07326913625001907, -0.020577751100063324`, \
-0.03734239190816879, -0.02064867690205574, -0.06622927635908127}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3c41//3h5EZJSojZDSsEorwfp1jJKmEtBelIUppU8oeGUWkRWkvGqL1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                    "], "Biases" -> 
                    RawArray["Real32",{-0.030063027516007423`, 
                    0.005276589188724756, 0.034229446202516556`, 
                    0.05075553059577942, -0.06685614585876465, 
                    0.027372051030397415`, 0.03557531535625458, 
                    0.004648264497518539, 0.04177340492606163, 
                    0.02522287517786026, -0.0001449950214009732, 
                    0.002198554575443268, 0.012790478765964508`, 
                    0.03486722335219383, 0.016843555495142937`, 
                    0.0017819623462855816`, 0.019490273669362068`, 
                    0.04125070199370384, 
                    0.00854523666203022, -0.01009075716137886, \
-0.027868807315826416`, 0.004661839921027422, -0.010232632979750633`, 
                    0.026751138269901276`, 
                    0.008956920355558395, -0.004177130293101072, \
-0.027126697823405266`, 0.0222404133528471, 
                    0.08659548312425613, -0.0003155063313897699, 
                    0.013418593443930149`, 
                    0.02583250217139721, -0.013104619458317757`, 
                    0.04141129553318024, 0.04637586697936058, 
                    0.036436375230550766`, -0.05047106742858887, \
-0.0008889898890629411, 0.027935005724430084`, 
                    0.008572832681238651, -0.005227686837315559, \
-0.08799728751182556, 0.049115005880594254`, -0.07409568130970001, 
                    0.037923507392406464`, 0.01145704835653305, 
                    0.006800258997827768, -0.0037555585149675608`, \
-0.02221069112420082, -0.0019542635418474674`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dUz4/3x5O0EDIaRNKgJFRU79e9lJKUIgoNyUjK3lklDWlpKdLQMIoG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                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.03796718642115593, -0.001990321557968855, 
                    0.0377935953438282, -0.015965381637215614`, 
                    0.018097558990120888`, 0.0009931507520377636, 
                    0.0194306168705225, 
                    0.03687294200062752, -0.021909767761826515`, \
-0.01740236207842827, 0.007138903718441725, -0.043690185993909836`, 
                    0.004321333486586809, 0.005162605084478855, 
                    0.002450853120535612, 0.04247913882136345, 
                    0.0070874048396945, -0.017167408019304276`, \
-0.036836519837379456`, -0.03156324103474617, 
                    0.0010555429616943002`, -0.047150347381830215`, \
-0.0178980715572834, 0.011140055023133755`, 
                    0.05795422941446304, -0.019233305007219315`, \
-0.012866195291280746`, -0.011395872570574284`, 
                    0.03959854319691658, -0.012687196023762226`, \
-0.037582725286483765`, 0.027420205995440483`, 0.03265412896871567, 
                    0.03069259226322174, -0.021741457283496857`, \
-0.03587467223405838, -0.029993552714586258`, -0.04374255612492561, 
                    0.011472064070403576`, 
                    0.012467099353671074`, -0.0642278641462326, 
                    0.0023048045113682747`, 
                    0.024208638817071915`, -0.05159434303641319, \
-0.02123260870575905, -0.020001612603664398`, 0.015488976612687111`, 
                    
                    0.013483239337801933`, -0.021791983395814896`, \
-0.015941284596920013`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{-0.13731522858142853`, 
                    0.12902770936489105`, -0.09802347421646118, \
-0.004416878335177898, 
                    0.21742363274097443`, -0.007565463427454233, \
-0.3295724093914032, -0.11095651239156723`, 0.12171099334955215`, 
                    0.1223401427268982, -0.11331968009471893`, \
-0.31805965304374695`, -0.19557686150074005`, 
                    0.19832022488117218`, -0.1581801176071167, 
                    0.07061675935983658, 
                    0.37643134593963623`, -0.14930853247642517`, \
-0.04455350339412689, 0.18586750328540802`, 0.23111043870449066`, 
                    0.07525002956390381, 0.14408862590789795`, 
                    0.14201994240283966`, -0.11244957894086838`, 
                    0.08873333781957626, -0.1976960450410843, 
                    0.19416217505931854`, -0.26159441471099854`, \
-0.2192765474319458, -0.12548290193080902`, -0.19443285465240479`, \
-0.23828177154064178`, 
                    0.06726047396659851, -0.2302032709121704, \
-0.10141995549201965`, -0.22491782903671265`, 
                    0.08470378071069717, -0.2163274586200714, \
-0.09365977346897125, -0.040421437472105026`, 
                    0.2258128821849823, -0.216217041015625, \
-0.24970576167106628`, -0.14839068055152893`, -0.04137441888451576, 
                    0.07611034065485, -0.05730540677905083, 
                    0.07003968209028244, -0.32573845982551575`}}], "Biases" -> 
                    RawArray["Real32",{-0.004799831658601761}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.9063896536827087}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.0992899, "MeanInputsPerSecond" -> 
          50203.06847037664], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.027364869431540095`, -0.007461502197225009, \
-0.013136325780024178`, -0.01927675619996479, 0.0063979477548652755`}, 
               "StandardDeviation" -> {1.0246478589930004`, 
                1.0152842818668375`, 0.9953921936656642, 0.9994237490579915, 
                0.9859462017439882}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 6683679153702456943]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[365377], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.30471250531130345`, "PreprocessingTime" -> 
        0.34621`6.990884601466593, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> Around[0.7228099249185113, 0.382576459897187],
            "StandardDeviation" -> 
           Around[0.42566184594124906`, 0.08184065763972302], 
           "EvaluationTime" -> 0.00015873015873015873`, "TestSize" -> 63, 
           "ModelMemory" -> 99880, "ModelUtility" -> 0.12319829973355534`, 
           "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
           "TrainingMemory" -> 451768, "ExperimentCount" -> 1, 
           "MeanCrossEntropyHistory" -> {
             Around[0.7228099249185113, 0.2705224091156442]}, 
           "StandardDeviationHistory" -> {
             Around[0.42566184594124906`, 0.057870083993814776`]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 34231101583091]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[2.7320232783156206`, 0.34129352328527945`], 
                "StandardDeviation" -> 
                Around[0.5919515011511073, 0.030750072314801244`], 
                "EvaluationTime" -> 0.0001497747329571884, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.17918631641742666`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.7943282347242815, "TrainingMemory" -> 
                495824, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.7320232783156206`, 0.24133096469006995`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5919515011511073, 0.021743584655772676`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[5.790314956554042, 0.9879920468917552], 
                "StandardDeviation" -> 
                Around[0.4688659286979528, 0.03306783604794172], 
                "EvaluationTime" -> 0.00016249866665033437`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.050250409017955855`, "TrainingSize" -> 50, "TrainingTime" -> 
                0.6309573444801932, "TrainingMemory" -> 499728, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[5.790314956554042, 0.6986158761155375]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4688659286979528, 0.023382491108664555`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.727010517830454, 0.31634418645129614`], 
                "StandardDeviation" -> 
                Around[0.4364848728870232, 0.07406331332513676], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.10244723383956988`, "TrainingSize" -> 252, "TrainingTime" -> 
                1.9952623149688797`, "TrainingMemory" -> 522568, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.727010517830454, 0.22368911942865305`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4364848728870232, 0.05237067108934818]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00025157034800970054`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4364848728870232, 0.07406331332513676], 
               "TrainingMemory" -> 522568, "TrainingTime" -> 
               3.288406128435381], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[7.468865913702491, 1.1066937391033975`], 
                "StandardDeviation" -> 
                Around[0.4783556309703589, 0.030577910222693093`], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.031518004571583935`, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 428864, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[7.468865913702491, 0.7825506476167082]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4783556309703589, 0.021621847672979738`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.8020552162754527, 0.350864586687805], 
                "StandardDeviation" -> 
                Around[0.4472616526551924, 0.07579523130150641], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.07810082855284017, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 451768, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.8020552162754527, 0.24809872852516215`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4472616526551924, 0.053595322034898044`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00025157034800970054`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.4472616526551924, 0.07579523130150641], 
               "TrainingMemory" -> 451768, "TrainingTime" -> 
               1.391017463958849], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.0276592996384295`, 0.3483537102733018], 
                "StandardDeviation" -> 
                Around[0.5968109938613018, 0.02907691096017196], 
                "EvaluationTime" -> 0.0001603641920883598, "TestSize" -> 305, 
                "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.18672139594950787`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.2589254117941673`, "TrainingMemory" -> 
                424704, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.0276592996384295`, 0.24632327078574556`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.5968109938613018, 0.02056048091589504]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[8.894195055032611, 1.3051636425468587`], 
                "StandardDeviation" -> 
                Around[0.469197710997709, 0.030112149363577752`], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.050797886633694556`, "TrainingSize" -> 50, "TrainingTime" -> 
                1.5848931924611136`, "TrainingMemory" -> 429256, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[8.894195055032611, 0.9228900622030188]}, 
                "StandardDeviationHistory" -> {
                  Around[0.469197710997709, 0.02129250501108801]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.7228099249185113, 0.382576459897187], 
                "StandardDeviation" -> 
                Around[0.42566184594124906`, 0.08184065763972302], 
                "EvaluationTime" -> 0.00015873015873015873`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.12319829973355534`, "TrainingSize" -> 252, "TrainingTime" -> 
                5.011872336272724, "TrainingMemory" -> 451768, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.7228099249185113, 0.2705224091156442]}, 
                "StandardDeviationHistory" -> {
                  Around[0.42566184594124906`, 0.057870083993814776`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00015873015873015873`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.42566184594124906`, 0.08184065763972302], 
               "TrainingMemory" -> 451768, "TrainingTime" -> 
               7.523765832135071], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 34226806615795]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 6.5263239875389`2.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097571709013439`17.333472284337297*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.8779106692426264`, 
            "ElapsedTimes" -> 2.598007, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 3.129851115404377, 
            "ElapsedTimes" -> 3.2293585, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 5.216418525673961, 
            "ElapsedTimes" -> 8.6621237, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 34239691517683]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{-1.58371347981322, 0.21494728902017465`, 
              6.938379786136243, 1., 3.912023005428146}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 15.2398463, 
        "MaxTrainingMemory" -> 942888, "DataMemory" -> 75768, 
        "FunctionMemory" -> 258088, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 52, 50.9312646`9.459559312426833}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {-0.19021557114341053`, -0.5355187121487698, 
                    0.14516630617213536`, 0.47619047619047616`, 
                    3.8157432169988876`}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.19021557114341053`, -0.5355187121487698, 
                    0.14516630617213536`, 0.47619047619047616`, 
                    3.8157432169988876`}, 
                    "StandardDeviation" -> {6.988075708274089, 
                    4.299445900182657, 4.3612648724229715`, 
                    0.4994327848429293, 1.3701027994132722`}, "Method" -> 
                    "NaiveSampler", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.6855968880771729, -0.14976680711042298`, 
                    0.0873902338851844, 
                    0.2558775315890855, -0.6591027586015821}, {
                    0.2510057830268041, -0.06271396642415111, 
                    0.8386091389231345, -0.38528209532502156`, \
-0.28522881067488787`}, {-0.21621675116048553`, -0.6721716448683458, \
-0.25560446588341934`, -0.6542515841230789, 
                    0.08975977966484068}, {-0.17959925225419657`, 
                    0.7019611247351062, -0.24889934327299398`, \
-0.5971808753703783, -0.2375264342352211}, {-0.6228542598821457, 
                    0.17050724647036716`, 
                    0.40226003166461294`, -0.03760668310484497, 
                    0.6478830559281468}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {-0.19021557114341053`, -0.5355187121487698, 
                    0.14516630617213536`, 0.47619047619047616`, 
                    3.8157432169988876`}, 
                    "StandardDeviation" -> {6.988075708274089, 
                    4.299445900182657, 4.3612648724229715`, 
                    0.4994327848429293, 1.3701027994132722`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0101733, "MaxTrainingMemory" -> 93112, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 52, 50.9562007`9.459771892272933}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.19021557114341053`, -0.5355187121487698, 
                0.14516630617213536`, 0.47619047619047616`, 
                3.8157432169988876`}, 
               "StandardDeviation" -> {6.988075708274089, 4.299445900182657, 
                4.3612648724229715`, 0.4994327848429293, 1.3701027994132722`},
                "Output" -> 
               Association[
                "f1" -> 
                 Association["Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.4194054913121184`}, 
               "StandardDeviation" -> {0.7140892567708482}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.4194054913121184` + 
         0.7140892567708482 #& ), 
        "ProcessorFunction" -> (3.3880995525024504` + 
         1.4003851626644772` #& ), "Name" -> "value", 
        "Quantiles" -> {-2.8524083552804136`, 2.5735093228045325`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX841HccwD0nHZ40nSxLytVEM4eSre6+748woRbKz1R+1Ropza8j1lA8
13WditypdkvbrYeY1GHy/bw/PZOaa2EWPXqq6cwmtidZ6dlYrf54vZ7n9bzE
yRmbPxGYmZllWb7W5iT5uszMpPwts9/ErqT0VSvT38yVr7F4TdnGvdhQuJF9
/8yFhFmWo81GDQiV5+isUi0Eui7CgZkR7l/D1zKt6H1mFyCiJQMpuNj7Fbr7
evI1++tg6IEzWygNZHG7LFmBMIh0GH+iDVlHSVzONupXlIbdHptY8VgUiA1W
7JDWhHdezWd1dhpQ4EoQ/Xoe+wWnwM0YjqbuELTIikTl8jtUtTSSCrao8QQf
QiY7OuGYQkDuGVK4itwyrDPfQPpmLaAzknwqlzwH7xPLeaODHQ5NPoWIe1/B
mLcO/3tnH7sSrYBk+2pOOWWCt0zD3Iu7L2hFfRw3ZrJie3A1ljxsxaF5LaC9
/gKGzgB3qdwcDld0QI6ZA5dXEEsv/mBPiga1OHgggEXa8rh+XjFrbRETnxY3
Mrg3ijpZL4FDCwxgcJzGb+OrpPp+PaSE5aJswWxin7iM2VqIobTAlxgTlag3
2ZNaZw05Im+mHpuFcF1wGlzqT5LRG0Z6dWsC6d9Tyy0Knk076WPavl3I1isO
YmG9L+k8pWHPpPe5Kqs8jkw24oeiP4GlumGGwJwYm7LZe93DHC+ZoK7iJxCo
ruROToVyC0ea+TU3GuHTk9W023ce03x0D/Z2/gazxu1IROsIqn2+wbyANPZ0
OppkxL8t7bVBXnG6DEcfhVPxzAOIFfiTiOQitMw7LYtIVME/Me4YszUBnDwz
+GH/XGKsdKaOB6+jjUEq8xq/jCG72rkdbavQZ18tdq0bxuZbArK2R0/P+mSz
KD9bsL4mw7/VDiyL6vBMXBHzuhxAhPGPceSIGJeG3KXtbdq1fFYwcWktwaVL
wlnMuIk/vukJpDo5QPB3NnghUciGrujosTXv0ouZ5dCj2wEpqEb18gPsSdcY
6kev0ZGPq7ir5zyxZk4J8/KZxLrHdqxJ9YhWrlag6mUC7I/5Egp7j8Kr6RXS
Tb0V+PI2tmemTPA7rW/Lsv/Q8RHT9sz2wk7Of3eVrCe7Bv66pcdfphpQXv05
TDQfBnf3SfDLNccNLAisrL/gegpSSWnaWXTMKYVGVRt3XzAfrLzqce7i42xJ
oCWLVhGWLnEEjTIIHJ/acWK3n/kdHstwPHsa/B/60ksKIVNKnsGAJB/P/+7C
ajZQaHy+gsmrq9hEjiuRfPYjyJkOr0kncO4HtkRXK2IeJJbNdDWD+YQGQvOj
8GGfEhumm9iJsGJm7GvC/ektOGXoQv/t2zC0bQ7ai27iTTzIdrsmY/s2Pfc/
cXL4Zw==
                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.010038422420620918`, -0.02050909772515297, 
                    0.0072827949188649654`, 
                    0.06937799602746964, -0.016860635951161385`, \
-0.023973021656274796`, -0.035736437886953354`, 
                    0.02320672571659088, -0.03563827648758888, \
-0.009668338112533092, -0.02078363671898842, -0.04330699145793915, \
-0.051574431359767914`, -0.05992034077644348, -0.019311724230647087`, 
                    0.0373065322637558, -0.016647975891828537`, 
                    0.005175502970814705, 
                    0.0022852267138659954`, -0.06886503100395203, 
                    0.06663321703672409, -0.052522994577884674`, \
-0.028010565787553787`, -0.09199719876050949, -0.01840813457965851, \
-0.04598628357052803, -0.04144957661628723, -0.04730575904250145, \
-0.04309021309018135, -0.016214512288570404`, 0.014975134283304214`, 
                    0.019320879131555557`, 0.04372916370630264, 
                    0.0071741375140845776`, -0.04151417315006256, 
                    0.01587568037211895, -0.03334138169884682, 
                    0.024761920794844627`, -0.03173978254199028, 
                    0.019326359033584595`, -0.0812927633523941, \
-0.003651424776762724, -0.026183081790804863`, -0.03465134650468826, 
                    0.02578897587954998, 
                    0.06155593320727348, -0.006243468727916479, \
-0.0829976424574852, -0.030077993869781494`, 0.011373971588909626`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dUz4/3x1MaRFsqDZEUmVH0ft1LNEhCaaASSRlpoPQhKi2jEpUGLTJC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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.016824761405587196`, -0.013733670115470886`, \
-0.0376148521900177, -0.04781661182641983, -0.04097680747509003, \
-0.030516961589455605`, 0.01245560310781002, -0.04482575133442879, 
                    0.01913580484688282, 
                    0.016594601795077324`, -0.01106379833072424, \
-0.02812187187373638, 
                    0.026885485276579857`, -0.024126887321472168`, \
-0.07240784168243408, -0.019123047590255737`, -0.028975043445825577`, 
                    0.02569611370563507, -0.04511138051748276, \
-0.0049764374271035194`, -0.0344136618077755, -0.05619840696454048, 
                    0.013376262970268726`, -0.016729990020394325`, \
-0.001413073856383562, 0.027876924723386765`, 
                    0.026884855702519417`, -0.005208200309425592, 
                    0.020301811397075653`, -0.01752282679080963, \
-0.050006307661533356`, 
                    0.0035038706846535206`, -0.029703626409173012`, \
-0.04292355105280876, -0.029390446841716766`, 0.010777791030704975`, 
                    0.013539554551243782`, 
                    0.018847079947590828`, -0.08348963409662247, \
-0.019390171393752098`, 
                    0.04738455265760422, -0.05220329016447067, \
-0.009878810495138168, -0.00982673279941082, -0.06800360232591629, \
-0.03413895145058632, 
                    0.006402482744306326, -0.014161393977701664`, \
-0.05939030647277832, 0.006855799816548824}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dYz9/7x9NAhXYio0WIaIner/tuEsnog4pSKqMysyujJRVpiajQMJqI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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.01450420543551445, -0.01624387688934803, \
-0.025859620422124863`, -0.007599727716296911, 0.014468676410615444`, 
                    0.01149796787649393, 0.003338733222335577, 
                    0.010568980127573013`, 
                    0.04605329781770706, -0.022841602563858032`, 
                    0.007494439370930195, -0.03442453220486641, \
-0.013598139397799969`, -0.03074566274881363, -0.022493913769721985`, 
                    0.006977748591452837, -0.007475103251636028, \
-0.04572856053709984, -0.028382111340761185`, -0.006450675427913666, \
-0.00993935763835907, -0.014010230079293251`, -0.011204684153199196`, 
                    0.012943673878908157`, -0.012342069298028946`, \
-0.01643480360507965, -0.03173288330435753, -0.0341079980134964, 
                    0.010127415880560875`, 0.01627136953175068, 
                    0.03171714022755623, -0.00008637718565296382, \
-0.01472745556384325, -0.008246545679867268, -0.02939571999013424, \
-0.009952960535883904, 0.03916684165596962, -0.02883407287299633, 
                    
                    0.03136907517910004, -0.04789634793996811, \
-0.044286489486694336`, -0.030973656103014946`, -0.03552357852458954, \
-0.030942995101213455`, -0.0567253939807415, -0.028440376743674278`, 
                    0.04883904382586479, -0.05518009513616562, 
                    0.02003357745707035, -0.014066986739635468`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3lUz+/TxrO0SloV7bRHKIU+75lEKJUoa9myRIUIlS3atFDafUVFyr5L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                    "], "Biases" -> 
                    RawArray["Real32",{-0.04406723007559776, 
                    0.019316766411066055`, 0.010434516705572605`, 
                    0.00745003717020154, 
                    0.025063054636120796`, -0.03248365968465805, \
-0.010687717236578465`, -0.0008179329452104867, 0.02785469777882099, 
                    0.0034537864848971367`, -0.027760734781622887`, \
-0.013667588122189045`, -0.01556154154241085, 
                    0.0015995741123333573`, -0.019358092918992043`, \
-0.026488643139600754`, -0.015339142642915249`, -0.003838143078610301, 
                    0.011021331883966923`, -0.017503958195447922`, 
                    0.015691101551055908`, -0.025264905765652657`, 
                    0.011939214542508125`, 
                    0.011272689327597618`, -0.016091397032141685`, 
                    0.014160525053739548`, 
                    0.001297944923862815, -0.006507453508675098, 
                    0.02991906739771366, 0.026420360431075096`, 
                    0.005445300135761499, -0.012670377269387245`, \
-0.013631410896778107`, -0.018789900466799736`, -0.006922577507793903, 
                    0.016572637483477592`, -0.024737535044550896`, \
-0.004035435151308775, 0.0076430318877100945`, 
                    0.01473577506840229, -0.04533113166689873, \
-0.05064934492111206, 0.037571124732494354`, -0.018077388405799866`, 
                    0.009145628660917282, -0.02721688337624073, 
                    0.009648305363953114, -0.03411697596311569, 
                    0.05789412930607796, -0.00991444755345583}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray[
                    "Real32",{{-0.2347847819328308, -0.058959126472473145`, 
                    0.10138283669948578`, 0.0908631756901741, 
                    0.05580632761120796, -0.2263711839914322, \
-0.2412569224834442, -0.17975586652755737`, -0.06831972301006317, 
                    0.019587570801377296`, -0.034297578036785126`, \
-0.17344094812870026`, -0.21533125638961792`, 
                    0.113852858543396, -0.02380371280014515, \
-0.23196864128112793`, -0.08638836443424225, -0.0878717452287674, 
                    0.07999160140752792, -0.21614979207515717`, \
-0.03692673146724701, -0.1504264771938324, 
                    0.18483218550682068`, -0.18445594608783722`, \
-0.0004941815277561545, 
                    0.05087685212492943, -0.009423059411346912, \
-0.2549363076686859, 0.10628245770931244`, 0.02627389505505562, 
                    0.03932083770632744, -0.09428586065769196, \
-0.16422151029109955`, -0.08562804013490677, -0.3812929093837738, 
                    0.30316421389579773`, 
                    0.12797532975673676`, -0.29547300934791565`, \
-0.09629827737808228, -0.10165131092071533`, -0.11561110615730286`, \
-0.21435360610485077`, 0.10439267009496689`, -0.20326495170593262`, 
                    0.1065782979130745, -0.18955259025096893`, 
                    0.15319973230361938`, -0.08722091466188431, 
                    0.18296577036380768`, -0.17516236007213593`}}], "Biases" -> 
                    RawArray["Real32",{0.018213506788015366`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.29776376485824585`}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.933712, "MeanInputsPerSecond" -> 
          43143.31399973574], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.01700052596683975, -0.036871022488626365`, 
                0.03392285927395132, 
                0.03154417416571133, -0.008117971554835273}, 
               "StandardDeviation" -> {1.0047736396934561`, 
                0.9897661554045372, 1.009143507073625, 1.0016116138963864`, 
                1.0068973492785442`}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2423397001610045589]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[365489], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.33674731497260624`, "PreprocessingTime" -> 
        0.3702348`7.020022231083194, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.5489052580384779, 0.0875087087492874], 
           "StandardDeviation" -> 
           Around[0.37517528111303616`, 0.06773424879624886], 
           "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
           "ModelMemory" -> 107736, "ModelUtility" -> 0.25170916130583076`, 
           "TrainingSize" -> 252, "TrainingTime" -> 6.309573444801933, 
           "TrainingMemory" -> 522776, "ExperimentCount" -> 1, 
           "MeanCrossEntropyHistory" -> {
             Around[0.5489052580384779, 0.061878001369499676`]}, 
           "StandardDeviationHistory" -> {
             Around[0.37517528111303616`, 0.0478953466424043]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 292062283329284]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.041196398417916, 0.46383421235759414`], 
                "StandardDeviation" -> 
                Around[0.6551822379264061, 0.032685223045688196`], 
                "EvaluationTime" -> 0.00012747981470194946`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.2802653879916309, "TrainingSize" -> 10, 
                "TrainingTime" -> 0.5011872336272722, "TrainingMemory" -> 
                424896, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.041196398417916, 0.3279803169043759]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6551822379264061, 0.02311194286020094]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[9.548215404842313, 1.5483378788287594`], 
                "StandardDeviation" -> 
                Around[0.4719035835055682, 0.033133038268233966`], 
                "EvaluationTime" -> 0.00015633372739584048`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.04385670032679201, "TrainingSize" -> 50, "TrainingTime" -> 
                0.6309573444801932, "TrainingMemory" -> 428736, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[9.548215404842313, 1.0948402136878106`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4719035835055682, 0.02342859604078162]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5881908919221835, 0.06710941279489768], 
                "StandardDeviation" -> 
                Around[0.38009491032436116`, 0.05881877479733367], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 0.2436745352403611, 
                "TrainingSize" -> 252, "TrainingTime" -> 1.9952623149688797`, 
                "TrainingMemory" -> 451768, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.5881908919221835, 0.04745352086871941]}, 
                "StandardDeviationHistory" -> {
                  Around[0.38009491032436116`, 0.04159115452027903]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.38009491032436116`, 0.05881877479733367], 
               "TrainingMemory" -> 451768, "TrainingTime" -> 
               2.9952651273383717`], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.8408220374213007`, 0.31184891258862485`], 
                "StandardDeviation" -> 
                Around[0.4643968518506628, 0.02972403172242609], 
                "EvaluationTime" -> 0.00009501323862597485, "TestSize" -> 265,
                 "ModelMemory" -> 107736, "ModelUtility" -> 
                0.061114873907002876`, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 499600, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.8408220374213007`, 0.2205104807970675]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4643968518506628, 0.02101806439513154]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.6235150757428285, 0.07354917157954764], 
                "StandardDeviation" -> 
                Around[0.4115736660085612, 0.05770305055703674], 
                "EvaluationTime" -> 0.00019982943044351853`, "TestSize" -> 63,
                 "ModelMemory" -> 107736, "ModelUtility" -> 0.166931833165071,
                 "TrainingSize" -> 252, "TrainingTime" -> 1., 
                "TrainingMemory" -> 522632, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.6235150757428285, 0.052007117974551036`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4115736660085612, 0.04080221834403087]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00019982943044351853`, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4115736660085612, 0.05770305055703674], 
               "TrainingMemory" -> 522632, "TrainingTime" -> 
               1.648107170553497], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.4068307417081476`, 0.384949962907615], 
                "StandardDeviation" -> 
                Around[0.6271729826726532, 0.030314607372368456`], 
                "EvaluationTime" -> 0.0001299709711359511, "TestSize" -> 305, 
                "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.23626882719920583`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                495824, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.4068307417081476`, 0.2722007291894845]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6271729826726532, 0.02143566444200944]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[5.595980903919578, 0.9883192931772439], 
                "StandardDeviation" -> 
                Around[0.439139555490073, 0.03195147614692784], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 107736, "ModelUtility" -> 
                0.1153099594194994, "TrainingSize" -> 50, "TrainingTime" -> 
                1.2589254117941673`, "TrainingMemory" -> 499792, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[5.595980903919578, 0.6988472741831246]}, 
                "StandardDeviationHistory" -> {
                  Around[0.439139555490073, 0.022593105452412894`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.5489052580384779, 0.0875087087492874], 
                "StandardDeviation" -> 
                Around[0.37517528111303616`, 0.06773424879624886], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.25170916130583076`, "TrainingSize" -> 252, "TrainingTime" -> 
                6.309573444801933, "TrainingMemory" -> 522776, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.5489052580384779, 0.061878001369499676`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.37517528111303616`, 0.0478953466424043]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.37517528111303616`, 0.06773424879624886], 
               "TrainingMemory" -> 522776, "TrainingTime" -> 
               9.471859998463529], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[9.3199855838569, 1.5058281731510244`], 
                "StandardDeviation" -> 
                Around[0.46135455215444515`, 0.03240080401859436], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.06646096259388046, "TrainingSize" -> 50, "TrainingTime" -> 
                1.5848931924611136`, "TrainingMemory" -> 428864, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[9.3199855838569, 1.06478131253684]}, 
                "StandardDeviationHistory" -> {
                  Around[0.46135455215444515`, 0.022910828237444412`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00014229478653976401`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.46135455215444515`, 0.03240080401859436], 
               "TrainingMemory" -> 428864, "TrainingTime" -> 
               6.577306748713622], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 292057988361988]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 6.1117455138662`2.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097571882730299`17.333472286317583*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 2.351403182602155, 
            "ElapsedTimes" -> 2.3736163, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 3.9190053043369257`, 
            "ElapsedTimes" -> 4.6655162, "ExperimentCounts" -> 4], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 6.5316755072282096`, 
            "ElapsedTimes" -> 9.5574259, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 292070873263876]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{2.2912429039761473`, -1.9058632965000448`, 
              1.936580480057262, 1., 3.912023005428146}}, "ID" -> 
             6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 17.3719853, 
        "MaxTrainingMemory" -> 961048, "DataMemory" -> 75768, 
        "FunctionMemory" -> 268520, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 53, 8.303948`8.671859588265127}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.36273439613998854`, -0.11166451761933531`, 
                    0.31952673331976117`, 0.5111111111111111, 
                    3.8062329558130026`}, "Method" -> "Naive", "VectorLength" -> 
                    5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.36273439613998854`, -0.11166451761933531`, 
                    0.31952673331976117`, 0.5111111111111111, 
                    3.8062329558130026`}, 
                    "StandardDeviation" -> {7.15889491665788, 
                    4.501829986826789, 4.424957386010651, 0.499876527964533, 
                    1.3749785885359092`}, "Method" -> "NaiveSampler", 
                    "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{-0.41506677395631153`, 0.28182929944492774`, 
                    0.26702920110119893`, 
                    0.8225387233400345, -0.020427273368793422`}, {
                    0.12375289068190187`, 
                    0.9133945002580799, -0.32400157937992546`, \
-0.1491092445722226, -0.152266603983204}, {-0.5930523970084526, \
-0.00013485671694105897`, 
                    0.2617233649296386, -0.40027025145551925`, \
-0.647744889802951}, {-0.2678422789717437, -0.27209643732680044`, \
-0.8605236332947599, 0.23133871857548474`, -0.24536812388394266`}, {
                    0.6236618981492493, -0.11066274657897378`, 
                    0.12131916217013018`, 
                    0.29574077310515506`, -0.7047117491073752}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.36273439613998854`, -0.11166451761933531`, 
                    0.31952673331976117`, 0.5111111111111111, 
                    3.8062329558130026`}, 
                    "StandardDeviation" -> {7.15889491665788, 
                    4.501829986826789, 4.424957386010651, 0.499876527964533, 
                    1.3749785885359092`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0114596, "MaxTrainingMemory" -> 93296, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 53, 8.3308757`8.673265622010472}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.36273439613998854`, -0.11166451761933531`, 
                0.31952673331976117`, 0.5111111111111111, 
                3.8062329558130026`}, 
               "StandardDeviation" -> {7.15889491665788, 4.501829986826789, 
                4.424957386010651, 0.499876527964533, 1.3749785885359092`}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.354000010009282}, 
               "StandardDeviation" -> {0.7499158179661473}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.354000010009282 + 
         0.7499158179661473 #& ), 
        "ProcessorFunction" -> (3.139019012018688 + 1.3334830070821924` #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-2.619971963456558, 2.363345106012295}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViX1Q03UcgH+CIG9yTQ1zx0heAwNEVBDZ7/MVA6SFL4G8+RoQlA2ShmCA
GjLQO6c5WyVwY6KAQajscKDofp8PWyKmSRApvpwK4tmZKMjhvASP8I/nuXvu
cU/bHpdpxXFcrt2U4lJ3RigUqQXxtm8jIzVrcXDW2xk8hc0Us7ak4Yp/QuF0
+SYQNiRQxS1v1tDqjd3KWTDidQZy1quwLS8bHK62XvS4tQy+Mcxhw4461Eb7
sLTHamYrec5LNJeN+QYpbJXPZ76xHnxUjieJVzwU9pWP8dlztIJPtxLuhIvY
i5o8DH4J4Bk8k6oUZRhjUcK5g5VQ9EszMH8NcEonGpbWo33hOjiyugTf3NyP
a6Zn45u9maxXehevFnuyiJ97IT2PI924Cw68EOHuGybc3NgEplGzdM/0VSxS
bs8fKy6hpGAJ7T42aUz6U42mk814JZwjVYmS/eCwjSUOODOzIpQet+j4/h31
pE/ch/EJQXTargc7ZbPZikATDt0rhrTXKVh7/SYMbdJDjkIrpMsmjYUn3fAd
07dUeuwwWM/4mIbCIvgEChDyrC2wzW9QcBX/ive5GUK29RKU8rk4pjJid2EL
DFRl4hFdQ/jZ/kFQijUXH4rcSDeSTGEeV9DY1gHRCUfQdjkHqU//xcFFBXRT
zRFN68CzgxKSe3bgfb0W7gUspfqsU7AxrAb/W1aMW5pVlHvIjmV1tmB8ZS+E
yI8L5iVPhC8VM6jzZTs0eheBy1MDb+qPpkeaj6hyfDmL/JuDRfazaefzavh0
nT/0tWrwWoqIma1sWFL8Stirb8ZTrSHwRH0Hv+rcCwvEyXixXAmypj7Mr1bj
jQU1WOVsxaJELqS1nUULV5WxZyUudK/dmWp3VQr57X3oW+FDm+sCSNOzhq32
VrEYdz3clvhRQ9fvuDJ2sXTlhb/AaPYib0MI1JkbMCK4ng9K8yNxWxw2ls2k
xmc27ESlFjxSrKFmrQxkEyGYsWAMI/c/gFe+gaRKvwXfRatwoUqDn3/BKEEs
oLvZBEVH59DCsvOQuPE+3nZ0YxOTZ9CQL8cdGdUw970ttFXnz8e4bMWqahGz
tzhQH/ccLIrPhLseImGa6zw6sMyeGke7IKkp0WhJsWFBDb9hUlwNPj57ASuu
HOJfO35IOa4+MDJQwnp26SHjeDOaQjLp+xM5dD19LZRUWPCApg68uqOACxVj
zeGD6F0ay2fFitiAlxuBYz0WJTfiyIMfYb3ajqo+kRmd/hjHws1O+CqzGt9v
G0b3nFwY9tvANm33oyWrPejdNi+KXLobRw0taDotp5/mXobzmjy69ME8OD5e
IJTOr4WuRxOCJMoKpFwpn/V1DJ07qscwqzq8tCeQXBZdwyZRh/F/Gevx1A==

                    "], "Biases" -> 
                    RawArray["Real32",{
                    0.0761341005563736, -0.10579570382833481`, \
-0.09103136509656906, -0.11250598728656769`, -0.04954184219241142, \
-0.10613773763179779`, -0.12089959532022476`, -0.01891978830099106, 
                    0.013051571324467659`, 0.042759042233228683`, 
                    0.04175915941596031, -0.11367406696081161`, \
-0.11395899951457977`, 0.04127618297934532, 0.07706557214260101, 
                    0.029949773102998734`, -0.02911306917667389, 
                    0.030293140560388565`, -0.07568173110485077, 
                    0.09250331670045853, 0.08292285352945328, 
                    0.008192538283765316, 0.033274997025728226`, 
                    0.06056080758571625, -0.02161358669400215, 
                    0.015420762822031975`, -0.057892993092536926`, 
                    0.0033201072365045547`, -0.014538847841322422`, \
-0.017471766099333763`, -0.11367432773113251`, -0.01505006942898035, \
-0.11389515548944473`, -0.08913353830575943, 0.10635460168123245`, 
                    0.044504739344120026`, -0.06869056075811386, 
                    0.04101283848285675, -0.0930701270699501, 
                    0.02610456570982933, 
                    0.03718843683600426, -0.025979049503803253`, 
                    0.04664114862680435, 
                    0.07036115229129791, -0.06960401684045792, 
                    0.032986052334308624`, 
                    0.0024910280480980873`, -0.09845314919948578, \
-0.012140446342527866`, 0.01070864126086235}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUj4/TxqPFFtFGJdqkoqJN9b1nkj2UJQotEkURQpQsbYhKixCyVFRK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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.012287440709769726`, -0.05479694530367851, \
-0.08667581528425217, 0.06869509071111679, 0.054943978786468506`, 
                    0.006522283423691988, -0.025441348552703857`, 
                    0.017691131681203842`, -0.04735605791211128, \
-0.06245756894350052, -0.12145735323429108`, -0.006060023792088032, 
                    0.036165542900562286`, -0.00982492696493864, \
-0.007335004862397909, -0.041116293519735336`, -0.08978240936994553, 
                    0.09382499009370804, 0.058600928634405136`, 
                    0.024861149489879608`, -0.01877054013311863, 
                    0.012201711535453796`, 
                    0.03491252660751343, -0.02950945682823658, \
-0.06047218292951584, -0.03509656339883804, -0.08170466125011444, 
                    0.04621116816997528, 
                    0.00023143875296227634`, -0.017563579604029655`, \
-0.0031093598809093237`, 0.12575523555278778`, -0.010655330494046211`, 
                    0.07124456018209457, -0.05552595853805542, 
                    0.013563710264861584`, 
                    0.050943389534950256`, -0.04114291071891785, \
-0.03639424592256546, 
                    0.004846562631428242, -0.029340000823140144`, \
-0.07581492513418198, -0.11428995430469513`, -0.06818165630102158, \
-0.05613274872303009, -0.1131354570388794, -0.0611676350235939, 
                    0.039700184017419815`, -0.012174565345048904`, 
                    0.047245994210243225`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dUz4/3x5tSaWgvEhKlQiTer3sjRaEhaZFPZUT2SNmpaEkhSUgSQkNW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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.061071768403053284`, -0.03887433186173439, \
-0.007294927723705769, 
                    0.04242287948727608, -0.015682224184274673`, \
-0.05545514449477196, -0.01278712134808302, -0.0371023528277874, \
-0.04879520460963249, -0.00033720055944286287`, 
                    0.0290669072419405, -0.04656406491994858, \
-0.05132883042097092, -0.050422195345163345`, 
                    0.029127029702067375`, -0.07099368423223495, \
-0.06415209174156189, 0.0005789230344817042, -0.03540031239390373, 
                    0.009374981746077538, 0.00021871058561373502`, 
                    0.08205457031726837, -0.025655649602413177`, \
-0.044446688145399094`, -0.04697650298476219, 0.03456020727753639, 
                    0.018457885831594467`, 
                    0.04307164251804352, -0.014867749996483326`, 
                    0.025438908487558365`, -0.026713814586400986`, \
-0.09150649607181549, -0.028530452400445938`, 
                    0.037823084741830826`, -0.026566339656710625`, 
                    0.04344090819358826, 
                    0.05964270979166031, -0.08224215358495712, 
                    0.00748273404315114, -0.06624314188957214, \
-0.0811658725142479, 0.01973531022667885, 
                    0.031518880277872086`, -0.04325740039348602, \
-0.031078005209565163`, -0.08623374998569489, -0.09161557257175446, \
-0.042070675641298294`, -0.10498365014791489`, -0.0917275995016098}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Dropout", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association[
                    "DropoutProbability" -> 0.01, "Method" -> "AlphaDropout", 
                    "OutputPorts" -> 
                    NeuralNetworks`ValidatedParameter[{"Output"}]], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "10" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtV2lUiI/TTWmXQinZJdpJez0zES3WFEXZypqtQv1SQilaKNoIFUUbJSql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                    "], "Biases" -> 
                    RawArray["Real32",{0.042793456465005875`, 
                    0.07801506668329239, -0.05660967901349068, \
-0.01639682613313198, -0.020966414362192154`, -0.021677054464817047`, \
-0.02074032463133335, -0.04482422396540642, -0.03649091348052025, \
-0.024550292640924454`, 0.06652039289474487, 0.06724295765161514, 
                    0.010991045273840427`, -0.006794900633394718, \
-0.05874546617269516, 0.038497377187013626`, -0.0463639572262764, 
                    0.02838735096156597, -0.06333418935537338, 
                    0.04824276268482208, -0.04562428221106529, 
                    0.07883350551128387, 0.06929460912942886, 
                    0.028594957664608955`, 0.02875913679599762, 
                    0.06657257676124573, 0.07889732718467712, 
                    0.03734530508518219, 0.05279446393251419, 
                    0.039937909692525864`, -0.029707912355661392`, \
-0.04618958383798599, -0.03446049988269806, 0.05226748436689377, 
                    0.02521088533103466, -0.01092276256531477, \
-0.009275226853787899, -0.003934703767299652, 0.00812047254294157, 
                    0.019748499616980553`, 0.023295070976018906`, 
                    0.08457469940185547, -0.09976084530353546, \
-0.055168267339468, 0.10126673430204391`, 
                    0.03647376969456673, -0.0043387929908931255`, 
                    0.022555598989129066`, -0.07417623698711395, 
                    0.04429416358470917}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "11" -> Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], 
                 "12" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray[
                    "Real32",{{-0.1604730635881424, -0.22232137620449066`, 
                    0.07284025847911835, 0.3017955422401428, 
                    0.14239855110645294`, 0.17651891708374023`, 
                    0.11921095103025436`, 0.08016237616539001, 
                    0.23432913422584534`, 
                    0.2014937400817871, -0.25808414816856384`, \
-0.0401759035885334, 0.19894596934318542`, 0.20738552510738373`, 
                    0.08856508880853653, -0.02965792641043663, 
                    0.2526565492153168, -0.16658830642700195`, 
                    0.022449547424912453`, -0.07173804193735123, 
                    0.09495950490236282, -0.069330133497715, \
-0.007603717036545277, -0.07374697923660278, -0.03113667108118534, \
-0.1037202998995781, -0.10782648622989655`, -0.10315171629190445`, \
-0.21145854890346527`, -0.19490014016628265`, 0.1698475480079651, 
                    0.07161246985197067, 
                    0.15610027313232422`, -0.08774804323911667, \
-0.025188572704792023`, -0.005485540255904198, 0.2266770750284195, 
                    0.28021496534347534`, 
                    0.14832085371017456`, -0.29212865233421326`, \
-0.03265126049518585, -0.10152359306812286`, 0.045618366450071335`, 
                    0.1825210154056549, -0.1393880844116211, \
-0.08829473704099655, -0.0981474444270134, -0.17865757644176483`, 
                    0.08648800104856491, -0.1409084051847458}}], "Biases" -> 
                    RawArray["Real32",{-0.04468536004424095}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "10", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "11", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "10", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "12", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "11", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "12", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.7289772033691406}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 1.6490029, "MeanInputsPerSecond" -> 
          46573.59911253036], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-0.03870925712034671, 0.048653743375636015`, 
                0.019623641826822424`, -0.02235102047894591, 
                0.015957739656478932`}, 
               "StandardDeviation" -> {1.0424161500448168`, 
                0.9657797446237216, 1.0180655999041692`, 1.0008972854775158`, 
                0.9943895546283442}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8351509718587206050]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> 0.01, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 300, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[365601], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.28779432146326916`, "PreprocessingTime" -> 
        0.3724886`7.022657979216915, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.6225335464474036, 0.23389894189224436`], 
           "StandardDeviation" -> 
           Around[0.4320212919833405, 0.073715126293825], "EvaluationTime" -> 
           0.0003987121319856475, "TestSize" -> 63, "ModelMemory" -> 107736, 
           "ModelUtility" -> 0.11254273014361438`, "TrainingSize" -> 252, 
           "TrainingTime" -> 1.9952623149688797`, "TrainingMemory" -> 522696, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.6225335464474036, 0.1653915279243642]}, 
           "StandardDeviationHistory" -> {
             Around[0.4320212919833405, 0.052124465678386425`]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> 0.01, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 300, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 214001252724499]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.6112911194941781`, 0.19750128908594083`], 
                "StandardDeviation" -> 
                Around[0.4932176584226742, 0.024259483135210175`], 
                "EvaluationTime" -> 0.0001444183103262347, "TestSize" -> 305, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.0038344494651351146`, "TrainingSize" -> 10, "TrainingTime" -> 
                0.6309573444801932, "TrainingMemory" -> 495888, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.6112911194941781`, 0.13965450080575342`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4932176584226742, 0.0171540450329878]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[5.944687142811069, 1.0155478560113023`], 
                "StandardDeviation" -> 
                Around[0.523085710528516, 0.037417345214647076`], 
                "EvaluationTime" -> 0.00013683847771505932`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.05937616093094622, "TrainingSize" -> 50, 
                "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                499856, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[5.944687142811069, 0.7181007756050513]}, 
                "StandardDeviationHistory" -> {
                  Around[0.523085710528516, 0.02645805853527496]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.6225335464474036, 0.23389894189224436`], 
                "StandardDeviation" -> 
                Around[0.4320212919833405, 0.073715126293825], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.11254273014361438`, "TrainingSize" -> 252, "TrainingTime" -> 
                1.9952623149688797`, "TrainingMemory" -> 522696, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.6225335464474036, 0.1653915279243642]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4320212919833405, 0.052124465678386425`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.4320212919833405, 0.073715126293825], 
               "TrainingMemory" -> 522696, "TrainingTime" -> 
               3.125035238191293], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.65537374418048, 0.2146471043200304], 
                "StandardDeviation" -> 
                Around[0.4759829256594031, 0.02400767687555892], 
                "EvaluationTime" -> 0.00013806927383312083`, "TestSize" -> 
                305, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.039156957259182334`, "TrainingSize" -> 10, "TrainingTime" -> 
                1.5848931924611136`, "TrainingMemory" -> 424768, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.65537374418048, 0.15177842302674976`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4759829256594031, 0.016975991119243177`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[9.78155096312194, 1.6785492104783315`], 
                "StandardDeviation" -> 
                Around[0.49718128140521567`, 0.03710306622167697], 
                "EvaluationTime" -> 0.00010731390959453888`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.009193739221780572, "TrainingSize" -> 50,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                428864, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[9.78155096312194, 1.1869135292845536`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.49718128140521567`, 0.026235829728161318`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.6963186885027357, 0.24257509267545554`], 
                "StandardDeviation" -> 
                Around[0.4626953829762187, 0.08103100208782764], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.04308072868196822, "TrainingSize" -> 252, "TrainingTime" -> 
                5.011872336272724, "TrainingMemory" -> 451848, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.6963186885027357, 0.1715264929777698]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4626953829762187, 0.057297571062644215`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00031670830396331406`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.4626953829762187, 0.08103100208782764], 
               "TrainingMemory" -> 451848, "TrainingTime" -> 
               7.849733612802018], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[5.148266352408669, 0.8514324096680421], 
                "StandardDeviation" -> 
                Around[0.47881363884327377`, 0.03269266883791862], 
                "EvaluationTime" -> 0.00012279953685898285`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.029701279719998586`, "TrainingSize" -> 50, "TrainingTime" -> 
                0.3981071705534972, "TrainingMemory" -> 428800, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[5.148266352408669, 0.6020536305982751]}, 
                "StandardDeviationHistory" -> {
                  Around[0.47881363884327377`, 0.023117207830378378`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.6513147561748605, 0.1866741108350994], 
                "StandardDeviation" -> 
                Around[0.44551655645451665`, 0.06377528921071954], 
                "EvaluationTime" -> 0.00025157034800970054`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 
                0.08711385482829082, "TrainingSize" -> 252, "TrainingTime" -> 
                0.7943282347242815, "TrainingMemory" -> 451832, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.6513147561748605, 0.13199852964346795`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.44551655645451665`, 0.045095939473033045`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00025157034800970054`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.44551655645451665`, 0.06377528921071954], 
               "TrainingMemory" -> 451832, "TrainingTime" -> 
               1.391017463958849], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 213996957757203]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 8.0490082644628`1.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097572033873044`17.33347228804054*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.877839903544686, 
            "ElapsedTimes" -> 2.5620751, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 3.1297331725744764`, 
            "ElapsedTimes" -> 3.016927, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 5.216221954290794, 
            "ElapsedTimes" -> 8.760559, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 214009842659091]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{-17.509317972619726`, -4.187905029120511, \
-7.444913458882694, 1., 3.912023005428146}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 15.1075474, 
        "MaxTrainingMemory" -> 978904, "DataMemory" -> 75768, 
        "FunctionMemory" -> 265960, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 53, 23.4132339`9.12203633020995}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["PredictorFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{}, {{}, {
                  PointSize[0.125], 
                  GrayLevel[0.55], 
                  
                  PointBox[{{-1, 1.5}, {0, 2.3}, {1, 0.8}, {2, 2}, {3, 1.3}, {
                    4, 4.}}]}, {
                  GrayLevel[0.7], 
                  AbsoluteThickness[1.5], 
                  
                  BSplineCurveBox[{{-1, 2}, {0, 2}, {1, 1}, {2, 1}, {4, 2}, {
                   5, 4}}]}}, {}}, Axes -> {False, False}, 
               AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
               BaseStyle -> {FontFamily -> "Arial", 
                 AbsoluteThickness[1.5]}, DisplayFunction -> Identity, 
               Frame -> {{True, True}, {True, True}}, 
               FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
               Directive[
                 Thickness[Tiny], 
                 GrayLevel[0.7]], FrameTicks -> {{None, None}, {None, None}}, 
               GridLines -> {None, None}, 
               LabelStyle -> {FontFamily -> "Arial"}, 
               Method -> {"ScalingFunctions" -> None}, 
               PlotRange -> {All, All}, PlotRangeClipping -> True, 
               PlotRangePadding -> {{1, 1}, {1, 1}}, Ticks -> {None, None}, 
               Axes -> False, AspectRatio -> 1, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}], Frame -> True, 
               FrameTicks -> None, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], Background -> 
               GrayLevel[0.94]], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Input type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    TemplateBox[{"\"NumericalVector\"", 
                    StyleBox[
                    
                    TemplateBox[{"\" (length: \"", "5", "\")\""}, 
                    "RowDefault"], 
                    GrayLevel[0.5], StripOnInput -> False]}, "RowDefault"], 
                    "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"NeuralNetwork\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Number of training examples: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["315", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    PredictorFunction[
     Association[
     "ExampleNumber" -> 315, "Input" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Length" -> 5]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"NumericalVector"}, 
                  "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                  "ExampleWeights" -> Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> 
           "Allowed"]], "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ImputeMissing", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Imputer" -> (DimensionReducerFunction[
                 Association[
                 "ExampleNumber" -> 315, "Imputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Fill" -> {0.287469387265977, 
                    0.0501208606673832, -0.3289651576085363, 
                    0.5333333333333333, 3.760173724897052}, "Method" -> 
                    "Naive", "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "RandomImputer" -> 
                  MachineLearning`MLProcessor["ImputeMissing", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Imputed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.287469387265977, 
                    0.0501208606673832, -0.3289651576085363, 
                    0.5333333333333333, 3.760173724897052}, 
                    "StandardDeviation" -> {7.194774800112802, 
                    4.38190979967786, 4.129582695793469, 0.49888765156985887`,
                     1.4097213282368326`}, "Method" -> "NaiveSampler", 
                    "VectorLength" -> 5, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
                    "NumericalVector"]], "Preprocessor" -> 
                  MachineLearning`MLProcessor["ToMLDataset", 
                    Association[
                    "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> Automatic, 
                    "ExampleWeights" -> Automatic, "RawExample" -> 
                    Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Processor" -> 
                  MachineLearning`MLProcessor["Identity"], "Padder" -> 
                  MachineLearning`MLProcessor["Identity"], "PostProcessor" -> 
                  MachineLearning`MLProcessor["FromMLDataset", 
                    Association[
                    "DatasetFormat" -> Automatic, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Length" -> 5]], 
                    "InversePreprocessor" -> 
                    MachineLearning`MLProcessor["Sequence", 
                    Association["Processors" -> {
                    MachineLearning`MLProcessor["List"], 
                    MachineLearning`MLProcessor["WrapMLDataset", 
                    Association[
                    "FeatureTypes" -> {"NumericalVector"}, 
                    "FeatureKeys" -> {"f1"}, "FeatureWeights" -> {1}, 
                    "ExampleWeights" -> 1, "StructurePreserving" -> 
                    False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
                    "Perfect", "StructurePreserving" -> False, "Missing" -> 
                    "Allowed"]], "Model" -> 
                  Association[
                   "Matrix" -> {{0.585443253627917, 0.27451436086615055`, 
                    0.002363083116361485, 0.5315470659675009, 
                    0.5471290478116959}, {
                    0.46914545227080406`, -0.39848094537355944`, \
-0.017835447373171002`, -0.6942814667235228, 0.3725192915394444}, {
                    0.3238078986168015, -0.6473751302642327, \
-0.4099453399502077, 0.38797653762876905`, -0.39682856501446584`}, {
                    0.2696134893381835, -0.18297024497172085`, 
                    0.8904155650139252, 
                    0.10302418205219577`, -0.3006270036362097}, \
{-0.5095250264270064, -0.5597161173512867, 0.19692956225316938`, 
                    0.27256409482476474`, 0.5603835089872746}}, "Processor" -> 
                    MachineLearning`MLProcessor["Standardize", 
                    Association[
                    "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
                    "StructurePreserving" -> True, "Input" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]], 
                    "Mean" -> {0.287469387265977, 
                    0.0501208606673832, -0.3289651576085363, 
                    0.5333333333333333, 3.760173724897052}, 
                    "StandardDeviation" -> {7.194774800112802, 
                    4.38190979967786, 4.129582695793469, 0.49888765156985887`,
                     1.4097213282368326`}, "Output" -> 
                    Association[
                    "f1" -> Association[
                    "Type" -> "NumericalVector", "Weight" -> 1]]]], 
                    "FinalDimension" -> 5, "Method" -> "Linear"], 
                  "PerformanceGoal" -> Automatic, "Invertibility" -> 
                  "Approximate", "Log" -> 
                  Association[
                   "TrainingTime" -> 0.0168321, "MaxTrainingMemory" -> 93176, 
                    "DataMemory" -> 12912, "FunctionMemory" -> 22712, 
                    "LanguageVersion" -> {12.1, 0}, "Date" -> 
                    DateObject[{
                    2020, 9, 22, 9, 53, 23.4441504`9.122609425251373}, 
                    "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, 
                    "ProcessorType" -> "x86-64", "OperatingSystem" -> 
                    "Windows", "SystemWordLength" -> 64, 
                    "Evaluations" -> {}]]][#, "ImputedVectors", 
                 PerformanceGoal -> "Quality"]& ), "Method" -> 
               "DimensionReduction", "VectorLength" -> 5, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Type" -> 
               "NumericalVector", "Version" -> {12.1, 0}, "ID" -> 
               4443728544268478220]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.287469387265977, 
                0.0501208606673832, -0.3289651576085363, 0.5333333333333333, 
                3.760173724897052}, 
               "StandardDeviation" -> {7.194774800112802, 4.38190979967786, 
                4.129582695793469, 0.49888765156985887`, 1.4097213282368326`},
                "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 8868013058718301057]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> True, 
           "Missing" -> "Imputed"]]], "Output" -> 
      Association["Preprocessor" -> MachineLearning`MLProcessor["ToMLDataset", 
          Association[
          "Input" -> Association["f1" -> Association["Type" -> "Numerical"]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Preprocessor" -> MachineLearning`MLProcessor["Sequence", 
             Association["Processors" -> {
                MachineLearning`MLProcessor["List"], 
                MachineLearning`MLProcessor["WrapMLDataset", 
                 Association[
                 "FeatureTypes" -> {"Numerical"}, "FeatureKeys" -> {"f1"}, 
                  "FeatureWeights" -> Automatic, "ExampleWeights" -> 
                  Automatic, "RawExample" -> 
                  Missing["KeyAbsent", "RawExample"], "StructurePreserving" -> 
                  False]]}]], "ScalarFeature" -> True, "Invertibility" -> 
           "Perfect", "StructurePreserving" -> False, "Missing" -> "Allowed"]]
         , "Processor" -> MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["ToVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2315181629334253493]], 
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {-2.2796595139680362`}, 
               "StandardDeviation" -> {0.7093127098719422}, "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 2606008482841597487]], 
             MachineLearning`MLProcessor["FromVector", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], "Output" -> 
               Association[
                "f1" -> Association["Type" -> "Numerical", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 681315040515848217]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association["Type" -> "Numerical", "Weight" -> 1], 
               "Key" -> "f1", "Invertibility" -> "Perfect", 
               "StructurePreserving" -> False, "Missing" -> "Allowed"]]}, 
           "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
           "Missing" -> "Allowed"]], "ProbabilityPostprocessor" -> Identity, 
        "InverseProcessorFunction" -> (-2.2796595139680362` + 
         0.7093127098719422 #& ), 
        "ProcessorFunction" -> (3.213899148063484 + 1.409815425668233 #& ), 
        "Name" -> "value", 
        "Quantiles" -> {-3.0686326488724456`, 2.1533908764825216`}], "Prior" -> 
      Automatic, "Utility" -> (DiracDelta[#2 - #]& ), "Threshold" -> 0, 
      "PerformanceGoal" -> Automatic, "BatchProcessing" -> Automatic, "Model" -> 
      Association["Method" -> "NeuralNetwork", "Network" -> NetGraph[
          Association[
          "Type" -> "Graph", "Inputs" -> 
           Association[
            "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
           "Outputs" -> 
           Association[
            "LogStd" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT], 
             "Mean" -> NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]], 
           "Nodes" -> Association[
            "1" -> Association[
              "Type" -> "Chain", "Nodes" -> 
               Association[
                "1" -> Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwViXs01nccgJHrdsLwzq0cl72vyC0vcnl/n+/KtVkjNFlmc3k59Mpe5T7X
9O49NK1inHLWWeTWRXRc4v19vgw5a+3VaMVkbsXJJdlFIjP98TznPOcxi0oK
ilVSUFA4ob6loMi0fcnJkRnBqm9DGCniO4reTsctVLY4LPmYxMoPYJ3MmDrc
qwX9+VYa2MgjKk4SrB5VIjXyLMHcui37RWMYTUqQ4OLGCLurthn784pwxMQA
m9gmj+U6Kf07hUtdeizYX/5RpMIrZaA86ySI4Vfinmd/sNJMN4Gz7uekbUIN
41V59CIR0qHEn3HiURGd5hHSZbgdvv9zJ3MnXQqKvhb43tEudqfHCWpb3su+
XiOU/7QbZg9fYzNqXbFKp4gN3NZDxXH+UMqX4Cs8i6m5YxBo4gUBX/vD4GgI
yXLvgVMH/TAgU8p0DP+LSRPX0X5TB3p874Mxr0YWu4Cd71xKx6PpV/HOqcuY
6G5BDolSCQZmYdvp58yU7yN2ciYO0jxNqLSqW7C4aMz0pqygkbENeaxnj4rm
+8kUEUJsxn20Gj4G2z8Qwn6j10y3cg3UD+0gYy6tQCYLmXQ3DbLcfBbHqj2Z
va3ZZCXKjvlGNsDEDx9HB78NeGlXhd3ZFmiu6UfKXU3RjF/AFidECTwMWEZ/
zhMN4wJg5c1VbC9who/EXOKkZkjV78oZBWk+cp7shvXoBgSeK2yWXIcm70KM
L55h830PoMMlN6q/8jvaNJu2m9pMYXxkP0gjC6FDLREVQhpZtWorGvzGHjli
I9xtzSGflEURj5YO+G7egrZp1zM+C86d3O4G9uaeB4LoG+6QJ/Ii/C+dyaEc
PQwN1WKMCnxpjOZL2YeC27haOoGSGEWyxhciUeXSbX43WfMlDujqlUKFiiUT
ei4EYw/KWPHS+/SnWxdgV9QK4608gZQfRINWRvHI3jo0aLNB0/lecIzzJNOS
b1HyUIaq3uPQdTcbXP87jV3WoaB6EVlFeQtqq3nShvQbgvCnDVDbZwVnVsth
zF+OfaIddEYhgwbbqlBZ2nHSEhZKBOGmMKk/iLq2Jsy9pTVBxGoZTl4oZzYy
JXCkQYv2B1xmpofOUeNBLVzoq2A92ts6u7gEdI4Zkoo6Hi7/IIcX3bdB47Ov
0ChlABMqc1BHLQcfy8swV/wKOOMLjH2JEuWe9CS/XUuCh08iaNVsIRMh1MVc
G20SnjmEJz9VJ88GlNBRiYMvllNhI+gvkHHX4YGLNWxKa5ic0lXm3XxLUjza
wYaZmML5oSiqMckFux572Bz/lfEaqACldR2K/SPIubIO4T6xJH/uR+oa3QCF
JfYAPgPE+bklrc/WJmKzOXRJDMa8Mw6EjUgmt+JFTNN5fdBcqMT/Ae426qc=

                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.0686236172914505, -0.01231891568750143, \
-0.03443847596645355, -0.017140252515673637`, 
                    0.02295646443963051, -0.01618422381579876, \
-0.07537394762039185, 
                    0.05271239951252937, -0.021726837381720543`, \
-0.0073912362568080425`, -0.03686396777629852, -0.018031420186161995`, \
-0.014670129865407944`, -0.04692541062831879, 0.07727274298667908, 
                    0.022154532372951508`, 
                    0.1279231756925583, -0.042726147919893265`, \
-0.030634423717856407`, 0.00529860332608223, -0.002985499333590269, 
                    0.05960597097873688, 0.03214159235358238, 
                    0.04484736546874046, 
                    0.04097111150622368, -0.021348698064684868`, 
                    0.025491632521152496`, 0.042795393615961075`, 
                    0.07686858624219894, 
                    0.00621545547619462, -0.022521428763866425`, 
                    0.04047014191746712, -0.035378098487854004`, 
                    0.026766587048768997`, -0.027946067973971367`, \
-0.0415579192340374, 
                    0.06413927674293518, -0.030592598021030426`, \
-0.06650659441947937, -0.012653294950723648`, 
                    0.0053106630221009254`, -0.04875956475734711, 
                    0.0995125025510788, 
                    0.039425820112228394`, -0.018999623134732246`, \
-0.022664133459329605`, -0.0392552949488163, 
                    0.0005342189106158912, -0.013832831755280495`, \
-0.07650984823703766}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 5, "$InputDimensions" -> {5}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "2" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "3" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUiI/ThpMWhRbRol1RURQp6pkJEUlFZacQJUJkKUWktNsSJWkhKSop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                    "], "Biases" -> 
                    RawArray["Real32",{0.01938934065401554, 
                    0.0005470940377563238, -0.03699667379260063, \
-0.0050063226372003555`, 
                    0.003653823398053646, -0.008064859546720982, \
-0.05527445301413536, -0.019866235554218292`, 0.02208685129880905, 
                    0.029749670997262, -0.028649408370256424`, 
                    0.02732682228088379, 0.03457118943333626, 
                    0.0684310719370842, -0.059052303433418274`, 
                    0.0005149459466338158, -0.035353995859622955`, 
                    0.0318048931658268, -0.03188307210803032, 
                    0.039805784821510315`, 0.04610276222229004, 
                    0.01718081720173359, 
                    0.016553066670894623`, -0.018617751076817513`, 
                    0.00895493384450674, -0.07942978292703629, 
                    0.02519296482205391, -0.016013789921998978`, \
-0.009734220802783966, -0.07619576156139374, 
                    0.09343081712722778, -0.002908164169639349, 
                    0.011099133640527725`, -0.16359065473079681`, 
                    0.02633325383067131, -0.00042396291974000633`, \
-0.005468882620334625, -0.022244056686758995`, 
                    0.04348449409008026, -0.0773908942937851, \
-0.021425090730190277`, 0.031822290271520615`, 
                    0.00402372982352972, -0.050742194056510925`, \
-0.013563856482505798`, 0.025836272165179253`, 0.008921884931623936, 
                    0.026383839547634125`, 
                    0.020067123696208, -0.02968561090528965}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "4" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "5" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl2lUj9/XxkvRpKgkEjIkEoWS+t57RxmSpJSZIiqSOUMpmjSoNIgooiKF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                    "], "Biases" -> 
                    RawArray[
                    "Real32",{-0.03959271311759949, -0.024322248995304108`, \
-0.050901416689157486`, -0.009643946774303913, -0.010015218518674374`, \
-0.010136792436242104`, 
                    0.052836671471595764`, -0.03293490409851074, \
-0.019504781812429428`, 
                    0.022089840844273567`, -0.039290763437747955`, \
-0.09694069623947144, -0.024609388783574104`, -0.013380549848079681`, \
-0.011432272382080555`, -0.021889090538024902`, 0.06738509982824326, 
                    0.058232665061950684`, -0.0654708594083786, 
                    0.009239709004759789, 
                    0.01972106471657753, -0.02112334780395031, 
                    0.03152290731668472, 0.0413987971842289, 
                    0.053424861282110214`, -0.017694372683763504`, 
                    0.06586108356714249, 0.03407051041722298, 
                    0.008975394070148468, 
                    0.004646522458642721, -0.003099191002547741, 
                    0.032264403998851776`, -0.006796014029532671, \
-0.01806975156068802, -0.07022538781166077, -0.017599286511540413`, \
-0.06725510209798813, 0.039092767983675, -0.030815167352557182`, 
                    0.01069107186049223, 
                    0.07096021622419357, -0.01619843952357769, 
                    0.022576140239834785`, 
                    0.0048165349289774895`, -0.022622108459472656`, \
-0.07521693408489227, 0.031551558524370193`, 
                    0.022150645032525063`, -0.009876725263893604, \
-0.016708331182599068`}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "6" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "7" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association["Weights" -> CompressedData["
1:eJwtl3dYz+33wBuSNGhoD1GUkgatz/uckIx4UGYhJBRFdjJatqYSIaVkNpC0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                    "], "Biases" -> 
                    RawArray["Real32",{0.00990433432161808, 
                    0.05491677671670914, 
                    0.032425541430711746`, -0.039285801351070404`, 
                    0.028194164857268333`, 0.012392304837703705`, 
                    0.00796821340918541, 0.026955975219607353`, 
                    0.041455913335084915`, 0.011548526585102081`, 
                    0.0034568742848932743`, 0.05408291518688202, 
                    0.027764350175857544`, -0.005876682233065367, \
-0.028704050928354263`, -0.018964074552059174`, 
                    0.011343722231686115`, -0.026570649817585945`, \
-0.03224789723753929, -0.00031669746385887265`, 
                    0.0023598745465278625`, -0.0181140024214983, \
-0.0032973045017570257`, 0.002742548706009984, 
                    0.007094343192875385, -0.03274337947368622, \
-0.02257770486176014, 0.015187252312898636`, 
                    0.0005858095828443766, -0.06329026818275452, 
                    0.023987602442502975`, 
                    0.029482973739504814`, -0.015619492158293724`, \
-0.006129039451479912, 0.0127313993871212, -0.0012967213988304138`, 
                    0.036127738654613495`, -0.014977546408772469`, \
-0.0237345602363348, -0.03561803326010704, 0.006065314635634422, 
                    0.004527744371443987, -0.005790475755929947, \
-0.023547852411866188`, -0.009793768636882305, 
                    0.03858046978712082, -0.05132417008280754, \
-0.004983565770089626, -0.032195158302783966`, 0.040948666632175446`}]], 
                   "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {50}, "$OutputSize" -> 50, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "8" -> 
                 Association[
                  "Type" -> "Elementwise", "Arrays" -> Association[], 
                   "Parameters" -> 
                   Association["Function" -> NeuralNetworks`ValidatedParameter[
                    NeuralNetworks`Private`ScalarFunctionObject[{
                    NeuralNetworks`Private`ScalarSymbol[1]}, 
                    NeuralNetworks`Private`ScalarSymbol[2], 
                    Association[
                    NeuralNetworks`Private`ScalarSymbol[2] -> {
                    "ScaledExponentialLinearUnit", 
                    NeuralNetworks`Private`ScalarSymbol[1]}]]], 
                    "$Dimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]]], "9" -> 
                 Association[
                  "Type" -> "Linear", "Arrays" -> 
                   Association[
                    "Weights" -> 
                    RawArray["Real32",{{
                    0.1364060342311859, -0.2882477641105652, \
-0.0221027173101902, -0.10950018465518951`, -0.08999276906251907, \
-0.15657886862754822`, -0.07194565236568451, 
                    0.22488833963871002`, -0.06513922661542892, 
                    0.087147057056427, 
                    0.16646668314933777`, -0.08670707046985626, \
-0.21449431777000427`, -0.019624805077910423`, 0.021213270723819733`, 
                    0.2934320867061615, 0.05783453583717346, 
                    0.11917717009782791`, 
                    0.4143853187561035, -0.07991977781057358, 
                    0.22741331160068512`, 
                    0.173384428024292, -0.14279364049434662`, \
-0.013708715327084064`, -0.0446225181221962, 0.05056898668408394, 
                    0.2169734388589859, 0.07789730280637741, 
                    0.1468358039855957, 
                    0.1593562662601471, -0.020164083689451218`, \
-0.25619831681251526`, 0.13881275057792664`, 
                    0.054206736385822296`, -0.03666609153151512, \
-0.11378210037946701`, -0.046781182289123535`, -0.06972619146108627, \
-0.05214744433760643, -0.02301587164402008, -0.06280568987131119, \
-0.22151154279708862`, -0.11983025074005127`, 0.1588950753211975, 
                    0.14193619787693024`, -0.1302744597196579, 
                    0.13850551843643188`, 0.1665286123752594, 
                    0.03876088559627533, -0.12662498652935028`}}], "Biases" -> 
                    RawArray["Real32",{-0.0193604975938797}]], "Parameters" -> 
                   Association[
                    "OutputDimensions" -> {1}, "$OutputSize" -> 1, 
                    "$InputSize" -> 50, "$InputDimensions" -> {50}], "Inputs" -> 
                   Association[
                    "Input" -> 
                    NeuralNetworks`TensorT[{50}, NeuralNetworks`RealT]], 
                   "Outputs" -> 
                   Association[
                    "Output" -> 
                    NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
               "Edges" -> {
                NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Inputs", "Input"], 
                 NeuralNetworks`NetPath["Nodes", "2", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "3", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "4", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "3", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "5", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "4", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "6", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "5", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "7", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "6", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "8", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "7", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Nodes", "9", "Inputs", "Input"] -> 
                 NeuralNetworks`NetPath["Nodes", "8", "Outputs", "Output"], 
                 NeuralNetworks`NetPath["Outputs", "Output"] -> 
                 NeuralNetworks`NetPath["Nodes", "9", "Outputs", "Output"]}, 
               "Inputs" -> 
               Association[
                "Input" -> NeuralNetworks`TensorT[{5}, NeuralNetworks`RealT]],
                "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]], "2" -> 
             Association[
              "Type" -> "ConstantArray", "Arrays" -> 
               Association[
                "Array" -> RawArray["Real32",{-0.8279363512992859}]], 
               "Parameters" -> 
               Association["Dimensions" -> {1}, "$ArrayDimensions" -> {1}], 
               "Inputs" -> Association[], "Outputs" -> 
               Association[
                "Output" -> 
                 NeuralNetworks`TensorT[{1}, NeuralNetworks`RealT]]]], 
           "Edges" -> {
            NeuralNetworks`NetPath["Nodes", "1", "Inputs", "Input"] -> 
             NeuralNetworks`NetPath["Inputs", "Input"], 
             NeuralNetworks`NetPath["Outputs", "Mean"] -> 
             NeuralNetworks`NetPath["Nodes", "1", "Outputs", "Output"], 
             NeuralNetworks`NetPath["Outputs", "LogStd"] -> 
             NeuralNetworks`NetPath["Nodes", "2", "Outputs", "Output"]}], 
          Association["Version" -> "12.1.4", "Unstable" -> False]], 
        "Training" -> 
        Association[
         "Optimizer" -> {"ADAM", "L2Regularization" -> None}, 
          TrainingProgressFunction -> {Null& , "Interval" -> 1}, 
          "TotalTrainingTime" -> 5.0221022, "MeanInputsPerSecond" -> 
          50974.66953181478], "InputType" -> "NumericalVector", "Processor" -> 
        MachineLearning`MLProcessor["Sequence", 
          Association[
          "Input" -> Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Output" -> 
           Association[
            "f1" -> Association["Type" -> "NumericalVector", "Weight" -> 1]], 
           "Processors" -> {
             MachineLearning`MLProcessor["Standardize", 
              Association[
              "Invertibility" -> "Perfect", "Missing" -> "Allowed", 
               "StructurePreserving" -> True, "Input" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Mean" -> {0.0372537071057433, 0.009103330628250295, 
                0.007972737131275782, -0.003385996322805949, \
-0.01977612364842169}, 
               "StandardDeviation" -> {0.9826181598840414, 0.9897986072915094,
                 0.9921454164002002, 1.0003331103618107`, 1.00579120892631}, 
               "Output" -> 
               Association[
                "f1" -> Association[
                  "Type" -> "NumericalVector", "Weight" -> 1]], 
               "Version" -> {12.1, 0}, "ID" -> 4979573711521073407]], 
             MachineLearning`MLProcessor["FirstValues", 
              Association[
              "Info" -> Association[
                "Type" -> "NumericalVector", "Weight" -> 1], "Key" -> "f1", 
               "Invertibility" -> "Perfect", "StructurePreserving" -> False, 
               "Missing" -> "Allowed"]]}, "Invertibility" -> "Perfect", 
           "StructurePreserving" -> False, "Missing" -> "Allowed"]], 
        "FeatureNumber" -> 5, 
        "DistributionData" -> {NormalDistribution, Automatic}, 
        "PostProcessor" -> MachineLearning`MLProcessor["Identity"], "Options" -> 
        Association[
         "NetworkType" -> 
          Association[
           "Value" -> "FullyConnected", "Options" -> Association[]], 
          "NetworkDepth" -> 
          Association["Value" -> 4, "Options" -> Association[]], 
          "NumberOfParameters" -> 
          Association["Value" -> 41, "Options" -> Association[]], 
          "ActivationFunction" -> 
          Association["Value" -> "SELU", "Options" -> Association[]], 
          "L2Regularization" -> 
          Association["Value" -> None, "Options" -> Association[]], "Dropout" -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetInitializationMethod" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "OptimizationMethod" -> 
          Association[
           "Value" -> {"ADAM", "L2Regularization" -> None}, "Options" -> 
            Association[]], MaxTrainingRounds -> 
          Association["Value" -> 1000, "Options" -> Association[]], 
          ValidationSet -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "EarlyStopping" -> 
          Association["Value" -> False, "Options" -> Association[]], 
          TrainingProgressReporting -> 
          Association["Value" -> None, "Options" -> Association[]], 
          "NetTrainOptions" -> 
          Association[
           "Value" -> {LearningRateMultipliers -> {}, TargetDevice -> "CPU"}, 
            "Options" -> Association[]], "LossFunction" -> 
          Association["Value" -> Automatic, "Options" -> Association[]], 
          "ValidationSetRatio" -> 
          Association[
           "Value" -> 0.15079365079365079`, "Options" -> Association[]]]], 
      "TrainingInformation" -> 
      Association[
       "PanelCell" -> CellObject[365713], "TrainingFunction" -> Predict, 
        "EMIterations" -> Missing["KeyAbsent", "EMIterations"], 
        "ProcessorEntropyShift" -> -0.3434587920400341, "PreprocessingTime" -> 
        0.3792404`7.030459589468131, "LossName" -> "StandardDeviation", 
        "BestModelInformation" -> Dataset[
          Association[
          "MeanCrossEntropy" -> 
           Around[0.16057406044511088`, 0.1678547805380447], 
           "StandardDeviation" -> 
           Around[0.2885575176943709, 0.06665941386749645], "EvaluationTime" -> 
           0.00031670830396331406`, "TestSize" -> 63, "ModelMemory" -> 99880, 
           "ModelUtility" -> 0.5045151166643882, "TrainingSize" -> 252, 
           "TrainingTime" -> 5.011872336272724, "TrainingMemory" -> 451832, 
           "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
             Around[0.16057406044511088`, 0.11869125357303112`]}, 
           "StandardDeviationHistory" -> {
             Around[0.2885575176943709, 0.04713532357562732]}, 
           "Configuration" -> {
            "NeuralNetwork", "NetworkType" -> "FullyConnected", 
             "NetworkDepth" -> 4, "NumberOfParameters" -> 41, 
             "ActivationFunction" -> "SELU", "L2Regularization" -> None, 
             "Dropout" -> None, "NetInitializationMethod" -> Automatic, 
             "OptimizationMethod" -> {"ADAM", "L2Regularization" -> None}, 
             MaxTrainingRounds -> 1000, ValidationSet -> Automatic, 
             "EarlyStopping" -> False, TrainingProgressReporting -> None, 
             "NetTrainOptions" -> Automatic, "LossFunction" -> Automatic}], 
          
          TypeSystem`Struct[{
           "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
            "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
            "TrainingTime", "TrainingMemory", "ExperimentCount", 
            "MeanCrossEntropyHistory", "StandardDeviationHistory", 
            "Configuration"}, {TypeSystem`AnyType, TypeSystem`AnyType, 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Real], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Atom[Integer], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Vector[TypeSystem`AnyType, 1], 
            TypeSystem`Tuple[{
              TypeSystem`Atom[String], TypeSystem`AnyType, TypeSystem`AnyType,
               TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType, 
              TypeSystem`AnyType, TypeSystem`AnyType, TypeSystem`AnyType}]}], 
          Association["ID" -> 222917604831010]], "Configurations" -> Dataset[
          Association[
          Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[3.9458178943118454`, 0.5735704485533868], 
                "StandardDeviation" -> 
                Around[0.6729315355232717, 0.04288370339855337], 
                "EvaluationTime" -> 0.00011429554593242835`, "TestSize" -> 
                305, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.30973417851922513`, "TrainingSize" -> 10,
                 "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                495824, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[3.9458178943118454`, 0.40557555366030956`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.6729315355232717, 0.030323357475509682`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[2.013520383499267, 0.35920150125206896`], 
                "StandardDeviation" -> 
                Around[0.4950528287759603, 0.03390323925839765], 
                "EvaluationTime" -> 0.00012135285045061535`, "TestSize" -> 
                265, "ModelMemory" -> 107736, 
                "ModelUtility" -> -0.0036941352106596437`, "TrainingSize" -> 
                50, "TrainingTime" -> 0.6309573444801932, "TrainingMemory" -> 
                499728, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[2.013520383499267, 0.2539938173477261]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4950528287759603, 0.023973210383802956`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.2110654254978072, 0.16249795573515743`], 
                "StandardDeviation" -> 
                Around[0.30562258102773265`, 0.05806848758191635], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 107736, "ModelUtility" -> 
                0.45492707780617003`, "TrainingSize" -> 252, "TrainingTime" -> 
                1.9952623149688797`, "TrainingMemory" -> 522696, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[0.2110654254978072, 0.11490340642928125`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.30562258102773265`, 0.041060621342419876`]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               107736, "StandardDeviation" -> 
               Around[0.30562258102773265`, 0.05806848758191635], 
               "TrainingMemory" -> 522696, "TrainingTime" -> 
               3.125035238191293], "Index" -> 1], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[1.7267749457803045`, 0.34180204711365186`], 
                "StandardDeviation" -> 
                Around[0.4817366181857113, 0.03616107462335966], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, "ModelUtility" -> 
                0.02227726628714355, "TrainingSize" -> 50, "TrainingTime" -> 
                0.31622776601683794`, "TrainingMemory" -> 429256, 
                "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[1.7267749457803045`, 0.24169054533750703`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.4817366181857113, 0.025569741081170393`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.22040725841352746`, 0.18623385448453494`], 
                "StandardDeviation" -> 
                Around[0.30823768299169035`, 0.06230433570493954], 
                "EvaluationTime" -> 0.0003987121319856475, "TestSize" -> 63, 
                "ModelMemory" -> 99880, "ModelUtility" -> 0.4440741755997819, 
                "TrainingSize" -> 252, "TrainingTime" -> 0.7943282347242815, 
                "TrainingMemory" -> 451704, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.22040725841352746`, 0.13168722139252337`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.30823768299169035`, 0.04405581827428588]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.0003987121319856475, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.30823768299169035`, 0.06230433570493954], 
               "TrainingMemory" -> 451704, "TrainingTime" -> 
               1.3091380594221897`], "Index" -> 2], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 100], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 3], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association["Experiments" -> {
               Association[
               "MeanCrossEntropy" -> 
                Around[4.955368705892204, 0.658983572352414], 
                "StandardDeviation" -> 
                Around[0.7468587643753982, 0.04468276722522941], 
                "EvaluationTime" -> 0.00010360807771383994`, "TestSize" -> 
                305, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.41319453945119555`, "TrainingSize" -> 10,
                 "TrainingTime" -> 1.5848931924611136`, "TrainingMemory" -> 
                424768, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[4.955368705892204, 0.4659717527009278]}, 
                "StandardDeviationHistory" -> {
                  Around[0.7468587643753982, 0.03159548770713973]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[23.627908533581824`, 3.3528341905823007`], 
                "StandardDeviation" -> 
                Around[0.694657060430551, 0.046263002755928186`], 
                "EvaluationTime" -> 0.00014229478653976401`, "TestSize" -> 
                265, "ModelMemory" -> 99880, 
                "ModelUtility" -> -0.3420740076946799, "TrainingSize" -> 50, 
                "TrainingTime" -> 1.2589254117941673`, "TrainingMemory" -> 
                428944, "ExperimentCount" -> 1, "MeanCrossEntropyHistory" -> {
                  Around[23.627908533581824`, 2.370811792354854]}, 
                "StandardDeviationHistory" -> {
                  Around[0.694657060430551, 0.032712882966768754`]}], 
               Association[
               "MeanCrossEntropy" -> 
                Around[0.16057406044511088`, 0.1678547805380447], 
                "StandardDeviation" -> 
                Around[0.2885575176943709, 0.06665941386749645], 
                "EvaluationTime" -> 0.00031670830396331406`, "TestSize" -> 63,
                 "ModelMemory" -> 99880, "ModelUtility" -> 0.5045151166643882,
                 "TrainingSize" -> 252, "TrainingTime" -> 5.011872336272724, 
                "TrainingMemory" -> 451832, "ExperimentCount" -> 1, 
                "MeanCrossEntropyHistory" -> {
                  Around[0.16057406044511088`, 0.11869125357303112`]}, 
                "StandardDeviationHistory" -> {
                  Around[0.2885575176943709, 0.04713532357562732]}]}, 
             "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 0.00031670830396331406`, "ModelMemory" -> 
               99880, "StandardDeviation" -> 
               Around[0.2885575176943709, 0.06665941386749645], 
               "TrainingMemory" -> 451832, "TrainingTime" -> 
               7.849733612802018], "Index" -> 4], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> None], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 300], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 5], 
           Association[
            "Value" -> "NeuralNetwork", "Options" -> 
             Association[
              "NetworkType" -> Association["Value" -> "FullyConnected"], 
               "NetworkDepth" -> Association["Value" -> 4], 
               "NumberOfParameters" -> Association["Value" -> 41], 
               "ActivationFunction" -> Association["Value" -> "SELU"], 
               "L2Regularization" -> Association["Value" -> None], "Dropout" -> 
               Association["Value" -> 0.01], "NetInitializationMethod" -> 
               Association["Value" -> Automatic], "OptimizationMethod" -> 
               Association["Value" -> {"ADAM", "L2Regularization" -> None}], 
               MaxTrainingRounds -> Association["Value" -> 1000], 
               ValidationSet -> Association["Value" -> Automatic], 
               "EarlyStopping" -> Association["Value" -> False], 
               TrainingProgressReporting -> Association["Value" -> None], 
               "NetTrainOptions" -> Association["Value" -> Automatic], 
               "LossFunction" -> Association["Value" -> Automatic]]] -> 
           Association[
            "Experiments" -> {}, "PredictedPerformances" -> 
             Association[
              "EvaluationTime" -> 1, "ModelMemory" -> 1, "StandardDeviation" -> 
               1, "TrainingMemory" -> 1, "TrainingTime" -> 1], "Index" -> 6]], 
          TypeSystem`Assoc[
           TypeSystem`Struct[{"Value", "Options"}, {
             TypeSystem`Atom[
              TypeSystem`Enumeration["NeuralNetwork"]], 
             TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Struct[{"Value"}, {TypeSystem`AnyType}], 14]}], 
           
           TypeSystem`Struct[{
            "Experiments", "PredictedPerformances", "Index"}, {
             TypeSystem`Vector[
              
              TypeSystem`Struct[{
               "MeanCrossEntropy", "StandardDeviation", "EvaluationTime", 
                "TestSize", "ModelMemory", "ModelUtility", "TrainingSize", 
                "TrainingTime", "TrainingMemory", "ExperimentCount", 
                "MeanCrossEntropyHistory", "StandardDeviationHistory"}, {
               TypeSystem`AnyType, TypeSystem`AnyType, 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Real], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Atom[Integer], 
                TypeSystem`Vector[TypeSystem`AnyType, 1], 
                TypeSystem`Vector[TypeSystem`AnyType, 1]}], 
              TypeSystem`AnyLength], 
             
             TypeSystem`Struct[{
              "EvaluationTime", "ModelMemory", "StandardDeviation", 
               "TrainingMemory", "TrainingTime"}, {
               TypeSystem`Atom[Real], 
               TypeSystem`Atom[Integer], TypeSystem`AnyType, 
               TypeSystem`Atom[Integer], 
               TypeSystem`Atom[Real]}], 
             TypeSystem`Atom[Integer]}], 6], 
          Association["ID" -> 222913309863714]], "MaxTrainingSize" -> 315, 
        "PreprocessorEvaluationTime" -> 7.04140625`2.*^-6, 
        "PreprocessorMemory" -> 37264, "InputDimension" -> 5, 
        "OutputDimension" -> 1, 
        "BaselineLogProbability" -> -1.4189385332046727`, "VariableBudget" -> 
        True, "CheckpointingInfo" -> Association["Checkpointing" -> False], 
        "UserStop" -> False, "NaturalStop" -> True, "AbortStop" -> False, 
        "LastReportingTime" -> 3.8097572181838779`17.333472289727283*^9, 
        "RoundPartitioning" -> Dataset[{
           Association[
           "TrainingSizes" -> 10, "TimeBudgets" -> 1.8478954355998507`, 
            "ElapsedTimes" -> 2.4593578000000003`, "ExperimentCounts" -> 2], 
           Association[
           "TrainingSizes" -> 50, "TimeBudgets" -> 3.079825725999751, 
            "ElapsedTimes" -> 2.8782983, "ExperimentCounts" -> 3], 
           Association[
           "TrainingSizes" -> 252, "TimeBudgets" -> 5.133042876666251, 
            "ElapsedTimes" -> 8.6199341, "ExperimentCounts" -> 3]}, 
          TypeSystem`Vector[
           
           TypeSystem`Struct[{
            "TrainingSizes", "TimeBudgets", "ElapsedTimes", 
             "ExperimentCounts"}, {
             TypeSystem`Atom[Integer], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Real], 
             TypeSystem`Atom[Integer]}], 3], 
          Association["ID" -> 222926194765602]]], "AnomalyDetector" -> None, 
      "Log" -> Association["Example" -> MachineLearning`MLDataset[
          Association[
          "f1" -> Association[
            "Type" -> "NumericalVector", "Weight" -> 1, 
             "Values" -> {{-7.22661819619284, 
              2.152496674228478, -3.2995241272622993`, 0., 
              5.298317366548036}}, "ID" -> 6900269369450652421]], 
          Association[
          "ExampleNumber" -> 1, "ExampleWeights" -> 1, "LogDensityRatios" -> 
           0, "RawExample" -> False]], "TrainingTime" -> 14.7979011, 
        "MaxTrainingMemory" -> 979784, "DataMemory" -> 75768, 
        "FunctionMemory" -> 258104, "LanguageVersion" -> {12.1, 0}, "Date" -> 
        DateObject[{2020, 9, 22, 9, 53, 38.2118036`9.334772422418187}, 
          "Instant", "Gregorian", 1.], "ProcessorCount" -> 4, "ProcessorType" -> 
        "x86-64", "OperatingSystem" -> "Windows", "SystemWordLength" -> 64, 
        "Evaluations" -> {}]]],
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.809753619868868*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"3241282a-7e0e-4ef8-98b5-ea9c09d4c007"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ensemblePredictionResultsUnscaled", "=", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"predictedSetTraining", "=", 
        RowBox[{"ensemblePredictions", "[", " ", 
         RowBox[{
          RowBox[{"trainingSet", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}], " ", ",", " ", 
          "networkEnsemble"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"trainingSet", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"Mean", "[", "predictedSetTraining", "]"}], ",", 
         RowBox[{"StandardDeviation", "[", "predictedSetTraining", "]"}]}], 
        "}"}]}], " ", "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "trainingSet", "]"}]}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ensemblePredictionResultsValidationUnscaled", "=", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"predictedSetValidation", "=", 
         RowBox[{"ensemblePredictions", "[", " ", 
          RowBox[{
           RowBox[{"validationSet", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}], " ", ",", " ", 
           "networkEnsemble"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"validationSet", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"Mean", "[", "predictedSetValidation", "]"}], ",", 
          RowBox[{"StandardDeviation", "[", "predictedSetValidation", "]"}]}],
          "}"}]}], "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", " ", "validationSet", "]"}]}], "}"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8045849738954487`*^9, 3.8045849868873453`*^9}, {
  3.804585112646468*^9, 3.8045852717903943`*^9}, {3.8045939786329446`*^9, 
  3.804593983644357*^9}, {3.8045969475976305`*^9, 3.8045969845607204`*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"56bb20da-0b82-4c74-8f13-48a420e56de6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1792090429475053`"}], ",", 
     RowBox[{"-", "2.2469227003026693`"}], ",", "0.26478140598575023`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.5150160176364371`"}], ",", 
     RowBox[{"-", "1.5513159609167095`"}], ",", "0.2452397469024325`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.49861134824271`"}], ",", 
     RowBox[{"-", "2.4127325188779016`"}], ",", "0.12991256754530267`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.6504938804901603`"}], ",", 
     RowBox[{"-", "3.662313766259096`"}], ",", "0.12422277098132778`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7634724030768383`"}], ",", 
     RowBox[{"-", "2.6289323040031505`"}], ",", "0.22244731256574513`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.683276549384816`"}], ",", 
     RowBox[{"-", "1.849740111332874`"}], ",", "0.21545565016906318`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.813942007779627`"}], ",", 
     RowBox[{"-", "2.866936743257866`"}], ",", "0.12441981491749404`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.735815338385749`"}], ",", 
     RowBox[{"-", "2.2338953289923524`"}], ",", "0.37173167168024684`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.520279859599943`"}], ",", 
     RowBox[{"-", "3.497933117423542`"}], ",", "0.11608539659187123`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.6720561661262874`"}], ",", 
     RowBox[{"-", "3.7022316476713315`"}], ",", "0.11431021246505846`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.173650745896161`"}], ",", 
     RowBox[{"-", "2.1670237516198076`"}], ",", "0.26081284671437943`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.6168823494888613`"}], ",", 
     RowBox[{"-", "2.8022358392093136`"}], ",", "0.17737945096176755`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.963215221854322`"}], ",", 
     RowBox[{"-", "2.932427957339015`"}], ",", "0.14638543066056342`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1729315829242166`"}], ",", 
     RowBox[{"-", "2.528699545334703`"}], ",", "0.3723407595486705`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.523297317775189`"}], ",", 
     RowBox[{"-", "3.5355915301820704`"}], ",", "0.15663309661956196`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.8221759428611772`"}], ",", 
     RowBox[{"-", "2.8700072662514`"}], ",", "0.09190201635418059`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.3596933372763467`"}], ",", 
     RowBox[{"-", "1.8980056062596509`"}], ",", "0.3800436040743165`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.946087580937209`"}], ",", 
     RowBox[{"-", "2.025899107328267`"}], ",", "0.12931974382934683`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.8252364815422863`"}], ",", 
     RowBox[{"-", "2.5926385432795107`"}], ",", "0.20838803911137915`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0793450244814395`"}], ",", 
     RowBox[{"-", "2.063522757299547`"}], ",", "0.14830283726832633`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.6867640887223556`"}], ",", 
     RowBox[{"-", "1.717004936448602`"}], ",", "0.1594042102480287`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0401040579417815`"}], ",", 
     RowBox[{"-", "2.1803149002790465`"}], ",", "0.18343031108277108`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.755728283085556`"}], ",", 
     RowBox[{"-", "1.52237072537671`"}], ",", "0.22293937906290745`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.318758428033179`"}], ",", 
     RowBox[{"-", "3.882541792087559`"}], ",", "0.5258958350517737`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.3658444415868374`"}], ",", 
     RowBox[{"-", "2.270260744752639`"}], ",", "0.1415884580701171`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.643278585190466`"}], ",", 
     RowBox[{"-", "2.900564688471232`"}], ",", "0.34773240241037023`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.273624233561373`"}], ",", 
     RowBox[{"-", "2.5398426751037246`"}], ",", "0.3454795722738791`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.986252610514135`"}], ",", 
     RowBox[{"-", "2.70001063251344`"}], ",", "0.1729209545901696`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.660280407539144`"}], ",", 
     RowBox[{"-", "2.662651037597827`"}], ",", "0.27732296409415264`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.916321435839302`"}], ",", 
     RowBox[{"-", "2.2308917241552524`"}], ",", "0.3423494555366327`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0124220646654263`"}], ",", 
     RowBox[{"-", "2.292229562101316`"}], ",", "0.29688896551771704`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.6715654720066184`"}], ",", 
     RowBox[{"-", "2.9639761849565724`"}], ",", "0.40749565488120926`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.5005975989784637`"}], ",", 
     RowBox[{"-", "2.4789631804828383`"}], ",", "0.11921929349624369`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.613259001836464`"}], ",", 
     RowBox[{"-", "1.7663822838407057`"}], ",", "0.19484199891149043`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.627146439456394`"}], ",", 
     RowBox[{"-", "3.3839193437950796`"}], ",", "0.24774982242669627`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.185391254252251`"}], ",", 
     RowBox[{"-", "2.8814067187247403`"}], ",", "0.18093421328745377`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.4025682895238605`"}], ",", 
     RowBox[{"-", "3.1401923702223073`"}], ",", "0.35235078286382376`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7357170797087846`"}], ",", 
     RowBox[{"-", "2.907627696757676`"}], ",", "0.2041185273952049`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.1605888820500527`"}], ",", 
     RowBox[{"-", "2.82869096403787`"}], ",", "0.28891311526608`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.8967016011938442`"}], ",", 
     RowBox[{"-", "1.3585518545156234`"}], ",", "0.2982910820961424`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.5296524689701387`"}], ",", 
     RowBox[{"-", "2.420615961883588`"}], ",", "0.2186001726419711`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.1786172622488342`"}], ",", 
     RowBox[{"-", "3.2092119920314253`"}], ",", "0.19925797766573203`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.285132624175161`"}], ",", 
     RowBox[{"-", "2.1173797159997734`"}], ",", "0.1825206939064871`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.052872440673891`"}], ",", 
     RowBox[{"-", "2.15605699309565`"}], ",", "0.18864475515333098`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.8932088070504725`"}], ",", 
     RowBox[{"-", "2.230492937316455`"}], ",", "0.3334466853255712`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.747995148726652`"}], ",", 
     RowBox[{"-", "2.65757990927302`"}], ",", "0.28042270758207877`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1854593041394104`"}], ",", 
     RowBox[{"-", "2.488833491842763`"}], ",", "0.34406905676689925`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.619205957028527`"}], ",", 
     RowBox[{"-", "2.8266006348397563`"}], ",", "0.23050227176369142`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.6364423764517784`"}], ",", 
     RowBox[{"-", "1.7859421899192336`"}], ",", "0.1982837780898968`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.268105494976362`"}], ",", 
     RowBox[{"-", "2.469557034823491`"}], ",", "0.23758649812857072`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2469034206779133`"}], ",", 
     RowBox[{"-", "1.194720510307153`"}], ",", "0.18946303313532986`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.573546270829839`"}], ",", 
     RowBox[{"-", "3.5474016495624037`"}], ",", "0.14965415804344498`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.420200839831268`"}], ",", 
     RowBox[{"-", "2.7570081886701865`"}], ",", "0.26219395107448584`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.9824046146929666`"}], ",", 
     RowBox[{"-", "2.7131816793808374`"}], ",", "0.3558965386849927`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2177377930408098`"}], ",", 
     RowBox[{"-", "1.2891960880774496`"}], ",", "0.2585258439321599`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.525901725524116`"}], ",", 
     RowBox[{"-", "1.7687271090259447`"}], ",", "0.1810253421934328`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.2732135829550124`"}], ",", 
     RowBox[{"-", "3.467158110267694`"}], ",", "0.19466060585945097`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.7522319959567022`"}], ",", 
     RowBox[{"-", "1.2710078357445058`"}], ",", "0.37966206824842524`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.541556933865403`"}], ",", 
     RowBox[{"-", "2.4005931145332196`"}], ",", "0.19318426500099878`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.3848314213029607`"}], ",", 
     RowBox[{"-", "3.3034427662063357`"}], ",", "0.1616766510286145`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.96002115893819`"}], ",", 
     RowBox[{"-", "2.992459550976463`"}], ",", "0.13337497725783962`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.3140264854248112`"}], ",", 
     RowBox[{"-", "1.9312727270257688`"}], ",", "0.3757695742872305`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.2021013593192458`"}], ",", 
     RowBox[{"-", "2.268493613439573`"}], ",", "0.11998974709957103`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.761936197260062`"}], ",", 
     RowBox[{"-", "2.712304498727079`"}], ",", "0.21735418125301317`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.781964757382926`"}], ",", 
     RowBox[{"-", "2.9151534963560923`"}], ",", "0.21265112090244692`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.360409687048968`"}], ",", 
     RowBox[{"-", "2.0119757971018988`"}], ",", "0.3834191457223931`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.3739411032345816`"}], ",", 
     RowBox[{"-", "2.252653992692742`"}], ",", "0.168565196951225`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1661277148813993`"}], ",", 
     RowBox[{"-", "2.3514084847271017`"}], ",", "0.1888257151126925`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.560634835382048`"}], ",", 
     RowBox[{"-", "2.2970686259594677`"}], ",", "0.29950527712611846`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2454386026690554`"}], ",", 
     RowBox[{"-", "2.028926461703596`"}], ",", "0.5459207920204296`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.449383637758643`"}], ",", 
     RowBox[{"-", "2.724123831522846`"}], ",", "0.2624292517951039`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.6878525222335004`"}], ",", 
     RowBox[{"-", "3.0212190063688023`"}], ",", "0.4420381721596563`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9311712014167497`"}], ",", 
     RowBox[{"-", "2.246256459342501`"}], ",", "0.33043208107417227`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.9929101067063706`"}], ",", 
     RowBox[{"-", "3.017243001171812`"}], ",", "0.14089055521410854`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0466615257484952`"}], ",", 
     RowBox[{"-", "2.2219712912208296`"}], ",", "0.24659129597890345`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.918638329393169`"}], ",", 
     RowBox[{"-", "2.1870857519539935`"}], ",", "0.36791313447988205`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.188719338941301`"}], ",", 
     RowBox[{"-", "1.3050762663986957`"}], ",", "0.19043901626915602`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.6798693324170957`"}], ",", 
     RowBox[{"-", "2.106026745676933`"}], ",", "0.2772416327561049`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9694279930005818`"}], ",", 
     RowBox[{"-", "1.8045108254905269`"}], ",", "0.17713346445196332`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.4249411448299518`"}], ",", 
     RowBox[{"-", "1.369064516735683`"}], ",", "0.11686027758936435`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7491024769764967`"}], ",", 
     RowBox[{"-", "2.7971447689880997`"}], ",", "0.11501042416883171`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.730671244941446`"}], ",", 
     RowBox[{"-", "3.0324243686748105`"}], ",", "0.2561377272914749`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.082516994091551`"}], ",", 
     RowBox[{"-", "3.294459076322174`"}], ",", "0.23971409521181153`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9480229493583494`"}], ",", 
     RowBox[{"-", "2.1544583047904085`"}], ",", "0.33430321344512937`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9978934440567908`"}], ",", 
     RowBox[{"-", "2.207700025820262`"}], ",", "0.2754466360094486`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.8824981005730477`"}], ",", 
     RowBox[{"-", "1.461220824912932`"}], ",", "0.2317975159610669`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7440363372598227`"}], ",", 
     RowBox[{"-", "2.9381560818123713`"}], ",", "0.1620141179109738`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.6839668370549503`"}], ",", 
     RowBox[{"-", "1.891612090718405`"}], ",", "0.24173440285348266`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.4824047830791938`"}], ",", 
     RowBox[{"-", "2.493315078063418`"}], ",", "0.15097255919286579`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.658610141813601`"}], ",", 
     RowBox[{"-", "2.7679390351916`"}], ",", "0.21995471863154728`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0425445255649137`"}], ",", 
     RowBox[{"-", "2.2356053566058023`"}], ",", "0.2987795700142993`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.356259062324824`"}], ",", 
     RowBox[{"-", "2.6167410113712646`"}], ",", "0.20878394467652236`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.327160275268008`"}], ",", 
     RowBox[{"-", "2.5391092899445113`"}], ",", "0.28119342061540614`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.709697050658297`"}], ",", 
     RowBox[{"-", "2.7044545479664537`"}], ",", "0.15106838601313466`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.6224079218098204`"}], ",", 
     RowBox[{"-", "2.677539553222436`"}], ",", "0.12138853702061193`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9753887101497345`"}], ",", 
     RowBox[{"-", "2.212968889666421`"}], ",", "0.2640026665479463`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.586328195605694`"}], ",", 
     RowBox[{"-", "2.8185036191858663`"}], ",", "0.21583084648535375`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.363480310047582`"}], ",", 
     RowBox[{"-", "3.1713796629146733`"}], ",", "0.2871257604592846`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.8229064258009817`"}], ",", 
     RowBox[{"-", "1.9815116708449356`"}], ",", "0.2458723714001076`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.3454925702912357`"}], ",", 
     RowBox[{"-", "2.2527134171186947`"}], ",", "0.21092307449221226`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.6401872356800253`"}], ",", 
     RowBox[{"-", "3.575830863639603`"}], ",", "0.1516996648822782`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.016415919516947`"}], ",", 
     RowBox[{"-", "2.2281308205538988`"}], ",", "0.49736148839113936`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.7704540681988712`"}], ",", 
     RowBox[{"-", "1.7860883628529407`"}], ",", "0.14530794747171288`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.863516272892588`"}], ",", 
     RowBox[{"-", "2.646439856590513`"}], ",", "0.19877289856574293`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.856474115282801`"}], ",", 
     RowBox[{"-", "2.853546411819312`"}], ",", "0.13160715065916836`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1815620553629445`"}], ",", 
     RowBox[{"-", "2.3442144490648866`"}], ",", "0.18479457206763356`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.737632397716744`"}], ",", 
     RowBox[{"-", "3.7637409963140938`"}], ",", "0.1295474951068918`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2697372505915945`"}], ",", 
     RowBox[{"-", "1.615403541784545`"}], ",", "0.40588393600975875`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.488449453362758`"}], ",", 
     RowBox[{"-", "1.7315649490793872`"}], ",", "0.18235485914980756`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.8424869028713913`"}], ",", 
     RowBox[{"-", "1.3441454443594592`"}], ",", "0.3647289945793418`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.3608718081963393`"}], ",", 
     RowBox[{"-", "1.9685248579163073`"}], ",", "0.3769917390278154`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1894689410787334`"}], ",", 
     RowBox[{"-", "1.948420401155854`"}], ",", "0.30693750707277107`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7608620706636264`"}], ",", 
     RowBox[{"-", "2.8384879156627303`"}], ",", "0.2083671145772358`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.8874403679155103`"}], ",", 
     RowBox[{"-", "2.943672775321089`"}], ",", "0.17436055264815617`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.301390829217894`"}], ",", 
     RowBox[{"-", "3.171021064853093`"}], ",", "0.1660161583806828`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7030520379939653`"}], ",", 
     RowBox[{"-", "2.734127299998684`"}], ",", "0.08598743851468553`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.0426924604687287`"}], ",", 
     RowBox[{"-", "1.2170516811885592`"}], ",", "0.20020774944785694`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.0128701193103373`"}], ",", 
     RowBox[{"-", "1.1518097068239908`"}], ",", "0.19277595684627347`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.9994340385742935`"}], ",", 
     RowBox[{"-", "2.9229402648718206`"}], ",", "0.11717490594821438`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.6805822901333904`"}], ",", 
     RowBox[{"-", "3.661547638683503`"}], ",", "0.1458095293950492`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.803027891215064`"}], ",", 
     RowBox[{"-", "3.423459379400538`"}], ",", "0.45722770656395567`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9169094525764343`"}], ",", 
     RowBox[{"-", "1.7727135692784863`"}], ",", "0.13910330831993242`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9673116239687343`"}], ",", 
     RowBox[{"-", "2.374912835135743`"}], ",", "0.32422576732449077`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.114429987868967`"}], ",", 
     RowBox[{"-", "2.783557547946987`"}], ",", "0.23891213052193738`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.8164885933623895`"}], ",", 
     RowBox[{"-", "3.864471726983007`"}], ",", "0.1461420611656798`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.189142117256492`"}], ",", 
     RowBox[{"-", "1.9836373183154743`"}], ",", "0.18757258667200086`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.177235930650831`"}], ",", 
     RowBox[{"-", "2.1683406619777044`"}], ",", "0.17465684994391228`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7902686081192933`"}], ",", 
     RowBox[{"-", "2.6161296201075483`"}], ",", "0.19035920349881458`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.780124495947955`"}], ",", 
     RowBox[{"-", "2.7575164422019673`"}], ",", "0.10707083862963314`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.37704131673849`"}], ",", 
     RowBox[{"-", "2.120752584492142`"}], ",", "0.2922419171117701`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.2256876851982477`"}], ",", 
     RowBox[{"-", "2.162074592854788`"}], ",", "0.15865626658289353`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2865664548721572`"}], ",", 
     RowBox[{"-", "1.2916867353478994`"}], ",", "0.1829519504855723`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.2207232682793134`"}], ",", 
     RowBox[{"-", "2.235698858982055`"}], ",", "0.19156609652974857`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.076658731637496`"}], ",", 
     RowBox[{"-", "2.9276602218596444`"}], ",", "0.16494300240839505`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.6653432216355186`"}], ",", 
     RowBox[{"-", "1.8741328720902408`"}], ",", "0.2023491064690433`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.2717636619424586`"}], ",", 
     RowBox[{"-", "2.261677875408559`"}], ",", "0.26593593683381384`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.6158587261674198`"}], ",", 
     RowBox[{"-", "2.3518163161202015`"}], ",", "0.38126148891158207`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.930420293298644`"}], ",", 
     RowBox[{"-", "1.8542298867893008`"}], ",", "0.17093309221589567`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9240505651557291`"}], ",", 
     RowBox[{"-", "1.82166507188885`"}], ",", "0.1798135060884163`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.0617495125649359`"}], ",", 
     RowBox[{"-", "1.2213113055517373`"}], ",", "0.17702634004688764`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.3737334343760965`"}], ",", 
     RowBox[{"-", "2.691899191918357`"}], ",", "0.2064103281220571`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0374515770058514`"}], ",", 
     RowBox[{"-", "1.777757631669598`"}], ",", "0.20971354279555723`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.0316044303058174`"}], ",", 
     RowBox[{"-", "2.8247485226399447`"}], ",", "0.17321164805168648`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.1919709459186112`"}], ",", 
     RowBox[{"-", "1.3951429449143415`"}], ",", "0.3862384297108365`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.814063583936894`"}], ",", 
     RowBox[{"-", "2.8473758445951955`"}], ",", "0.1377555441436993`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.591682722672434`"}], ",", 
     RowBox[{"-", "2.864501178210246`"}], ",", "0.23479355009802774`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0640299998793146`"}], ",", 
     RowBox[{"-", "2.259400254492525`"}], ",", "0.1336343928953383`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.069331154893534`"}], ",", 
     RowBox[{"-", "2.7379774978390796`"}], ",", "0.3181919749133119`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.4256362122058936`"}], ",", 
     RowBox[{"-", "2.6122667883112016`"}], ",", "0.2509573674335884`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.4505125964286294`"}], ",", 
     RowBox[{"-", "2.4756058412167468`"}], ",", "0.25314676876819875`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0014263713509326`"}], ",", 
     RowBox[{"-", "2.1223813050456273`"}], ",", "0.18134147208405108`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.0282195152942757`"}], ",", 
     RowBox[{"-", "2.518241791947818`"}], ",", "0.46279634387931123`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.4582893658871239`"}], ",", 
     RowBox[{"-", "1.3332701812216823`"}], ",", "0.15171204806516606`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.1820708952868766`"}], ",", 
     RowBox[{"-", "3.47242622103734`"}], ",", "0.2894529885636125`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.3594362232756527`"}], ",", 
     RowBox[{"-", "3.1634183674495326`"}], ",", "0.30192602710369476`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.273198516707776`"}], ",", 
     RowBox[{"-", "2.360079598316194`"}], ",", "0.16227465713327072`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2023459834541594`"}], ",", 
     RowBox[{"-", "1.461201808902071`"}], ",", "0.30757077028865054`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.8799593071920673`"}], ",", 
     RowBox[{"-", "2.8886551536127643`"}], ",", "0.13251016378569194`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.110221254322642`"}], ",", 
     RowBox[{"-", "2.4286259177208858`"}], ",", "0.24432086797488986`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.1409551391080244`"}], ",", 
     RowBox[{"-", "1.2363478690807608`"}], ",", "0.14972477638543394`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.757314862094801`"}], ",", 
     RowBox[{"-", "3.2928328362857124`"}], ",", "0.44667303828321275`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.873256267938004`"}], ",", 
     RowBox[{"-", "2.5340145694920877`"}], ",", "0.38670960903788343`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.958119834719342`"}], ",", 
     RowBox[{"-", "3.594019098742083`"}], ",", "0.35116851817322997`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.011362880157096`"}], ",", 
     RowBox[{"-", "2.8166052651821047`"}], ",", "0.22944648779833657`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.5001603587002417`"}], ",", 
     RowBox[{"-", "1.9552896352722167`"}], ",", "0.331816622781749`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.1380548574532705`"}], ",", 
     RowBox[{"-", "3.733320319279217`"}], ",", "0.4969659886497134`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.0500562195050378`"}], ",", 
     RowBox[{"-", "1.498078353294592`"}], ",", "0.42107488000041443`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.9139589467304607`"}], ",", 
     RowBox[{"-", "2.596729597832007`"}], ",", "0.32779205250358484`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.4118205473153038`"}], ",", 
     RowBox[{"-", "1.431924743966417`"}], ",", "0.21953412030489391`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.95440885286236`"}], ",", 
     RowBox[{"-", "2.9826275820143353`"}], ",", "0.12455937876326006`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.6510665052994216`"}], ",", 
     RowBox[{"-", "2.35455621937674`"}], ",", "0.42760010445808716`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.8383060838072642`"}], ",", 
     RowBox[{"-", "1.6224283953198961`"}], ",", "0.27130781701159445`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.2331523039317482`"}], ",", 
     RowBox[{"-", "2.0627219237090864`"}], ",", "0.2555359041249296`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7182683359530375`"}], ",", 
     RowBox[{"-", "2.7874819935635693`"}], ",", "0.15538005305872096`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.2746710762594033`"}], ",", 
     RowBox[{"-", "2.02355782911737`"}], ",", "0.21034107344395234`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.2733648386925838`"}], ",", 
     RowBox[{"-", "2.437560601801981`"}], ",", "0.4421216130765764`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1626891748902994`"}], ",", 
     RowBox[{"-", "2.0473076853525867`"}], ",", "0.15917030199621`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.650537371161189`"}], ",", 
     RowBox[{"-", "1.7787141144354135`"}], ",", "0.2443454022813938`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.1365945418896721`"}], ",", 
     RowBox[{"-", "1.2575898205410914`"}], ",", "0.17908250385424543`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.3080582130606784`"}], ",", 
     RowBox[{"-", "2.4207402455542297`"}], ",", "0.21772518691892226`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.0885067501309114`"}], ",", 
     RowBox[{"-", "2.94660422018673`"}], ",", "0.13278357501968474`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0131599376264857`"}], ",", 
     RowBox[{"-", "2.2245228040001623`"}], ",", "0.2932462550222935`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.8348597920688643`"}], ",", 
     RowBox[{"-", "2.2437217228127313`"}], ",", "0.3643214001705258`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.544200737734242`"}], ",", 
     RowBox[{"-", "2.8591004504281954`"}], ",", "0.37398563276386837`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.521293293515738`"}], ",", 
     RowBox[{"-", "2.5826915567650635`"}], ",", "0.15557762247983326`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.3241736834096076`"}], ",", 
     RowBox[{"-", "2.294085202258271`"}], ",", "0.1604170678038642`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.7340162389758447`"}], ",", 
     RowBox[{"-", "1.9127246007206868`"}], ",", "0.15856834424995034`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.8539575168817375`"}], ",", 
     RowBox[{"-", "1.9123828820958209`"}], ",", "0.1719109626688543`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1048395446750088`"}], ",", 
     RowBox[{"-", "2.2979834815421527`"}], ",", "0.26771225211207395`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.952689176029899`"}], ",", 
     RowBox[{"-", "2.8363217333637367`"}], ",", "0.17054337693912597`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.5411808264715219`"}], ",", 
     RowBox[{"-", "1.4862172359339458`"}], ",", "0.1394070045068586`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.814221232047535`"}], ",", 
     RowBox[{"-", "2.609707363450393`"}], ",", "0.2642410921076888`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.5285461133840186`"}], ",", 
     RowBox[{"-", "2.78645478845944`"}], ",", "0.21398739494355298`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1913375931097825`"}], ",", 
     RowBox[{"-", "2.1040214033111084`"}], ",", "0.19873019966957126`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.6835333866290907`"}], ",", 
     RowBox[{"-", "3.498290957334191`"}], ",", "0.23052408942003122`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1457496061260297`"}], ",", 
     RowBox[{"-", "2.60046146678981`"}], ",", "0.4318026822294109`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.0565671181188865`"}], ",", 
     RowBox[{"-", "2.542719301514128`"}], ",", "0.4291190451849804`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.1077317153304014`"}], ",", 
     RowBox[{"-", "1.202206917870946`"}], ",", "0.17829197334001437`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.8443055980381835`"}], ",", 
     RowBox[{"-", "2.084190639578871`"}], ",", "0.20830174853791686`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.4648958353707653`"}], ",", 
     RowBox[{"-", "2.7538201375060405`"}], ",", "0.3230793698354854`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.542890841782037`"}], ",", 
     RowBox[{"-", "1.7638990647586439`"}], ",", "0.2566367052796702`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0277404984492904`"}], ",", 
     RowBox[{"-", "1.9436517226182048`"}], ",", "0.24362293119412345`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.295095284737405`"}], ",", 
     RowBox[{"-", "1.8676861634800346`"}], ",", "0.39028858502600106`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.4972092249656637`"}], ",", 
     RowBox[{"-", "2.4636453355593284`"}], ",", "0.18528918304100886`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0834595120350223`"}], ",", 
     RowBox[{"-", "2.018093984736141`"}], ",", "0.30987898110549805`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.8100517264073053`"}], ",", 
     RowBox[{"-", "1.6576247789596765`"}], ",", "0.17378789412809215`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.6772607818904013`"}], ",", 
     RowBox[{"-", "2.572894904114901`"}], ",", "0.2070152154018366`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.1611530901898215`"}], ",", 
     RowBox[{"-", "3.1609349807246456`"}], ",", "0.27318976525344707`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.1658466088092159`"}], ",", 
     RowBox[{"-", "1.247304662495801`"}], ",", "0.12271165345555628`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.6377205409905283`"}], ",", 
     RowBox[{"-", "1.1548873101329216`"}], ",", "0.44535720440801013`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.580553238258253`"}], ",", 
     RowBox[{"-", "3.4987041970240385`"}], ",", "0.23880644731629205`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9200999178918784`"}], ",", 
     RowBox[{"-", "1.0915585177813392`"}], ",", "0.24669925770808368`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.036813052438891`"}], ",", 
     RowBox[{"-", "3.4986652421807145`"}], ",", "0.3290117046365321`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.753081229975076`"}], ",", 
     RowBox[{"-", "2.8029327281784684`"}], ",", "0.09085565195066765`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.246348327862958`"}], ",", 
     RowBox[{"-", "2.9844263024926`"}], ",", "0.35267454759491357`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9805869302767483`"}], ",", 
     RowBox[{"-", "2.1810696583878535`"}], ",", "0.3033884904518529`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.6235617865259395`"}], ",", 
     RowBox[{"-", "2.535557222857991`"}], ",", "0.12894367846396446`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.288768471273212`"}], ",", 
     RowBox[{"-", "3.2651502436553295`"}], ",", "0.15854528738619328`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.6085759944569897`"}], ",", 
     RowBox[{"-", "2.4585888148928468`"}], ",", "0.19991695528542133`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5816901316977806`"}], ",", 
     RowBox[{"-", "1.0380754642919638`"}], ",", "0.35854239036650803`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1492796721908647`"}], ",", 
     RowBox[{"-", "2.3161435066990164`"}], ",", "0.30346440506820743`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.7228955699790829`"}], ",", 
     RowBox[{"-", "1.8566154607965117`"}], ",", "0.18189264647525624`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9535947635417147`"}], ",", 
     RowBox[{"-", "1.4068380621949048`"}], ",", "0.22387572733733554`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.456279653741267`"}], ",", 
     RowBox[{"-", "3.883271521276932`"}], ",", "0.5885320352617869`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.3339358439843125`"}], ",", 
     RowBox[{"-", "2.591726232396769`"}], ",", "0.18797835420816816`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7294918467340534`"}], ",", 
     RowBox[{"-", "2.8173450487058753`"}], ",", "0.1658286226945285`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.1292019965777838`"}], ",", 
     RowBox[{"-", "1.2321581157357757`"}], ",", "0.1789618342119321`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.3037787661901432`"}], ",", 
     RowBox[{"-", "1.5851814359371843`"}], ",", "0.32938044547424605`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7235728987357857`"}], ",", 
     RowBox[{"-", "2.81782594567644`"}], ",", "0.1806591400877971`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9726148832794022`"}], ",", 
     RowBox[{"-", "1.9294125328572684`"}], ",", "0.1341765128100796`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.942539460985966`"}], ",", 
     RowBox[{"-", "2.759449443973683`"}], ",", "0.18274446255790883`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.4565529297476747`"}], ",", 
     RowBox[{"-", "3.1209493489208615`"}], ",", "0.3166975111297329`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.401298724106231`"}], ",", 
     RowBox[{"-", "2.771859173037343`"}], ",", "0.32389513161912603`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.236988921501675`"}], ",", 
     RowBox[{"-", "3.4302443741743143`"}], ",", "0.34525667857001974`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.722152833698788`"}], ",", 
     RowBox[{"-", "2.973206432890358`"}], ",", "0.20833030905244268`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.5913808238504437`"}], ",", 
     RowBox[{"-", "1.4633150125585663`"}], ",", "0.27654553523931363`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.781842790278421`"}], ",", 
     RowBox[{"-", "2.6115229349697`"}], ",", "0.24245469029641975`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.6964798041401727`"}], ",", 
     RowBox[{"-", "3.125442263456083`"}], ",", "0.48572236125146595`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2211347274050246`"}], ",", 
     RowBox[{"-", "1.1038725573616723`"}], ",", "0.2503304094068779`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9113824523376886`"}], ",", 
     RowBox[{"-", "1.8576480042818604`"}], ",", "0.12869284986186838`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.665478071547456`"}], ",", 
     RowBox[{"-", "1.7542062602321102`"}], ",", "0.1527192546578329`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.950197320535693`"}], ",", 
     RowBox[{"-", "3.012686009372683`"}], ",", "0.2690074249009792`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.149064046324306`"}], ",", 
     RowBox[{"-", "2.1040911064365773`"}], ",", "0.13850771959234429`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.80130141525066`"}], ",", 
     RowBox[{"-", "2.5713573163513606`"}], ",", "0.2576317483852512`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9390361178869782`"}], ",", 
     RowBox[{"-", "1.8619808892999452`"}], ",", "0.2519921032956156`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.3241077961483065`"}], ",", 
     RowBox[{"-", "3.106227188775931`"}], ",", "0.2062409064489614`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.6108665485060056`"}], ",", 
     RowBox[{"-", "2.2796689009582924`"}], ",", "0.2620327235118439`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.2987538947032866`"}], ",", 
     RowBox[{"-", "2.4020598915765725`"}], ",", "0.15414182817289332`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.626646345751855`"}], ",", 
     RowBox[{"-", "3.2407753967879547`"}], ",", "0.3572182812085686`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.0514135943576965`"}], ",", 
     RowBox[{"-", "2.843630034612831`"}], ",", "0.2038055047856899`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.7014678903682787`"}], ",", 
     RowBox[{"-", "1.8910503563678163`"}], ",", "0.20997383064144248`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.524949497345547`"}], ",", 
     RowBox[{"-", "2.373461151888557`"}], ",", "0.17945721035854018`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.945753880415252`"}], ",", 
     RowBox[{"-", "3.00108623876031`"}], ",", "0.2219552009481381`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9382787710334402`"}], ",", 
     RowBox[{"-", "1.8958715361205738`"}], ",", "0.17853692924282252`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.3753427076762832`"}], ",", 
     RowBox[{"-", "2.1085017363429643`"}], ",", "0.43710498776328033`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.8081821610694333`"}], ",", 
     RowBox[{"-", "3.4024826384074793`"}], ",", "0.4235225858814849`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.2659874142665286`"}], ",", 
     RowBox[{"-", "1.6445560880794758`"}], ",", "0.44309842309913505`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.536805537084552`"}], ",", 
     RowBox[{"-", "1.673930937517291`"}], ",", "0.28026462811469716`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.175054634094643`"}], ",", 
     RowBox[{"-", "2.207311578678443`"}], ",", "0.20949334853720003`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.2276095507328586`"}], ",", 
     RowBox[{"-", "3.368815562177496`"}], ",", "0.3296053069575576`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.957317162420805`"}], ",", 
     RowBox[{"-", "2.054314855217533`"}], ",", "0.13299933551318543`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.1577727048318107`"}], ",", 
     RowBox[{"-", "2.924701356839728`"}], ",", "0.3315183418014457`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.7620022450104076`"}], ",", 
     RowBox[{"-", "1.8475360528231362`"}], ",", "0.1547872238252136`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.653769904931855`"}], ",", 
     RowBox[{"-", "2.789968625066846`"}], ",", "0.21581249155649496`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.85178634144325`"}], ",", 
     RowBox[{"-", "2.8918423081935054`"}], ",", "0.11512181543185845`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.5387762505249283`"}], ",", 
     RowBox[{"-", "2.3551884038706725`"}], ",", "0.1597616529801716`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.843904164266386`"}], ",", 
     RowBox[{"-", "1.3450685167250545`"}], ",", "0.31762805804112026`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1183514729034654`"}], ",", 
     RowBox[{"-", "2.058660503963763`"}], ",", "0.2156802628568871`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.436144007731041`"}], ",", 
     RowBox[{"-", "1.7428947559340975`"}], ",", "0.2289664094039746`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.5964012768069344`"}], ",", 
     RowBox[{"-", "1.5197537770285199`"}], ",", "0.2307053059759594`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.885479715221432`"}], ",", 
     RowBox[{"-", "1.8778043372290378`"}], ",", "0.1345085025225044`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.709713025513575`"}], ",", 
     RowBox[{"-", "2.7527460296198303`"}], ",", "0.12238313849406317`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.5109357192409476`"}], ",", 
     RowBox[{"-", "2.8561097580990826`"}], ",", "0.25732765554932213`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.098081263678752`"}], ",", 
     RowBox[{"-", "1.899802625578264`"}], ",", "0.21346819485470214`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.602267783018035`"}], ",", 
     RowBox[{"-", "1.3988763131267812`"}], ",", "0.22831335850530887`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.6638146270975036`"}], ",", 
     RowBox[{"-", "1.7664641759003883`"}], ",", "0.2537968079409975`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.0772015129318868`"}], ",", 
     RowBox[{"-", "1.4307297107356796`"}], ",", "0.3497526521050675`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7549373955187453`"}], ",", 
     RowBox[{"-", "2.6400394810330043`"}], ",", "0.25790182067553785`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.479864682599629`"}], ",", 
     RowBox[{"-", "2.6839620001060385`"}], ",", "0.20276484562210056`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.69770557881176`"}], ",", 
     RowBox[{"-", "2.9185131650023792`"}], ",", "0.28474445916928026`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2949453146233938`"}], ",", 
     RowBox[{"-", "1.3403358091500885`"}], ",", "0.13863271841190014`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.1989999901509663`"}], ",", 
     RowBox[{"-", "2.846161409928972`"}], ",", "0.2960120395927561`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.46785008355726`"}], ",", 
     RowBox[{"-", "2.4930551434926778`"}], ",", "0.1440742842131468`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.262772304628116`"}], ",", 
     RowBox[{"-", "3.1533477206138323`"}], ",", "0.15333026349886428`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.0149769601533443`"}], ",", 
     RowBox[{"-", "1.9517575838349914`"}], ",", "0.14905311957232992`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.3482123232837777`"}], ",", 
     RowBox[{"-", "2.1467136747685847`"}], ",", "0.2208929682236461`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1661442128588955`"}], ",", 
     RowBox[{"-", "2.0271972234012408`"}], ",", "0.21250976957876894`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.269466511135165`"}], ",", 
     RowBox[{"-", "3.2728622653202706`"}], ",", "0.17910402667407074`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.006640828534197`"}], ",", 
     RowBox[{"-", "2.808214930167511`"}], ",", "0.3551987935427403`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.6867485320537914`"}], ",", 
     RowBox[{"-", "1.550039482509601`"}], ",", "0.30346948752947733`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.3877360141264714`"}], ",", 
     RowBox[{"-", "1.9273756442505052`"}], ",", "0.3469130086790017`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.165398781133524`"}], ",", 
     RowBox[{"-", "2.0397255932131473`"}], ",", "0.18539632759306704`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.7573567288112952`"}], ",", 
     RowBox[{"-", "1.9141647291965533`"}], ",", "0.16208415182710717`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.4352519764305685`"}], ",", 
     RowBox[{"-", "3.3143025142282974`"}], ",", "0.1671509530250747`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.1691503513099413`"}], ",", 
     RowBox[{"-", "2.1695024688721576`"}], ",", "0.3066104209799578`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.815887852043558`"}], ",", 
     RowBox[{"-", "1.6216177751683822`"}], ",", "0.22309358490439526`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.30413350906229`"}], ",", 
     RowBox[{"-", "2.328099419697503`"}], ",", "0.15196303007466716`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.701786937116347`"}], ",", 
     RowBox[{"-", "1.6539706589508845`"}], ",", "0.20812926690889513`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.831127223144348`"}], ",", 
     RowBox[{"-", "1.9309920774957938`"}], ",", "0.24342548926299604`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.5150595469067576`"}], ",", 
     RowBox[{"-", "2.07603608565759`"}], ",", "0.402617420900946`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.5365501539847872`"}], ",", 
     RowBox[{"-", "3.5095354706724176`"}], ",", "0.21573002737570315`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.0699541104387413`"}], ",", 
     RowBox[{"-", "3.203105165755266`"}], ",", "0.14390833630565464`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7205621675864418`"}], ",", 
     RowBox[{"-", "2.7489596618664236`"}], ",", "0.1631389024757917`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.3894430010754864`"}], ",", 
     RowBox[{"-", "2.2611853844205805`"}], ",", "0.22922694988049358`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9555440876736012`"}], ",", 
     RowBox[{"-", "2.1952358189573675`"}], ",", "0.23703118851094307`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.513299540798506`"}], ",", 
     RowBox[{"-", "2.411003821535837`"}], ",", "0.25068094746656683`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.2026265938006944`"}], ",", 
     RowBox[{"-", "2.192617354269934`"}], ",", "0.27156964479415013`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.7886601610330888`"}], ",", 
     RowBox[{"-", "2.149251480939499`"}], ",", "0.4069432027973003`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.0954929706672867`"}], ",", 
     RowBox[{"-", "2.3265450902200993`"}], ",", "0.47923323447277855`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.974241031379715`"}], ",", 
     RowBox[{"-", "2.9840447007627304`"}], ",", "0.18852658324951174`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.8979337642157876`"}], ",", 
     RowBox[{"-", "2.1227206183577927`"}], ",", "0.32194234374028385`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.6858987971555437`"}], ",", 
     RowBox[{"-", "2.7339628381823013`"}], ",", "0.11724843982406145`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.8667485844753542`"}], ",", 
     RowBox[{"-", "1.751587037924479`"}], ",", "0.17583166927380187`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.878408679643283`"}], ",", 
     RowBox[{"-", "2.8811101216809396`"}], ",", "0.14025990139400954`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.2381502044229378`"}], ",", 
     RowBox[{"-", "2.733375656245344`"}], ",", "0.2792723521601391`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8097537345065737`*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"e92a8a51-aef7-45ae-a882-7f8796d19ee4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ensemblePredictionResultsValidationScaleVals", "=", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"validationSet", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"-", "2"}]}], "]"}], "]"}], ">", "0.5"}], ",", 
       "tio2ScaleVal", ",", "goldScaleVal"}], "]"}], " ", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", " ", "validationSet", "]"}]}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"ensemblePredictionResultsScaleVals", "=", 
  RowBox[{"Table", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"trainingSet", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"-", "2"}]}], "]"}], "]"}], ">", "0.5"}], ",", 
      "tio2ScaleVal", ",", "goldScaleVal"}], "]"}], " ", 
    "\[IndentingNewLine]", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "trainingSet", "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8045849738954487`*^9, 3.8045849868873453`*^9}, {
  3.804585112646468*^9, 3.8045852717903943`*^9}, {3.8045939786329446`*^9, 
  3.804593983644357*^9}, {3.8045969475976305`*^9, 3.8045969845607204`*^9}, {
  3.804597105646654*^9, 3.8045971133605003`*^9}, {3.8051829544055386`*^9, 
  3.8051829642467203`*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"a7721b20-c2b0-44a7-91c0-0754ac37fbad"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`"}], "}"}]], "Output",
 CellChangeTimes->{3.8097537910563188`*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"7d3481d5-e7d6-4dcf-9c44-354664ff18bf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "72.08829`", ",", "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "8.775015`", ",", 
   "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", "72.08829`", ",", 
   "72.08829`", ",", "8.775015`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "72.08829`", ",", "8.775015`", ",", "72.08829`", ",", 
   "8.775015`", ",", "8.775015`", ",", "72.08829`"}], "}"}]], "Output",
 CellChangeTimes->{3.809753791107095*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"fb3ea7ec-3715-486a-892e-6601a84e1982"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ensemblePredictionResults", " ", "=", " ", 
  RowBox[{
  "ensemblePredictionResultsScaleVals", "*", 
   "ensemblePredictionResultsUnscaled"}]}], "\[IndentingNewLine]", 
 RowBox[{"ensemblePredictionResultsValidation", " ", "=", " ", 
  RowBox[{
  "ensemblePredictionResultsValidationScaleVals", "*", 
   "ensemblePredictionResultsValidationUnscaled"}]}], \
"\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8045849738954487`*^9, 3.8045849868873453`*^9}, {
  3.804585112646468*^9, 3.8045852717903943`*^9}, {3.8045939786329446`*^9, 
  3.804593983644357*^9}, {3.8045969475976305`*^9, 3.8045969845607204`*^9}, {
  3.804597105646654*^9, 3.8045971133605003`*^9}, {3.8051829544055386`*^9, 
  3.8051829642467203`*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"3c38b259-4e51-420e-9b7e-226d4fcb8a36"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.122592040000004`"}], ",", 
     RowBox[{"-", "19.716780398996427`"}], ",", "2.323460809246048`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13.29428828`"}], ",", 
     RowBox[{"-", "13.61282082678354`"}], ",", "2.151982457665049`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "21.925352060000005`"}], ",", 
     RowBox[{"-", "21.17176404414137`"}], ",", "1.139984728898544`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "263.1578615`"}], ",", 
     RowBox[{"-", "264.00993685307793`"}], ",", "8.955007139105541`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "199.214`"}], ",", 
     RowBox[{"-", "189.51523432134726`"}], ",", "16.03584637796008`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.770776970000002`"}], ",", 
     RowBox[{"-", "16.23149722304764`"}], ",", "1.8906265620682818`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "202.8522675`"}], ",", 
     RowBox[{"-", "206.67256735962857`"}], ",", "8.969211699518636`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "197.2202495`"}], ",", 
     RowBox[{"-", "161.03769430604612`"}], ",", "26.79750055027042`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "253.7709554`"}], ",", 
     RowBox[{"-", "252.16001696943238`"}], ",", "8.368397734279824`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "264.7122498`"}], ",", 
     RowBox[{"-", "266.88754866450876`"}], ",", "8.24042774614275`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.0738179`"}], ",", 
     RowBox[{"-", "19.015665925820088`"}], ",", "2.28863664211138`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.96318187`"}], ",", 
     RowBox[{"-", "24.589661522599314`"}], ",", "1.5565073428812746`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.002258020000003`"}], ",", 
     RowBox[{"-", "25.732099312069213`"}], ",", "1.2845343498279038`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "156.64292209999996`"}], ",", 
     RowBox[{"-", "182.28962614695624`"}], ",", "26.84140865316483`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "253.9884788`"}], ",", 
     RowBox[{"-", "254.87474754930884`"}], ",", "11.291412092709002`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "203.44583779999996`"}], ",", 
     RowBox[{"-", "206.89391611163813`"}], ",", "6.625059206524913`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.931329430000002`"}], ",", 
     RowBox[{"-", "16.65502766501253`"}], ",", "3.334888326406188`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "140.2901259`"}], ",", 
     RowBox[{"-", "146.04360235982125`"}], ",", "9.322439195895665`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "203.6664668`"}], ",", 
     RowBox[{"-", "186.8988791731109`"}], ",", "15.022337395992443`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.24628378`"}], ",", 
     RowBox[{"-", "18.107443148144885`"}], ",", "1.3013596215721226`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.80138018`"}], ",", 
     RowBox[{"-", "15.066744072410529`"}], ",", "1.3987743359896054`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.90194371`"}], ",", 
     RowBox[{"-", "19.132295954672138`"}], ",", "1.6096037312059823`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.40654202`"}], ",", 
     RowBox[{"-", "13.358825950741512`"}], ",", "1.9562963953676988`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "311.33191`"}], ",", 
     RowBox[{"-", "279.88579864512764`"}], ",", "37.91093146700443`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "170.54968019999998`"}], ",", 
     RowBox[{"-", "163.6592149433442`"}], ",", "10.206869826011442`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "190.5494332`"}], ",", 
     RowBox[{"-", "209.09674842627385`"}], ",", "25.06743426735547`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "163.9016831`"}], ",", 
     RowBox[{"-", "183.09291531725307`"}], ",", "24.905031595155357`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "215.2738442`"}], ",", 
     RowBox[{"-", "194.6391494797123`"}], ",", "12.465575921572977`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "191.7750655`"}], ",", 
     RowBox[{"-", "191.94596016715306`"}], ",", "19.99173825927886`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "138.1443354`"}], ",", 
     RowBox[{"-", "160.82116956950384`"}], ",", "24.679386832066886`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "145.0720654`"}], ",", 
     RowBox[{"-", "165.24290941933268`"}], ",", "21.402217844041186`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "192.5885865`"}], ",", 
     RowBox[{"-", "213.66797477424302`"}], ",", "29.375664942816528`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "21.942781440000005`"}], ",", 
     RowBox[{"-", "21.75293909318461`"}], ",", "1.0461510887189407`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.15637194`"}], ",", 
     RowBox[{"-", "15.50003103643645`"}], ",", "1.709741463078312`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "261.4747844`"}], ",", 
     RowBox[{"-", "243.94095899210942`"}], ",", "17.859861046544186`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "229.6294085`"}], ",", 
     RowBox[{"-", "207.71568314737752`"}], ",", "13.04323803838782`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "245.2853296`"}], ",", 
     RowBox[{"-", "226.37109824037307`"}], ",", "25.40036541681436`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "197.2131662`"}], ",", 
     RowBox[{"-", "209.6059086158994`"}], ",", "14.714555597238475`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "227.8414479`"}], ",", 
     RowBox[{"-", "203.91549453594155`"}], ",", "20.8272524381046`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "7.868570001000001`"}], ",", 
     RowBox[{"-", "11.921312901652414`"}], ",", "2.617508719759881`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.197738360000002`"}], ",", 
     RowBox[{"-", "21.240941374767914`"}], ",", "1.918219793935886`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "229.141083`"}], ",", 
     RowBox[{"-", "231.3466047530391`"}], ",", "14.364166878780814`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "164.7313033`"}], ",", 
     RowBox[{"-", "152.6382830071093`"}], ",", "13.157604713332075`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.01398646`"}], ",", 
     RowBox[{"-", "18.919432455269227`"}], ",", "1.6553605561418065`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.61293568`"}], ",", 
     RowBox[{"-", "19.57260898234595`"}], ",", "2.925999665432167`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "198.0982712`"}], ",", 
     RowBox[{"-", "191.58039119784718`"}], ",", "20.21519346676209`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "157.5460241`"}], ",", 
     RowBox[{"-", "179.41575052167374`"}], ",", "24.803349944238697`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "188.8140786`"}], ",", 
     RowBox[{"-", "203.76480627851245`"}], ",", "16.6165146125598`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.359806400000002`"}], ",", 
     RowBox[{"-", "15.671669505674123`"}], ",", "1.7399431269955157`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.90265974`"}], ",", 
     RowBox[{"-", "21.670400023931656`"}], ",", "2.0848250848756797`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.94159622`"}], ",", 
     RowBox[{"-", "10.483690398752922`"}], ",", "1.6625409577080166`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "257.6108399`"}], ",", 
     RowBox[{"-", "255.72611886013294`"}], ",", "10.788312344741694`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "174.46814`"}], ",", 
     RowBox[{"-", "198.74800583723112`"}], ",", "18.901113581303346`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.17064523`"}], ",", 
     RowBox[{"-", "23.808209934292037`"}], ",", "3.1229974654088912`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.685667400000002`"}], ",", 
     RowBox[{"-", "11.312715010820941`"}], ",", "2.268568158392362`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13.389810530000002`"}], ",", 
     RowBox[{"-", "15.5206069126093`"}], ",", "1.5885000931275057`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "235.96036999999998`"}], ",", 
     RowBox[{"-", "249.9414993288295`"}], ",", "14.032750206771802`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6.600847048000001`"}], ",", 
     RowBox[{"-", "11.153112823775574`"}], ",", "3.331540343810955`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "183.2164933`"}], ",", 
     RowBox[{"-", "173.05465261247394`"}], ",", "13.92632331882885`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "244.0067091`"}], ",", 
     RowBox[{"-", "238.13954012868453`"}], ",", "11.654993305579561`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "25.97423007`"}], ",", 
     RowBox[{"-", "26.258877446711725`"}], ",", "1.1703674260622015`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.53060212`"}], ",", 
     RowBox[{"-", "16.946947148742026`"}], ",", "3.297383650914062`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "158.74572139999998`"}], ",", 
     RowBox[{"-", "163.53182546877983`"}], ",", "8.649855685940535`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "24.23603156`"}], ",", 
     RowBox[{"-", "23.800512660897596`"}], ",", "1.9072862008079094`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "200.5470822`"}], ",", 
     RowBox[{"-", "210.14843063983193`"}], ",", "15.329655672440655`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.71263041`"}], ",", 
     RowBox[{"-", "17.655117799206117`"}], ",", "3.3645087550011854`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.831368790000003`"}], ",", 
     RowBox[{"-", "19.7670725756887`"}], ",", "1.4791621317249535`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.00780319`"}], ",", 
     RowBox[{"-", "20.63364472460759`"}], ",", "1.6569484824996032`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.46960909`"}], ",", 
     RowBox[{"-", "20.15681164882372`"}], ",", "2.628163299360846`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.92874242`"}], ",", 
     RowBox[{"-", "17.80386013534598`"}], ",", "4.79046313879115`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "176.571878`"}], ",", 
     RowBox[{"-", "196.3774287627301`"}], ",", "18.91807600788847`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "193.7626921`"}], ",", 
     RowBox[{"-", "217.79451188462608`"}], ",", "31.865775945715228`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.94605626`"}], ",", 
     RowBox[{"-", "19.71093412457734`"}], ",", "2.8995464679070775`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.26283108`"}], ",", 
     RowBox[{"-", "26.47635259392767`"}], ",", "1.2363167353621305`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "147.5403296`"}], ",", 
     RowBox[{"-", "160.1781108132016`"}], ",", "17.776344856003025`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.83608012`"}], ",", 
     RowBox[{"-", "19.19171027968257`"}], ",", "3.228443273757982`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.43103003`"}], ",", 
     RowBox[{"-", "11.45206381379255`"}], ",", "1.671105224347088`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.740878590000001`"}], ",", 
     RowBox[{"-", "18.480416283716274`"}], ",", "2.432799486059312`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.28176018`"}], ",", 
     RowBox[{"-", "15.834609561341756`"}], ",", "1.5543488075679448`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.50387992`"}], ",", 
     RowBox[{"-", "12.01356167032337`"}], ",", "1.025450688750836`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "198.1780966`"}], ",", 
     RowBox[{"-", "201.64138327879715`"}], ",", "8.290904810505749`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "196.84942059999997`"}], ",", 
     RowBox[{"-", "218.60228729209666`"}], ",", "18.464530764928757`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "222.213379`"}], ",", 
     RowBox[{"-", "237.49192128704502`"}], ",", "17.28057921271668`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "140.4296433`"}], ",", 
     RowBox[{"-", "155.31121506863934`"}], ",", "24.099346998764386`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.53154494`"}], ",", 
     RowBox[{"-", "19.372600842073187`"}], ",", "2.4170483626824515`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.51894907`"}], ",", 
     RowBox[{"-", "12.822234656923351`"}], ",", "2.0340266795211015`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "24.078960020000004`"}], ",", 
     RowBox[{"-", "25.782363690244786`"}], ",", "1.4216763148805638`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "121.3942897`"}], ",", 
     RowBox[{"-", "136.36308096321468`"}], ",", "17.426219735878686`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "178.9523159`"}], ",", 
     RowBox[{"-", "179.73882040880832`"}], ",", "10.883353629137474`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "191.6546589`"}], ",", 
     RowBox[{"-", "199.53599187121227`"}], ",", "15.856159543579384`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.92335885`"}], ",", 
     RowBox[{"-", "19.617470538296264`"}], ",", "2.621795208569026`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "169.8586866`"}], ",", 
     RowBox[{"-", "188.636384882625`"}], ",", "15.050877551185101`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "167.7610048`"}], ",", 
     RowBox[{"-", "183.040046835214`"}], ",", "20.270752851415377`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "195.3374268`"}], ",", 
     RowBox[{"-", "194.95950374562463`"}], ",", "10.890261620746795`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "23.01166885`"}], ",", 
     RowBox[{"-", "23.495449742620174`"}], ",", "1.065186233183925`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "142.4023942`"}], ",", 
     RowBox[{"-", "159.52914307925096`"}], ",", "19.03150078688165`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "186.443977`"}], ",", 
     RowBox[{"-", "203.1811062659203`"}], ",", "15.558876652381661`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "242.467544`"}], ",", 
     RowBox[{"-", "228.6193368402952`"}], ",", "20.69840508645944`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.996031230000002`"}], ",", 
     RowBox[{"-", "17.38779463433937`"}], ",", "2.1575337471215152`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "169.0825486`"}], ",", 
     RowBox[{"-", "162.39425810014342`"}], ",", "15.2050837616862`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "262.4148731`"}], ",", 
     RowBox[{"-", "257.7755322890022`"}], ",", "10.935769434936487`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.46909494`"}], ",", 
     RowBox[{"-", "19.551881372322768`"}], ",", "4.364354521054573`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "127.6290063`"}], ",", 
     RowBox[{"-", "128.756055866968`"}], ",", "10.475001456645606`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "206.4259915`"}], ",", 
     RowBox[{"-", "190.7773238494553`"}], ",", "14.32919835594786`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "205.9183344`"}], ",", 
     RowBox[{"-", "205.70728126369`"}], ",", "9.48733444279182`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "157.26507809999998`"}], ",", 
     RowBox[{"-", "168.99041102637977`"}], ",", "13.321524701637468`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "269.4395282`"}], ",", 
     RowBox[{"-", "271.32165242717934`"}], ",", "9.338857396039199`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.14196342`"}], ",", 
     RowBox[{"-", "14.175190310212509`"}], ",", "3.561637626744673`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13.06116628`"}], ",", 
     RowBox[{"-", "15.194508401645859`"}], ",", "1.6001666243624486`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.16785021`"}], ",", 
     RowBox[{"-", "11.79489643643592`"}], ",", "3.200502398368643`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.94167053`"}], ",", 
     RowBox[{"-", "17.273835156088463`"}], ",", "3.3081081648451653`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.212622800000002`"}], ",", 
     RowBox[{"-", "17.097418246448633`"}], ",", "2.6933812286261722`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "199.0258256`"}], ",", 
     RowBox[{"-", "204.62174002579044`"}], ",", "15.020828982107002`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "208.1506386`"}], ",", 
     RowBox[{"-", "212.2043366924515`"}], ",", "12.56935408386055`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "237.9916195`"}], ",", 
     RowBox[{"-", "228.5934861192386`"}], ",", "11.96782097003259`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "194.85839919999998`"}], ",", 
     RowBox[{"-", "197.09856169922213`"}], ",", "6.198687404003819`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9.149641981`"}], ",", 
     RowBox[{"-", "10.679646758204825`"}], ",", "1.7568260045211863`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8.88795049`"}], ",", 
     RowBox[{"-", "10.107147454526121`"}], ",", "1.6916119129654024`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.32007868`"}], ",", 
     RowBox[{"-", "25.648844668354197`"}], ",", "1.0282115573191704`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "265.3268835`"}], ",", 
     RowBox[{"-", "263.9547080262316`"}], ",", "10.511159639793831`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "202.0654875`"}], ",", 
     RowBox[{"-", "246.791332545446`"}], ",", "32.960763506817344`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.8209092`"}], ",", 
     RowBox[{"-", "15.555588161122257`"}], ",", "1.2206336170570318`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.26318901`"}], ",", 
     RowBox[{"-", "20.83989575200867`"}], ",", "2.845085971658916`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "27.329169860000004`"}], ",", 
     RowBox[{"-", "24.42575923659803`"}], ",", "2.0964575290119583`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "275.1241365`"}], ",", 
     RowBox[{"-", "278.58315855155183`"}], ",", "10.535131286509262`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "157.8115118`"}], ",", 
     RowBox[{"-", "142.99702225754822`"}], ",", "13.521787024061332`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.10527795`"}], ",", 
     RowBox[{"-", "19.027221833964283`"}], ",", "1.5326164781105793`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "201.14569259999996`"}], ",", 
     RowBox[{"-", "188.59231073190278`"}], ",", "13.72266946599156`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "200.4144209`"}], ",", 
     RowBox[{"-", "198.78464496522366`"}], ",", "7.718553665676196`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.85857321`"}], ",", 
     RowBox[{"-", "18.609635740207313`"}], ",", "2.5644272062845395`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "160.4460193`"}], ",", 
     RowBox[{"-", "155.86026025134788`"}], ",", "11.437258955744937`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.289639940000002`"}], ",", 
     RowBox[{"-", "11.334570477978847`"}], ",", "1.6054061097901542`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.48687999`"}], ",", 
     RowBox[{"-", "19.618291023050418`"}], ",", "1.6809953705399916`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.99772652`"}], ",", 
     RowBox[{"-", "25.690262361721707`"}], ",", "1.4473773202787026`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.613411750000001`"}], ",", 
     RowBox[{"-", "16.445544064584944`"}], ",", "1.775616444502452`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.934760210000004`"}], ",", 
     RowBox[{"-", "19.846257281878238`"}], ",", "2.3335918347557687`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.95419956`"}], ",", 
     RowBox[{"-", "20.63722345119951`"}], ",", "3.345575284121466`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.93946703`"}], ",", 
     RowBox[{"-", "16.270895070024416`"}], ",", "1.4999404481908678`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.883572570000002`"}], ",", 
     RowBox[{"-", "15.985138330800737`"}], ",", "1.5778662131284442`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9.316867899`"}], ",", 
     RowBox[{"-", "10.717025025886077`"}], ",", "1.5534087893065396`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "171.1183842`"}], ",", 
     RowBox[{"-", "194.05440959777619`"}], ",", "14.879767592658007`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.87866815`"}], ",", 
     RowBox[{"-", "15.599849884265197`"}], ",", "1.8402394837341567`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.60237435`"}], ",", 
     RowBox[{"-", "24.787210657393352`"}], ",", "1.5199348098282697`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.459562930000002`"}], ",", 
     RowBox[{"-", "12.24240026876752`"}], ",", "3.389248014289036`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "24.69345016`"}], ",", 
     RowBox[{"-", "24.98576574696051`"}], ",", "1.2088069661941236`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "186.8299757`"}], ",", 
     RowBox[{"-", "206.4969916401619`"}], ",", "16.92586552959615`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "148.7923932`"}], ",", 
     RowBox[{"-", "162.87630077193094`"}], ",", "9.633474869013087`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "221.2628344`"}], ",", 
     RowBox[{"-", "197.37611587769794`"}], ",", "22.937915363223553`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "174.8599667`"}], ",", 
     RowBox[{"-", "188.31384579314653`"}], ",", "18.091087481189074`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "176.6532627`"}], ",", 
     RowBox[{"-", "178.4621918073268`"}], ",", "18.248917679524855`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.562546430000005`"}], ",", 
     RowBox[{"-", "18.623927787494953`"}], ",", "1.5912741376596293`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.57267167`"}], ",", 
     RowBox[{"-", "22.097609497968982`"}], ",", "4.061044859486114`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.79651106`"}], ",", 
     RowBox[{"-", "11.69946583927298`"}], ",", "1.3312754974525531`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "229.3900495`"}], ",", 
     RowBox[{"-", "250.32126842574388`"}], ",", "20.86617098094038`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "242.1760127`"}], ",", 
     RowBox[{"-", "228.04542066402848`"}], ",", "21.76533100039901`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "163.8709939`"}], ",", 
     RowBox[{"-", "170.1341025065013`"}], ",", "11.698102543073789`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.550604040000001`"}], ",", 
     RowBox[{"-", "12.822067791142807`"}], ",", "2.6989381228444627`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "25.27168612`"}], ",", 
     RowBox[{"-", "25.34799230277931`"}], ",", "1.1627786748719036`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.51722316`"}], ",", 
     RowBox[{"-", "21.311228857389537`"}], ",", "2.143919281292678`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.01189846`"}], ",", 
     RowBox[{"-", "10.848971096401712`"}], ",", "1.3138371586538287`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "198.7701134`"}], ",", 
     RowBox[{"-", "237.37468842368696`"}], ",", "32.19989551894135`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "25.21286685`"}], ",", 
     RowBox[{"-", "22.23601585751161`"}], ",", "3.3933826199515624`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "285.3340905`"}], ",", 
     RowBox[{"-", "259.0866910556579`"}], ",", "25.315137976942072`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "217.0840006`"}], ",", 
     RowBox[{"-", "203.04425717197446`"}], ",", "16.540404951887947`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "21.93894465`"}], ",", 
     RowBox[{"-", "17.15769587885823`"}], ",", "2.911695842159189`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "298.3052986`"}], ",", 
     RowBox[{"-", "269.1286778390928`"}], ",", "35.82542830991725`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9.214259077`"}], ",", 
     RowBox[{"-", "13.145660021335344`"}], ",", "3.6949383881268365`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "210.0623176`"}], ",", 
     RowBox[{"-", "187.1937963000971`"}], ",", "23.62996854057365`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.38874648`"}], ",", 
     RowBox[{"-", "12.565161107176467`"}], ",", "1.9264151986872486`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "25.924982000000004`"}], ",", 
     RowBox[{"-", "26.172601771589523`"}], ",", "1.0930104170382884`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "23.26314835`"}], ",", 
     RowBox[{"-", "20.661266143374185`"}], ",", "3.7521973306212817`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.13116346`"}], ",", 
     RowBox[{"-", "14.236833505358018`"}], ",", "2.3807301638939964`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "160.9841309`"}], ",", 
     RowBox[{"-", "148.6980962256985`"}], ",", "18.42114636197012`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "195.9553161`"}], ",", 
     RowBox[{"-", "200.9448103217887`"}], ",", "11.201082325112464`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "163.9771482`"}], ",", 
     RowBox[{"-", "145.87482361718344`"}], ",", "15.163128301338935`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "28.72382556`"}], ",", 
     RowBox[{"-", "21.38963084422141`"}], ",", "3.8796237865711536`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.97762995`"}], ",", 
     RowBox[{"-", "17.96515564858423`"}], ",", "1.3967217875712725`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.483490190000001`"}], ",", 
     RowBox[{"-", "15.60824303488247`"}], ",", "2.1441345702002645`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9.973634154`"}], ",", 
     RowBox[{"-", "11.035369539095385`"}], ",", "1.5714516575585613`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "166.38396979999996`"}], ",", 
     RowBox[{"-", "174.5070248361845`"}], ",", "15.695436414915475`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "27.10169306`"}], ",", 
     RowBox[{"-", "25.856496231201856`"}], ",", "1.165177862551359`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "145.1252574`"}], ",", 
     RowBox[{"-", "160.36204500637686`"}], ",", "21.13962107346105`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "132.2719048`"}], ",", 
     RowBox[{"-", "161.7460622334238`"}], ",", "26.263306748698913`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "183.4070806`"}], ",", 
     RowBox[{"-", "206.10766240959836`"}], ",", "26.959984750515243`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.12438647`"}], ",", 
     RowBox[{"-", "22.663157150986784`"}], ",", "1.365195970924874`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "167.5457065`"}], ",", 
     RowBox[{"-", "165.3766793451029`"}], ",", "11.564192104794625`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "125.0022655`"}], ",", 
     RowBox[{"-", "137.88504570688707`"}], ",", "11.430920785110253`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.26850502`"}], ",", 
     RowBox[{"-", "16.78118847613406`"}], ",", "1.5085212760836366`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "151.7342835`"}], ",", 
     RowBox[{"-", "165.65769963262036`"}], ",", "19.2989184668083`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "25.909891810000005`"}], ",", 
     RowBox[{"-", "24.88876575509279`"}], ",", "1.4965206907914843`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13.523884870000002`"}], ",", 
     RowBox[{"-", "13.041578538578914`"}], ",", "1.2232985556527518`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "202.8723963`"}], ",", 
     RowBox[{"-", "188.12934123154733`"}], ",", "19.048688477775784`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "182.2785655`"}], ",", 
     RowBox[{"-", "200.87076086235277`"}], ",", "15.425985383035382`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "157.9697799`"}], ",", 
     RowBox[{"-", "151.67530508809816`"}], ",", "14.326120265537957`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "265.539623`"}], ",", 
     RowBox[{"-", "252.18581303668478`"}], ",", "16.618087410097143`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.82898498`"}], ",", 
     RowBox[{"-", "22.819088378002583`"}], ",", "3.7890750136033136`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.82142231`"}], ",", 
     RowBox[{"-", "22.312400011575996`"}], ",", "3.7655260582838808`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9.720362418000002`"}], ",", 
     RowBox[{"-", "10.54938373742132`"}], ",", "1.5645147404382262`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "132.9528368`"}], ",", 
     RowBox[{"-", "150.24573924124715`"}], ",", "15.016116856108427`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "177.69012579999998`"}], ",", 
     RowBox[{"-", "198.51818468037533`"}], ",", "23.290239305717726`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13.538890280000002`"}], ",", 
     RowBox[{"-", "15.478240751743071`"}], ",", "2.2519909383796852`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.79345329`"}], ",", 
     RowBox[{"-", "17.055573020750586`"}], ",", "2.137794875572401`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.13949555`"}], ",", 
     RowBox[{"-", "16.388974099829756`"}], ",", "3.4247881879319344`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "180.0195428`"}], ",", 
     RowBox[{"-", "177.5999794069482`"}], ",", "13.357180360923328`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.28238847`"}], ",", 
     RowBox[{"-", "17.708804987469406`"}], ",", "2.719192707385462`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.88323105`"}], ",", 
     RowBox[{"-", "14.545682299742845`"}], ",", "1.5249913777924204`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "23.49300352`"}], ",", 
     RowBox[{"-", "22.577191377031816`"}], ",", "1.816561620379347`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "227.8821207`"}], ",", 
     RowBox[{"-", "227.86639756162268`"}], ",", "19.693783022622416`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.23032148`"}], ",", 
     RowBox[{"-", "10.945117122970592`"}], ",", "1.0767965997473081`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5.596007313000001`"}], ",", 
     RowBox[{"-", "10.134153469726039`"}], ",", "3.908016149038355`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "258.1159602`"}], ",", 
     RowBox[{"-", "252.21560277928603`"}], ",", "17.215148428006582`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8.073890581`"}], ",", 
     RowBox[{"-", "9.578442366909018`"}], ",", "2.1647896868773`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "291.00694999999996`"}], ",", 
     RowBox[{"-", "252.21279459124358`"}], ",", "23.717891177232673`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "198.46491809999998`"}], ",", 
     RowBox[{"-", "202.0586273594206`"}], ",", "6.5496285859587955`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "234.02369969999998`"}], ",", 
     RowBox[{"-", "215.14218877771427`"}], ",", "25.42370506264093`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "142.777125`"}], ",", 
     RowBox[{"-", "157.22958204406453`"}], ",", "21.870757482355405`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "189.1280829`"}], ",", 
     RowBox[{"-", "182.7839843929815`"}], ",", "9.295329286777024`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "237.08169529999998`"}], ",", 
     RowBox[{"-", "235.37909765819606`"}], ",", "11.429258655229242`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.89029348`"}], ",", 
     RowBox[{"-", "21.574153729516954`"}], ",", "1.7542742813839014`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5.104339631`"}], ",", 
     RowBox[{"-", "9.109127770293947`"}], ",", "3.1462148536019634`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "154.93789629999998`"}], ",", 
     RowBox[{"-", "166.96682479253565`"}], ",", "21.876230037234407`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.118434470000002`"}], ",", 
     RowBox[{"-", "16.291828517721303`"}], ",", "1.5961107012100706`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8.367808354`"}], ",", 
     RowBox[{"-", "12.345025098331222`"}], ",", "1.9645128655210293`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "321.24558`"}], ",", 
     RowBox[{"-", "279.93840357455264`"}], ",", "42.42626803224192`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.48032204`"}], ",", 
     RowBox[{"-", "22.742436565175133`"}], ",", "1.6495128778519887`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "196.7643998`"}], ",", 
     RowBox[{"-", "203.09758690117326`"}], ",", "11.954301843103751`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9.908764458`"}], ",", 
     RowBox[{"-", "10.812205947953167`"}], ",", "1.5703927796372172`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.44067823`"}], ",", 
     RowBox[{"-", "13.909990878070332`"}], ",", "2.890318349743191`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "23.89939304`"}], ",", 
     RowBox[{"-", "24.726464940699945`"}], ",", "1.5852866641575207`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.30972519`"}], ",", 
     RowBox[{"-", "16.93062391701052`"}], ",", "1.1774009125561407`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "212.122638`"}], ",", 
     RowBox[{"-", "198.92399175751362`"}], ",", "13.173735812768673`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "249.17699`"}], ",", 
     RowBox[{"-", "224.98390174031826`"}], ",", "22.83018202459841`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "173.10551879999997`"}], ",", 
     RowBox[{"-", "199.81858790507619`"}], ",", "23.349046177747727`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "233.3489961`"}], ",", 
     RowBox[{"-", "247.28045121634648`"}], ",", "24.88896356919237`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "196.2353429`"}], ",", 
     RowBox[{"-", "214.33336756406567`"}], ",", "15.018175734762114`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13.9643906`"}], ",", 
     RowBox[{"-", "12.840611184926608`"}], ",", "2.4266912199080055`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "200.5382898`"}], ",", 
     RowBox[{"-", "188.26022267774687`"}], ",", "17.47814402594849`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "266.4729081`"}], ",", 
     RowBox[{"-", "225.3077882662785`"}], ",", "35.01489443738044`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.715475550000003`"}], ",", 
     RowBox[{"-", "9.686498248937035`"}], ",", "2.1966530975014944`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.772409690000003`"}], ",", 
     RowBox[{"-", "16.30088910229339`"}], ",", "1.1292816879306429`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.61459506`"}], ",", 
     RowBox[{"-", "15.39318624663067`"}], ",", "1.3401137504113034`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "212.67468`"}], ",", 
     RowBox[{"-", "217.1793827226007`"}], ",", "19.392285258415008`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "154.9223522`"}], ",", 
     RowBox[{"-", "151.68032986722085`"}], ",", "9.984784657211597`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "201.9410288`"}], ",", 
     RowBox[{"-", "185.3647519147586`"}], ",", "18.57223219080302`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.01507102`"}], ",", 
     RowBox[{"-", "16.33891023332036`"}], ",", "2.2112344863005764`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "239.6292468`"}], ",", 
     RowBox[{"-", "223.92260639036405`"}], ",", "14.8675542739556`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "188.2129049`"}], ",", 
     RowBox[{"-", "164.33743283626268`"}], ",", "18.889490962011624`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "165.7132374`"}], ",", 
     RowBox[{"-", "173.1603900613405`"}], ",", "11.111820810457704`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "261.4387335`"}], ",", 
     RowBox[{"-", "233.62195662851514`"}], ",", "25.75125504906484`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "219.9711881`"}], ",", 
     RowBox[{"-", "204.9924265878798`"}], ",", "14.691990332587201`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.930406260000002`"}], ",", 
     RowBox[{"-", "16.593995242882933`"}], ",", "1.8425235134861173`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "182.0192916`"}], ",", 
     RowBox[{"-", "171.09875582107637`"}], ",", "12.936763422917448`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "212.35436`"}], ",", 
     RowBox[{"-", "216.34317509476247`"}], ",", "16.000370892957655`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.00842529`"}], ",", 
     RowBox[{"-", "16.636301167531077`"}], ",", "1.5666642321597062`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.06865289`"}], ",", 
     RowBox[{"-", "18.502134363935557`"}], ",", "3.8356028241976015`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "274.52534`"}], ",", 
     RowBox[{"-", "245.2791551574835`"}], ",", "30.53101899257439`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.884073550000004`"}], ",", 
     RowBox[{"-", "14.43100434123872`"}], ",", "3.8881953091712567`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13.48549164`"}], ",", 
     RowBox[{"-", "14.688769085678292`"}], ",", "2.4593263156758893`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.08613704`"}], ",", 
     RowBox[{"-", "19.36919221257702`"}], ",", "1.8383072758141583`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "232.6728533`"}], ",", 
     RowBox[{"-", "242.85215320276436`"}], ",", "23.76068295349543`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.17548746`"}], ",", 
     RowBox[{"-", "18.02664366925668`"}], ",", "1.167071164118235`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "227.6384345`"}], ",", 
     RowBox[{"-", "210.8367195752558`"}], ",", "23.89859036410174`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.461596130000002`"}], ",", 
     RowBox[{"-", "16.21215657656381`"}], ",", "1.3582602108746067`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "191.30573449999997`"}], ",", 
     RowBox[{"-", "201.12406733472005`"}], ",", "15.55755347694716`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "205.5804008`"}], ",", 
     RowBox[{"-", "208.4679669473228`"}], ",", "8.298934816178287`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.277799680000005`"}], ",", 
     RowBox[{"-", "20.66681357179121`"}], ",", "1.4019109013258004`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.1802867`"}], ",", 
     RowBox[{"-", "11.802996410290103`"}], ",", "2.787190973731701`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.588565950000003`"}], ",", 
     RowBox[{"-", "18.064776802189577`"}], ",", "1.8925975417731271`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.60218521`"}], ",", 
     RowBox[{"-", "15.293927626743043`"}], ",", "2.009183677016018`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.008445150000002`"}], ",", 
     RowBox[{"-", "13.335862189731918`"}], ",", "2.024442520518633`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "135.9210085`"}], ",", 
     RowBox[{"-", "135.36770362542467`"}], ",", "9.69648793730803`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "195.3385784`"}], ",", 
     RowBox[{"-", "198.44075407958292`"}], ",", "8.82239117887019`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "181.0090623`"}], ",", 
     RowBox[{"-", "205.89206851367652`"}], ",", "18.550310658259644`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.410694560000003`"}], ",", 
     RowBox[{"-", "16.670796536488652`"}], ",", "1.8731866118729341`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.059923830000002`"}], ",", 
     RowBox[{"-", "12.275160630832202`"}], ",", "2.003453145584463`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.59999831`"}], ",", 
     RowBox[{"-", "15.500749640488545`"}], ",", "2.227070796634372`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9.452459434000001`"}], ",", 
     RowBox[{"-", "12.554674672651249`"}], ",", "3.069084768511749`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "198.5987259`"}], ",", 
     RowBox[{"-", "190.31593172015673`"}], ",", "18.59170124038617`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "178.7692044`"}], ",", 
     RowBox[{"-", "193.48223101262414`"}], ",", "14.616970993011217`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "194.4729821`"}], ",", 
     RowBox[{"-", "210.39062340750937`"}], ",", "20.526741148488235`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.36316456`"}], ",", 
     RowBox[{"-", "11.761466830329164`"}], ",", "1.2165041835552`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "230.610439`"}], ",", 
     RowBox[{"-", "205.17490910576862`"}], ",", "21.339001753654085`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "177.90309249999999`"}], ",", 
     RowBox[{"-", "179.72008217009176`"}], ",", "10.386068781899748`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "235.2076761`"}], ",", 
     RowBox[{"-", "227.31944495444893`"}], ",", "11.053316500882543`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.68145305`"}], ",", 
     RowBox[{"-", "17.12670207451581`"}], ",", "1.3079433600439885`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.60559836`"}], ",", 
     RowBox[{"-", "18.83744469679945`"}], ",", "1.9383391095570177`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.00794796`"}], ",", 
     RowBox[{"-", "17.78868604330424`"}], ",", "1.864776415700241`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "235.69025`"}], ",", 
     RowBox[{"-", "235.93504411246462`"}], ",", "12.911303015048148`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.383318370000005`"}], ",", 
     RowBox[{"-", "24.642128135443862`"}], ",", "3.116874741319449`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.80124367`"}], ",", 
     RowBox[{"-", "13.601619709613987`"}], ",", "2.6629493051134765`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.95241934`"}], ",", 
     RowBox[{"-", "16.912750188932847`"}], ",", "3.04416685485337`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "156.0998953`"}], ",", 
     RowBox[{"-", "147.04033008397138`"}], ",", "13.364904228464018`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "126.6848415`"}], ",", 
     RowBox[{"-", "137.9888621060926`"}], ",", "11.68436934131653`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "247.64144069999998`"}], ",", 
     RowBox[{"-", "238.92240079341863`"}], ",", "12.049626375447962`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.034326870000005`"}], ",", 
     RowBox[{"-", "19.037416706890216`"}], ",", "2.690511043255444`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.93444314`"}], ",", 
     RowBox[{"-", "14.22972030136918`"}], ",", "1.957649553939842`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "166.1010446`"}], ",", 
     RowBox[{"-", "167.8287061159853`"}], ",", "10.954754981301328`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.9332059`"}], ",", 
     RowBox[{"-", "14.513617341853895`"}], ",", "1.8263374390645584`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.06816885`"}], ",", 
     RowBox[{"-", "16.944484444906752`"}], ",", "2.136062319665129`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.069685250000003`"}], ",", 
     RowBox[{"-", "18.217247792186637`"}], ",", "3.5329739076671145`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "254.9438531`"}], ",", 
     RowBox[{"-", "252.99641077511973`"}], ",", "15.551608775167628`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "221.3077422`"}], ",", 
     RowBox[{"-", "230.90637408946367`"}], ",", "10.37410588101956`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "196.1206745`"}], ",", 
     RowBox[{"-", "198.1678013029287`"}], ",", "11.760404511956589`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "172.25085999999996`"}], ",", 
     RowBox[{"-", "163.00498773587228`"}], ",", "16.524578838800487`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "140.9718293`"}], ",", 
     RowBox[{"-", "158.2507963353862`"}], ",", "17.087173056421534`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.05424117`"}], ",", 
     RowBox[{"-", "21.156594699034294`"}], ",", "2.199729074233336`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.3280814`"}], ",", 
     RowBox[{"-", "19.240250172978985`"}], ",", "2.383027706613339`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "128.9414524`"}], ",", 
     RowBox[{"-", "154.93586404089606`"}], ",", "29.335839616780593`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "27.16299725`"}], ",", 
     RowBox[{"-", "20.415468064857723`"}], ",", "4.205278820997148`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "214.40795`"}], ",", 
     RowBox[{"-", "215.11467976154694`"}], ",", "13.590559005999944`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.65439725`"}], ",", 
     RowBox[{"-", "18.626905266898905`"}], ",", "2.825048895456147`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "193.6218514`"}], ",", 
     RowBox[{"-", "197.0867059281088`"}], ",", "8.45223953208449`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.38074683`"}], ",", 
     RowBox[{"-", "15.37020253159287`"}], ",", "1.5429255353526505`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "25.258079340000002`"}], ",", 
     RowBox[{"-", "25.28178453440207`"}], ",", "1.2307827386309547`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "161.344421`"}], ",", 
     RowBox[{"-", "197.04437698635468`"}], ",", "20.132266311502235`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8097537913944583`*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"f08ad3e8-5d66-4e3b-aaf7-a94a66b089b6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.452591430000002`"}], ",", 
     RowBox[{"-", "14.456563390413141`"}], ",", "1.6270268394334375`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "202.192968`"}], ",", 
     RowBox[{"-", "253.8013547748957`"}], ",", "33.67027659666272`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "252.11954999999998`"}], ",", 
     RowBox[{"-", "218.9781903093363`"}], ",", "22.72540258645243`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "215.5739689`"}], ",", 
     RowBox[{"-", "194.5791670916178`"}], ",", "15.073674218772728`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.69029945`"}], ",", 
     RowBox[{"-", "13.102589968098473`"}], ",", "2.8193990198644605`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "156.9681656`"}], ",", 
     RowBox[{"-", "162.60868474080857`"}], ",", "15.906826545955182`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.402835910000002`"}], ",", 
     RowBox[{"-", "14.127207331674649`"}], ",", "2.5602583127418925`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "152.214854`"}], ",", 
     RowBox[{"-", "155.7308747174218`"}], ",", "13.79504305271857`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "166.2670094`"}], ",", 
     RowBox[{"-", "191.04244779557698`"}], ",", "14.961489791048864`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "24.973489780000005`"}], ",", 
     RowBox[{"-", "21.083807848532572`"}], ",", "3.1651634227848584`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "273.6209767`"}], ",", 
     RowBox[{"-", "267.475805640935`"}], ",", "13.201798415859594`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.51465421`"}], ",", 
     RowBox[{"-", "17.08171776717295`"}], ",", "1.7406944453035804`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "228.6788813`"}], ",", 
     RowBox[{"-", "203.66875876494154`"}], ",", "12.170219594907572`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "261.2832517`"}], ",", 
     RowBox[{"-", "251.81353496776654`"}], ",", "14.801928673593432`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "199.781755`"}], ",", 
     RowBox[{"-", "205.83020768321907`"}], ",", "15.770518058170403`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.65401523`"}], ",", 
     RowBox[{"-", "21.974098927590774`"}], ",", "1.5306411915312745`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "233.1004677`"}], ",", 
     RowBox[{"-", "216.99659065915338`"}], ",", "21.147091196731065`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.58593557`"}], ",", 
     RowBox[{"-", "19.66163270657321`"}], ",", "2.3236042517465245`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.035328210000001`"}], ",", 
     RowBox[{"-", "16.099547886069136`"}], ",", "1.5736447475121131`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "180.9368838`"}], ",", 
     RowBox[{"-", "209.03328365540784`"}], ",", "23.5353855697652`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.2795015`"}], ",", 
     RowBox[{"-", "19.09238897278913`"}], ",", "1.9185053892546216`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.63682455`"}], ",", 
     RowBox[{"-", "21.155761495425377`"}], ",", "1.5447659311929802`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5.866946123`"}], ",", 
     RowBox[{"-", "12.442987084365884`"}], ",", "1.5743932975758195`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.1054112`"}], ",", 
     RowBox[{"-", "15.69027443801492`"}], ",", "2.1897812073497422`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "230.1019404`"}], ",", 
     RowBox[{"-", "235.60653761923209`"}], ",", "22.185490488188616`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "291.30778`"}], ",", 
     RowBox[{"-", "230.44888208962217`"}], ",", "17.08921760396958`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.28408675`"}], ",", 
     RowBox[{"-", "10.917361208145469`"}], ",", "2.1175015002411897`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "24.67568185`"}], ",", 
     RowBox[{"-", "25.20693008996167`"}], ",", "1.3138201710691155`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.480867`"}], ",", 
     RowBox[{"-", "20.188886667237874`"}], ",", "1.7297340969009405`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "283.1428106`"}], ",", 
     RowBox[{"-", "252.23889841880802`"}], ",", "22.28574037111975`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.758344080000002`"}], ",", 
     RowBox[{"-", "12.615862016219314`"}], ",", "1.4758862524461016`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "287.80513`"}], ",", 
     RowBox[{"-", "255.50620753009636`"}], ",", "24.25691608652178`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.75612748`"}], ",", 
     RowBox[{"-", "16.24577164485567`"}], ",", "1.623711497147486`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.47694274`"}], ",", 
     RowBox[{"-", "21.45197143263925`"}], ",", "3.0077836883561933`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.56226548`"}], ",", 
     RowBox[{"-", "14.673979941133252`"}], ",", "2.189463352426358`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "195.6663408`"}], ",", 
     RowBox[{"-", "215.4163712348732`"}], ",", "23.889556997528587`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "161.4118904`"}], ",", 
     RowBox[{"-", "202.70016164915643`"}], ",", "14.469329004821157`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13.761870920000002`"}], ",", 
     RowBox[{"-", "15.220785784018718`"}], ",", "1.7292011234265825`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "214.39039`"}], ",", 
     RowBox[{"-", "209.3179401728306`"}], ",", "15.714903622883371`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "266.5537267`"}], ",", 
     RowBox[{"-", "232.79657120319246`"}], ",", "28.553308977004683`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "232.4892347`"}], ",", 
     RowBox[{"-", "253.81447345683128`"}], ",", "26.44447481469939`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "197.47946709999997`"}], ",", 
     RowBox[{"-", "203.51461725340727`"}], ",", "15.159581416012001`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "150.6709562`"}], ",", 
     RowBox[{"-", "166.35000888188628`"}], ",", "18.833267884868313`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "163.2012471`"}], ",", 
     RowBox[{"-", "148.44076353585046`"}], ",", "15.335636706044154`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "171.1272905`"}], ",", 
     RowBox[{"-", "149.85249361996745`"}], ",", "14.039476842376038`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13.546501870000002`"}], ",", 
     RowBox[{"-", "13.411952948229056`"}], ",", "2.6023780923362665`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "252.8883428`"}], ",", 
     RowBox[{"-", "231.9429612033868`"}], ",", "23.068458717527204`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "167.91973299999998`"}], ",", 
     RowBox[{"-", "182.67088178794288`"}], ",", "24.018916604292176`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "193.4124013`"}], ",", 
     RowBox[{"-", "205.53628934209294`"}], ",", "16.761511803734138`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "28.18247172`"}], ",", 
     RowBox[{"-", "20.310114590044396`"}], ",", "2.733616263655132`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "156.9436822`"}], ",", 
     RowBox[{"-", "147.35758195627295`"}], ",", "10.739483602410923`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.866955680000002`"}], ",", 
     RowBox[{"-", "19.245947373004984`"}], ",", "2.843498444158885`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "277.922571`"}], ",", 
     RowBox[{"-", "275.7305147598983`"}], ",", "12.974907484539012`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.280727263`"}], ",", 
     RowBox[{"-", "9.86526859450576`"}], ",", "3.270415095016391`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "239.0259818`"}], ",", 
     RowBox[{"-", "249.37199133701688`"}], ",", "13.754035754532733`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "171.486215`"}], ",", 
     RowBox[{"-", "162.27467623645506`"}], ",", "19.530916901178756`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.44477691`"}], ",", 
     RowBox[{"-", "15.67783842241245`"}], ",", "1.6192321313438274`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "231.4164105`"}], ",", 
     RowBox[{"-", "243.40994421135252`"}], ",", "18.19656231058039`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "27.08475597`"}], ",", 
     RowBox[{"-", "21.31957696575311`"}], ",", "3.65264798536941`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "158.590581`"}], ",", 
     RowBox[{"-", "206.20538891660277`"}], ",", "13.878439036861762`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.597435060000002`"}], ",", 
     RowBox[{"-", "17.024356812453348`"}], ",", "2.0521730480660243`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "201.0474559`"}], ",", 
     RowBox[{"-", "153.49365472552785`"}], ",", "22.68991714052678`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.310022820000002`"}], ",", 
     RowBox[{"-", "10.958372740272779`"}], ",", "1.6498091751146626`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "136.6105064`"}], ",", 
     RowBox[{"-", "162.5916995717822`"}], ",", "22.474133082981496`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.94997182`"}], ",", 
     RowBox[{"-", "16.261822766204908`"}], ",", "2.8264441904558932`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "25.16425491`"}], ",", 
     RowBox[{"-", "23.10611829915087`"}], ",", "2.162020275142762`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "187.4796539`"}], ",", 
     RowBox[{"-", "185.1224212851796`"}], ",", "16.039427282997817`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.595815280000002`"}], ",", 
     RowBox[{"-", "19.878544750810622`"}], ",", "1.9599569581826046`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "127.3825838`"}], ",", 
     RowBox[{"-", "135.45055385394764`"}], ",", "15.39682020698622`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9.491366085`"}], ",", 
     RowBox[{"-", "14.417046782106471`"}], ",", "3.6429347965050307`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "7.541234718000001`"}], ",", 
     RowBox[{"-", "10.940593928645436`"}], ",", "1.728297902841749`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.008740730000001`"}], ",", 
     RowBox[{"-", "17.284578538407125`"}], ",", "3.143002836277325`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.516404840000002`"}], ",", 
     RowBox[{"-", "13.980880874433588`"}], ",", "2.6753299947332225`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.219611940000002`"}], ",", 
     RowBox[{"-", "16.60851173343404`"}], ",", "3.3600542893688163`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.46927914`"}], ",", 
     RowBox[{"-", "15.557243394371072`"}], ",", "2.2754984214489746`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "23.399845550000002`"}], ",", 
     RowBox[{"-", "24.41020285490692`"}], ",", "1.5171526618174267`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "206.6846623`"}], ",", 
     RowBox[{"-", "185.94623607815325`"}], ",", "14.160097174375283`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.711117860000005`"}], ",", 
     RowBox[{"-", "20.122993686435727`"}], ",", "1.9536092466074184`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "198.3854754`"}], ",", 
     RowBox[{"-", "157.07356586330658`"}], ",", "21.366991203590114`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.09458197`"}], ",", 
     RowBox[{"-", "12.48012826606362`"}], ",", "2.2478636891835944`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.59242554`"}], ",", 
     RowBox[{"-", "19.765941706379955`"}], ",", "2.9066650773895635`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "133.0975666`"}], ",", 
     RowBox[{"-", "170.72721952524324`"}], ",", "9.94113277360606`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "159.7965766`"}], ",", 
     RowBox[{"-", "146.97723338311818`"}], ",", "15.260443142602893`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13.55166265`"}], ",", 
     RowBox[{"-", "10.943156015314585`"}], ",", "3.2514372083259846`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.215672570000002`"}], ",", 
     RowBox[{"-", "16.137845116072338`"}], ",", "2.673540137149434`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.74204637`"}], ",", 
     RowBox[{"-", "13.498790737307939`"}], ",", "2.825461154777152`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "173.7177977`"}], ",", 
     RowBox[{"-", "206.27091703260874`"}], ",", "21.303199909518412`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "193.11558879999998`"}], ",", 
     RowBox[{"-", "196.74474372078208`"}], ",", "9.46800989156168`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.00060878`"}], ",", 
     RowBox[{"-", "16.6953616950895`"}], ",", "1.8805889823010546`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13.838459270000001`"}], ",", 
     RowBox[{"-", "16.454402164310896`"}], ",", "1.9347489464998784`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.80179863`"}], ",", 
     RowBox[{"-", "23.51160705403352`"}], ",", "1.3255447890614425`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "231.6668386`"}], ",", 
     RowBox[{"-", "245.72345102069346`"}], ",", "10.129138836792505`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.8303766`"}], ",", 
     RowBox[{"-", "15.969131529630936`"}], ",", "1.8851141101264701`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "167.7111972`"}], ",", 
     RowBox[{"-", "146.82854585923474`"}], ",", "11.505089607159256`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.61514001`"}], ",", 
     RowBox[{"-", "14.361757697669406`"}], ",", "2.7563932624582144`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "247.58565`"}], ",", 
     RowBox[{"-", "216.02131028900914`"}], ",", "28.98073743119502`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "164.4031021`"}], ",", 
     RowBox[{"-", "164.0568391318588`"}], ",", "14.852173097721446`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.565501530000002`"}], ",", 
     RowBox[{"-", "18.746977770324236`"}], ",", "2.445787137319086`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "167.4371538`"}], ",", 
     RowBox[{"-", "154.98530185011518`"}], ",", "13.655482265132182`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "194.8134055`"}], ",", 
     RowBox[{"-", "196.70520095098783`"}], ",", "12.011619628407484`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "267.8469255`"}], ",", 
     RowBox[{"-", "263.8264222761086`"}], ",", "12.345941820879583`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "224.942923`"}], ",", 
     RowBox[{"-", "202.52915662900602`"}], ",", "12.509103973129019`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.736214950000003`"}], ",", 
     RowBox[{"-", "16.023990015115483`"}], ",", "1.7538946999707021`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "250.1519291`"}], ",", 
     RowBox[{"-", "245.53088017872372`"}], ",", "18.242551319672458`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "248.88074339999997`"}], ",", 
     RowBox[{"-", "235.01171908087866`"}], ",", "14.784215549661678`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "7.196171530000001`"}], ",", 
     RowBox[{"-", "9.501516920151047`"}], ",", "2.0791492136377463`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "141.8710277`"}], ",", 
     RowBox[{"-", "144.79668300444249`"}], ",", "17.710193681172726`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "27.00825379`"}], ",", 
     RowBox[{"-", "17.320954907481102`"}], ",", "3.575379213864542`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "25.08293619`"}], ",", 
     RowBox[{"-", "24.286620361096855`"}], ",", "2.0972529508267965`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9.076562506`"}], ",", 
     RowBox[{"-", "11.692221572120205`"}], ",", "2.595627056329959`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "205.153409`"}], ",", 
     RowBox[{"-", "212.27982992727073`"}], ",", "13.580396752755005`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "202.1253899`"}], ",", 
     RowBox[{"-", "198.25970125971241`"}], ",", "10.022112764735928`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.35430533`"}], ",", 
     RowBox[{"-", "22.22405490150119`"}], ",", "2.09953513097263`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.69722556`"}], ",", 
     RowBox[{"-", "14.266196241947691`"}], ",", "2.387513085149152`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "24.34314783`"}], ",", 
     RowBox[{"-", "19.763221403331652`"}], ",", "3.062417475586488`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "150.9222046`"}], ",", 
     RowBox[{"-", "155.7436687682736`"}], ",", "15.992856389211612`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "194.3196694`"}], ",", 
     RowBox[{"-", "204.90928685851233`"}], ",", "15.503335812959259`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "138.8310933`"}], ",", 
     RowBox[{"-", "135.9505163853742`"}], ",", "11.867933671967057`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "25.942436430000004`"}], ",", 
     RowBox[{"-", "24.317120374550306`"}], ",", "2.1664229704248563`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "173.3533045`"}], ",", 
     RowBox[{"-", "198.25756433053297`"}], ",", "23.862641794733374`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "214.1880015`"}], ",", 
     RowBox[{"-", "194.76616308330594`"}], ",", "12.271568889078308`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "249.5946904`"}], ",", 
     RowBox[{"-", "234.66398191429016`"}], ",", "21.57493756032279`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "198.294944`"}], ",", 
     RowBox[{"-", "201.92541426207515`"}], ",", "7.991454063751494`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.44868644`"}], ",", 
     RowBox[{"-", "15.18605050263092`"}], ",", "1.8753559584373927`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "155.4720648`"}], ",", 
     RowBox[{"-", "139.19077062840782`"}], ",", "11.437775671469048`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.99950242`"}], ",", 
     RowBox[{"-", "16.039675852580697`"}], ",", "1.3938519194127046`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.343036990000005`"}], ",", 
     RowBox[{"-", "20.432660341654028`"}], ",", "1.6951931194076542`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "231.3836841`"}], ",", 
     RowBox[{"-", "217.8222427856907`"}], ",", "21.620706974107808`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.34619017`"}], ",", 
     RowBox[{"-", "18.760089797254906`"}], ",", "1.801983277920053`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "137.2083688`"}], ",", 
     RowBox[{"-", "162.46565039243075`"}], ",", "14.080897602721597`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.16411359`"}], ",", 
     RowBox[{"-", "21.94427946670459`"}], ",", "1.2702143209565444`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "228.8679563`"}], ",", 
     RowBox[{"-", "224.40366719634554`"}], ",", "22.946727605099618`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.21770702`"}], ",", 
     RowBox[{"-", "20.668079122161583`"}], ",", "2.518919993842861`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "200.34562289999997`"}], ",", 
     RowBox[{"-", "190.8540927432975`"}], ",", "18.15449351244635`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.05789764`"}], ",", 
     RowBox[{"-", "15.288541994166781`"}], ",", "1.4605860326017934`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.57202202`"}], ",", 
     RowBox[{"-", "16.39595707271473`"}], ",", "2.991794538561793`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.34208923`"}], ",", 
     RowBox[{"-", "13.584724606597385`"}], ",", "2.2056050912904257`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.06899218`"}], ",", 
     RowBox[{"-", "18.11127143078656`"}], ",", "1.6609475765567396`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.571342020000003`"}], ",", 
     RowBox[{"-", "16.800350863759448`"}], ",", "2.087399137620826`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "192.0334666`"}], ",", 
     RowBox[{"-", "200.42053030897125`"}], ",", "11.232499359315518`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.67410847`"}], ",", 
     RowBox[{"-", "25.813658598160753`"}], ",", "1.2299551405634213`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "136.3388297`"}], ",", 
     RowBox[{"-", "159.22858330753238`"}], ",", "15.416773233187543`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "193.2731135`"}], ",", 
     RowBox[{"-", "202.29286943181458`"}], ",", "16.997328064010357`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.1726578`"}], ",", 
     RowBox[{"-", "22.38772081373989`"}], ",", "3.354897637647878`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.17301452`"}], ",", 
     RowBox[{"-", "15.99329899302641`"}], ",", "1.8119863016901172`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "173.6078787`"}], ",", 
     RowBox[{"-", "192.136249403327`"}], ",", "26.802849255627276`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.46433826`"}], ",", 
     RowBox[{"-", "17.14829128677881`"}], ",", "1.9196671396330116`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.932678710000005`"}], ",", 
     RowBox[{"-", "24.688650323576567`"}], ",", "3.2953591765759507`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "21.74484064`"}], ",", 
     RowBox[{"-", "20.250947953398278`"}], ",", "3.4471875888358534`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "180.848529`"}], ",", 
     RowBox[{"-", "192.4045795076202`"}], ",", "18.581862909741382`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.657632000000003`"}], ",", 
     RowBox[{"-", "17.583324067825824`"}], ",", "3.536349142311258`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "195.1780703`"}], ",", 
     RowBox[{"-", "202.20075379147963`"}], ",", "12.237083300491369`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "202.9638538`"}], ",", 
     RowBox[{"-", "186.48222199515624`"}], ",", "16.280435960266416`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "277.7060449`"}], ",", 
     RowBox[{"-", "229.92377335493552`"}], ",", "18.47656063394388`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "282.7374245`"}], ",", 
     RowBox[{"-", "264.87238395031807`"}], ",", "15.681595909085534`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.16303922`"}], ",", 
     RowBox[{"-", "22.761569374419956`"}], ",", "1.5972068096315641`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.46032233`"}], ",", 
     RowBox[{"-", "11.84399398761229`"}], ",", "1.7930563775466466`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8097537914710364`*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"c42878e0-808d-4895-8478-320494d44bf6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"figp1", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"ensemblePredictionResults", " ", "/.", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], "\[RuleDelayed]", 
           RowBox[{"{", 
            RowBox[{"a", ",", " ", 
             RowBox[{"Around", "[", 
              RowBox[{"b", ",", "c"}], "]"}]}], "}"}]}]}], "  ", "}"}], ",", 
        RowBox[{"Frame", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"True", ",", "False"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<E [\!\(\*SubscriptBox[\(k\), \(B\)]\)T]\>\"", ",", 
           "\"\<\!\(\*OverscriptBox[\(E\), \(^\)]\)  \
[\!\(\*SubscriptBox[\(k\), \(B\)]\)T]\>\""}], "}"}]}], ",", " ", 
        RowBox[{"LabelStyle", "\[Rule]", "Medium"}], ",", " ", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "310"}], ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "310"}], ",", "5"}], "}"}]}], "}"}]}]}], "]"}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"Plot", "[", 
       RowBox[{"x", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "1000"}], ",", "0"}], "}"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "Dotted"}], "]"}]}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"figp2", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{"ensemblePredictionResultsValidation", " ", "/.", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], "\[RuleDelayed]", 
          RowBox[{"{", 
           RowBox[{"a", ",", " ", 
            RowBox[{"Around", "[", 
             RowBox[{"b", ",", "c"}], "]"}]}], "}"}]}]}], "  ", "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"True", ",", "False"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<E [\!\(\*SubscriptBox[\(k\), \(B\)]\)T]\>\"", ",", 
          "\"\<\!\(\*OverscriptBox[\(E\), \(^\)]\)  \
[\!\(\*SubscriptBox[\(k\), \(B\)]\)T]\>\""}], "}"}]}], ",", " ", 
       RowBox[{"LabelStyle", "\[Rule]", "Medium"}], ",", " ", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "310"}], ",", "5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "310"}], ",", "5"}], "}"}]}], "}"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1000"}], ",", "0"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", "Dotted"}], "]"}]}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figp3", "=", 
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{"ensemblePredictionResults", " ", "/.", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], " ", "\[RuleDelayed]", 
        " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], "/", "a"}]}]}], "   ", "}"}], ",", 
     " ", "Automatic", ",", "  ", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"True", ",", "False"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Rel. err\>\"", ",", " ", "\"\<Count\>\""}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", "Medium"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"figp4", "=", 
  RowBox[{"Histogram", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{"ensemblePredictionResultsValidation", " ", "/.", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], " ", "\[RuleDelayed]", 
       " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "-", "b"}], ")"}], "/", "a"}]}]}], "   ", "}"}], ",", 
    " ", "Automatic", ",", "  ", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"True", ",", "False"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Rel. err\>\"", ",", " ", "\"\<Count\>\""}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "Medium"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"figure4Total", "=", 
  RowBox[{"GraphicsGrid", "[", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"figp1", ",", "figp3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"figp2", ",", "figp4"}], "}"}]}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"KendallTau", "[", 
  RowBox[{"ensemblePredictionResultsUnscaled", " ", "/.", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"a", ",", " ", "b"}], "}"}]}]}], "   ", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"KendallTau", "[", 
  RowBox[{"ensemblePredictionResultsValidationUnscaled", " ", "/.", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"a", ",", " ", "b"}], "}"}]}]}], "   ", "]"}]}], "Input",
 CellChangeTimes->{{3.80458527595148*^9, 3.8045852805207963`*^9}, {
  3.804597127421747*^9, 3.804597152865554*^9}, {3.8045972416944947`*^9, 
  3.804597250503337*^9}, {3.8051829761055183`*^9, 3.80518300350483*^9}, {
  3.809754013411232*^9, 3.8097540342736044`*^9}, {3.8097540899947205`*^9, 
  3.8097541423142166`*^9}, {3.809754190528204*^9, 3.809754192196859*^9}},
 CellLabel->
  "In[111]:=",ExpressionUUID->"d27a5d98-854a-482a-991f-dd1d6dcbc610"],

Cell[BoxData[
 GraphicsBox[{{{
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.122592040000004`, -22.040241208242474`}, \
{-19.122592040000004`, -19.716780398996427`}}], 
         LineBox[{{-19.122592040000004`, -19.716780398996427`}, \
{-19.122592040000004`, -17.39331958975038}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-13.29428828, -15.76480328444859}, {-13.29428828, \
-13.61282082678354}}], 
         LineBox[{{-13.29428828, -13.61282082678354}, {-13.29428828, \
-11.460838369118491`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-21.925352060000005`, -22.311748773039913`}, \
{-21.925352060000005`, -21.17176404414137}}], 
         LineBox[{{-21.925352060000005`, -21.17176404414137}, \
{-21.925352060000005`, -20.031779315242826`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-263.1578615, -272.96494399218346`}, {-263.1578615, \
-264.00993685307793`}}], 
         LineBox[{{-263.1578615, -264.00993685307793`}, {-263.1578615, \
-255.0549297139724}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-199.214, -205.55108069930733`}, {-199.214, \
-189.51523432134726`}}], 
         LineBox[{{-199.214, -189.51523432134726`}, {-199.214, \
-173.4793879433872}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.770776970000002`, -18.12212378511592}, \
{-14.770776970000002`, -16.23149722304764}}], 
         LineBox[{{-14.770776970000002`, -16.23149722304764}, \
{-14.770776970000002`, -14.340870660979359`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-202.8522675, -215.6417790591472}, {-202.8522675, \
-206.67256735962857`}}], 
         LineBox[{{-202.8522675, -206.67256735962857`}, {-202.8522675, \
-197.70335566010993`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-197.2202495, -187.83519485631655`}, {-197.2202495, \
-161.03769430604612`}}], 
         LineBox[{{-197.2202495, -161.03769430604612`}, {-197.2202495, \
-134.2401937557757}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-253.7709554, -260.5284147037122}, {-253.7709554, \
-252.16001696943238`}}], 
         LineBox[{{-253.7709554, -252.16001696943238`}, {-253.7709554, \
-243.79161923515255`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-264.7122498, -275.1279764106515}, {-264.7122498, \
-266.88754866450876`}}], 
         LineBox[{{-264.7122498, -266.88754866450876`}, {-264.7122498, \
-258.647120918366}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.0738179, -21.30430256793147}, {-19.0738179, \
-19.015665925820088`}}], 
         LineBox[{{-19.0738179, -19.015665925820088`}, {-19.0738179, \
-16.727029283708706`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-22.96318187, -26.14616886548059}, {-22.96318187, \
-24.589661522599314`}}], 
         LineBox[{{-22.96318187, -24.589661522599314`}, {-22.96318187, \
-23.03315417971804}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-26.002258020000003`, -27.016633661897117`}, \
{-26.002258020000003`, -25.732099312069213`}}], 
         LineBox[{{-26.002258020000003`, -25.732099312069213`}, \
{-26.002258020000003`, -24.44756496224131}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-156.64292209999996`, -209.13103480012106`}, \
{-156.64292209999996`, -182.28962614695624`}}], 
         LineBox[{{-156.64292209999996`, -182.28962614695624`}, \
{-156.64292209999996`, -155.44821749379142`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-253.9884788, -266.1661596420178}, {-253.9884788, \
-254.87474754930884`}}], 
         LineBox[{{-253.9884788, -254.87474754930884`}, {-253.9884788, \
-243.58333545659983`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-203.44583779999996`, -213.51897531816306`}, \
{-203.44583779999996`, -206.89391611163813`}}], 
         LineBox[{{-203.44583779999996`, -206.89391611163813`}, \
{-203.44583779999996`, -200.2688569051132}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.931329430000002`, -19.989915991418716`}, \
{-11.931329430000002`, -16.65502766501253}}], 
         LineBox[{{-11.931329430000002`, -16.65502766501253}, \
{-11.931329430000002`, -13.32013933860634}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-140.2901259, -155.36604155571692`}, {-140.2901259, \
-146.04360235982125`}}], 
         LineBox[{{-140.2901259, -146.04360235982125`}, {-140.2901259, \
-136.72116316392558`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-203.6664668, -201.92121656910336`}, {-203.6664668, \
-186.8988791731109}}], 
         LineBox[{{-203.6664668, -186.8988791731109}, {-203.6664668, \
-171.87654177711846`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.24628378, -19.408802769717006`}, {-18.24628378, \
-18.107443148144885`}}], 
         LineBox[{{-18.24628378, -18.107443148144885`}, {-18.24628378, \
-16.806083526572763`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.80138018, -16.465518408400136`}, {-14.80138018, \
-15.066744072410529`}}], 
         LineBox[{{-14.80138018, -15.066744072410529`}, {-14.80138018, \
-13.667969736420924`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.90194371, -20.74189968587812}, {-17.90194371, \
-19.132295954672138`}}], 
         LineBox[{{-17.90194371, -19.132295954672138`}, {-17.90194371, \
-17.522692223466155`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.40654202, -15.315122346109211`}, {-15.40654202, \
-13.358825950741512`}}], 
         LineBox[{{-15.40654202, -13.358825950741512`}, {-15.40654202, \
-11.402529555373812`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-311.33191, -317.7967301121321}, {-311.33191, \
-279.88579864512764`}}], 
         LineBox[{{-311.33191, -279.88579864512764`}, {-311.33191, \
-241.9748671781232}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-170.54968019999998`, -173.86608476935567`}, \
{-170.54968019999998`, -163.6592149433442}}], 
         LineBox[{{-170.54968019999998`, -163.6592149433442}, \
{-170.54968019999998`, -153.45234511733275`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-190.5494332, -234.16418269362933`}, {-190.5494332, \
-209.09674842627385`}}], 
         LineBox[{{-190.5494332, -209.09674842627385`}, {-190.5494332, \
-184.02931415891837`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-163.9016831, -207.99794691240842`}, {-163.9016831, \
-183.09291531725307`}}], 
         LineBox[{{-163.9016831, -183.09291531725307`}, {-163.9016831, \
-158.18788372209772`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-215.2738442, -207.1047254012853}, {-215.2738442, \
-194.6391494797123}}], 
         LineBox[{{-215.2738442, -194.6391494797123}, {-215.2738442, \
-182.1735735581393}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-191.7750655, -211.93769842643192`}, {-191.7750655, \
-191.94596016715306`}}], 
         LineBox[{{-191.7750655, -191.94596016715306`}, {-191.7750655, \
-171.9542219078742}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-138.1443354, -185.50055640157072`}, {-138.1443354, \
-160.82116956950384`}}], 
         LineBox[{{-138.1443354, -160.82116956950384`}, {-138.1443354, \
-136.14178273743696`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-145.0720654, -186.64512726337387`}, {-145.0720654, \
-165.24290941933268`}}], 
         LineBox[{{-145.0720654, -165.24290941933268`}, {-145.0720654, \
-143.8406915752915}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-192.5885865, -243.04363971705953`}, {-192.5885865, \
-213.66797477424302`}}], 
         LineBox[{{-192.5885865, -213.66797477424302`}, {-192.5885865, \
-184.2923098314265}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-21.942781440000005`, -22.79909018190355}, \
{-21.942781440000005`, -21.75293909318461}}], 
         LineBox[{{-21.942781440000005`, -21.75293909318461}, \
{-21.942781440000005`, -20.706788004465672`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.15637194, -17.209772499514763`}, {-14.15637194, \
-15.50003103643645}}], 
         LineBox[{{-14.15637194, -15.50003103643645}, {-14.15637194, \
-13.790289573358137`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-261.4747844, -261.8008200386536}, {-261.4747844, \
-243.94095899210942`}}], 
         LineBox[{{-261.4747844, -243.94095899210942`}, {-261.4747844, \
-226.08109794556523`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-229.6294085, -220.75892118576533`}, {-229.6294085, \
-207.71568314737752`}}], 
         LineBox[{{-229.6294085, -207.71568314737752`}, {-229.6294085, \
-194.6724451089897}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-245.2853296, -251.77146365718744`}, {-245.2853296, \
-226.37109824037307`}}], 
         LineBox[{{-245.2853296, -226.37109824037307`}, {-245.2853296, \
-200.9707328235587}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-197.2131662, -224.32046421313788`}, {-197.2131662, \
-209.6059086158994}}], 
         LineBox[{{-197.2131662, -209.6059086158994}, {-197.2131662, \
-194.89135301866094`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-227.8414479, -224.74274697404616`}, {-227.8414479, \
-203.91549453594155`}}], 
         LineBox[{{-227.8414479, -203.91549453594155`}, {-227.8414479, \
-183.08824209783694`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-7.868570001000001, -14.538821621412295`}, \
{-7.868570001000001, -11.921312901652414`}}], 
         LineBox[{{-7.868570001000001, -11.921312901652414`}, \
{-7.868570001000001, -9.303804181892533}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-22.197738360000002`, -23.1591611687038}, \
{-22.197738360000002`, -21.240941374767914`}}], 
         LineBox[{{-22.197738360000002`, -21.240941374767914`}, \
{-22.197738360000002`, -19.322721580832027`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-229.141083, -245.7107716318199}, {-229.141083, \
-231.3466047530391}}], 
         LineBox[{{-229.141083, -231.3466047530391}, {-229.141083, \
-216.98243787425827`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-164.7313033, -165.79588772044136`}, {-164.7313033, \
-152.6382830071093}}], 
         LineBox[{{-164.7313033, -152.6382830071093}, {-164.7313033, \
-139.48067829377723`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.01398646, -20.574793011411035`}, {-18.01398646, \
-18.919432455269227`}}], 
         LineBox[{{-18.01398646, -18.919432455269227`}, {-18.01398646, \
-17.26407189912742}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.61293568, -22.49860864777812}, {-16.61293568, \
-19.57260898234595}}], 
         LineBox[{{-16.61293568, -19.57260898234595}, {-16.61293568, \
-16.646609316913782`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-198.0982712, -211.79558466460927`}, {-198.0982712, \
-191.58039119784718`}}], 
         LineBox[{{-198.0982712, -191.58039119784718`}, {-198.0982712, \
-171.3651977310851}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-157.5460241, -204.21910046591245`}, {-157.5460241, \
-179.41575052167374`}}], 
         LineBox[{{-157.5460241, -179.41575052167374`}, {-157.5460241, \
-154.61240057743504`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-188.8140786, -220.38132089107225`}, {-188.8140786, \
-203.76480627851245`}}], 
         LineBox[{{-188.8140786, -203.76480627851245`}, {-188.8140786, \
-187.14829166595266`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.359806400000002`, -17.411612632669637`}, \
{-14.359806400000002`, -15.671669505674123`}}], 
         LineBox[{{-14.359806400000002`, -15.671669505674123`}, \
{-14.359806400000002`, -13.931726378678608`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.90265974, -23.755225108807334`}, {-19.90265974, \
-21.670400023931656`}}], 
         LineBox[{{-19.90265974, -21.670400023931656`}, {-19.90265974, \
-19.585574939055977`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.94159622, -12.146231356460937`}, {-10.94159622, \
-10.483690398752922`}}], 
         LineBox[{{-10.94159622, -10.483690398752922`}, {-10.94159622, \
-8.821149441044906}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-257.6108399, -266.51443120487465`}, {-257.6108399, \
-255.72611886013294`}}], 
         LineBox[{{-257.6108399, -255.72611886013294`}, {-257.6108399, \
-244.93780651539126`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-174.46814, -217.64911941853447`}, {-174.46814, \
-198.74800583723112`}}], 
         LineBox[{{-174.46814, -198.74800583723112`}, {-174.46814, \
-179.84689225592777`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-26.17064523, -26.931207399700927`}, {-26.17064523, \
-23.808209934292037`}}], 
         LineBox[{{-26.17064523, -23.808209934292037`}, {-26.17064523, \
-20.685212468883147`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.685667400000002`, -13.581283169213304`}, \
{-10.685667400000002`, -11.312715010820941`}}], 
         LineBox[{{-10.685667400000002`, -11.312715010820941`}, \
{-10.685667400000002`, -9.044146852428579}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-13.389810530000002`, -17.109107005736806`}, \
{-13.389810530000002`, -15.5206069126093}}], 
         LineBox[{{-13.389810530000002`, -15.5206069126093}, \
{-13.389810530000002`, -13.932106819481794`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-235.96036999999998`, -263.9742495356013}, \
{-235.96036999999998`, -249.9414993288295}}], 
         LineBox[{{-235.96036999999998`, -249.9414993288295}, \
{-235.96036999999998`, -235.9087491220577}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-6.600847048000001, -14.48465316758653}, \
{-6.600847048000001, -11.153112823775574`}}], 
         LineBox[{{-6.600847048000001, -11.153112823775574`}, \
{-6.600847048000001, -7.821572479964619}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-183.2164933, -186.9809759313028}, {-183.2164933, \
-173.05465261247394`}}], 
         LineBox[{{-183.2164933, -173.05465261247394`}, {-183.2164933, \
-159.1283292936451}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-244.0067091, -249.79453343426408`}, {-244.0067091, \
-238.13954012868453`}}], 
         LineBox[{{-244.0067091, -238.13954012868453`}, {-244.0067091, \
-226.48454682310498`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-25.97423007, -27.42924487277393}, {-25.97423007, \
-26.258877446711725`}}], 
         LineBox[{{-25.97423007, -26.258877446711725`}, {-25.97423007, \
-25.088510020649522`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.53060212, -20.24433079965609}, {-11.53060212, \
-16.946947148742026`}}], 
         LineBox[{{-11.53060212, -16.946947148742026`}, {-11.53060212, \
-13.649563497827964`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-158.74572139999998`, -172.18168115472037`}, \
{-158.74572139999998`, -163.53182546877983`}}], 
         LineBox[{{-158.74572139999998`, -163.53182546877983`}, \
{-158.74572139999998`, -154.8819697828393}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-24.23603156, -25.707798861705506`}, {-24.23603156, \
-23.800512660897596`}}], 
         LineBox[{{-24.23603156, -23.800512660897596`}, {-24.23603156, \
-21.893226460089686`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-200.5470822, -225.47808631227258`}, {-200.5470822, \
-210.14843063983193`}}], 
         LineBox[{{-200.5470822, -210.14843063983193`}, {-200.5470822, \
-194.81877496739128`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.71263041, -21.019626554207303`}, {-20.71263041, \
-17.655117799206117`}}], 
         LineBox[{{-20.71263041, -17.655117799206117`}, {-20.71263041, \
-14.290609044204931`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.831368790000003`, -21.246234707413656`}, \
{-20.831368790000003`, -19.7670725756887}}], 
         LineBox[{{-20.831368790000003`, -19.7670725756887}, \
{-20.831368790000003`, -18.287910443963746`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.00780319, -22.290593207107193`}, {-19.00780319, \
-20.63364472460759}}], 
         LineBox[{{-19.00780319, -20.63364472460759}, {-19.00780319, \
-18.976696242107984`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-22.46960909, -22.784974948184566`}, {-22.46960909, \
-20.15681164882372}}], 
         LineBox[{{-22.46960909, -20.15681164882372}, {-22.46960909, \
-17.528648349462873`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.92874242, -22.594323274137132`}, {-10.92874242, \
-17.80386013534598}}], 
         LineBox[{{-10.92874242, -17.80386013534598}, {-10.92874242, \
-13.013396996554832`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-176.571878, -215.29550477061855`}, {-176.571878, \
-196.3774287627301}}], 
         LineBox[{{-176.571878, -196.3774287627301}, {-176.571878, \
-177.45935275484163`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-193.7626921, -249.6602878303413}, {-193.7626921, \
-217.79451188462608`}}], 
         LineBox[{{-193.7626921, -217.79451188462608`}, {-193.7626921, \
-185.92873593891085`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.94605626, -22.610480592484414`}, {-16.94605626, \
-19.71093412457734}}], 
         LineBox[{{-16.94605626, -19.71093412457734}, {-16.94605626, \
-16.811387656670263`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-26.26283108, -27.7126693292898}, {-26.26283108, \
-26.47635259392767}}], 
         LineBox[{{-26.26283108, -26.47635259392767}, {-26.26283108, \
-25.240035858565538`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-147.5403296, -177.95445566920463`}, {-147.5403296, \
-160.1781108132016}}], 
         LineBox[{{-147.5403296, -160.1781108132016}, {-147.5403296, \
-142.4017659571986}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.83608012, -22.420153553440553`}, {-16.83608012, \
-19.19171027968257}}], 
         LineBox[{{-16.83608012, -19.19171027968257}, {-16.83608012, \
-15.963267005924589`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.43103003, -13.123169038139638`}, {-10.43103003, \
-11.45206381379255}}], 
         LineBox[{{-10.43103003, -11.45206381379255}, {-10.43103003, \
-9.780958589445463}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.740878590000001`, -20.913215769775586`}, \
{-14.740878590000001`, -18.480416283716274`}}], 
         LineBox[{{-14.740878590000001`, -18.480416283716274`}, \
{-14.740878590000001`, -16.04761679765696}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.28176018, -17.3889583689097}, {-17.28176018, \
-15.834609561341756`}}], 
         LineBox[{{-17.28176018, -15.834609561341756`}, {-17.28176018, \
-14.280260753773812`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-12.50387992, -13.039012359074205`}, {-12.50387992, \
-12.01356167032337}}], 
         LineBox[{{-12.50387992, -12.01356167032337}, {-12.50387992, \
-10.988110981572534`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-198.1780966, -209.9322880893029}, {-198.1780966, \
-201.64138327879715`}}], 
         LineBox[{{-198.1780966, -201.64138327879715`}, {-198.1780966, \
-193.3504784682914}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-196.84942059999997`, -237.06681805702542`}, \
{-196.84942059999997`, -218.60228729209666`}}], 
         LineBox[{{-196.84942059999997`, -218.60228729209666`}, \
{-196.84942059999997`, -200.1377565271679}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-222.213379, -254.7725004997617}, {-222.213379, \
-237.49192128704502`}}], 
         LineBox[{{-222.213379, -237.49192128704502`}, {-222.213379, \
-220.21134207432834`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-140.4296433, -179.41056206740373`}, {-140.4296433, \
-155.31121506863934`}}], 
         LineBox[{{-140.4296433, -155.31121506863934`}, {-140.4296433, \
-131.21186806987495`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.53154494, -21.789649204755637`}, {-17.53154494, \
-19.372600842073187`}}], 
         LineBox[{{-17.53154494, -19.372600842073187`}, {-17.53154494, \
-16.955552479390736`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.51894907, -14.856261336444453`}, {-16.51894907, \
-12.822234656923351`}}], 
         LineBox[{{-16.51894907, -12.822234656923351`}, {-16.51894907, \
-10.78820797740225}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-24.078960020000004`, -27.20404000512535}, \
{-24.078960020000004`, -25.782363690244786`}}], 
         LineBox[{{-24.078960020000004`, -25.782363690244786`}, \
{-24.078960020000004`, -24.360687375364222`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-121.3942897, -153.78930069909336`}, {-121.3942897, \
-136.36308096321468`}}], 
         LineBox[{{-121.3942897, -136.36308096321468`}, {-121.3942897, \
-118.936861227336}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-178.9523159, -190.6221740379458}, {-178.9523159, \
-179.73882040880832`}}], 
         LineBox[{{-178.9523159, -179.73882040880832`}, {-178.9523159, \
-168.85546677967085`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-191.6546589, -215.39215141479167`}, {-191.6546589, \
-199.53599187121227`}}], 
         LineBox[{{-191.6546589, -199.53599187121227`}, {-191.6546589, \
-183.67983232763288`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.92335885, -22.23926574686529}, {-17.92335885, \
-19.617470538296264`}}], 
         LineBox[{{-17.92335885, -19.617470538296264`}, {-17.92335885, \
-16.995675329727238`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-169.8586866, -203.6872624338101}, {-169.8586866, \
-188.636384882625}}], 
         LineBox[{{-169.8586866, -188.636384882625}, {-169.8586866, \
-173.5855073314399}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-167.7610048, -203.3107996866294}, {-167.7610048, \
-183.040046835214}}], 
         LineBox[{{-167.7610048, -183.040046835214}, {-167.7610048, \
-162.76929398379863`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-195.3374268, -205.84976536637143`}, {-195.3374268, \
-194.95950374562463`}}], 
         LineBox[{{-195.3374268, -194.95950374562463`}, {-195.3374268, \
-184.06924212487783`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-23.01166885, -24.5606359758041}, {-23.01166885, \
-23.495449742620174`}}], 
         LineBox[{{-23.01166885, -23.495449742620174`}, {-23.01166885, \
-22.430263509436248`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-142.4023942, -178.5606438661326}, {-142.4023942, \
-159.52914307925096`}}], 
         LineBox[{{-142.4023942, -159.52914307925096`}, {-142.4023942, \
-140.4976422923693}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-186.443977, -218.73998291830196`}, {-186.443977, \
-203.1811062659203}}], 
         LineBox[{{-186.443977, -203.1811062659203}, {-186.443977, \
-187.62222961353865`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-242.467544, -249.31774192675465`}, {-242.467544, \
-228.6193368402952}}], 
         LineBox[{{-242.467544, -228.6193368402952}, {-242.467544, \
-207.92093175383576`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.996031230000002`, -19.545328381460887`}, \
{-15.996031230000002`, -17.38779463433937}}], 
         LineBox[{{-15.996031230000002`, -17.38779463433937}, \
{-15.996031230000002`, -15.230260887217856`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-169.0825486, -177.59934186182963`}, {-169.0825486, \
-162.39425810014342`}}], 
         LineBox[{{-169.0825486, -162.39425810014342`}, {-169.0825486, \
-147.1891743384572}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-262.4148731, -268.7113017239387}, {-262.4148731, \
-257.7755322890022}}], 
         LineBox[{{-262.4148731, -257.7755322890022}, {-262.4148731, \
-246.8397628540657}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-26.46909494, -23.91623589337734}, {-26.46909494, \
-19.551881372322768`}}], 
         LineBox[{{-26.46909494, -19.551881372322768`}, {-26.46909494, \
-15.187526851268196`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-127.6290063, -139.2310573236136}, {-127.6290063, \
-128.756055866968}}], 
         LineBox[{{-127.6290063, -128.756055866968}, {-127.6290063, \
-118.28105441032241`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-206.4259915, -205.10652220540317`}, {-206.4259915, \
-190.7773238494553}}], 
         LineBox[{{-206.4259915, -190.7773238494553}, {-206.4259915, \
-176.44812549350746`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-205.9183344, -215.1946157064818}, {-205.9183344, \
-205.70728126369}}], 
         LineBox[{{-205.9183344, -205.70728126369}, {-205.9183344, \
-196.21994682089817`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-157.26507809999998`, -182.31193572801723`}, \
{-157.26507809999998`, -168.99041102637977`}}], 
         LineBox[{{-157.26507809999998`, -168.99041102637977`}, \
{-157.26507809999998`, -155.66888632474232`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-269.4395282, -280.66050982321855`}, {-269.4395282, \
-271.32165242717934`}}], 
         LineBox[{{-269.4395282, -271.32165242717934`}, {-269.4395282, \
-261.98279503114014`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.14196342, -17.736827936957184`}, {-11.14196342, \
-14.175190310212509`}}], 
         LineBox[{{-11.14196342, -14.175190310212509`}, {-11.14196342, \
-10.613552683467836`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-13.06116628, -16.794675026008306`}, {-13.06116628, \
-15.194508401645859`}}], 
         LineBox[{{-13.06116628, -15.194508401645859`}, {-13.06116628, \
-13.594341777283411`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.16785021, -14.995398834804563`}, {-16.16785021, \
-11.79489643643592}}], 
         LineBox[{{-16.16785021, -11.79489643643592}, {-16.16785021, \
-8.594394038067277}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.94167053, -20.58194332093363}, {-11.94167053, \
-17.273835156088463`}}], 
         LineBox[{{-11.94167053, -17.273835156088463`}, {-11.94167053, \
-13.965726991243297`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.212622800000002`, -19.790799475074806`}, \
{-19.212622800000002`, -17.097418246448633`}}], 
         LineBox[{{-19.212622800000002`, -17.097418246448633`}, \
{-19.212622800000002`, -14.40403701782246}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-199.0258256, -219.64256900789744`}, {-199.0258256, \
-204.62174002579044`}}], 
         LineBox[{{-199.0258256, -204.62174002579044`}, {-199.0258256, \
-189.60091104368345`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-208.1506386, -224.77369077631207`}, {-208.1506386, \
-212.2043366924515}}], 
         LineBox[{{-208.1506386, -212.2043366924515}, {-208.1506386, \
-199.63498260859095`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-237.9916195, -240.5613070892712}, {-237.9916195, \
-228.5934861192386}}], 
         LineBox[{{-237.9916195, -228.5934861192386}, {-237.9916195, \
-216.62566514920601`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-194.85839919999998`, -203.29724910322594`}, \
{-194.85839919999998`, -197.09856169922213`}}], 
         LineBox[{{-194.85839919999998`, -197.09856169922213`}, \
{-194.85839919999998`, -190.89987429521832`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-9.149641981, -12.436472762726012`}, {-9.149641981, \
-10.679646758204825`}}], 
         LineBox[{{-9.149641981, -10.679646758204825`}, {-9.149641981, \
-8.922820753683638}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-8.88795049, -11.798759367491524`}, {-8.88795049, \
-10.107147454526121`}}], 
         LineBox[{{-8.88795049, -10.107147454526121`}, {-8.88795049, \
-8.415535541560718}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-26.32007868, -26.67705622567337}, {-26.32007868, \
-25.648844668354197`}}], 
         LineBox[{{-26.32007868, -25.648844668354197`}, {-26.32007868, \
-24.620633111035026`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-265.3268835, -274.4658676660254}, {-265.3268835, \
-263.9547080262316}}], 
         LineBox[{{-265.3268835, -263.9547080262316}, {-265.3268835, \
-253.44354838643773`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-202.0654875, -279.75209605226337`}, {-202.0654875, \
-246.791332545446}}], 
         LineBox[{{-202.0654875, -246.791332545446}, {-202.0654875, \
-213.83056903862865`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.8209092, -16.776221778179288`}, {-16.8209092, \
-15.555588161122257`}}], 
         LineBox[{{-16.8209092, -15.555588161122257`}, {-16.8209092, \
-14.334954544065225`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.26318901, -23.684981723667583`}, {-17.26318901, \
-20.83989575200867}}], 
         LineBox[{{-17.26318901, -20.83989575200867}, {-17.26318901, \
-17.994809780349755`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-27.329169860000004`, -26.522216765609986`}, \
{-27.329169860000004`, -24.42575923659803}}], 
         LineBox[{{-27.329169860000004`, -24.42575923659803}, \
{-27.329169860000004`, -22.329301707586072`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-275.1241365, -289.1182898380611}, {-275.1241365, \
-278.58315855155183`}}], 
         LineBox[{{-275.1241365, -278.58315855155183`}, {-275.1241365, \
-268.04802726504255`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-157.8115118, -156.51880928160955`}, {-157.8115118, \
-142.99702225754822`}}], 
         LineBox[{{-157.8115118, -142.99702225754822`}, {-157.8115118, \
-129.4752352334869}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.10527795, -20.559838312074863`}, {-19.10527795, \
-19.027221833964283`}}], 
         LineBox[{{-19.10527795, -19.027221833964283`}, {-19.10527795, \
-17.494605355853704`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-201.14569259999996`, -202.31498019789436`}, \
{-201.14569259999996`, -188.59231073190278`}}], 
         LineBox[{{-201.14569259999996`, -188.59231073190278`}, \
{-201.14569259999996`, -174.8696412659112}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-200.4144209, -206.50319863089985`}, {-200.4144209, \
-198.78464496522366`}}], 
         LineBox[{{-200.4144209, -198.78464496522366`}, {-200.4144209, \
-191.06609129954748`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.85857321, -21.17406294649185}, {-20.85857321, \
-18.609635740207313`}}], 
         LineBox[{{-20.85857321, -18.609635740207313`}, {-20.85857321, \
-16.045208533922775`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-160.4460193, -167.29751920709282`}, {-160.4460193, \
-155.86026025134788`}}], 
         LineBox[{{-160.4460193, -155.86026025134788`}, {-160.4460193, \
-144.42300129560294`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.289639940000002`, -12.939976587769001`}, \
{-11.289639940000002`, -11.334570477978847`}}], 
         LineBox[{{-11.289639940000002`, -11.334570477978847`}, \
{-11.289639940000002`, -9.729164368188693}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.48687999, -21.29928639359041}, {-19.48687999, \
-19.618291023050418`}}], 
         LineBox[{{-19.48687999, -19.618291023050418`}, {-19.48687999, \
-17.937295652510425`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-26.99772652, -27.13763968200041}, {-26.99772652, \
-25.690262361721707`}}], 
         LineBox[{{-26.99772652, -25.690262361721707`}, {-26.99772652, \
-24.242885041443003`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.613411750000001`, -18.221160509087397`}, \
{-14.613411750000001`, -16.445544064584944`}}], 
         LineBox[{{-14.613411750000001`, -16.445544064584944`}, \
{-14.613411750000001`, -14.669927620082492`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.934760210000004`, -22.179849116634006`}, \
{-19.934760210000004`, -19.846257281878238`}}], 
         LineBox[{{-19.934760210000004`, -19.846257281878238`}, \
{-19.934760210000004`, -17.51266544712247}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-22.95419956, -23.982798735320976`}, {-22.95419956, \
-20.63722345119951}}], 
         LineBox[{{-22.95419956, -20.63722345119951}, {-22.95419956, \
-17.291648167078044`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.93946703, -17.770835518215282`}, {-16.93946703, \
-16.270895070024416`}}], 
         LineBox[{{-16.93946703, -16.270895070024416`}, {-16.93946703, \
-14.770954621833548`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.883572570000002`, -17.563004543929182`}, \
{-16.883572570000002`, -15.985138330800737`}}], 
         LineBox[{{-16.883572570000002`, -15.985138330800737`}, \
{-16.883572570000002`, -14.407272117672292`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-9.316867899, -12.270433815192616`}, {-9.316867899, \
-10.717025025886077`}}], 
         LineBox[{{-9.316867899, -10.717025025886077`}, {-9.316867899, \
-9.163616236579537}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-171.1183842, -208.93417719043418`}, {-171.1183842, \
-194.05440959777619`}}], 
         LineBox[{{-171.1183842, -194.05440959777619`}, {-171.1183842, \
-179.1746420051182}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.87866815, -17.440089367999352`}, {-17.87866815, \
-15.599849884265197`}}], 
         LineBox[{{-17.87866815, -15.599849884265197`}, {-17.87866815, \
-13.75961040053104}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-26.60237435, -26.307145467221623`}, {-26.60237435, \
-24.787210657393352`}}], 
         LineBox[{{-26.60237435, -24.787210657393352`}, {-26.60237435, \
-23.26727584756508}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.459562930000002`, -15.631648283056556`}, \
{-10.459562930000002`, -12.24240026876752}}], 
         LineBox[{{-10.459562930000002`, -12.24240026876752}, \
{-10.459562930000002`, -8.853152254478484}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-24.69345016, -26.194572713154635`}, {-24.69345016, \
-24.98576574696051}}], 
         LineBox[{{-24.69345016, -24.98576574696051}, {-24.69345016, \
-23.776958780766385`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-186.8299757, -223.42285716975806`}, {-186.8299757, \
-206.4969916401619}}], 
         LineBox[{{-186.8299757, -206.4969916401619}, {-186.8299757, \
-189.57112611056573`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-148.7923932, -172.50977564094404`}, {-148.7923932, \
-162.87630077193094`}}], 
         LineBox[{{-148.7923932, -162.87630077193094`}, {-148.7923932, \
-153.24282590291784`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-221.2628344, -220.3140312409215}, {-221.2628344, \
-197.37611587769794`}}], 
         LineBox[{{-221.2628344, -197.37611587769794`}, {-221.2628344, \
-174.43820051447437`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-174.8599667, -206.4049332743356}, {-174.8599667, \
-188.31384579314653`}}], 
         LineBox[{{-174.8599667, -188.31384579314653`}, {-174.8599667, \
-170.22275831195745`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-176.6532627, -196.71110948685165`}, {-176.6532627, \
-178.4621918073268}}], 
         LineBox[{{-176.6532627, -178.4621918073268}, {-176.6532627, \
-160.21327412780195`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.562546430000005`, -20.21520192515458}, \
{-17.562546430000005`, -18.623927787494953`}}], 
         LineBox[{{-17.562546430000005`, -18.623927787494953`}, \
{-17.562546430000005`, -17.032653649835325`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-26.57267167, -26.158654357455095`}, {-26.57267167, \
-22.097609497968982`}}], 
         LineBox[{{-26.57267167, -22.097609497968982`}, {-26.57267167, \
-18.03656463848287}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-12.79651106, -13.030741336725534`}, {-12.79651106, \
-11.69946583927298}}], 
         LineBox[{{-12.79651106, -11.69946583927298}, {-12.79651106, \
-10.368190341820426`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-229.3900495, -271.18743940668423`}, {-229.3900495, \
-250.32126842574388`}}], 
         LineBox[{{-229.3900495, -250.32126842574388`}, {-229.3900495, \
-229.4550974448035}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-242.1760127, -249.8107516644275}, {-242.1760127, \
-228.04542066402848`}}], 
         LineBox[{{-242.1760127, -228.04542066402848`}, {-242.1760127, \
-206.28008966362947`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-163.8709939, -181.8322050495751}, {-163.8709939, \
-170.1341025065013}}], 
         LineBox[{{-163.8709939, -170.1341025065013}, {-163.8709939, \
-158.43599996342752`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.550604040000001`, -15.52100591398727}, \
{-10.550604040000001`, -12.822067791142807`}}], 
         LineBox[{{-10.550604040000001`, -12.822067791142807`}, \
{-10.550604040000001`, -10.123129668298343`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-25.27168612, -26.510770977651212`}, {-25.27168612, \
-25.34799230277931}}], 
         LineBox[{{-25.27168612, -25.34799230277931}, {-25.27168612, \
-24.18521362790741}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.51722316, -23.455148138682215`}, {-18.51722316, \
-21.311228857389537`}}], 
         LineBox[{{-18.51722316, -21.311228857389537`}, {-18.51722316, \
-19.16730957609686}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.01189846, -12.162808255055541`}, {-10.01189846, \
-10.848971096401712`}}], 
         LineBox[{{-10.01189846, -10.848971096401712`}, {-10.01189846, \
-9.535133937747883}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-198.7701134, -269.5745839426283}, {-198.7701134, \
-237.37468842368696`}}], 
         LineBox[{{-198.7701134, -237.37468842368696`}, {-198.7701134, \
-205.17479290474563`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-25.21286685, -25.629398477463173`}, {-25.21286685, \
-22.23601585751161}}], 
         LineBox[{{-25.21286685, -22.23601585751161}, {-25.21286685, \
-18.842633237560047`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-285.3340905, -284.4018290326}, {-285.3340905, \
-259.0866910556579}}], 
         LineBox[{{-285.3340905, -259.0866910556579}, {-285.3340905, \
-233.77155307871584`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-217.0840006, -219.58466212386242`}, {-217.0840006, \
-203.04425717197446`}}], 
         LineBox[{{-217.0840006, -203.04425717197446`}, {-217.0840006, \
-186.50385222008651`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-21.93894465, -20.06939172101742}, {-21.93894465, \
-17.15769587885823}}], 
         LineBox[{{-21.93894465, -17.15769587885823}, {-21.93894465, \
-14.246000036699042`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-298.3052986, -304.95410614901004`}, {-298.3052986, \
-269.1286778390928}}], 
         LineBox[{{-298.3052986, -269.1286778390928}, {-298.3052986, \
-233.30324952917556`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-9.214259077, -16.84059840946218}, {-9.214259077, \
-13.145660021335344`}}], 
         LineBox[{{-9.214259077, -13.145660021335344`}, {-9.214259077, \
-9.450721633208508}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-210.0623176, -210.82376484067075`}, {-210.0623176, \
-187.1937963000971}}], 
         LineBox[{{-210.0623176, -187.1937963000971}, {-210.0623176, \
-163.56382775952343`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-12.38874648, -14.491576305863715`}, {-12.38874648, \
-12.565161107176467`}}], 
         LineBox[{{-12.38874648, -12.565161107176467`}, {-12.38874648, \
-10.638745908489218`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-25.924982000000004`, -27.265612188627813`}, \
{-25.924982000000004`, -26.172601771589523`}}], 
         LineBox[{{-25.924982000000004`, -26.172601771589523`}, \
{-25.924982000000004`, -25.079591354551233`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-23.26314835, -24.413463473995467`}, {-23.26314835, \
-20.661266143374185`}}], 
         LineBox[{{-23.26314835, -20.661266143374185`}, {-23.26314835, \
-16.909068812752903`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.13116346, -16.617563669252014`}, {-16.13116346, \
-14.236833505358018`}}], 
         LineBox[{{-16.13116346, -14.236833505358018`}, {-16.13116346, \
-11.85610334146402}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-160.9841309, -167.11924258766862`}, {-160.9841309, \
-148.6980962256985}}], 
         LineBox[{{-160.9841309, -148.6980962256985}, {-160.9841309, \
-130.27694986372836`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-195.9553161, -212.14589264690116`}, {-195.9553161, \
-200.9448103217887}}], 
         LineBox[{{-195.9553161, -200.9448103217887}, {-195.9553161, \
-189.74372799667626`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-163.9771482, -161.03795191852237`}, {-163.9771482, \
-145.87482361718344`}}], 
         LineBox[{{-163.9771482, -145.87482361718344`}, {-163.9771482, \
-130.7116953158445}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-28.72382556, -25.269254630792567`}, {-28.72382556, \
-21.38963084422141}}], 
         LineBox[{{-28.72382556, -21.38963084422141}, {-28.72382556, \
-17.510007057650256`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.97762995, -19.361877436155503`}, {-18.97762995, \
-17.96515564858423}}], 
         LineBox[{{-18.97762995, -17.96515564858423}, {-18.97762995, \
-16.568433861012956`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.483490190000001`, -17.752377605082735`}, \
{-14.483490190000001`, -15.60824303488247}}], 
         LineBox[{{-14.483490190000001`, -15.60824303488247}, \
{-14.483490190000001`, -13.464108464682205`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-9.973634154, -12.606821196653947`}, {-9.973634154, \
-11.035369539095385`}}], 
         LineBox[{{-9.973634154, -11.035369539095385`}, {-9.973634154, \
-9.463917881536823}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-166.38396979999996`, -190.20246125109998`}, \
{-166.38396979999996`, -174.5070248361845}}], 
         LineBox[{{-166.38396979999996`, -174.5070248361845}, \
{-166.38396979999996`, -158.81158842126905`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-27.10169306, -27.021674093753216`}, {-27.10169306, \
-25.856496231201856`}}], 
         LineBox[{{-27.10169306, -25.856496231201856`}, {-27.10169306, \
-24.691318368650496`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-145.1252574, -181.50166607983792`}, {-145.1252574, \
-160.36204500637686`}}], 
         LineBox[{{-145.1252574, -160.36204500637686`}, {-145.1252574, \
-139.2224239329158}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-132.2719048, -188.0093689821227}, {-132.2719048, \
-161.7460622334238}}], 
         LineBox[{{-132.2719048, -161.7460622334238}, {-132.2719048, \
-135.4827554847249}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-183.4070806, -233.0676471601136}, {-183.4070806, \
-206.10766240959836`}}], 
         LineBox[{{-183.4070806, -206.10766240959836`}, {-183.4070806, \
-179.14767765908312`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-22.12438647, -24.028353121911657`}, {-22.12438647, \
-22.663157150986784`}}], 
         LineBox[{{-22.12438647, -22.663157150986784`}, {-22.12438647, \
-21.29796118006191}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-167.5457065, -176.94087144989751`}, {-167.5457065, \
-165.3766793451029}}], 
         LineBox[{{-167.5457065, -165.3766793451029}, {-167.5457065, \
-153.8124872403083}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-125.0022655, -149.31596649199733`}, {-125.0022655, \
-137.88504570688707`}}], 
         LineBox[{{-125.0022655, -137.88504570688707`}, {-125.0022655, \
-126.45412492177681`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.26850502, -18.289709752217696`}, {-16.26850502, \
-16.78118847613406}}], 
         LineBox[{{-16.26850502, -16.78118847613406}, {-16.26850502, \
-15.272667200050423`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-151.7342835, -184.95661809942865`}, {-151.7342835, \
-165.65769963262036`}}], 
         LineBox[{{-151.7342835, -165.65769963262036`}, {-151.7342835, \
-146.35878116581208`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-25.909891810000005`, -26.385286445884276`}, \
{-25.909891810000005`, -24.88876575509279}}], 
         LineBox[{{-25.909891810000005`, -24.88876575509279}, \
{-25.909891810000005`, -23.392245064301306`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-13.523884870000002`, -14.264877094231666`}, \
{-13.523884870000002`, -13.041578538578914`}}], 
         LineBox[{{-13.523884870000002`, -13.041578538578914`}, \
{-13.523884870000002`, -11.818279982926162`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-202.8723963, -207.1780297093231}, {-202.8723963, \
-188.12934123154733`}}], 
         LineBox[{{-202.8723963, -188.12934123154733`}, {-202.8723963, \
-169.08065275377155`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-182.2785655, -216.29674624538814`}, {-182.2785655, \
-200.87076086235277`}}], 
         LineBox[{{-182.2785655, -200.87076086235277`}, {-182.2785655, \
-185.4447754793174}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-157.9697799, -166.0014253536361}, {-157.9697799, \
-151.67530508809816`}}], 
         LineBox[{{-157.9697799, -151.67530508809816`}, {-157.9697799, \
-137.3491848225602}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-265.539623, -268.80390044678194`}, {-265.539623, \
-252.18581303668478`}}], 
         LineBox[{{-265.539623, -252.18581303668478`}, {-265.539623, \
-235.56772562658765`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.82898498, -26.608163391605895`}, {-18.82898498, \
-22.819088378002583`}}], 
         LineBox[{{-18.82898498, -22.819088378002583`}, {-18.82898498, \
-19.03001336439927}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-26.82142231, -26.077926069859878`}, {-26.82142231, \
-22.312400011575996`}}], 
         LineBox[{{-26.82142231, -22.312400011575996`}, {-26.82142231, \
-18.546873953292113`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-9.720362418000002, -12.113898477859546`}, \
{-9.720362418000002, -10.54938373742132}}], 
         LineBox[{{-9.720362418000002, -10.54938373742132}, \
{-9.720362418000002, -8.984868996983092}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-132.9528368, -165.26185609735558`}, {-132.9528368, \
-150.24573924124715`}}], 
         LineBox[{{-132.9528368, -150.24573924124715`}, {-132.9528368, \
-135.22962238513873`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-177.69012579999998`, -221.80842398609306`}, \
{-177.69012579999998`, -198.51818468037533`}}], 
         LineBox[{{-177.69012579999998`, -198.51818468037533`}, \
{-177.69012579999998`, -175.2279453746576}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-13.538890280000002`, -17.730231690122757`}, \
{-13.538890280000002`, -15.478240751743071`}}], 
         LineBox[{{-13.538890280000002`, -15.478240751743071`}, \
{-13.538890280000002`, -13.226249813363385`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.79345329, -19.193367896322986`}, {-17.79345329, \
-17.055573020750586`}}], 
         LineBox[{{-17.79345329, -17.055573020750586`}, {-17.79345329, \
-14.917778145178184`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.13949555, -19.81376228776169}, {-20.13949555, \
-16.388974099829756`}}], 
         LineBox[{{-20.13949555, -16.388974099829756`}, {-20.13949555, \
-12.964185911897822`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-180.0195428, -190.95715976787153`}, {-180.0195428, \
-177.5999794069482}}], 
         LineBox[{{-180.0195428, -177.5999794069482}, {-180.0195428, \
-164.24279904602486`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.28238847, -20.427997694854866`}, {-18.28238847, \
-17.708804987469406`}}], 
         LineBox[{{-18.28238847, -17.708804987469406`}, {-18.28238847, \
-14.989612280083945`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.88323105, -16.070673677535265`}, {-15.88323105, \
-14.545682299742845`}}], 
         LineBox[{{-15.88323105, -14.545682299742845`}, {-15.88323105, \
-13.020690921950425`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-23.49300352, -24.393752997411163`}, {-23.49300352, \
-22.577191377031816`}}], 
         LineBox[{{-23.49300352, -22.577191377031816`}, {-23.49300352, \
-20.76062975665247}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-227.8821207, -247.5601805842451}, {-227.8821207, \
-227.86639756162268`}}], 
         LineBox[{{-227.8821207, -227.86639756162268`}, {-227.8821207, \
-208.17261453900025`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.23032148, -12.0219137227179}, {-10.23032148, \
-10.945117122970592`}}], 
         LineBox[{{-10.23032148, -10.945117122970592`}, {-10.23032148, \
-9.868320523223284}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-5.596007313000001, -14.042169618764394`}, \
{-5.596007313000001, -10.134153469726039`}}], 
         LineBox[{{-5.596007313000001, -10.134153469726039`}, \
{-5.596007313000001, -6.226137320687684}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-258.1159602, -269.4307512072926}, {-258.1159602, \
-252.21560277928603`}}], 
         LineBox[{{-258.1159602, -252.21560277928603`}, {-258.1159602, \
-235.00045435127944`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-8.073890581, -11.743232053786318`}, {-8.073890581, \
-9.578442366909018}}], 
         LineBox[{{-8.073890581, -9.578442366909018}, {-8.073890581, \
-7.413652680031718}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-291.00694999999996`, -275.9306857684762}, \
{-291.00694999999996`, -252.21279459124358`}}], 
         LineBox[{{-291.00694999999996`, -252.21279459124358`}, \
{-291.00694999999996`, -228.4949034140109}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-198.46491809999998`, -208.6082559453794}, \
{-198.46491809999998`, -202.0586273594206}}], 
         LineBox[{{-198.46491809999998`, -202.0586273594206}, \
{-198.46491809999998`, -195.5089987734618}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-234.02369969999998`, -240.5658938403552}, \
{-234.02369969999998`, -215.14218877771427`}}], 
         LineBox[{{-234.02369969999998`, -215.14218877771427`}, \
{-234.02369969999998`, -189.71848371507335`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-142.777125, -179.10033952641993`}, {-142.777125, \
-157.22958204406453`}}], 
         LineBox[{{-142.777125, -157.22958204406453`}, {-142.777125, \
-135.35882456170913`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-189.1280829, -192.0793136797585}, {-189.1280829, \
-182.7839843929815}}], 
         LineBox[{{-189.1280829, -182.7839843929815}, {-189.1280829, \
-173.48865510620448`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-237.08169529999998`, -246.8083563134253}, \
{-237.08169529999998`, -235.37909765819606`}}], 
         LineBox[{{-237.08169529999998`, -235.37909765819606`}, \
{-237.08169529999998`, -223.94983900296683`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-22.89029348, -23.328428010900854`}, {-22.89029348, \
-21.574153729516954`}}], 
         LineBox[{{-22.89029348, -21.574153729516954`}, {-22.89029348, \
-19.819879448133054`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-5.104339631, -12.25534262389591}, {-5.104339631, \
-9.109127770293947}}], 
         LineBox[{{-5.104339631, -9.109127770293947}, {-5.104339631, \
-5.962912916691984}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-154.93789629999998`, -188.84305482977004`}, \
{-154.93789629999998`, -166.96682479253565`}}], 
         LineBox[{{-154.93789629999998`, -166.96682479253565`}, \
{-154.93789629999998`, -145.09059475530125`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.118434470000002`, -17.887939218931372`}, \
{-15.118434470000002`, -16.291828517721303`}}], 
         LineBox[{{-15.118434470000002`, -16.291828517721303`}, \
{-15.118434470000002`, -14.695717816511232`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-8.367808354, -14.309537963852252`}, {-8.367808354, \
-12.345025098331222`}}], 
         LineBox[{{-8.367808354, -12.345025098331222`}, {-8.367808354, \
-10.380512232810192`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-321.24558, -322.36467160679456`}, {-321.24558, \
-279.93840357455264`}}], 
         LineBox[{{-321.24558, -279.93840357455264`}, {-321.24558, \
-237.51213554231072`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.48032204, -24.391949443027123`}, {-20.48032204, \
-22.742436565175133`}}], 
         LineBox[{{-20.48032204, -22.742436565175133`}, {-20.48032204, \
-21.092923687323143`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-196.7643998, -215.05188874427702`}, {-196.7643998, \
-203.09758690117326`}}], 
         LineBox[{{-196.7643998, -203.09758690117326`}, {-196.7643998, \
-191.1432850580695}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-9.908764458, -12.382598727590384`}, {-9.908764458, \
-10.812205947953167`}}], 
         LineBox[{{-9.908764458, -10.812205947953167`}, {-9.908764458, \
-9.24181316831595}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.44067823, -16.80030922781352}, {-11.44067823, \
-13.909990878070332`}}], 
         LineBox[{{-11.44067823, -13.909990878070332`}, {-11.44067823, \
-11.01967252832714}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-23.89939304, -26.311751604857466`}, {-23.89939304, \
-24.726464940699945`}}], 
         LineBox[{{-23.89939304, -24.726464940699945`}, {-23.89939304, \
-23.141178276542423`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.30972519, -18.108024829566663`}, {-17.30972519, \
-16.93062391701052}}], 
         LineBox[{{-17.30972519, -16.93062391701052}, {-17.30972519, \
-15.75322300445438}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-212.122638, -212.0977275702823}, {-212.122638, \
-198.92399175751362`}}], 
         LineBox[{{-212.122638, -198.92399175751362`}, {-212.122638, \
-185.75025594474494`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-249.17699, -247.81408376491666`}, {-249.17699, \
-224.98390174031826`}}], 
         LineBox[{{-249.17699, -224.98390174031826`}, {-249.17699, \
-202.15371971571986`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-173.10551879999997`, -223.16763408282392`}, \
{-173.10551879999997`, -199.81858790507619`}}], 
         LineBox[{{-173.10551879999997`, -199.81858790507619`}, \
{-173.10551879999997`, -176.46954172732845`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-233.3489961, -272.16941478553883`}, {-233.3489961, \
-247.28045121634648`}}], 
         LineBox[{{-233.3489961, -247.28045121634648`}, {-233.3489961, \
-222.39148764715412`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-196.2353429, -229.35154329882778`}, {-196.2353429, \
-214.33336756406567`}}], 
         LineBox[{{-196.2353429, -214.33336756406567`}, {-196.2353429, \
-199.31519182930356`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-13.9643906, -15.267302404834613`}, {-13.9643906, \
-12.840611184926608`}}], 
         LineBox[{{-13.9643906, -12.840611184926608`}, {-13.9643906, \
-10.413919965018604`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-200.5382898, -205.73836670369536`}, {-200.5382898, \
-188.26022267774687`}}], 
         LineBox[{{-200.5382898, -188.26022267774687`}, {-200.5382898, \
-170.78207865179837`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-266.4729081, -260.3226827036589}, {-266.4729081, \
-225.3077882662785}}], 
         LineBox[{{-266.4729081, -225.3077882662785}, {-266.4729081, \
-190.29289382889806`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.715475550000003`, -11.88315134643853}, \
{-10.715475550000003`, -9.686498248937035}}], 
         LineBox[{{-10.715475550000003`, -9.686498248937035}, \
{-10.715475550000003`, -7.48984515143554}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.772409690000003`, -17.430170790224032`}, \
{-16.772409690000003`, -16.30088910229339}}], 
         LineBox[{{-16.772409690000003`, -16.30088910229339}, \
{-16.772409690000003`, -15.171607414362747`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.61459506, -16.733299997041975`}, {-14.61459506, \
-15.39318624663067}}], 
         LineBox[{{-14.61459506, -15.39318624663067}, {-14.61459506, \
-14.053072496219366`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-212.67468, -236.5716679810157}, {-212.67468, \
-217.1793827226007}}], 
         LineBox[{{-212.67468, -217.1793827226007}, {-212.67468, \
-197.7870974641857}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-154.9223522, -161.66511452443245`}, {-154.9223522, \
-151.68032986722085`}}], 
         LineBox[{{-154.9223522, -151.68032986722085`}, {-154.9223522, \
-141.69554521000924`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-201.9410288, -203.93698410556163`}, {-201.9410288, \
-185.3647519147586}}], 
         LineBox[{{-201.9410288, -185.3647519147586}, {-201.9410288, \
-166.7925197239556}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.01507102, -18.550144719620935`}, {-17.01507102, \
-16.33891023332036}}], 
         LineBox[{{-17.01507102, -16.33891023332036}, {-17.01507102, \
-14.127675747019783`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-239.6292468, -238.79016066431964`}, {-239.6292468, \
-223.92260639036405`}}], 
         LineBox[{{-239.6292468, -223.92260639036405`}, {-239.6292468, \
-209.05505211640846`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-188.2129049, -183.2269237982743}, {-188.2129049, \
-164.33743283626268`}}], 
         LineBox[{{-188.2129049, -164.33743283626268`}, {-188.2129049, \
-145.44794187425106`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-165.7132374, -184.27221087179822`}, {-165.7132374, \
-173.1603900613405}}], 
         LineBox[{{-165.7132374, -173.1603900613405}, {-165.7132374, \
-162.0485692508828}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-261.4387335, -259.37321167758}, {-261.4387335, \
-233.62195662851514`}}], 
         LineBox[{{-261.4387335, -233.62195662851514`}, {-261.4387335, \
-207.8707015794503}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-219.9711881, -219.68441692046702`}, {-219.9711881, \
-204.9924265878798}}], 
         LineBox[{{-219.9711881, -204.9924265878798}, {-219.9711881, \
-190.3004362552926}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.930406260000002`, -18.43651875636905}, \
{-14.930406260000002`, -16.593995242882933`}}], 
         LineBox[{{-14.930406260000002`, -16.593995242882933`}, \
{-14.930406260000002`, -14.751471729396815`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-182.0192916, -184.0355192439938}, {-182.0192916, \
-171.09875582107637`}}], 
         LineBox[{{-182.0192916, -171.09875582107637`}, {-182.0192916, \
-158.16199239815893`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-212.35436, -232.34354598772012`}, {-212.35436, \
-216.34317509476247`}}], 
         LineBox[{{-212.35436, -216.34317509476247`}, {-212.35436, \
-200.34280420180482`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.00842529, -18.202965399690783`}, {-17.00842529, \
-16.636301167531077`}}], 
         LineBox[{{-17.00842529, -16.636301167531077`}, {-17.00842529, \
-15.06963693537137}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-12.06865289, -22.337737188133158`}, {-12.06865289, \
-18.502134363935557`}}], 
         LineBox[{{-12.06865289, -18.502134363935557`}, {-12.06865289, \
-14.666531539737957`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-274.52534, -275.8101741500579}, {-274.52534, \
-245.2791551574835}}], 
         LineBox[{{-274.52534, -245.2791551574835}, {-274.52534, \
-214.7481361649091}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.884073550000004`, -18.319199650409978`}, \
{-19.884073550000004`, -14.43100434123872}}], 
         LineBox[{{-19.884073550000004`, -14.43100434123872}, \
{-19.884073550000004`, -10.542809032067463`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-13.48549164, -17.14809540135418}, {-13.48549164, \
-14.688769085678292`}}], 
         LineBox[{{-13.48549164, -14.688769085678292`}, {-13.48549164, \
-12.229442770002402`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.08613704, -21.20749948839118}, {-19.08613704, \
-19.36919221257702}}], 
         LineBox[{{-19.08613704, -19.36919221257702}, {-19.08613704, \
-17.53088493676286}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-232.6728533, -266.6128361562598}, {-232.6728533, \
-242.85215320276436`}}], 
         LineBox[{{-232.6728533, -242.85215320276436`}, {-232.6728533, \
-219.09147024926892`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.17548746, -19.193714833374912`}, {-17.17548746, \
-18.02664366925668}}], 
         LineBox[{{-17.17548746, -18.02664366925668}, {-17.17548746, \
-16.859572505138445`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-227.6384345, -234.73530993935756`}, {-227.6384345, \
-210.8367195752558}}], 
         LineBox[{{-227.6384345, -210.8367195752558}, {-227.6384345, \
-186.93812921115406`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.461596130000002`, -17.57041678743842}, \
{-15.461596130000002`, -16.21215657656381}}], 
         LineBox[{{-15.461596130000002`, -16.21215657656381}, \
{-15.461596130000002`, -14.853896365689204`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-191.30573449999997`, -216.68162081166722`}, \
{-191.30573449999997`, -201.12406733472005`}}], 
         LineBox[{{-191.30573449999997`, -201.12406733472005`}, \
{-191.30573449999997`, -185.5665138577729}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-205.5804008, -216.76690176350107`}, {-205.5804008, \
-208.4679669473228}}], 
         LineBox[{{-205.5804008, -208.4679669473228}, {-205.5804008, \
-200.16903213114452`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-22.277799680000005`, -22.06872447311701}, \
{-22.277799680000005`, -20.66681357179121}}], 
         LineBox[{{-22.277799680000005`, -20.66681357179121}, \
{-22.277799680000005`, -19.26490267046541}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.1802867, -14.590187384021803`}, {-16.1802867, \
-11.802996410290103`}}], 
         LineBox[{{-16.1802867, -11.802996410290103`}, {-16.1802867, \
-9.015805436558402}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.588565950000003`, -19.957374343962705`}, \
{-18.588565950000003`, -18.064776802189577`}}], 
         LineBox[{{-18.588565950000003`, -18.064776802189577`}, \
{-18.588565950000003`, -16.17217926041645}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-12.60218521, -17.30311130375906}, {-12.60218521, \
-15.293927626743043`}}], 
         LineBox[{{-12.60218521, -15.293927626743043`}, {-12.60218521, \
-13.284743949727025`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.008445150000002`, -15.360304710250551`}, \
{-14.008445150000002`, -13.335862189731918`}}], 
         LineBox[{{-14.008445150000002`, -13.335862189731918`}, \
{-14.008445150000002`, -11.311419669213285`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-135.9210085, -145.0641915627327}, {-135.9210085, \
-135.36770362542467`}}], 
         LineBox[{{-135.9210085, -135.36770362542467`}, {-135.9210085, \
-125.67121568811663`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-195.3385784, -207.2631452584531}, {-195.3385784, \
-198.44075407958292`}}], 
         LineBox[{{-195.3385784, -198.44075407958292`}, {-195.3385784, \
-189.61836290071273`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-181.0090623, -224.44237917193615`}, {-181.0090623, \
-205.89206851367652`}}], 
         LineBox[{{-181.0090623, -205.89206851367652`}, {-181.0090623, \
-187.3417578554169}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.410694560000003`, -18.543983148361587`}, \
{-18.410694560000003`, -16.670796536488652`}}], 
         LineBox[{{-18.410694560000003`, -16.670796536488652`}, \
{-18.410694560000003`, -14.797609924615717`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.059923830000002`, -14.278613776416666`}, \
{-14.059923830000002`, -12.275160630832202`}}], 
         LineBox[{{-14.059923830000002`, -12.275160630832202`}, \
{-14.059923830000002`, -10.271707485247738`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.59999831, -17.727820437122915`}, {-14.59999831, \
-15.500749640488545`}}], 
         LineBox[{{-14.59999831, -15.500749640488545`}, {-14.59999831, \
-13.273678843854173`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-9.452459434000001, -15.623759441162997`}, \
{-9.452459434000001, -12.554674672651249`}}], 
         LineBox[{{-9.452459434000001, -12.554674672651249`}, \
{-9.452459434000001, -9.4855899041395}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-198.5987259, -208.90763296054288`}, {-198.5987259, \
-190.31593172015673`}}], 
         LineBox[{{-198.5987259, -190.31593172015673`}, {-198.5987259, \
-171.72423047977057`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-178.7692044, -208.09920200563536`}, {-178.7692044, \
-193.48223101262414`}}], 
         LineBox[{{-178.7692044, -193.48223101262414`}, {-178.7692044, \
-178.86526001961292`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-194.4729821, -230.9173645559976}, {-194.4729821, \
-210.39062340750937`}}], 
         LineBox[{{-194.4729821, -210.39062340750937`}, {-194.4729821, \
-189.86388225902112`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.36316456, -12.977971013884364`}, {-11.36316456, \
-11.761466830329164`}}], 
         LineBox[{{-11.36316456, -11.761466830329164`}, {-11.36316456, \
-10.544962646773964`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-230.610439, -226.5139108594227}, {-230.610439, \
-205.17490910576862`}}], 
         LineBox[{{-230.610439, -205.17490910576862`}, {-230.610439, \
-183.83590735211453`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-177.90309249999999`, -190.1061509519915}, \
{-177.90309249999999`, -179.72008217009176`}}], 
         LineBox[{{-177.90309249999999`, -179.72008217009176`}, \
{-177.90309249999999`, -169.334013388192}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-235.2076761, -238.37276145533147`}, {-235.2076761, \
-227.31944495444893`}}], 
         LineBox[{{-235.2076761, -227.31944495444893`}, {-235.2076761, \
-216.26612845356638`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.68145305, -18.434645434559798`}, {-17.68145305, \
-17.12670207451581}}], 
         LineBox[{{-17.68145305, -17.12670207451581}, {-17.68145305, \
-15.81875871447182}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.60559836, -20.77578380635647}, {-20.60559836, \
-18.83744469679945}}], 
         LineBox[{{-20.60559836, -18.83744469679945}, {-20.60559836, \
-16.899105587242435`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.00794796, -19.65346245900448}, {-19.00794796, \
-17.78868604330424}}], 
         LineBox[{{-19.00794796, -17.78868604330424}, {-19.00794796, \
-15.923909627603997`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-235.69025, -248.8463471275128}, {-235.69025, \
-235.93504411246462`}}], 
         LineBox[{{-235.69025, -235.93504411246462`}, {-235.69025, \
-223.02374109741646`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-26.383318370000005`, -27.75900287676331}, \
{-26.383318370000005`, -24.642128135443862`}}], 
         LineBox[{{-26.383318370000005`, -24.642128135443862`}, \
{-26.383318370000005`, -21.525253394124412`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.80124367, -16.264569014727464`}, {-14.80124367, \
-13.601619709613987`}}], 
         LineBox[{{-14.80124367, -13.601619709613987`}, {-14.80124367, \
-10.93867040450051}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.95241934, -19.956917043786216`}, {-20.95241934, \
-16.912750188932847`}}], 
         LineBox[{{-20.95241934, -16.912750188932847`}, {-20.95241934, \
-13.868583334079478`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-156.0998953, -160.4052343124354}, {-156.0998953, \
-147.04033008397138`}}], 
         LineBox[{{-156.0998953, -147.04033008397138`}, {-156.0998953, \
-133.67542585550737`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-126.6848415, -149.67323144740914`}, {-126.6848415, \
-137.9888621060926}}], 
         LineBox[{{-126.6848415, -137.9888621060926}, {-126.6848415, \
-126.30449276477607`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-247.64144069999998`, -250.9720271688666}, \
{-247.64144069999998`, -238.92240079341863`}}], 
         LineBox[{{-247.64144069999998`, -238.92240079341863`}, \
{-247.64144069999998`, -226.87277441797067`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.034326870000005`, -21.72792775014566}, \
{-19.034326870000005`, -19.037416706890216`}}], 
         LineBox[{{-19.034326870000005`, -19.037416706890216`}, \
{-19.034326870000005`, -16.34690566363477}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.93444314, -16.187369855309022`}, {-15.93444314, \
-14.22972030136918}}], 
         LineBox[{{-15.93444314, -14.22972030136918}, {-15.93444314, \
-12.27207074742934}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-166.1010446, -178.78346109728665`}, {-166.1010446, \
-167.8287061159853}}], 
         LineBox[{{-166.1010446, -167.8287061159853}, {-166.1010446, \
-156.87395113468398`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.9332059, -16.339954780918454`}, {-14.9332059, \
-14.513617341853895`}}], 
         LineBox[{{-14.9332059, -14.513617341853895`}, {-14.9332059, \
-12.687279902789337`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.06816885, -19.08054676457188}, {-16.06816885, \
-16.944484444906752`}}], 
         LineBox[{{-16.06816885, -16.944484444906752`}, {-16.06816885, \
-14.808422125241623`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-22.069685250000003`, -21.75022169985375}, \
{-22.069685250000003`, -18.217247792186637`}}], 
         LineBox[{{-22.069685250000003`, -18.217247792186637`}, \
{-22.069685250000003`, -14.684273884519522`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-254.9438531, -268.54801955028734`}, {-254.9438531, \
-252.99641077511973`}}], 
         LineBox[{{-254.9438531, -252.99641077511973`}, {-254.9438531, \
-237.4448019999521}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-221.3077422, -241.2804799704832}, {-221.3077422, \
-230.90637408946367`}}], 
         LineBox[{{-221.3077422, -230.90637408946367`}, {-221.3077422, \
-220.53226820844412`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-196.1206745, -209.92820581488527`}, {-196.1206745, \
-198.1678013029287}}], 
         LineBox[{{-196.1206745, -198.1678013029287}, {-196.1206745, \
-186.40739679097211`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-172.25085999999996`, -179.52956657467277`}, \
{-172.25085999999996`, -163.00498773587228`}}], 
         LineBox[{{-172.25085999999996`, -163.00498773587228`}, \
{-172.25085999999996`, -146.48040889707178`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-140.9718293, -175.33796939180775`}, {-140.9718293, \
-158.2507963353862}}], 
         LineBox[{{-140.9718293, -158.2507963353862}, {-140.9718293, \
-141.16362327896468`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-22.05424117, -23.35632377326763}, {-22.05424117, \
-21.156594699034294`}}], 
         LineBox[{{-22.05424117, -21.156594699034294`}, {-22.05424117, \
-18.956865624800958`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.3280814, -21.623277879592326`}, {-19.3280814, \
-19.240250172978985`}}], 
         LineBox[{{-19.3280814, -19.240250172978985`}, {-19.3280814, \
-16.857222466365645`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-128.9414524, -184.27170365767665`}, {-128.9414524, \
-154.93586404089606`}}], 
         LineBox[{{-128.9414524, -154.93586404089606`}, {-128.9414524, \
-125.60002442411547`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-27.16299725, -24.62074688585487}, {-27.16299725, \
-20.415468064857723`}}], 
         LineBox[{{-27.16299725, -20.415468064857723`}, {-27.16299725, \
-16.210189243860576`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-214.40795, -228.7052387675469}, {-214.40795, \
-215.11467976154694`}}], 
         LineBox[{{-214.40795, -215.11467976154694`}, {-214.40795, \
-201.524120755547}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.65439725, -21.45195416235505}, {-16.65439725, \
-18.626905266898905`}}], 
         LineBox[{{-16.65439725, -18.626905266898905`}, {-16.65439725, \
-15.801856371442758`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-193.6218514, -205.5389454601933}, {-193.6218514, \
-197.0867059281088}}], 
         LineBox[{{-193.6218514, -197.0867059281088}, {-193.6218514, \
-188.63446639602432`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.38074683, -16.91312806694552}, {-16.38074683, \
-15.37020253159287}}], 
         LineBox[{{-16.38074683, -15.37020253159287}, {-16.38074683, \
-13.827276996240219`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-25.258079340000002`, -26.512567273033024`}, \
{-25.258079340000002`, -25.28178453440207}}], 
         LineBox[{{-25.258079340000002`, -25.28178453440207}, \
{-25.258079340000002`, -24.051001795771118`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-161.344421, -217.1766432978569}, {-161.344421, \
-197.04437698635468`}}], 
         LineBox[{{-161.344421, -197.04437698635468`}, {-161.344421, \
-176.91211067485244`}}]}},
       Antialiasing->False]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVmGlUDV4bxVOkKE0kFalu83TnRhKlNCpJROre252akyFSiAzhn0qUBg0k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       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.007333333333333334], AbsoluteThickness[
       1.6]}, {}}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], Dashing[{0, Small}],
        LineBox[CompressedData["
1:eJxFxW0w03EcAPCdp0uHErKLecgaL5bpNM2E6pyVUDlP05k4EbKtk/GvzWSe
x4iu0Z3z0Io6lsRplSUP83COyrmOo7prqeXh6M7+8nCqF76/F5/7OCfwwq4a
EAiEkH/+PzMbvLbjX9G7+1gl9knqi1YHPFbZ+qAbW3dENC/0NWGHSRwVjdsR
iWoi2vryN6ZwVQaHTmO5603oRQ3r2ev1cniickOrYaNrfr6PWOkpg8uOnU3V
WqMHIhUFTllSmJLeGOA6VgrzLPv8gsnorbtD/qqiErjTkKtdmSuG2y/9qeD7
o6uPtggsFEVwwwZOyNoshFcfUqtcOeh0P4OhphcF8ETSptdJM7QgbbqNxM+H
WfHRwyMaCRzr+UbX44au0/cqhaI8uJ+lU7Kn7sDumfquHAa6v1pxhSvLhb1J
PHLwFzGscp/dxptzYNlhqYN3pAheHDcM2WsnhOtj1X38wVuww55epZUAgylp
0pZA32xY0l6js/glgFOUPEZyWyZsP1y+vSm4CZMHlkwplAy4K9uW/HXhBvxg
n6SAJufDB9R8HamDC5fcS+mMOHMdfkqbN39ZlwLP+ejzmJRkWGVWWvgDS4Rp
Nq0C85l4mEvqN2oe58AfaunexWI2HLU+rnhSGg47l5lOYrEXYCYz/37QxwCY
zq6tPIHT4cSC9u6YenTV86HPIhZ62VRPHZAfh1tehY1cZHjC9vZmBqmYB2ys
3p5n4EfghINUupiFVnNjJINyMpzt2O0YxnCBF3P50WmYE/yoSFPtg9vAHIaL
x7DcGibqxGPhDCu4LMjbmIvth7WHopdO4cZwlNCSEsMwhEfnRjkZGAFOOH27
4Ty+9nb3c0bLljnYChwne2cSj3+H2W6hk1J8Cl74vRUcmLSm3v0viQ2Giw==

        "]]},
      Annotation[#, "Charting`Private`Tag$10449016#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*OverscriptBox[\\(E\\), \\(^\\)]\\)  \
[\\!\\(\\*SubscriptBox[\\(k\\), \\(B\\)]\\)T]\"", TraditionalForm], None}, {
     FormBox[
     "\"E [\\!\\(\\*SubscriptBox[\\(k\\), \\(B\\)]\\)T]\"", TraditionalForm], 
     None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Medium,
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-310, 5}, {-310, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8097537923816104`*^9, {3.809754018554528*^9, 3.8097540352803907`*^9}, {
   3.809754099949095*^9, 3.809754112997416*^9}, 3.809754143173547*^9, 
   3.8097541931458797`*^9},
 CellLabel->
  "Out[111]=",ExpressionUUID->"cf264f19-d4cc-4ea5-a974-94419a64d4f4"],

Cell[BoxData[
 GraphicsBox[{{{
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.452591430000002`, -16.08359022984658}, \
{-10.452591430000002`, -14.456563390413141`}}], 
         LineBox[{{-10.452591430000002`, -14.456563390413141`}, \
{-10.452591430000002`, -12.829536550979704`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-202.192968, -287.47163137155843`}, {-202.192968, \
-253.8013547748957}}], 
         LineBox[{{-202.192968, -253.8013547748957}, {-202.192968, \
-220.131078178233}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-252.11954999999998`, -241.70359289578872`}, \
{-252.11954999999998`, -218.9781903093363}}], 
         LineBox[{{-252.11954999999998`, -218.9781903093363}, \
{-252.11954999999998`, -196.25278772288388`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-215.5739689, -209.65284131039053`}, {-215.5739689, \
-194.5791670916178}}], 
         LineBox[{{-215.5739689, -194.5791670916178}, {-215.5739689, \
-179.50549287284505`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.69029945, -15.921988987962933`}, {-19.69029945, \
-13.102589968098473`}}], 
         LineBox[{{-19.69029945, -13.102589968098473`}, {-19.69029945, \
-10.283190948234012`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-156.9681656, -178.51551128676374`}, {-156.9681656, \
-162.60868474080857`}}], 
         LineBox[{{-156.9681656, -162.60868474080857`}, {-156.9681656, \
-146.7018581948534}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.402835910000002`, -16.68746564441654}, \
{-15.402835910000002`, -14.127207331674649`}}], 
         LineBox[{{-15.402835910000002`, -14.127207331674649`}, \
{-15.402835910000002`, -11.566949018932757`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-152.214854, -169.52591777014038`}, {-152.214854, \
-155.7308747174218}}], 
         LineBox[{{-152.214854, -155.7308747174218}, {-152.214854, \
-141.93583166470324`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-166.2670094, -206.00393758662585`}, {-166.2670094, \
-191.04244779557698`}}], 
         LineBox[{{-166.2670094, -191.04244779557698`}, {-166.2670094, \
-176.0809580045281}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-24.973489780000005`, -24.24897127131743}, \
{-24.973489780000005`, -21.083807848532572`}}], 
         LineBox[{{-24.973489780000005`, -21.083807848532572`}, \
{-24.973489780000005`, -17.918644425747715`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-273.6209767, -280.67760405679456`}, {-273.6209767, \
-267.475805640935}}], 
         LineBox[{{-273.6209767, -267.475805640935}, {-273.6209767, \
-254.2740072250754}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.51465421, -18.822412212476532`}, {-17.51465421, \
-17.08171776717295}}], 
         LineBox[{{-17.51465421, -17.08171776717295}, {-17.51465421, \
-15.34102332186937}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-228.6788813, -215.8389783598491}, {-228.6788813, \
-203.66875876494154`}}], 
         LineBox[{{-228.6788813, -203.66875876494154`}, {-228.6788813, \
-191.49853917003398`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-261.2832517, -266.61546364135995`}, {-261.2832517, \
-251.81353496776654`}}], 
         LineBox[{{-261.2832517, -251.81353496776654`}, {-261.2832517, \
-237.0116062941731}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-199.781755, -221.60072574138948`}, {-199.781755, \
-205.83020768321907`}}], 
         LineBox[{{-199.781755, -205.83020768321907`}, {-199.781755, \
-190.05968962504866`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.65401523, -23.504740119122047`}, {-18.65401523, \
-21.974098927590774`}}], 
         LineBox[{{-18.65401523, -21.974098927590774`}, {-18.65401523, \
-20.4434577360595}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-233.1004677, -238.14368185588444`}, {-233.1004677, \
-216.99659065915338`}}], 
         LineBox[{{-233.1004677, -216.99659065915338`}, {-233.1004677, \
-195.84949946242233`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.58593557, -21.985236958319735`}, {-20.58593557, \
-19.66163270657321}}], 
         LineBox[{{-20.58593557, -19.66163270657321}, {-20.58593557, \
-17.338028454826688`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.035328210000001`, -17.673192633581248`}, \
{-14.035328210000001`, -16.099547886069136`}}], 
         LineBox[{{-14.035328210000001`, -16.099547886069136`}, \
{-14.035328210000001`, -14.525903138557023`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-180.9368838, -232.56866922517304`}, {-180.9368838, \
-209.03328365540784`}}], 
         LineBox[{{-180.9368838, -209.03328365540784`}, {-180.9368838, \
-185.49789808564265`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.2795015, -21.010894362043754`}, {-20.2795015, \
-19.09238897278913}}], 
         LineBox[{{-20.2795015, -19.09238897278913}, {-20.2795015, \
-17.173883583534508`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.63682455, -22.700527426618358`}, {-15.63682455, \
-21.155761495425377`}}], 
         LineBox[{{-15.63682455, -21.155761495425377`}, {-15.63682455, \
-19.610995564232397`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-5.866946123, -14.017380381941702`}, {-5.866946123, \
-12.442987084365884`}}], 
         LineBox[{{-5.866946123, -12.442987084365884`}, {-5.866946123, \
-10.868593786790065`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.1054112, -17.880055645364664`}, {-10.1054112, \
-15.69027443801492}}], 
         LineBox[{{-10.1054112, -15.69027443801492}, {-10.1054112, \
-13.500493230665178`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-230.1019404, -257.7920281074207}, {-230.1019404, \
-235.60653761923209`}}], 
         LineBox[{{-230.1019404, -235.60653761923209`}, {-230.1019404, \
-213.42104713104348`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-291.30778, -247.53809969359176`}, {-291.30778, \
-230.44888208962217`}}], 
         LineBox[{{-291.30778, -230.44888208962217`}, {-291.30778, \
-213.3596644856526}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-12.28408675, -13.034862708386658`}, {-12.28408675, \
-10.917361208145469`}}], 
         LineBox[{{-12.28408675, -10.917361208145469`}, {-12.28408675, \
-8.799859707904279}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-24.67568185, -26.520750261030784`}, {-24.67568185, \
-25.20693008996167}}], 
         LineBox[{{-24.67568185, -25.20693008996167}, {-24.67568185, \
-23.893109918892556`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.480867, -21.918620764138815`}, {-15.480867, \
-20.188886667237874`}}], 
         LineBox[{{-15.480867, -20.188886667237874`}, {-15.480867, \
-18.459152570336933`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-283.1428106, -274.5246387899278}, {-283.1428106, \
-252.23889841880802`}}], 
         LineBox[{{-283.1428106, -252.23889841880802`}, {-283.1428106, \
-229.95315804768828`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.758344080000002`, -14.091748268665416`}, \
{-14.758344080000002`, -12.615862016219314`}}], 
         LineBox[{{-14.758344080000002`, -12.615862016219314`}, \
{-14.758344080000002`, -11.139975763773212`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-287.80513, -279.76312361661815`}, {-287.80513, \
-255.50620753009636`}}], 
         LineBox[{{-287.80513, -255.50620753009636`}, {-287.80513, \
-231.24929144357458`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.75612748, -17.869483142003155`}, {-11.75612748, \
-16.24577164485567}}], 
         LineBox[{{-11.75612748, -16.24577164485567}, {-11.75612748, \
-14.622060147708183`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.47694274, -24.459755120995446`}, {-17.47694274, \
-21.45197143263925}}], 
         LineBox[{{-17.47694274, -21.45197143263925}, {-17.47694274, \
-18.444187744283056`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.56226548, -16.86344329355961}, {-15.56226548, \
-14.673979941133252`}}], 
         LineBox[{{-15.56226548, -14.673979941133252`}, {-15.56226548, \
-12.484516588706894`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-195.6663408, -239.30592823240178`}, {-195.6663408, \
-215.4163712348732}}], 
         LineBox[{{-195.6663408, -215.4163712348732}, {-195.6663408, \
-191.5268142373446}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-161.4118904, -217.1694906539776}, {-161.4118904, \
-202.70016164915643`}}], 
         LineBox[{{-161.4118904, -202.70016164915643`}, {-161.4118904, \
-188.23083264433527`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-13.761870920000002`, -16.9499869074453}, \
{-13.761870920000002`, -15.220785784018718`}}], 
         LineBox[{{-13.761870920000002`, -15.220785784018718`}, \
{-13.761870920000002`, -13.491584660592135`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-214.39039, -225.03284379571397`}, {-214.39039, \
-209.3179401728306}}], 
         LineBox[{{-214.39039, -209.3179401728306}, {-214.39039, \
-193.6030365499472}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-266.5537267, -261.34988018019715`}, {-266.5537267, \
-232.79657120319246`}}], 
         LineBox[{{-266.5537267, -232.79657120319246`}, {-266.5537267, \
-204.24326222618777`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-232.4892347, -280.2589482715307}, {-232.4892347, \
-253.81447345683128`}}], 
         LineBox[{{-232.4892347, -253.81447345683128`}, {-232.4892347, \
-227.3699986421319}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-197.47946709999997`, -218.67419866941927`}, \
{-197.47946709999997`, -203.51461725340727`}}], 
         LineBox[{{-197.47946709999997`, -203.51461725340727`}, \
{-197.47946709999997`, -188.35503583739526`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-150.6709562, -185.1832767667546}, {-150.6709562, \
-166.35000888188628`}}], 
         LineBox[{{-150.6709562, -166.35000888188628`}, {-150.6709562, \
-147.51674099701796`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-163.2012471, -163.7764002418946}, {-163.2012471, \
-148.44076353585046`}}], 
         LineBox[{{-163.2012471, -148.44076353585046`}, {-163.2012471, \
-133.10512682980632`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-171.1272905, -163.8919704623435}, {-171.1272905, \
-149.85249361996745`}}], 
         LineBox[{{-171.1272905, -149.85249361996745`}, {-171.1272905, \
-135.8130167775914}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-13.546501870000002`, -16.014331040565324`}, \
{-13.546501870000002`, -13.411952948229056`}}], 
         LineBox[{{-13.546501870000002`, -13.411952948229056`}, \
{-13.546501870000002`, -10.809574855892789`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-252.8883428, -255.011419920914}, {-252.8883428, \
-231.9429612033868}}], 
         LineBox[{{-252.8883428, -231.9429612033868}, {-252.8883428, \
-208.8745024858596}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-167.91973299999998`, -206.68979839223505`}, \
{-167.91973299999998`, -182.67088178794288`}}], 
         LineBox[{{-167.91973299999998`, -182.67088178794288`}, \
{-167.91973299999998`, -158.6519651836507}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-193.4124013, -222.29780114582707`}, {-193.4124013, \
-205.53628934209294`}}], 
         LineBox[{{-193.4124013, -205.53628934209294`}, {-193.4124013, \
-188.77477753835882`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-28.18247172, -23.04373085369953}, {-28.18247172, \
-20.310114590044396`}}], 
         LineBox[{{-28.18247172, -20.310114590044396`}, {-28.18247172, \
-17.576498326389263`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-156.9436822, -158.09706555868388`}, {-156.9436822, \
-147.35758195627295`}}], 
         LineBox[{{-156.9436822, -147.35758195627295`}, {-156.9436822, \
-136.61809835386202`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.866955680000002`, -22.08944581716387}, \
{-10.866955680000002`, -19.245947373004984`}}], 
         LineBox[{{-10.866955680000002`, -19.245947373004984`}, \
{-10.866955680000002`, -16.4024489288461}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-277.922571, -288.70542224443733`}, {-277.922571, \
-275.7305147598983}}], 
         LineBox[{{-277.922571, -275.7305147598983}, {-277.922571, \
-262.7556072753593}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-4.280727263, -13.135683689522152`}, {-4.280727263, \
-9.86526859450576}}], 
         LineBox[{{-4.280727263, -9.86526859450576}, {-4.280727263, \
-6.5948534994893695`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-239.0259818, -263.1260270915496}, {-239.0259818, \
-249.37199133701688`}}], 
         LineBox[{{-239.0259818, -249.37199133701688`}, {-239.0259818, \
-235.61795558248414`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-171.486215, -181.80559313763382`}, {-171.486215, \
-162.27467623645506`}}], 
         LineBox[{{-171.486215, -162.27467623645506`}, {-171.486215, \
-142.7437593352763}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.44477691, -17.297070553756278`}, {-11.44477691, \
-15.67783842241245}}], 
         LineBox[{{-11.44477691, -15.67783842241245}, {-11.44477691, \
-14.058606291068623`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-231.4164105, -261.60650652193294`}, {-231.4164105, \
-243.40994421135252`}}], 
         LineBox[{{-231.4164105, -243.40994421135252`}, {-231.4164105, \
-225.21338190077213`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-27.08475597, -24.97222495112252}, {-27.08475597, \
-21.31957696575311}}], 
         LineBox[{{-27.08475597, -21.31957696575311}, {-27.08475597, \
-17.6669289803837}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-158.590581, -220.08382795346452`}, {-158.590581, \
-206.20538891660277`}}], 
         LineBox[{{-158.590581, -206.20538891660277`}, {-158.590581, \
-192.32694987974102`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.597435060000002`, -19.076529860519372`}, \
{-15.597435060000002`, -17.024356812453348`}}], 
         LineBox[{{-15.597435060000002`, -17.024356812453348`}, \
{-15.597435060000002`, -14.972183764387324`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-201.0474559, -176.18357186605462`}, {-201.0474559, \
-153.49365472552785`}}], 
         LineBox[{{-201.0474559, -153.49365472552785`}, {-201.0474559, \
-130.80373758500107`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.310022820000002`, -12.60818191538744}, \
{-11.310022820000002`, -10.958372740272779`}}], 
         LineBox[{{-11.310022820000002`, -10.958372740272779`}, \
{-11.310022820000002`, -9.308563565158117}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-136.6105064, -185.06583265476368`}, {-136.6105064, \
-162.5916995717822}}], 
         LineBox[{{-136.6105064, -162.5916995717822}, {-136.6105064, \
-140.1175664888007}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-26.94997182, -19.088266956660803`}, {-26.94997182, \
-16.261822766204908`}}], 
         LineBox[{{-26.94997182, -16.261822766204908`}, {-26.94997182, \
-13.435378575749015`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-25.16425491, -25.268138574293634`}, {-25.16425491, \
-23.10611829915087}}], 
         LineBox[{{-25.16425491, -23.10611829915087}, {-25.16425491, \
-20.94409802400811}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-187.4796539, -201.16184856817742`}, {-187.4796539, \
-185.1224212851796}}], 
         LineBox[{{-187.4796539, -185.1224212851796}, {-187.4796539, \
-169.08299400218178`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.595815280000002`, -21.838501708993228`}, \
{-10.595815280000002`, -19.878544750810622`}}], 
         LineBox[{{-10.595815280000002`, -19.878544750810622`}, \
{-10.595815280000002`, -17.918587792628017`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-127.3825838, -150.84737406093387`}, {-127.3825838, \
-135.45055385394764`}}], 
         LineBox[{{-127.3825838, -135.45055385394764`}, {-127.3825838, \
-120.05373364696142`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-9.491366085, -18.059981578611502`}, {-9.491366085, \
-14.417046782106471`}}], 
         LineBox[{{-9.491366085, -14.417046782106471`}, {-9.491366085, \
-10.77411198560144}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-7.541234718000001, -12.668891831487185`}, \
{-7.541234718000001, -10.940593928645436`}}], 
         LineBox[{{-7.541234718000001, -10.940593928645436`}, \
{-7.541234718000001, -9.212296025803687}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-12.008740730000001`, -20.42758137468445}, \
{-12.008740730000001`, -17.284578538407125`}}], 
         LineBox[{{-12.008740730000001`, -17.284578538407125`}, \
{-12.008740730000001`, -14.1415757021298}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-14.516404840000002`, -16.65621086916681}, \
{-14.516404840000002`, -13.980880874433588`}}], 
         LineBox[{{-14.516404840000002`, -13.980880874433588`}, \
{-14.516404840000002`, -11.305550879700366`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.219611940000002`, -19.968566022802854`}, \
{-11.219611940000002`, -16.60851173343404}}], 
         LineBox[{{-11.219611940000002`, -16.60851173343404}, \
{-11.219611940000002`, -13.248457444065222`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.46927914, -17.832741815820047`}, {-17.46927914, \
-15.557243394371072`}}], 
         LineBox[{{-17.46927914, -15.557243394371072`}, {-17.46927914, \
-13.281744972922098`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-23.399845550000002`, -25.927355516724347`}, \
{-23.399845550000002`, -24.41020285490692}}], 
         LineBox[{{-23.399845550000002`, -24.41020285490692}, \
{-23.399845550000002`, -22.893050193089493`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-206.6846623, -200.10633325252854`}, {-206.6846623, \
-185.94623607815325`}}], 
         LineBox[{{-206.6846623, -185.94623607815325`}, {-206.6846623, \
-171.78613890377795`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.711117860000005`, -22.076602933043144`}, \
{-20.711117860000005`, -20.122993686435727`}}], 
         LineBox[{{-20.711117860000005`, -20.122993686435727`}, \
{-20.711117860000005`, -18.16938443982831}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-198.3854754, -178.4405570668967}, {-198.3854754, \
-157.07356586330658`}}], 
         LineBox[{{-198.3854754, -157.07356586330658`}, {-198.3854754, \
-135.70657465971647`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-10.09458197, -14.727991955247214`}, {-10.09458197, \
-12.48012826606362}}], 
         LineBox[{{-10.09458197, -12.48012826606362}, {-10.09458197, \
-10.232264576880025`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-22.59242554, -22.672606783769517`}, {-22.59242554, \
-19.765941706379955`}}], 
         LineBox[{{-22.59242554, -19.765941706379955`}, {-22.59242554, \
-16.859276628990393`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-133.0975666, -180.6683522988493}, {-133.0975666, \
-170.72721952524324`}}], 
         LineBox[{{-133.0975666, -170.72721952524324`}, {-133.0975666, \
-160.78608675163719`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-159.7965766, -162.23767652572107`}, {-159.7965766, \
-146.97723338311818`}}], 
         LineBox[{{-159.7965766, -146.97723338311818`}, {-159.7965766, \
-131.71679024051528`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-13.55166265, -14.19459322364057}, {-13.55166265, \
-10.943156015314585`}}], 
         LineBox[{{-13.55166265, -10.943156015314585`}, {-13.55166265, \
-7.6917188069886}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.215672570000002`, -18.811385253221772`}, \
{-15.215672570000002`, -16.137845116072338`}}], 
         LineBox[{{-15.215672570000002`, -16.137845116072338`}, \
{-15.215672570000002`, -13.464304978922904`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-12.74204637, -16.32425189208509}, {-12.74204637, \
-13.498790737307939`}}], 
         LineBox[{{-12.74204637, -13.498790737307939`}, {-12.74204637, \
-10.673329582530787`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-173.7177977, -227.57411694212715`}, {-173.7177977, \
-206.27091703260874`}}], 
         LineBox[{{-173.7177977, -206.27091703260874`}, {-173.7177977, \
-184.96771712309032`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-193.11558879999998`, -206.21275361234376`}, \
{-193.11558879999998`, -196.74474372078208`}}], 
         LineBox[{{-193.11558879999998`, -196.74474372078208`}, \
{-193.11558879999998`, -187.2767338292204}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-12.00060878, -18.575950677390555`}, {-12.00060878, \
-16.6953616950895}}], 
         LineBox[{{-12.00060878, -16.6953616950895}, {-12.00060878, \
-14.814772712788445`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-13.838459270000001`, -18.389151110810772`}, \
{-13.838459270000001`, -16.454402164310896`}}], 
         LineBox[{{-13.838459270000001`, -16.454402164310896`}, \
{-13.838459270000001`, -14.519653217811017`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.80179863, -24.83715184309496}, {-20.80179863, \
-23.51160705403352}}], 
         LineBox[{{-20.80179863, -23.51160705403352}, {-20.80179863, \
-22.186062264972076`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-231.6668386, -255.85258985748595`}, {-231.6668386, \
-245.72345102069346`}}], 
         LineBox[{{-231.6668386, -245.72345102069346`}, {-231.6668386, \
-235.59431218390097`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.8303766, -17.854245639757405`}, {-16.8303766, \
-15.969131529630936`}}], 
         LineBox[{{-16.8303766, -15.969131529630936`}, {-16.8303766, \
-14.084017419504466`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-167.7111972, -158.33363546639399`}, {-167.7111972, \
-146.82854585923474`}}], 
         LineBox[{{-167.7111972, -146.82854585923474`}, {-167.7111972, \
-135.3234562520755}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.61514001, -17.118150960127622`}, {-16.61514001, \
-14.361757697669406`}}], 
         LineBox[{{-16.61514001, -14.361757697669406`}, {-16.61514001, \
-11.605364435211191`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-247.58565, -245.00204772020416`}, {-247.58565, \
-216.02131028900914`}}], 
         LineBox[{{-247.58565, -216.02131028900914`}, {-247.58565, \
-187.0405728578141}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-164.4031021, -178.90901222958024`}, {-164.4031021, \
-164.0568391318588}}], 
         LineBox[{{-164.4031021, -164.0568391318588}, {-164.4031021, \
-149.20466603413735`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-12.565501530000002`, -21.192764907643323`}, \
{-12.565501530000002`, -18.746977770324236`}}], 
         LineBox[{{-12.565501530000002`, -18.746977770324236`}, \
{-12.565501530000002`, -16.30119063300515}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-167.4371538, -168.64078411524736`}, {-167.4371538, \
-154.98530185011518`}}], 
         LineBox[{{-167.4371538, -154.98530185011518`}, {-167.4371538, \
-141.329819584983}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-194.8134055, -208.71682057939532`}, {-194.8134055, \
-196.70520095098783`}}], 
         LineBox[{{-194.8134055, -196.70520095098783`}, {-194.8134055, \
-184.69358132258034`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-267.8469255, -276.1723640969882}, {-267.8469255, \
-263.8264222761086}}], 
         LineBox[{{-267.8469255, -263.8264222761086}, {-267.8469255, \
-251.480480455229}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-224.942923, -215.03826060213504`}, {-224.942923, \
-202.52915662900602`}}], 
         LineBox[{{-224.942923, -202.52915662900602`}, {-224.942923, \
-190.020052655877}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.736214950000003`, -17.777884715086184`}, \
{-15.736214950000003`, -16.023990015115483`}}], 
         LineBox[{{-15.736214950000003`, -16.023990015115483`}, \
{-15.736214950000003`, -14.270095315144781`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-250.1519291, -263.7734314983962}, {-250.1519291, \
-245.53088017872372`}}], 
         LineBox[{{-250.1519291, -245.53088017872372`}, {-250.1519291, \
-227.28832885905126`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-248.88074339999997`, -249.79593463054033`}, \
{-248.88074339999997`, -235.01171908087866`}}], 
         LineBox[{{-248.88074339999997`, -235.01171908087866`}, \
{-248.88074339999997`, -220.227503531217}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-7.196171530000001, -11.580666133788794`}, \
{-7.196171530000001, -9.501516920151047}}], 
         LineBox[{{-7.196171530000001, -9.501516920151047}, \
{-7.196171530000001, -7.422367706513301}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-141.8710277, -162.50687668561523`}, {-141.8710277, \
-144.79668300444249`}}], 
         LineBox[{{-141.8710277, -144.79668300444249`}, {-141.8710277, \
-127.08648932326976`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-27.00825379, -20.896334121345646`}, {-27.00825379, \
-17.320954907481102`}}], 
         LineBox[{{-27.00825379, -17.320954907481102`}, {-27.00825379, \
-13.74557569361656}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-25.08293619, -26.38387331192365}, {-25.08293619, \
-24.286620361096855`}}], 
         LineBox[{{-25.08293619, -24.286620361096855`}, {-25.08293619, \
-22.18936741027006}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-9.076562506, -14.287848628450163`}, {-9.076562506, \
-11.692221572120205`}}], 
         LineBox[{{-9.076562506, -11.692221572120205`}, {-9.076562506, \
-9.096594515790247}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-205.153409, -225.86022668002573`}, {-205.153409, \
-212.27982992727073`}}], 
         LineBox[{{-205.153409, -212.27982992727073`}, {-205.153409, \
-198.69943317451572`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-202.1253899, -208.28181402444835`}, {-202.1253899, \
-198.25970125971241`}}], 
         LineBox[{{-202.1253899, -198.25970125971241`}, {-202.1253899, \
-188.23758849497648`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.35430533, -24.32359003247382}, {-16.35430533, \
-22.22405490150119}}], 
         LineBox[{{-16.35430533, -22.22405490150119}, {-16.35430533, \
-20.12451977052856}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.69722556, -16.65370932709684}, {-15.69722556, \
-14.266196241947691`}}], 
         LineBox[{{-15.69722556, -14.266196241947691`}, {-15.69722556, \
-11.87868315679854}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-24.34314783, -22.82563887891814}, {-24.34314783, \
-19.763221403331652`}}], 
         LineBox[{{-24.34314783, -19.763221403331652`}, {-24.34314783, \
-16.700803927745163`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-150.9222046, -171.73652515748523`}, {-150.9222046, \
-155.7436687682736}}], 
         LineBox[{{-150.9222046, -155.7436687682736}, {-150.9222046, \
-139.75081237906198`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-194.3196694, -220.41262267147158`}, {-194.3196694, \
-204.90928685851233`}}], 
         LineBox[{{-194.3196694, -204.90928685851233`}, {-194.3196694, \
-189.40595104555308`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-138.8310933, -147.81845005734124`}, {-138.8310933, \
-135.9505163853742}}], 
         LineBox[{{-138.8310933, -135.9505163853742}, {-138.8310933, \
-124.08258271340713`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-25.942436430000004`, -26.483543344975164`}, \
{-25.942436430000004`, -24.317120374550306`}}], 
         LineBox[{{-25.942436430000004`, -24.317120374550306`}, \
{-25.942436430000004`, -22.15069740412545}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-173.3533045, -222.12020612526635`}, {-173.3533045, \
-198.25756433053297`}}], 
         LineBox[{{-173.3533045, -198.25756433053297`}, {-173.3533045, \
-174.3949225357996}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-214.1880015, -207.03773197238425`}, {-214.1880015, \
-194.76616308330594`}}], 
         LineBox[{{-214.1880015, -194.76616308330594`}, {-214.1880015, \
-182.49459419422763`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-249.5946904, -256.23891947461294`}, {-249.5946904, \
-234.66398191429016`}}], 
         LineBox[{{-249.5946904, -234.66398191429016`}, {-249.5946904, \
-213.08904435396738`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-198.294944, -209.91686832582664`}, {-198.294944, \
-201.92541426207515`}}], 
         LineBox[{{-198.294944, -201.92541426207515`}, {-198.294944, \
-193.93396019832366`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.44868644, -17.061406461068312`}, {-16.44868644, \
-15.18605050263092}}], 
         LineBox[{{-16.44868644, -15.18605050263092}, {-16.44868644, \
-13.310694544193527`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-155.4720648, -150.62854629987686`}, {-155.4720648, \
-139.19077062840782`}}], 
         LineBox[{{-155.4720648, -139.19077062840782`}, {-155.4720648, \
-127.75299495693878`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.99950242, -17.4335277719934}, {-16.99950242, \
-16.039675852580697`}}], 
         LineBox[{{-16.99950242, -16.039675852580697`}, {-16.99950242, \
-14.645823933167993`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.343036990000005`, -22.127853461061683`}, \
{-18.343036990000005`, -20.432660341654028`}}], 
         LineBox[{{-18.343036990000005`, -20.432660341654028`}, \
{-18.343036990000005`, -18.737467222246373`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-231.3836841, -239.4429497597985}, {-231.3836841, \
-217.8222427856907}}], 
         LineBox[{{-231.3836841, -217.8222427856907}, {-231.3836841, \
-196.2015358115829}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.34619017, -20.562073075174958`}, {-18.34619017, \
-18.760089797254906`}}], 
         LineBox[{{-18.34619017, -18.760089797254906`}, {-18.34619017, \
-16.958106519334855`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-137.2083688, -176.54654799515234`}, {-137.2083688, \
-162.46565039243075`}}], 
         LineBox[{{-137.2083688, -162.46565039243075`}, {-137.2083688, \
-148.38475278970915`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-22.16411359, -23.214493787661134`}, {-22.16411359, \
-21.94427946670459}}], 
         LineBox[{{-22.16411359, -21.94427946670459}, {-22.16411359, \
-20.674065145748045`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-228.8679563, -247.35039480144516`}, {-228.8679563, \
-224.40366719634554`}}], 
         LineBox[{{-228.8679563, -224.40366719634554`}, {-228.8679563, \
-201.4569395912459}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.21770702, -23.186999116004444`}, {-20.21770702, \
-20.668079122161583`}}], 
         LineBox[{{-20.21770702, -20.668079122161583`}, {-20.21770702, \
-18.149159128318722`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-200.34562289999997`, -209.00858625574386`}, \
{-200.34562289999997`, -190.8540927432975}}], 
         LineBox[{{-200.34562289999997`, -190.8540927432975}, \
{-200.34562289999997`, -172.69959923085116`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-16.05789764, -16.749128026768574`}, {-16.05789764, \
-15.288541994166781`}}], 
         LineBox[{{-16.05789764, -15.288541994166781`}, {-16.05789764, \
-13.827955961564989`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.57202202, -19.38775161127652}, {-11.57202202, \
-16.39595707271473}}], 
         LineBox[{{-11.57202202, -16.39595707271473}, {-11.57202202, \
-13.404162534152936`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.34208923, -15.790329697887811`}, {-11.34208923, \
-13.584724606597385`}}], 
         LineBox[{{-11.34208923, -13.584724606597385`}, {-11.34208923, \
-11.379119515306959`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.06899218, -19.7722190073433}, {-18.06899218, \
-18.11127143078656}}], 
         LineBox[{{-18.06899218, -18.11127143078656}, {-18.06899218, \
-16.45032385422982}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-20.571342020000003`, -18.887750001380272`}, \
{-20.571342020000003`, -16.800350863759448`}}], 
         LineBox[{{-20.571342020000003`, -16.800350863759448`}, \
{-20.571342020000003`, -14.712951726138622`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-192.0334666, -211.65302966828676`}, {-192.0334666, \
-200.42053030897125`}}], 
         LineBox[{{-192.0334666, -200.42053030897125`}, {-192.0334666, \
-189.18803094965574`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-22.67410847, -27.043613738724176`}, {-22.67410847, \
-25.813658598160753`}}], 
         LineBox[{{-22.67410847, -25.813658598160753`}, {-22.67410847, \
-24.58370345759733}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-136.3388297, -174.64535654071992`}, {-136.3388297, \
-159.22858330753238`}}], 
         LineBox[{{-136.3388297, -159.22858330753238`}, {-136.3388297, \
-143.81181007434483`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-193.2731135, -219.29019749582494`}, {-193.2731135, \
-202.29286943181458`}}], 
         LineBox[{{-193.2731135, -202.29286943181458`}, {-193.2731135, \
-185.29554136780422`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-18.1726578, -25.742618451387766`}, {-18.1726578, \
-22.38772081373989}}], 
         LineBox[{{-18.1726578, -22.38772081373989}, {-18.1726578, \
-19.032823176092013`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-15.17301452, -17.805285294716526`}, {-15.17301452, \
-15.99329899302641}}], 
         LineBox[{{-15.17301452, -15.99329899302641}, {-15.17301452, \
-14.181312691336293`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-173.6078787, -218.9390986589543}, {-173.6078787, \
-192.136249403327}}], 
         LineBox[{{-173.6078787, -192.136249403327}, {-173.6078787, \
-165.33340014769973`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-12.46433826, -19.067958426411824`}, {-12.46433826, \
-17.14829128677881}}], 
         LineBox[{{-12.46433826, -17.14829128677881}, {-12.46433826, \
-15.2286241471458}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-26.932678710000005`, -27.984009500152517`}, \
{-26.932678710000005`, -24.688650323576567`}}], 
         LineBox[{{-26.932678710000005`, -24.688650323576567`}, \
{-26.932678710000005`, -21.393291147000618`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-21.74484064, -23.69813554223413}, {-21.74484064, \
-20.250947953398278`}}], 
         LineBox[{{-21.74484064, -20.250947953398278`}, {-21.74484064, \
-16.803760364562425`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-180.848529, -210.9864424173616}, {-180.848529, \
-192.4045795076202}}], 
         LineBox[{{-180.848529, -192.4045795076202}, {-180.848529, \
-173.82271659787884`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-17.657632000000003`, -21.119673210137083`}, \
{-17.657632000000003`, -17.583324067825824`}}], 
         LineBox[{{-17.657632000000003`, -17.583324067825824`}, \
{-17.657632000000003`, -14.046974925514567`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-195.1780703, -214.437837091971}, {-195.1780703, \
-202.20075379147963`}}], 
         LineBox[{{-195.1780703, -202.20075379147963`}, {-195.1780703, \
-189.96367049098825`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-202.9638538, -202.76265795542264`}, {-202.9638538, \
-186.48222199515624`}}], 
         LineBox[{{-202.9638538, -186.48222199515624`}, {-202.9638538, \
-170.20178603488984`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-277.7060449, -248.4003339888794}, {-277.7060449, \
-229.92377335493552`}}], 
         LineBox[{{-277.7060449, -229.92377335493552`}, {-277.7060449, \
-211.44721272099164`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-282.7374245, -280.5539798594036}, {-282.7374245, \
-264.87238395031807`}}], 
         LineBox[{{-282.7374245, -264.87238395031807`}, {-282.7374245, \
-249.19078804123254`}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-19.16303922, -24.35877618405152}, {-19.16303922, \
-22.761569374419956`}}], 
         LineBox[{{-19.16303922, -22.761569374419956`}, {-19.16303922, \
-21.16436256478839}}]}},
       Antialiasing->False]}, 
     {RGBColor[0.368417, 0.506779, 0.709798], 
      StyleBox[{{}, {
         LineBox[{{-11.46032233, -13.637050365158936`}, {-11.46032233, \
-11.84399398761229}}], 
         LineBox[{{-11.46032233, -11.84399398761229}, {-11.46032233, \
-10.050937610065644`}}]}},
       Antialiasing->False]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVlnk0FAobxrMkt1ISiZR9G2JWa0nZtdiyixkzmBnDmOySblpQuYWkG/pS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       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.009166666666666668], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.009166666666666668], AbsoluteThickness[
       1.6]}, {}}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], Dashing[{0, Small}],
        LineBox[CompressedData["
1:eJxFxW0w03EcAPCdp0uHErKLecgaL5bpNM2E6pyVUDlP05k4EbKtk/GvzWSe
x4iu0Z3z0Io6lsRplSUP83COyrmOo7prqeXh6M7+8nCqF76/F5/7OCfwwq4a
EAiEkH/+PzMbvLbjX9G7+1gl9knqi1YHPFbZ+qAbW3dENC/0NWGHSRwVjdsR
iWoi2vryN6ZwVQaHTmO5603oRQ3r2ev1cniickOrYaNrfr6PWOkpg8uOnU3V
WqMHIhUFTllSmJLeGOA6VgrzLPv8gsnorbtD/qqiErjTkKtdmSuG2y/9qeD7
o6uPtggsFEVwwwZOyNoshFcfUqtcOeh0P4OhphcF8ETSptdJM7QgbbqNxM+H
WfHRwyMaCRzr+UbX44au0/cqhaI8uJ+lU7Kn7sDumfquHAa6v1pxhSvLhb1J
PHLwFzGscp/dxptzYNlhqYN3pAheHDcM2WsnhOtj1X38wVuww55epZUAgylp
0pZA32xY0l6js/glgFOUPEZyWyZsP1y+vSm4CZMHlkwplAy4K9uW/HXhBvxg
n6SAJufDB9R8HamDC5fcS+mMOHMdfkqbN39ZlwLP+ejzmJRkWGVWWvgDS4Rp
Nq0C85l4mEvqN2oe58AfaunexWI2HLU+rnhSGg47l5lOYrEXYCYz/37QxwCY
zq6tPIHT4cSC9u6YenTV86HPIhZ62VRPHZAfh1tehY1cZHjC9vZmBqmYB2ys
3p5n4EfghINUupiFVnNjJINyMpzt2O0YxnCBF3P50WmYE/yoSFPtg9vAHIaL
x7DcGibqxGPhDCu4LMjbmIvth7WHopdO4cZwlNCSEsMwhEfnRjkZGAFOOH27
4Ty+9nb3c0bLljnYChwne2cSj3+H2W6hk1J8Cl74vRUcmLSm3v0viQ2Giw==

        "]]},
      Annotation[#, "Charting`Private`Tag$10450366#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*OverscriptBox[\\(E\\), \\(^\\)]\\)  \
[\\!\\(\\*SubscriptBox[\\(k\\), \\(B\\)]\\)T]\"", TraditionalForm], None}, {
     FormBox[
     "\"E [\\!\\(\\*SubscriptBox[\\(k\\), \\(B\\)]\\)T]\"", TraditionalForm], 
     None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Medium,
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-310, 5}, {-310, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8097537923816104`*^9, {3.809754018554528*^9, 3.8097540352803907`*^9}, {
   3.809754099949095*^9, 3.809754112997416*^9}, 3.809754143173547*^9, 
   3.809754193650494*^9},
 CellLabel->
  "Out[112]=",ExpressionUUID->"3b06ac14-2001-4dbd-bf0b-30d367efe114"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.5389999999999999], Thickness[Small]}], {{}, 
     {RGBColor[0.97858, 0.678934, 0.157834], Opacity[0.5], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.85, 0.}, {-0.8, 1}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{39.93799999999995, 52.415130434782526`}, {
            65.95716916536806, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.8, 0.}, {-0.75, 1}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{51.96513043478253, 64.44226086956516}, {
            65.95716916536806, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.7, 0.}, {-0.65, 1}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{76.01939130434778, 88.49652173913039}, {
            65.95716916536807, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.65, 0.}, {-0.6, 1}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{88.04652173913038, 100.52365217391299`}, {
            65.95716916536807, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.55, 0.}, {-0.5, 2}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{112.1007826086956, 124.57791304347823`}, {
            63.08967477273471, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 2]& ,
         TagBoxNote->"2"],
        StyleBox["2", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[2, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.5, 0.}, {-0.45, 2}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{124.1279130434782, 136.6050434782608}, {
            63.08967477273471, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 2]& ,
         TagBoxNote->"2"],
        StyleBox["2", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[2, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.45, 0.}, {-0.4, 2}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{136.1550434782608, 148.63217391304346`}, {
            63.08967477273471, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 2]& ,
         TagBoxNote->"2"],
        StyleBox["2", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[2, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.4, 0.}, {-0.35, 1}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{148.18217391304344`, 160.65930434782604`}, {
            65.95716916536807, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.35, 0.}, {-0.3, 1}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{160.20930434782605`, 172.68643478260864`}, {
            65.95716916536807, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.3, 0.}, {-0.25, 2}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{172.23643478260865`, 184.71356521739125`}, {
            63.08967477273471, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 2]& ,
         TagBoxNote->"2"],
        StyleBox["2", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[2, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.25, 0.}, {-0.2, 9}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{184.26356521739126`, 196.74069565217388`}, {
            43.01721402430122, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 9]& ,
         TagBoxNote->"9"],
        StyleBox["9", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[9, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.2, 0.}, {-0.15, 13}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{196.29069565217387`, 208.76782608695652`}, {
            31.54723645376778, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 13]& ,
         TagBoxNote->"13"],
        StyleBox["13", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[13, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.15, 0.}, {-0.1, 32}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{208.3178260869565, 
            220.7949565217391}, {-22.93515700626598, 69.27466355800146}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 32]& ,
         TagBoxNote->"32"],
        StyleBox["32", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[32, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.1, 0.}, {-0.05, 44}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{220.3449565217391, 
            232.82208695652173`}, {-57.34508971786629, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 44]& ,
         TagBoxNote->"44"],
        StyleBox["44", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[44, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.05, 0.}, {0., 59}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{232.3720869565217, 
            244.8492173913043}, {-100.35750560736662`, 69.27466355800144}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 59]& ,
         TagBoxNote->"59"],
        StyleBox["59", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[59, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0., 0.}, {0.05, 57}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{244.3992173913043, 
            256.87634782608694`}, {-94.62251682209993, 69.27466355800146}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 57]& ,
         TagBoxNote->"57"],
        StyleBox["57", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[57, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.05, 0.}, {0.1, 48}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{256.4263478260869, 
            268.9034782608695}, {-68.81506728839972, 69.27466355800146}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 48]& ,
         TagBoxNote->"48"],
        StyleBox["48", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[48, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.1, 0.}, {0.15, 24}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{268.45347826086953`, 280.9306086956521}, {
            0.004798134800836351, 69.27466355800146}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 24]& ,
         TagBoxNote->"24"],
        StyleBox["24", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[24, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.15, 0.}, {0.2, 7}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{280.4806086956521, 292.95773913043473`}, {
            48.75220280956791, 69.27466355800146}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 7]& ,
         TagBoxNote->"7"],
        StyleBox["7", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[7, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.2, 0.}, {0.25, 3}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{292.50773913043474`, 304.9848695652173}, {
            60.22218038010134, 69.27466355800146}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 3]& ,
         TagBoxNote->"3"],
        StyleBox["3", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[3, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.25, 0.}, {0.3, 5}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{304.5348695652173, 317.01199999999994`}, {
            54.487191594834634`, 69.27466355800146}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 5]& ,
         TagBoxNote->"5"],
        StyleBox["5", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[5, {FontSize -> Medium}], 
        "Tooltip"]& ]}, {}, {}}}, {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-0.873, 0.},
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox["\"Count\"", TraditionalForm], None}, {
     FormBox["\"Rel. err\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Medium,
  PlotRange->{{-0.85, 0.3}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8097537923816104`*^9, {3.809754018554528*^9, 3.8097540352803907`*^9}, {
   3.809754099949095*^9, 3.809754112997416*^9}, 3.809754143173547*^9, 
   3.8097541938954725`*^9},
 CellLabel->
  "Out[113]=",ExpressionUUID->"f6ee2094-594e-43de-80a1-644ac6a69625"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.574], Thickness[Small]}], {{}, 
     {RGBColor[0.97858, 0.678934, 0.157834], Opacity[0.5], EdgeForm[{Opacity[
      0.574], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-1.4, 0.}, {-1.3, 1}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{39.93800000000001, 55.75599999999997}, {
            66.48179768964657, 70.45642621392508}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-1.2, 0.}, {-1.1, 1}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{70.674, 86.49199999999998}, {66.48179768964658, 
            70.45642621392508}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.9, 0.}, {-0.8, 1}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{116.77799999999999`, 132.59599999999998`}, {
            66.48179768964658, 70.45642621392508}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.8, 0.}, {-0.7, 1}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{132.146, 147.964}, {66.48179768964658, 
            70.45642621392508}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.6, 0.}, {-0.5, 2}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{162.882, 178.7}, {62.95716916536807, 
            70.45642621392508}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 2]& ,
         TagBoxNote->"2"],
        StyleBox["2", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[2, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.5, 0.}, {-0.4, 5}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{178.25, 194.06799999999998`}, {52.38328359253257,
             70.45642621392508}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 5]& ,
         TagBoxNote->"5"],
        StyleBox["5", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[5, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.4, 0.}, {-0.3, 10}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{193.618, 209.43600000000004`}, {
            34.76014097114006, 70.45642621392508}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 10]& ,
         TagBoxNote->"10"],
        StyleBox["10", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[10, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.3, 0.}, {-0.2, 7}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{208.98600000000002`, 224.80400000000003`}, {
            45.33402654397556, 70.45642621392508}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 7]& ,
         TagBoxNote->"7"],
        StyleBox["7", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[7, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.2, 0.}, {-0.1, 19}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{224.354, 240.172}, {3.038484252633552, 
            70.4564262139251}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 19]& ,
         TagBoxNote->"19"],
        StyleBox["19", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[19, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{-0.1, 0.}, {0., 34}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{239.722, 
            255.54000000000002`}, {-49.83094361154396, 70.45642621392508}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 34]& ,
         TagBoxNote->"34"],
        StyleBox["34", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[34, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0., 0.}, {0.1, 48}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{255.08999999999997`, 270.908}, {-99.175742951443,
             70.45642621392511}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 48]& ,
         TagBoxNote->"48"],
        StyleBox["48", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[48, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.1, 0.}, {0.2, 20}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{270.45799999999997`, 
            286.27599999999995`}, {-0.4861442716449744, 70.45642621392511}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 20]& ,
         TagBoxNote->"20"],
        StyleBox["20", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[20, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.2, 0.}, {0.3, 5}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{285.82599999999996`, 301.64399999999995`}, {
            52.38328359253256, 70.45642621392511}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 5]& ,
         TagBoxNote->"5"],
        StyleBox["5", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[5, {FontSize -> Medium}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.3, 0.}, {0.4, 3}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{301.19399999999996`, 317.012}, {
            59.43254064108955, 70.45642621392511}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 3]& ,
         TagBoxNote->"3"],
        StyleBox["3", {FontSize -> Medium}, StripOnInput -> False]],
       Annotation[#, 
        Style[3, {FontSize -> Medium}], 
        "Tooltip"]& ]}, {}, {}}}, {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-1.436, 0.},
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox["\"Count\"", TraditionalForm], None}, {
     FormBox["\"Rel. err\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Medium,
  PlotRange->{{-1.4, 0.4}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8097537923816104`*^9, {3.809754018554528*^9, 3.8097540352803907`*^9}, {
   3.809754099949095*^9, 3.809754112997416*^9}, 3.809754143173547*^9, 
   3.809754194101756*^9},
 CellLabel->
  "Out[114]=",ExpressionUUID->"002b71e1-6c12-487f-a7e0-461c4c54eb67"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{{
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.122592040000004`, -22.040241208242474`}, \
{-19.122592040000004`, -19.716780398996427`}}], 
              LineBox[{{-19.122592040000004`, -19.716780398996427`}, \
{-19.122592040000004`, -17.39331958975038}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-13.29428828, -15.76480328444859}, {-13.29428828, \
-13.61282082678354}}], 
              LineBox[{{-13.29428828, -13.61282082678354}, {-13.29428828, \
-11.460838369118491`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-21.925352060000005`, -22.311748773039913`}, \
{-21.925352060000005`, -21.17176404414137}}], 
              LineBox[{{-21.925352060000005`, -21.17176404414137}, \
{-21.925352060000005`, -20.031779315242826`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-263.1578615, -272.96494399218346`}, {-263.1578615, \
-264.00993685307793`}}], 
              LineBox[{{-263.1578615, -264.00993685307793`}, {-263.1578615, \
-255.0549297139724}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-199.214, -205.55108069930733`}, {-199.214, \
-189.51523432134726`}}], 
              LineBox[{{-199.214, -189.51523432134726`}, {-199.214, \
-173.4793879433872}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.770776970000002`, -18.12212378511592}, \
{-14.770776970000002`, -16.23149722304764}}], 
              LineBox[{{-14.770776970000002`, -16.23149722304764}, \
{-14.770776970000002`, -14.340870660979359`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-202.8522675, -215.6417790591472}, {-202.8522675, \
-206.67256735962857`}}], 
              LineBox[{{-202.8522675, -206.67256735962857`}, {-202.8522675, \
-197.70335566010993`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-197.2202495, -187.83519485631655`}, {-197.2202495, \
-161.03769430604612`}}], 
              LineBox[{{-197.2202495, -161.03769430604612`}, {-197.2202495, \
-134.2401937557757}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-253.7709554, -260.5284147037122}, {-253.7709554, \
-252.16001696943238`}}], 
              LineBox[{{-253.7709554, -252.16001696943238`}, {-253.7709554, \
-243.79161923515255`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-264.7122498, -275.1279764106515}, {-264.7122498, \
-266.88754866450876`}}], 
              LineBox[{{-264.7122498, -266.88754866450876`}, {-264.7122498, \
-258.647120918366}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.0738179, -21.30430256793147}, {-19.0738179, \
-19.015665925820088`}}], 
              LineBox[{{-19.0738179, -19.015665925820088`}, {-19.0738179, \
-16.727029283708706`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-22.96318187, -26.14616886548059}, {-22.96318187, \
-24.589661522599314`}}], 
              LineBox[{{-22.96318187, -24.589661522599314`}, {-22.96318187, \
-23.03315417971804}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-26.002258020000003`, -27.016633661897117`}, \
{-26.002258020000003`, -25.732099312069213`}}], 
              LineBox[{{-26.002258020000003`, -25.732099312069213`}, \
{-26.002258020000003`, -24.44756496224131}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-156.64292209999996`, -209.13103480012106`}, \
{-156.64292209999996`, -182.28962614695624`}}], 
              LineBox[{{-156.64292209999996`, -182.28962614695624`}, \
{-156.64292209999996`, -155.44821749379142`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-253.9884788, -266.1661596420178}, {-253.9884788, \
-254.87474754930884`}}], 
              LineBox[{{-253.9884788, -254.87474754930884`}, {-253.9884788, \
-243.58333545659983`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-203.44583779999996`, -213.51897531816306`}, \
{-203.44583779999996`, -206.89391611163813`}}], 
              LineBox[{{-203.44583779999996`, -206.89391611163813`}, \
{-203.44583779999996`, -200.2688569051132}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.931329430000002`, -19.989915991418716`}, \
{-11.931329430000002`, -16.65502766501253}}], 
              LineBox[{{-11.931329430000002`, -16.65502766501253}, \
{-11.931329430000002`, -13.32013933860634}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-140.2901259, -155.36604155571692`}, {-140.2901259, \
-146.04360235982125`}}], 
              LineBox[{{-140.2901259, -146.04360235982125`}, {-140.2901259, \
-136.72116316392558`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-203.6664668, -201.92121656910336`}, {-203.6664668, \
-186.8988791731109}}], 
              LineBox[{{-203.6664668, -186.8988791731109}, {-203.6664668, \
-171.87654177711846`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.24628378, -19.408802769717006`}, {-18.24628378, \
-18.107443148144885`}}], 
              LineBox[{{-18.24628378, -18.107443148144885`}, {-18.24628378, \
-16.806083526572763`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.80138018, -16.465518408400136`}, {-14.80138018, \
-15.066744072410529`}}], 
              LineBox[{{-14.80138018, -15.066744072410529`}, {-14.80138018, \
-13.667969736420924`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.90194371, -20.74189968587812}, {-17.90194371, \
-19.132295954672138`}}], 
              LineBox[{{-17.90194371, -19.132295954672138`}, {-17.90194371, \
-17.522692223466155`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.40654202, -15.315122346109211`}, {-15.40654202, \
-13.358825950741512`}}], 
              LineBox[{{-15.40654202, -13.358825950741512`}, {-15.40654202, \
-11.402529555373812`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-311.33191, -317.7967301121321}, {-311.33191, \
-279.88579864512764`}}], 
              LineBox[{{-311.33191, -279.88579864512764`}, {-311.33191, \
-241.9748671781232}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-170.54968019999998`, -173.86608476935567`}, \
{-170.54968019999998`, -163.6592149433442}}], 
              LineBox[{{-170.54968019999998`, -163.6592149433442}, \
{-170.54968019999998`, -153.45234511733275`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-190.5494332, -234.16418269362933`}, {-190.5494332, \
-209.09674842627385`}}], 
              LineBox[{{-190.5494332, -209.09674842627385`}, {-190.5494332, \
-184.02931415891837`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-163.9016831, -207.99794691240842`}, {-163.9016831, \
-183.09291531725307`}}], 
              LineBox[{{-163.9016831, -183.09291531725307`}, {-163.9016831, \
-158.18788372209772`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-215.2738442, -207.1047254012853}, {-215.2738442, \
-194.6391494797123}}], 
              LineBox[{{-215.2738442, -194.6391494797123}, {-215.2738442, \
-182.1735735581393}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-191.7750655, -211.93769842643192`}, {-191.7750655, \
-191.94596016715306`}}], 
              LineBox[{{-191.7750655, -191.94596016715306`}, {-191.7750655, \
-171.9542219078742}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-138.1443354, -185.50055640157072`}, {-138.1443354, \
-160.82116956950384`}}], 
              LineBox[{{-138.1443354, -160.82116956950384`}, {-138.1443354, \
-136.14178273743696`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-145.0720654, -186.64512726337387`}, {-145.0720654, \
-165.24290941933268`}}], 
              LineBox[{{-145.0720654, -165.24290941933268`}, {-145.0720654, \
-143.8406915752915}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              
              LineBox[{{-192.5885865, -243.04363971705953`}, {-192.5885865, \
-213.66797477424302`}}], 
              LineBox[{{-192.5885865, -213.66797477424302`}, {-192.5885865, \
-184.2923098314265}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-21.942781440000005`, -22.79909018190355}, \
{-21.942781440000005`, -21.75293909318461}}], 
              LineBox[{{-21.942781440000005`, -21.75293909318461}, \
{-21.942781440000005`, -20.706788004465672`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.15637194, -17.209772499514763`}, {-14.15637194, \
-15.50003103643645}}], 
              LineBox[{{-14.15637194, -15.50003103643645}, {-14.15637194, \
-13.790289573358137`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-261.4747844, -261.8008200386536}, {-261.4747844, \
-243.94095899210942`}}], 
              LineBox[{{-261.4747844, -243.94095899210942`}, {-261.4747844, \
-226.08109794556523`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-229.6294085, -220.75892118576533`}, {-229.6294085, \
-207.71568314737752`}}], 
              LineBox[{{-229.6294085, -207.71568314737752`}, {-229.6294085, \
-194.6724451089897}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-245.2853296, -251.77146365718744`}, {-245.2853296, \
-226.37109824037307`}}], 
              LineBox[{{-245.2853296, -226.37109824037307`}, {-245.2853296, \
-200.9707328235587}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-197.2131662, -224.32046421313788`}, {-197.2131662, \
-209.6059086158994}}], 
              LineBox[{{-197.2131662, -209.6059086158994}, {-197.2131662, \
-194.89135301866094`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-227.8414479, -224.74274697404616`}, {-227.8414479, \
-203.91549453594155`}}], 
              LineBox[{{-227.8414479, -203.91549453594155`}, {-227.8414479, \
-183.08824209783694`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-7.868570001000001, -14.538821621412295`}, \
{-7.868570001000001, -11.921312901652414`}}], 
              LineBox[{{-7.868570001000001, -11.921312901652414`}, \
{-7.868570001000001, -9.303804181892533}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-22.197738360000002`, -23.1591611687038}, \
{-22.197738360000002`, -21.240941374767914`}}], 
              LineBox[{{-22.197738360000002`, -21.240941374767914`}, \
{-22.197738360000002`, -19.322721580832027`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-229.141083, -245.7107716318199}, {-229.141083, \
-231.3466047530391}}], 
              LineBox[{{-229.141083, -231.3466047530391}, {-229.141083, \
-216.98243787425827`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-164.7313033, -165.79588772044136`}, {-164.7313033, \
-152.6382830071093}}], 
              LineBox[{{-164.7313033, -152.6382830071093}, {-164.7313033, \
-139.48067829377723`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.01398646, -20.574793011411035`}, {-18.01398646, \
-18.919432455269227`}}], 
              LineBox[{{-18.01398646, -18.919432455269227`}, {-18.01398646, \
-17.26407189912742}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.61293568, -22.49860864777812}, {-16.61293568, \
-19.57260898234595}}], 
              LineBox[{{-16.61293568, -19.57260898234595}, {-16.61293568, \
-16.646609316913782`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-198.0982712, -211.79558466460927`}, {-198.0982712, \
-191.58039119784718`}}], 
              LineBox[{{-198.0982712, -191.58039119784718`}, {-198.0982712, \
-171.3651977310851}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-157.5460241, -204.21910046591245`}, {-157.5460241, \
-179.41575052167374`}}], 
              LineBox[{{-157.5460241, -179.41575052167374`}, {-157.5460241, \
-154.61240057743504`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-188.8140786, -220.38132089107225`}, {-188.8140786, \
-203.76480627851245`}}], 
              LineBox[{{-188.8140786, -203.76480627851245`}, {-188.8140786, \
-187.14829166595266`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.359806400000002`, -17.411612632669637`}, \
{-14.359806400000002`, -15.671669505674123`}}], 
              LineBox[{{-14.359806400000002`, -15.671669505674123`}, \
{-14.359806400000002`, -13.931726378678608`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.90265974, -23.755225108807334`}, {-19.90265974, \
-21.670400023931656`}}], 
              LineBox[{{-19.90265974, -21.670400023931656`}, {-19.90265974, \
-19.585574939055977`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-10.94159622, -12.146231356460937`}, {-10.94159622, \
-10.483690398752922`}}], 
              LineBox[{{-10.94159622, -10.483690398752922`}, {-10.94159622, \
-8.821149441044906}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-257.6108399, -266.51443120487465`}, {-257.6108399, \
-255.72611886013294`}}], 
              LineBox[{{-257.6108399, -255.72611886013294`}, {-257.6108399, \
-244.93780651539126`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-174.46814, -217.64911941853447`}, {-174.46814, \
-198.74800583723112`}}], 
              LineBox[{{-174.46814, -198.74800583723112`}, {-174.46814, \
-179.84689225592777`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-26.17064523, -26.931207399700927`}, {-26.17064523, \
-23.808209934292037`}}], 
              LineBox[{{-26.17064523, -23.808209934292037`}, {-26.17064523, \
-20.685212468883147`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-10.685667400000002`, -13.581283169213304`}, \
{-10.685667400000002`, -11.312715010820941`}}], 
              LineBox[{{-10.685667400000002`, -11.312715010820941`}, \
{-10.685667400000002`, -9.044146852428579}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-13.389810530000002`, -17.109107005736806`}, \
{-13.389810530000002`, -15.5206069126093}}], 
              LineBox[{{-13.389810530000002`, -15.5206069126093}, \
{-13.389810530000002`, -13.932106819481794`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-235.96036999999998`, -263.9742495356013}, \
{-235.96036999999998`, -249.9414993288295}}], 
              LineBox[{{-235.96036999999998`, -249.9414993288295}, \
{-235.96036999999998`, -235.9087491220577}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-6.600847048000001, -14.48465316758653}, \
{-6.600847048000001, -11.153112823775574`}}], 
              LineBox[{{-6.600847048000001, -11.153112823775574`}, \
{-6.600847048000001, -7.821572479964619}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-183.2164933, -186.9809759313028}, {-183.2164933, \
-173.05465261247394`}}], 
              LineBox[{{-183.2164933, -173.05465261247394`}, {-183.2164933, \
-159.1283292936451}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-244.0067091, -249.79453343426408`}, {-244.0067091, \
-238.13954012868453`}}], 
              LineBox[{{-244.0067091, -238.13954012868453`}, {-244.0067091, \
-226.48454682310498`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-25.97423007, -27.42924487277393}, {-25.97423007, \
-26.258877446711725`}}], 
              LineBox[{{-25.97423007, -26.258877446711725`}, {-25.97423007, \
-25.088510020649522`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.53060212, -20.24433079965609}, {-11.53060212, \
-16.946947148742026`}}], 
              LineBox[{{-11.53060212, -16.946947148742026`}, {-11.53060212, \
-13.649563497827964`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-158.74572139999998`, -172.18168115472037`}, \
{-158.74572139999998`, -163.53182546877983`}}], 
              LineBox[{{-158.74572139999998`, -163.53182546877983`}, \
{-158.74572139999998`, -154.8819697828393}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-24.23603156, -25.707798861705506`}, {-24.23603156, \
-23.800512660897596`}}], 
              LineBox[{{-24.23603156, -23.800512660897596`}, {-24.23603156, \
-21.893226460089686`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-200.5470822, -225.47808631227258`}, {-200.5470822, \
-210.14843063983193`}}], 
              LineBox[{{-200.5470822, -210.14843063983193`}, {-200.5470822, \
-194.81877496739128`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-20.71263041, -21.019626554207303`}, {-20.71263041, \
-17.655117799206117`}}], 
              LineBox[{{-20.71263041, -17.655117799206117`}, {-20.71263041, \
-14.290609044204931`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-20.831368790000003`, -21.246234707413656`}, \
{-20.831368790000003`, -19.7670725756887}}], 
              LineBox[{{-20.831368790000003`, -19.7670725756887}, \
{-20.831368790000003`, -18.287910443963746`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.00780319, -22.290593207107193`}, {-19.00780319, \
-20.63364472460759}}], 
              LineBox[{{-19.00780319, -20.63364472460759}, {-19.00780319, \
-18.976696242107984`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-22.46960909, -22.784974948184566`}, {-22.46960909, \
-20.15681164882372}}], 
              LineBox[{{-22.46960909, -20.15681164882372}, {-22.46960909, \
-17.528648349462873`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-10.92874242, -22.594323274137132`}, {-10.92874242, \
-17.80386013534598}}], 
              LineBox[{{-10.92874242, -17.80386013534598}, {-10.92874242, \
-13.013396996554832`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-176.571878, -215.29550477061855`}, {-176.571878, \
-196.3774287627301}}], 
              LineBox[{{-176.571878, -196.3774287627301}, {-176.571878, \
-177.45935275484163`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-193.7626921, -249.6602878303413}, {-193.7626921, \
-217.79451188462608`}}], 
              LineBox[{{-193.7626921, -217.79451188462608`}, {-193.7626921, \
-185.92873593891085`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.94605626, -22.610480592484414`}, {-16.94605626, \
-19.71093412457734}}], 
              LineBox[{{-16.94605626, -19.71093412457734}, {-16.94605626, \
-16.811387656670263`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-26.26283108, -27.7126693292898}, {-26.26283108, \
-26.47635259392767}}], 
              LineBox[{{-26.26283108, -26.47635259392767}, {-26.26283108, \
-25.240035858565538`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-147.5403296, -177.95445566920463`}, {-147.5403296, \
-160.1781108132016}}], 
              LineBox[{{-147.5403296, -160.1781108132016}, {-147.5403296, \
-142.4017659571986}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.83608012, -22.420153553440553`}, {-16.83608012, \
-19.19171027968257}}], 
              LineBox[{{-16.83608012, -19.19171027968257}, {-16.83608012, \
-15.963267005924589`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-10.43103003, -13.123169038139638`}, {-10.43103003, \
-11.45206381379255}}], 
              LineBox[{{-10.43103003, -11.45206381379255}, {-10.43103003, \
-9.780958589445463}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.740878590000001`, -20.913215769775586`}, \
{-14.740878590000001`, -18.480416283716274`}}], 
              LineBox[{{-14.740878590000001`, -18.480416283716274`}, \
{-14.740878590000001`, -16.04761679765696}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.28176018, -17.3889583689097}, {-17.28176018, \
-15.834609561341756`}}], 
              LineBox[{{-17.28176018, -15.834609561341756`}, {-17.28176018, \
-14.280260753773812`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-12.50387992, -13.039012359074205`}, {-12.50387992, \
-12.01356167032337}}], 
              LineBox[{{-12.50387992, -12.01356167032337}, {-12.50387992, \
-10.988110981572534`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-198.1780966, -209.9322880893029}, {-198.1780966, \
-201.64138327879715`}}], 
              LineBox[{{-198.1780966, -201.64138327879715`}, {-198.1780966, \
-193.3504784682914}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-196.84942059999997`, -237.06681805702542`}, \
{-196.84942059999997`, -218.60228729209666`}}], 
              LineBox[{{-196.84942059999997`, -218.60228729209666`}, \
{-196.84942059999997`, -200.1377565271679}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-222.213379, -254.7725004997617}, {-222.213379, \
-237.49192128704502`}}], 
              LineBox[{{-222.213379, -237.49192128704502`}, {-222.213379, \
-220.21134207432834`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-140.4296433, -179.41056206740373`}, {-140.4296433, \
-155.31121506863934`}}], 
              LineBox[{{-140.4296433, -155.31121506863934`}, {-140.4296433, \
-131.21186806987495`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.53154494, -21.789649204755637`}, {-17.53154494, \
-19.372600842073187`}}], 
              LineBox[{{-17.53154494, -19.372600842073187`}, {-17.53154494, \
-16.955552479390736`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.51894907, -14.856261336444453`}, {-16.51894907, \
-12.822234656923351`}}], 
              LineBox[{{-16.51894907, -12.822234656923351`}, {-16.51894907, \
-10.78820797740225}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-24.078960020000004`, -27.20404000512535}, \
{-24.078960020000004`, -25.782363690244786`}}], 
              LineBox[{{-24.078960020000004`, -25.782363690244786`}, \
{-24.078960020000004`, -24.360687375364222`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-121.3942897, -153.78930069909336`}, {-121.3942897, \
-136.36308096321468`}}], 
              LineBox[{{-121.3942897, -136.36308096321468`}, {-121.3942897, \
-118.936861227336}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-178.9523159, -190.6221740379458}, {-178.9523159, \
-179.73882040880832`}}], 
              LineBox[{{-178.9523159, -179.73882040880832`}, {-178.9523159, \
-168.85546677967085`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-191.6546589, -215.39215141479167`}, {-191.6546589, \
-199.53599187121227`}}], 
              LineBox[{{-191.6546589, -199.53599187121227`}, {-191.6546589, \
-183.67983232763288`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.92335885, -22.23926574686529}, {-17.92335885, \
-19.617470538296264`}}], 
              LineBox[{{-17.92335885, -19.617470538296264`}, {-17.92335885, \
-16.995675329727238`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-169.8586866, -203.6872624338101}, {-169.8586866, \
-188.636384882625}}], 
              LineBox[{{-169.8586866, -188.636384882625}, {-169.8586866, \
-173.5855073314399}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-167.7610048, -203.3107996866294}, {-167.7610048, \
-183.040046835214}}], 
              LineBox[{{-167.7610048, -183.040046835214}, {-167.7610048, \
-162.76929398379863`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-195.3374268, -205.84976536637143`}, {-195.3374268, \
-194.95950374562463`}}], 
              LineBox[{{-195.3374268, -194.95950374562463`}, {-195.3374268, \
-184.06924212487783`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-23.01166885, -24.5606359758041}, {-23.01166885, \
-23.495449742620174`}}], 
              LineBox[{{-23.01166885, -23.495449742620174`}, {-23.01166885, \
-22.430263509436248`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-142.4023942, -178.5606438661326}, {-142.4023942, \
-159.52914307925096`}}], 
              LineBox[{{-142.4023942, -159.52914307925096`}, {-142.4023942, \
-140.4976422923693}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-186.443977, -218.73998291830196`}, {-186.443977, \
-203.1811062659203}}], 
              LineBox[{{-186.443977, -203.1811062659203}, {-186.443977, \
-187.62222961353865`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-242.467544, -249.31774192675465`}, {-242.467544, \
-228.6193368402952}}], 
              LineBox[{{-242.467544, -228.6193368402952}, {-242.467544, \
-207.92093175383576`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.996031230000002`, -19.545328381460887`}, \
{-15.996031230000002`, -17.38779463433937}}], 
              LineBox[{{-15.996031230000002`, -17.38779463433937}, \
{-15.996031230000002`, -15.230260887217856`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-169.0825486, -177.59934186182963`}, {-169.0825486, \
-162.39425810014342`}}], 
              LineBox[{{-169.0825486, -162.39425810014342`}, {-169.0825486, \
-147.1891743384572}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-262.4148731, -268.7113017239387}, {-262.4148731, \
-257.7755322890022}}], 
              LineBox[{{-262.4148731, -257.7755322890022}, {-262.4148731, \
-246.8397628540657}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-26.46909494, -23.91623589337734}, {-26.46909494, \
-19.551881372322768`}}], 
              LineBox[{{-26.46909494, -19.551881372322768`}, {-26.46909494, \
-15.187526851268196`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-127.6290063, -139.2310573236136}, {-127.6290063, \
-128.756055866968}}], 
              LineBox[{{-127.6290063, -128.756055866968}, {-127.6290063, \
-118.28105441032241`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-206.4259915, -205.10652220540317`}, {-206.4259915, \
-190.7773238494553}}], 
              LineBox[{{-206.4259915, -190.7773238494553}, {-206.4259915, \
-176.44812549350746`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-205.9183344, -215.1946157064818}, {-205.9183344, \
-205.70728126369}}], 
              LineBox[{{-205.9183344, -205.70728126369}, {-205.9183344, \
-196.21994682089817`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-157.26507809999998`, -182.31193572801723`}, \
{-157.26507809999998`, -168.99041102637977`}}], 
              LineBox[{{-157.26507809999998`, -168.99041102637977`}, \
{-157.26507809999998`, -155.66888632474232`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-269.4395282, -280.66050982321855`}, {-269.4395282, \
-271.32165242717934`}}], 
              LineBox[{{-269.4395282, -271.32165242717934`}, {-269.4395282, \
-261.98279503114014`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-11.14196342, -17.736827936957184`}, {-11.14196342, \
-14.175190310212509`}}], 
              LineBox[{{-11.14196342, -14.175190310212509`}, {-11.14196342, \
-10.613552683467836`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-13.06116628, -16.794675026008306`}, {-13.06116628, \
-15.194508401645859`}}], 
              LineBox[{{-13.06116628, -15.194508401645859`}, {-13.06116628, \
-13.594341777283411`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.16785021, -14.995398834804563`}, {-16.16785021, \
-11.79489643643592}}], 
              LineBox[{{-16.16785021, -11.79489643643592}, {-16.16785021, \
-8.594394038067277}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.94167053, -20.58194332093363}, {-11.94167053, \
-17.273835156088463`}}], 
              LineBox[{{-11.94167053, -17.273835156088463`}, {-11.94167053, \
-13.965726991243297`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.212622800000002`, -19.790799475074806`}, \
{-19.212622800000002`, -17.097418246448633`}}], 
              LineBox[{{-19.212622800000002`, -17.097418246448633`}, \
{-19.212622800000002`, -14.40403701782246}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-199.0258256, -219.64256900789744`}, {-199.0258256, \
-204.62174002579044`}}], 
              LineBox[{{-199.0258256, -204.62174002579044`}, {-199.0258256, \
-189.60091104368345`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-208.1506386, -224.77369077631207`}, {-208.1506386, \
-212.2043366924515}}], 
              LineBox[{{-208.1506386, -212.2043366924515}, {-208.1506386, \
-199.63498260859095`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-237.9916195, -240.5613070892712}, {-237.9916195, \
-228.5934861192386}}], 
              LineBox[{{-237.9916195, -228.5934861192386}, {-237.9916195, \
-216.62566514920601`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-194.85839919999998`, -203.29724910322594`}, \
{-194.85839919999998`, -197.09856169922213`}}], 
              LineBox[{{-194.85839919999998`, -197.09856169922213`}, \
{-194.85839919999998`, -190.89987429521832`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-9.149641981, -12.436472762726012`}, {-9.149641981, \
-10.679646758204825`}}], 
              LineBox[{{-9.149641981, -10.679646758204825`}, {-9.149641981, \
-8.922820753683638}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-8.88795049, -11.798759367491524`}, {-8.88795049, \
-10.107147454526121`}}], 
              LineBox[{{-8.88795049, -10.107147454526121`}, {-8.88795049, \
-8.415535541560718}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-26.32007868, -26.67705622567337}, {-26.32007868, \
-25.648844668354197`}}], 
              LineBox[{{-26.32007868, -25.648844668354197`}, {-26.32007868, \
-24.620633111035026`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-265.3268835, -274.4658676660254}, {-265.3268835, \
-263.9547080262316}}], 
              LineBox[{{-265.3268835, -263.9547080262316}, {-265.3268835, \
-253.44354838643773`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-202.0654875, -279.75209605226337`}, {-202.0654875, \
-246.791332545446}}], 
              LineBox[{{-202.0654875, -246.791332545446}, {-202.0654875, \
-213.83056903862865`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.8209092, -16.776221778179288`}, {-16.8209092, \
-15.555588161122257`}}], 
              LineBox[{{-16.8209092, -15.555588161122257`}, {-16.8209092, \
-14.334954544065225`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.26318901, -23.684981723667583`}, {-17.26318901, \
-20.83989575200867}}], 
              LineBox[{{-17.26318901, -20.83989575200867}, {-17.26318901, \
-17.994809780349755`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-27.329169860000004`, -26.522216765609986`}, \
{-27.329169860000004`, -24.42575923659803}}], 
              LineBox[{{-27.329169860000004`, -24.42575923659803}, \
{-27.329169860000004`, -22.329301707586072`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-275.1241365, -289.1182898380611}, {-275.1241365, \
-278.58315855155183`}}], 
              LineBox[{{-275.1241365, -278.58315855155183`}, {-275.1241365, \
-268.04802726504255`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-157.8115118, -156.51880928160955`}, {-157.8115118, \
-142.99702225754822`}}], 
              LineBox[{{-157.8115118, -142.99702225754822`}, {-157.8115118, \
-129.4752352334869}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-19.10527795, -20.559838312074863`}, {-19.10527795, \
-19.027221833964283`}}], 
              LineBox[{{-19.10527795, -19.027221833964283`}, {-19.10527795, \
-17.494605355853704`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-201.14569259999996`, -202.31498019789436`}, \
{-201.14569259999996`, -188.59231073190278`}}], 
              LineBox[{{-201.14569259999996`, -188.59231073190278`}, \
{-201.14569259999996`, -174.8696412659112}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-200.4144209, -206.50319863089985`}, {-200.4144209, \
-198.78464496522366`}}], 
              LineBox[{{-200.4144209, -198.78464496522366`}, {-200.4144209, \
-191.06609129954748`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-20.85857321, -21.17406294649185}, {-20.85857321, \
-18.609635740207313`}}], 
              LineBox[{{-20.85857321, -18.609635740207313`}, {-20.85857321, \
-16.045208533922775`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-160.4460193, -167.29751920709282`}, {-160.4460193, \
-155.86026025134788`}}], 
              LineBox[{{-160.4460193, -155.86026025134788`}, {-160.4460193, \
-144.42300129560294`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.289639940000002`, -12.939976587769001`}, \
{-11.289639940000002`, -11.334570477978847`}}], 
              LineBox[{{-11.289639940000002`, -11.334570477978847`}, \
{-11.289639940000002`, -9.729164368188693}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.48687999, -21.29928639359041}, {-19.48687999, \
-19.618291023050418`}}], 
              LineBox[{{-19.48687999, -19.618291023050418`}, {-19.48687999, \
-17.937295652510425`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-26.99772652, -27.13763968200041}, {-26.99772652, \
-25.690262361721707`}}], 
              LineBox[{{-26.99772652, -25.690262361721707`}, {-26.99772652, \
-24.242885041443003`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.613411750000001`, -18.221160509087397`}, \
{-14.613411750000001`, -16.445544064584944`}}], 
              LineBox[{{-14.613411750000001`, -16.445544064584944`}, \
{-14.613411750000001`, -14.669927620082492`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.934760210000004`, -22.179849116634006`}, \
{-19.934760210000004`, -19.846257281878238`}}], 
              LineBox[{{-19.934760210000004`, -19.846257281878238`}, \
{-19.934760210000004`, -17.51266544712247}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-22.95419956, -23.982798735320976`}, {-22.95419956, \
-20.63722345119951}}], 
              LineBox[{{-22.95419956, -20.63722345119951}, {-22.95419956, \
-17.291648167078044`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.93946703, -17.770835518215282`}, {-16.93946703, \
-16.270895070024416`}}], 
              LineBox[{{-16.93946703, -16.270895070024416`}, {-16.93946703, \
-14.770954621833548`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.883572570000002`, -17.563004543929182`}, \
{-16.883572570000002`, -15.985138330800737`}}], 
              LineBox[{{-16.883572570000002`, -15.985138330800737`}, \
{-16.883572570000002`, -14.407272117672292`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-9.316867899, -12.270433815192616`}, {-9.316867899, \
-10.717025025886077`}}], 
              LineBox[{{-9.316867899, -10.717025025886077`}, {-9.316867899, \
-9.163616236579537}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-171.1183842, -208.93417719043418`}, {-171.1183842, \
-194.05440959777619`}}], 
              LineBox[{{-171.1183842, -194.05440959777619`}, {-171.1183842, \
-179.1746420051182}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.87866815, -17.440089367999352`}, {-17.87866815, \
-15.599849884265197`}}], 
              LineBox[{{-17.87866815, -15.599849884265197`}, {-17.87866815, \
-13.75961040053104}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-26.60237435, -26.307145467221623`}, {-26.60237435, \
-24.787210657393352`}}], 
              LineBox[{{-26.60237435, -24.787210657393352`}, {-26.60237435, \
-23.26727584756508}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-10.459562930000002`, -15.631648283056556`}, \
{-10.459562930000002`, -12.24240026876752}}], 
              LineBox[{{-10.459562930000002`, -12.24240026876752}, \
{-10.459562930000002`, -8.853152254478484}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-24.69345016, -26.194572713154635`}, {-24.69345016, \
-24.98576574696051}}], 
              LineBox[{{-24.69345016, -24.98576574696051}, {-24.69345016, \
-23.776958780766385`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-186.8299757, -223.42285716975806`}, {-186.8299757, \
-206.4969916401619}}], 
              LineBox[{{-186.8299757, -206.4969916401619}, {-186.8299757, \
-189.57112611056573`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-148.7923932, -172.50977564094404`}, {-148.7923932, \
-162.87630077193094`}}], 
              LineBox[{{-148.7923932, -162.87630077193094`}, {-148.7923932, \
-153.24282590291784`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-221.2628344, -220.3140312409215}, {-221.2628344, \
-197.37611587769794`}}], 
              LineBox[{{-221.2628344, -197.37611587769794`}, {-221.2628344, \
-174.43820051447437`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-174.8599667, -206.4049332743356}, {-174.8599667, \
-188.31384579314653`}}], 
              LineBox[{{-174.8599667, -188.31384579314653`}, {-174.8599667, \
-170.22275831195745`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-176.6532627, -196.71110948685165`}, {-176.6532627, \
-178.4621918073268}}], 
              LineBox[{{-176.6532627, -178.4621918073268}, {-176.6532627, \
-160.21327412780195`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.562546430000005`, -20.21520192515458}, \
{-17.562546430000005`, -18.623927787494953`}}], 
              LineBox[{{-17.562546430000005`, -18.623927787494953`}, \
{-17.562546430000005`, -17.032653649835325`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-26.57267167, -26.158654357455095`}, {-26.57267167, \
-22.097609497968982`}}], 
              LineBox[{{-26.57267167, -22.097609497968982`}, {-26.57267167, \
-18.03656463848287}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-12.79651106, -13.030741336725534`}, {-12.79651106, \
-11.69946583927298}}], 
              LineBox[{{-12.79651106, -11.69946583927298}, {-12.79651106, \
-10.368190341820426`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-229.3900495, -271.18743940668423`}, {-229.3900495, \
-250.32126842574388`}}], 
              LineBox[{{-229.3900495, -250.32126842574388`}, {-229.3900495, \
-229.4550974448035}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-242.1760127, -249.8107516644275}, {-242.1760127, \
-228.04542066402848`}}], 
              LineBox[{{-242.1760127, -228.04542066402848`}, {-242.1760127, \
-206.28008966362947`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-163.8709939, -181.8322050495751}, {-163.8709939, \
-170.1341025065013}}], 
              LineBox[{{-163.8709939, -170.1341025065013}, {-163.8709939, \
-158.43599996342752`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-10.550604040000001`, -15.52100591398727}, \
{-10.550604040000001`, -12.822067791142807`}}], 
              LineBox[{{-10.550604040000001`, -12.822067791142807`}, \
{-10.550604040000001`, -10.123129668298343`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-25.27168612, -26.510770977651212`}, {-25.27168612, \
-25.34799230277931}}], 
              LineBox[{{-25.27168612, -25.34799230277931}, {-25.27168612, \
-24.18521362790741}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.51722316, -23.455148138682215`}, {-18.51722316, \
-21.311228857389537`}}], 
              LineBox[{{-18.51722316, -21.311228857389537`}, {-18.51722316, \
-19.16730957609686}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-10.01189846, -12.162808255055541`}, {-10.01189846, \
-10.848971096401712`}}], 
              LineBox[{{-10.01189846, -10.848971096401712`}, {-10.01189846, \
-9.535133937747883}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-198.7701134, -269.5745839426283}, {-198.7701134, \
-237.37468842368696`}}], 
              LineBox[{{-198.7701134, -237.37468842368696`}, {-198.7701134, \
-205.17479290474563`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-25.21286685, -25.629398477463173`}, {-25.21286685, \
-22.23601585751161}}], 
              LineBox[{{-25.21286685, -22.23601585751161}, {-25.21286685, \
-18.842633237560047`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-285.3340905, -284.4018290326}, {-285.3340905, \
-259.0866910556579}}], 
              LineBox[{{-285.3340905, -259.0866910556579}, {-285.3340905, \
-233.77155307871584`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-217.0840006, -219.58466212386242`}, {-217.0840006, \
-203.04425717197446`}}], 
              LineBox[{{-217.0840006, -203.04425717197446`}, {-217.0840006, \
-186.50385222008651`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-21.93894465, -20.06939172101742}, {-21.93894465, \
-17.15769587885823}}], 
              LineBox[{{-21.93894465, -17.15769587885823}, {-21.93894465, \
-14.246000036699042`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-298.3052986, -304.95410614901004`}, {-298.3052986, \
-269.1286778390928}}], 
              LineBox[{{-298.3052986, -269.1286778390928}, {-298.3052986, \
-233.30324952917556`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-9.214259077, -16.84059840946218}, {-9.214259077, \
-13.145660021335344`}}], 
              LineBox[{{-9.214259077, -13.145660021335344`}, {-9.214259077, \
-9.450721633208508}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-210.0623176, -210.82376484067075`}, {-210.0623176, \
-187.1937963000971}}], 
              LineBox[{{-210.0623176, -187.1937963000971}, {-210.0623176, \
-163.56382775952343`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-12.38874648, -14.491576305863715`}, {-12.38874648, \
-12.565161107176467`}}], 
              LineBox[{{-12.38874648, -12.565161107176467`}, {-12.38874648, \
-10.638745908489218`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-25.924982000000004`, -27.265612188627813`}, \
{-25.924982000000004`, -26.172601771589523`}}], 
              LineBox[{{-25.924982000000004`, -26.172601771589523`}, \
{-25.924982000000004`, -25.079591354551233`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-23.26314835, -24.413463473995467`}, {-23.26314835, \
-20.661266143374185`}}], 
              LineBox[{{-23.26314835, -20.661266143374185`}, {-23.26314835, \
-16.909068812752903`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.13116346, -16.617563669252014`}, {-16.13116346, \
-14.236833505358018`}}], 
              LineBox[{{-16.13116346, -14.236833505358018`}, {-16.13116346, \
-11.85610334146402}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-160.9841309, -167.11924258766862`}, {-160.9841309, \
-148.6980962256985}}], 
              LineBox[{{-160.9841309, -148.6980962256985}, {-160.9841309, \
-130.27694986372836`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-195.9553161, -212.14589264690116`}, {-195.9553161, \
-200.9448103217887}}], 
              LineBox[{{-195.9553161, -200.9448103217887}, {-195.9553161, \
-189.74372799667626`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-163.9771482, -161.03795191852237`}, {-163.9771482, \
-145.87482361718344`}}], 
              LineBox[{{-163.9771482, -145.87482361718344`}, {-163.9771482, \
-130.7116953158445}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-28.72382556, -25.269254630792567`}, {-28.72382556, \
-21.38963084422141}}], 
              LineBox[{{-28.72382556, -21.38963084422141}, {-28.72382556, \
-17.510007057650256`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.97762995, -19.361877436155503`}, {-18.97762995, \
-17.96515564858423}}], 
              LineBox[{{-18.97762995, -17.96515564858423}, {-18.97762995, \
-16.568433861012956`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.483490190000001`, -17.752377605082735`}, \
{-14.483490190000001`, -15.60824303488247}}], 
              LineBox[{{-14.483490190000001`, -15.60824303488247}, \
{-14.483490190000001`, -13.464108464682205`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-9.973634154, -12.606821196653947`}, {-9.973634154, \
-11.035369539095385`}}], 
              LineBox[{{-9.973634154, -11.035369539095385`}, {-9.973634154, \
-9.463917881536823}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-166.38396979999996`, -190.20246125109998`}, \
{-166.38396979999996`, -174.5070248361845}}], 
              LineBox[{{-166.38396979999996`, -174.5070248361845}, \
{-166.38396979999996`, -158.81158842126905`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-27.10169306, -27.021674093753216`}, {-27.10169306, \
-25.856496231201856`}}], 
              LineBox[{{-27.10169306, -25.856496231201856`}, {-27.10169306, \
-24.691318368650496`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-145.1252574, -181.50166607983792`}, {-145.1252574, \
-160.36204500637686`}}], 
              LineBox[{{-145.1252574, -160.36204500637686`}, {-145.1252574, \
-139.2224239329158}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-132.2719048, -188.0093689821227}, {-132.2719048, \
-161.7460622334238}}], 
              LineBox[{{-132.2719048, -161.7460622334238}, {-132.2719048, \
-135.4827554847249}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-183.4070806, -233.0676471601136}, {-183.4070806, \
-206.10766240959836`}}], 
              LineBox[{{-183.4070806, -206.10766240959836`}, {-183.4070806, \
-179.14767765908312`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-22.12438647, -24.028353121911657`}, {-22.12438647, \
-22.663157150986784`}}], 
              LineBox[{{-22.12438647, -22.663157150986784`}, {-22.12438647, \
-21.29796118006191}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-167.5457065, -176.94087144989751`}, {-167.5457065, \
-165.3766793451029}}], 
              LineBox[{{-167.5457065, -165.3766793451029}, {-167.5457065, \
-153.8124872403083}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-125.0022655, -149.31596649199733`}, {-125.0022655, \
-137.88504570688707`}}], 
              LineBox[{{-125.0022655, -137.88504570688707`}, {-125.0022655, \
-126.45412492177681`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.26850502, -18.289709752217696`}, {-16.26850502, \
-16.78118847613406}}], 
              LineBox[{{-16.26850502, -16.78118847613406}, {-16.26850502, \
-15.272667200050423`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-151.7342835, -184.95661809942865`}, {-151.7342835, \
-165.65769963262036`}}], 
              LineBox[{{-151.7342835, -165.65769963262036`}, {-151.7342835, \
-146.35878116581208`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-25.909891810000005`, -26.385286445884276`}, \
{-25.909891810000005`, -24.88876575509279}}], 
              
              LineBox[{{-25.909891810000005`, -24.88876575509279}, \
{-25.909891810000005`, -23.392245064301306`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-13.523884870000002`, -14.264877094231666`}, \
{-13.523884870000002`, -13.041578538578914`}}], 
              LineBox[{{-13.523884870000002`, -13.041578538578914`}, \
{-13.523884870000002`, -11.818279982926162`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-202.8723963, -207.1780297093231}, {-202.8723963, \
-188.12934123154733`}}], 
              LineBox[{{-202.8723963, -188.12934123154733`}, {-202.8723963, \
-169.08065275377155`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-182.2785655, -216.29674624538814`}, {-182.2785655, \
-200.87076086235277`}}], 
              LineBox[{{-182.2785655, -200.87076086235277`}, {-182.2785655, \
-185.4447754793174}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-157.9697799, -166.0014253536361}, {-157.9697799, \
-151.67530508809816`}}], 
              LineBox[{{-157.9697799, -151.67530508809816`}, {-157.9697799, \
-137.3491848225602}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-265.539623, -268.80390044678194`}, {-265.539623, \
-252.18581303668478`}}], 
              LineBox[{{-265.539623, -252.18581303668478`}, {-265.539623, \
-235.56772562658765`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.82898498, -26.608163391605895`}, {-18.82898498, \
-22.819088378002583`}}], 
              LineBox[{{-18.82898498, -22.819088378002583`}, {-18.82898498, \
-19.03001336439927}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-26.82142231, -26.077926069859878`}, {-26.82142231, \
-22.312400011575996`}}], 
              LineBox[{{-26.82142231, -22.312400011575996`}, {-26.82142231, \
-18.546873953292113`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-9.720362418000002, -12.113898477859546`}, \
{-9.720362418000002, -10.54938373742132}}], 
              LineBox[{{-9.720362418000002, -10.54938373742132}, \
{-9.720362418000002, -8.984868996983092}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-132.9528368, -165.26185609735558`}, {-132.9528368, \
-150.24573924124715`}}], 
              LineBox[{{-132.9528368, -150.24573924124715`}, {-132.9528368, \
-135.22962238513873`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-177.69012579999998`, -221.80842398609306`}, \
{-177.69012579999998`, -198.51818468037533`}}], 
              LineBox[{{-177.69012579999998`, -198.51818468037533`}, \
{-177.69012579999998`, -175.2279453746576}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-13.538890280000002`, -17.730231690122757`}, \
{-13.538890280000002`, -15.478240751743071`}}], 
              LineBox[{{-13.538890280000002`, -15.478240751743071`}, \
{-13.538890280000002`, -13.226249813363385`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.79345329, -19.193367896322986`}, {-17.79345329, \
-17.055573020750586`}}], 
              LineBox[{{-17.79345329, -17.055573020750586`}, {-17.79345329, \
-14.917778145178184`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-20.13949555, -19.81376228776169}, {-20.13949555, \
-16.388974099829756`}}], 
              LineBox[{{-20.13949555, -16.388974099829756`}, {-20.13949555, \
-12.964185911897822`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-180.0195428, -190.95715976787153`}, {-180.0195428, \
-177.5999794069482}}], 
              LineBox[{{-180.0195428, -177.5999794069482}, {-180.0195428, \
-164.24279904602486`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.28238847, -20.427997694854866`}, {-18.28238847, \
-17.708804987469406`}}], 
              LineBox[{{-18.28238847, -17.708804987469406`}, {-18.28238847, \
-14.989612280083945`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.88323105, -16.070673677535265`}, {-15.88323105, \
-14.545682299742845`}}], 
              LineBox[{{-15.88323105, -14.545682299742845`}, {-15.88323105, \
-13.020690921950425`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-23.49300352, -24.393752997411163`}, {-23.49300352, \
-22.577191377031816`}}], 
              LineBox[{{-23.49300352, -22.577191377031816`}, {-23.49300352, \
-20.76062975665247}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-227.8821207, -247.5601805842451}, {-227.8821207, \
-227.86639756162268`}}], 
              LineBox[{{-227.8821207, -227.86639756162268`}, {-227.8821207, \
-208.17261453900025`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              
              LineBox[{{-10.23032148, -12.0219137227179}, {-10.23032148, \
-10.945117122970592`}}], 
              LineBox[{{-10.23032148, -10.945117122970592`}, {-10.23032148, \
-9.868320523223284}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-5.596007313000001, -14.042169618764394`}, \
{-5.596007313000001, -10.134153469726039`}}], 
              LineBox[{{-5.596007313000001, -10.134153469726039`}, \
{-5.596007313000001, -6.226137320687684}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-258.1159602, -269.4307512072926}, {-258.1159602, \
-252.21560277928603`}}], 
              LineBox[{{-258.1159602, -252.21560277928603`}, {-258.1159602, \
-235.00045435127944`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-8.073890581, -11.743232053786318`}, {-8.073890581, \
-9.578442366909018}}], 
              LineBox[{{-8.073890581, -9.578442366909018}, {-8.073890581, \
-7.413652680031718}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-291.00694999999996`, -275.9306857684762}, \
{-291.00694999999996`, -252.21279459124358`}}], 
              LineBox[{{-291.00694999999996`, -252.21279459124358`}, \
{-291.00694999999996`, -228.4949034140109}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-198.46491809999998`, -208.6082559453794}, \
{-198.46491809999998`, -202.0586273594206}}], 
              LineBox[{{-198.46491809999998`, -202.0586273594206}, \
{-198.46491809999998`, -195.5089987734618}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-234.02369969999998`, -240.5658938403552}, \
{-234.02369969999998`, -215.14218877771427`}}], 
              LineBox[{{-234.02369969999998`, -215.14218877771427`}, \
{-234.02369969999998`, -189.71848371507335`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-142.777125, -179.10033952641993`}, {-142.777125, \
-157.22958204406453`}}], 
              LineBox[{{-142.777125, -157.22958204406453`}, {-142.777125, \
-135.35882456170913`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-189.1280829, -192.0793136797585}, {-189.1280829, \
-182.7839843929815}}], 
              LineBox[{{-189.1280829, -182.7839843929815}, {-189.1280829, \
-173.48865510620448`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-237.08169529999998`, -246.8083563134253}, \
{-237.08169529999998`, -235.37909765819606`}}], 
              LineBox[{{-237.08169529999998`, -235.37909765819606`}, \
{-237.08169529999998`, -223.94983900296683`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-22.89029348, -23.328428010900854`}, {-22.89029348, \
-21.574153729516954`}}], 
              LineBox[{{-22.89029348, -21.574153729516954`}, {-22.89029348, \
-19.819879448133054`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-5.104339631, -12.25534262389591}, {-5.104339631, \
-9.109127770293947}}], 
              LineBox[{{-5.104339631, -9.109127770293947}, {-5.104339631, \
-5.962912916691984}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-154.93789629999998`, -188.84305482977004`}, \
{-154.93789629999998`, -166.96682479253565`}}], 
              LineBox[{{-154.93789629999998`, -166.96682479253565`}, \
{-154.93789629999998`, -145.09059475530125`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.118434470000002`, -17.887939218931372`}, \
{-15.118434470000002`, -16.291828517721303`}}], 
              LineBox[{{-15.118434470000002`, -16.291828517721303`}, \
{-15.118434470000002`, -14.695717816511232`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-8.367808354, -14.309537963852252`}, {-8.367808354, \
-12.345025098331222`}}], 
              LineBox[{{-8.367808354, -12.345025098331222`}, {-8.367808354, \
-10.380512232810192`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-321.24558, -322.36467160679456`}, {-321.24558, \
-279.93840357455264`}}], 
              LineBox[{{-321.24558, -279.93840357455264`}, {-321.24558, \
-237.51213554231072`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-20.48032204, -24.391949443027123`}, {-20.48032204, \
-22.742436565175133`}}], 
              LineBox[{{-20.48032204, -22.742436565175133`}, {-20.48032204, \
-21.092923687323143`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-196.7643998, -215.05188874427702`}, {-196.7643998, \
-203.09758690117326`}}], 
              LineBox[{{-196.7643998, -203.09758690117326`}, {-196.7643998, \
-191.1432850580695}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-9.908764458, -12.382598727590384`}, {-9.908764458, \
-10.812205947953167`}}], 
              LineBox[{{-9.908764458, -10.812205947953167`}, {-9.908764458, \
-9.24181316831595}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.44067823, -16.80030922781352}, {-11.44067823, \
-13.909990878070332`}}], 
              LineBox[{{-11.44067823, -13.909990878070332`}, {-11.44067823, \
-11.01967252832714}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-23.89939304, -26.311751604857466`}, {-23.89939304, \
-24.726464940699945`}}], 
              LineBox[{{-23.89939304, -24.726464940699945`}, {-23.89939304, \
-23.141178276542423`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.30972519, -18.108024829566663`}, {-17.30972519, \
-16.93062391701052}}], 
              LineBox[{{-17.30972519, -16.93062391701052}, {-17.30972519, \
-15.75322300445438}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-212.122638, -212.0977275702823}, {-212.122638, \
-198.92399175751362`}}], 
              LineBox[{{-212.122638, -198.92399175751362`}, {-212.122638, \
-185.75025594474494`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-249.17699, -247.81408376491666`}, {-249.17699, \
-224.98390174031826`}}], 
              LineBox[{{-249.17699, -224.98390174031826`}, {-249.17699, \
-202.15371971571986`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-173.10551879999997`, -223.16763408282392`}, \
{-173.10551879999997`, -199.81858790507619`}}], 
              LineBox[{{-173.10551879999997`, -199.81858790507619`}, \
{-173.10551879999997`, -176.46954172732845`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-233.3489961, -272.16941478553883`}, {-233.3489961, \
-247.28045121634648`}}], 
              LineBox[{{-233.3489961, -247.28045121634648`}, {-233.3489961, \
-222.39148764715412`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-196.2353429, -229.35154329882778`}, {-196.2353429, \
-214.33336756406567`}}], 
              LineBox[{{-196.2353429, -214.33336756406567`}, {-196.2353429, \
-199.31519182930356`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-13.9643906, -15.267302404834613`}, {-13.9643906, \
-12.840611184926608`}}], 
              LineBox[{{-13.9643906, -12.840611184926608`}, {-13.9643906, \
-10.413919965018604`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-200.5382898, -205.73836670369536`}, {-200.5382898, \
-188.26022267774687`}}], 
              LineBox[{{-200.5382898, -188.26022267774687`}, {-200.5382898, \
-170.78207865179837`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-266.4729081, -260.3226827036589}, {-266.4729081, \
-225.3077882662785}}], 
              LineBox[{{-266.4729081, -225.3077882662785}, {-266.4729081, \
-190.29289382889806`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-10.715475550000003`, -11.88315134643853}, \
{-10.715475550000003`, -9.686498248937035}}], 
              LineBox[{{-10.715475550000003`, -9.686498248937035}, \
{-10.715475550000003`, -7.48984515143554}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.772409690000003`, -17.430170790224032`}, \
{-16.772409690000003`, -16.30088910229339}}], 
              LineBox[{{-16.772409690000003`, -16.30088910229339}, \
{-16.772409690000003`, -15.171607414362747`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.61459506, -16.733299997041975`}, {-14.61459506, \
-15.39318624663067}}], 
              LineBox[{{-14.61459506, -15.39318624663067}, {-14.61459506, \
-14.053072496219366`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-212.67468, -236.5716679810157}, {-212.67468, \
-217.1793827226007}}], 
              LineBox[{{-212.67468, -217.1793827226007}, {-212.67468, \
-197.7870974641857}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-154.9223522, -161.66511452443245`}, {-154.9223522, \
-151.68032986722085`}}], 
              LineBox[{{-154.9223522, -151.68032986722085`}, {-154.9223522, \
-141.69554521000924`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-201.9410288, -203.93698410556163`}, {-201.9410288, \
-185.3647519147586}}], 
              LineBox[{{-201.9410288, -185.3647519147586}, {-201.9410288, \
-166.7925197239556}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.01507102, -18.550144719620935`}, {-17.01507102, \
-16.33891023332036}}], 
              LineBox[{{-17.01507102, -16.33891023332036}, {-17.01507102, \
-14.127675747019783`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-239.6292468, -238.79016066431964`}, {-239.6292468, \
-223.92260639036405`}}], 
              LineBox[{{-239.6292468, -223.92260639036405`}, {-239.6292468, \
-209.05505211640846`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-188.2129049, -183.2269237982743}, {-188.2129049, \
-164.33743283626268`}}], 
              LineBox[{{-188.2129049, -164.33743283626268`}, {-188.2129049, \
-145.44794187425106`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-165.7132374, -184.27221087179822`}, {-165.7132374, \
-173.1603900613405}}], 
              LineBox[{{-165.7132374, -173.1603900613405}, {-165.7132374, \
-162.0485692508828}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-261.4387335, -259.37321167758}, {-261.4387335, \
-233.62195662851514`}}], 
              LineBox[{{-261.4387335, -233.62195662851514`}, {-261.4387335, \
-207.8707015794503}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-219.9711881, -219.68441692046702`}, {-219.9711881, \
-204.9924265878798}}], 
              LineBox[{{-219.9711881, -204.9924265878798}, {-219.9711881, \
-190.3004362552926}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.930406260000002`, -18.43651875636905}, \
{-14.930406260000002`, -16.593995242882933`}}], 
              LineBox[{{-14.930406260000002`, -16.593995242882933`}, \
{-14.930406260000002`, -14.751471729396815`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-182.0192916, -184.0355192439938}, {-182.0192916, \
-171.09875582107637`}}], 
              LineBox[{{-182.0192916, -171.09875582107637`}, {-182.0192916, \
-158.16199239815893`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-212.35436, -232.34354598772012`}, {-212.35436, \
-216.34317509476247`}}], 
              LineBox[{{-212.35436, -216.34317509476247`}, {-212.35436, \
-200.34280420180482`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.00842529, -18.202965399690783`}, {-17.00842529, \
-16.636301167531077`}}], 
              LineBox[{{-17.00842529, -16.636301167531077`}, {-17.00842529, \
-15.06963693537137}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-12.06865289, -22.337737188133158`}, {-12.06865289, \
-18.502134363935557`}}], 
              LineBox[{{-12.06865289, -18.502134363935557`}, {-12.06865289, \
-14.666531539737957`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-274.52534, -275.8101741500579}, {-274.52534, \
-245.2791551574835}}], 
              LineBox[{{-274.52534, -245.2791551574835}, {-274.52534, \
-214.7481361649091}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.884073550000004`, -18.319199650409978`}, \
{-19.884073550000004`, -14.43100434123872}}], 
              LineBox[{{-19.884073550000004`, -14.43100434123872}, \
{-19.884073550000004`, -10.542809032067463`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-13.48549164, -17.14809540135418}, {-13.48549164, \
-14.688769085678292`}}], 
              LineBox[{{-13.48549164, -14.688769085678292`}, {-13.48549164, \
-12.229442770002402`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.08613704, -21.20749948839118}, {-19.08613704, \
-19.36919221257702}}], 
              LineBox[{{-19.08613704, -19.36919221257702}, {-19.08613704, \
-17.53088493676286}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-232.6728533, -266.6128361562598}, {-232.6728533, \
-242.85215320276436`}}], 
              LineBox[{{-232.6728533, -242.85215320276436`}, {-232.6728533, \
-219.09147024926892`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.17548746, -19.193714833374912`}, {-17.17548746, \
-18.02664366925668}}], 
              LineBox[{{-17.17548746, -18.02664366925668}, {-17.17548746, \
-16.859572505138445`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-227.6384345, -234.73530993935756`}, {-227.6384345, \
-210.8367195752558}}], 
              LineBox[{{-227.6384345, -210.8367195752558}, {-227.6384345, \
-186.93812921115406`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.461596130000002`, -17.57041678743842}, \
{-15.461596130000002`, -16.21215657656381}}], 
              LineBox[{{-15.461596130000002`, -16.21215657656381}, \
{-15.461596130000002`, -14.853896365689204`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-191.30573449999997`, -216.68162081166722`}, \
{-191.30573449999997`, -201.12406733472005`}}], 
              LineBox[{{-191.30573449999997`, -201.12406733472005`}, \
{-191.30573449999997`, -185.5665138577729}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-205.5804008, -216.76690176350107`}, {-205.5804008, \
-208.4679669473228}}], 
              LineBox[{{-205.5804008, -208.4679669473228}, {-205.5804008, \
-200.16903213114452`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-22.277799680000005`, -22.06872447311701}, \
{-22.277799680000005`, -20.66681357179121}}], 
              LineBox[{{-22.277799680000005`, -20.66681357179121}, \
{-22.277799680000005`, -19.26490267046541}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.1802867, -14.590187384021803`}, {-16.1802867, \
-11.802996410290103`}}], 
              LineBox[{{-16.1802867, -11.802996410290103`}, {-16.1802867, \
-9.015805436558402}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.588565950000003`, -19.957374343962705`}, \
{-18.588565950000003`, -18.064776802189577`}}], 
              LineBox[{{-18.588565950000003`, -18.064776802189577`}, \
{-18.588565950000003`, -16.17217926041645}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-12.60218521, -17.30311130375906}, {-12.60218521, \
-15.293927626743043`}}], 
              LineBox[{{-12.60218521, -15.293927626743043`}, {-12.60218521, \
-13.284743949727025`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.008445150000002`, -15.360304710250551`}, \
{-14.008445150000002`, -13.335862189731918`}}], 
              LineBox[{{-14.008445150000002`, -13.335862189731918`}, \
{-14.008445150000002`, -11.311419669213285`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-135.9210085, -145.0641915627327}, {-135.9210085, \
-135.36770362542467`}}], 
              LineBox[{{-135.9210085, -135.36770362542467`}, {-135.9210085, \
-125.67121568811663`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-195.3385784, -207.2631452584531}, {-195.3385784, \
-198.44075407958292`}}], 
              LineBox[{{-195.3385784, -198.44075407958292`}, {-195.3385784, \
-189.61836290071273`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-181.0090623, -224.44237917193615`}, {-181.0090623, \
-205.89206851367652`}}], 
              LineBox[{{-181.0090623, -205.89206851367652`}, {-181.0090623, \
-187.3417578554169}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.410694560000003`, -18.543983148361587`}, \
{-18.410694560000003`, -16.670796536488652`}}], 
              LineBox[{{-18.410694560000003`, -16.670796536488652`}, \
{-18.410694560000003`, -14.797609924615717`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.059923830000002`, -14.278613776416666`}, \
{-14.059923830000002`, -12.275160630832202`}}], 
              LineBox[{{-14.059923830000002`, -12.275160630832202`}, \
{-14.059923830000002`, -10.271707485247738`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.59999831, -17.727820437122915`}, {-14.59999831, \
-15.500749640488545`}}], 
              LineBox[{{-14.59999831, -15.500749640488545`}, {-14.59999831, \
-13.273678843854173`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-9.452459434000001, -15.623759441162997`}, \
{-9.452459434000001, -12.554674672651249`}}], 
              LineBox[{{-9.452459434000001, -12.554674672651249`}, \
{-9.452459434000001, -9.4855899041395}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-198.5987259, -208.90763296054288`}, {-198.5987259, \
-190.31593172015673`}}], 
              
              LineBox[{{-198.5987259, -190.31593172015673`}, {-198.5987259, \
-171.72423047977057`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-178.7692044, -208.09920200563536`}, {-178.7692044, \
-193.48223101262414`}}], 
              LineBox[{{-178.7692044, -193.48223101262414`}, {-178.7692044, \
-178.86526001961292`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-194.4729821, -230.9173645559976}, {-194.4729821, \
-210.39062340750937`}}], 
              LineBox[{{-194.4729821, -210.39062340750937`}, {-194.4729821, \
-189.86388225902112`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.36316456, -12.977971013884364`}, {-11.36316456, \
-11.761466830329164`}}], 
              LineBox[{{-11.36316456, -11.761466830329164`}, {-11.36316456, \
-10.544962646773964`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-230.610439, -226.5139108594227}, {-230.610439, \
-205.17490910576862`}}], 
              LineBox[{{-230.610439, -205.17490910576862`}, {-230.610439, \
-183.83590735211453`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-177.90309249999999`, -190.1061509519915}, \
{-177.90309249999999`, -179.72008217009176`}}], 
              LineBox[{{-177.90309249999999`, -179.72008217009176`}, \
{-177.90309249999999`, -169.334013388192}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-235.2076761, -238.37276145533147`}, {-235.2076761, \
-227.31944495444893`}}], 
              LineBox[{{-235.2076761, -227.31944495444893`}, {-235.2076761, \
-216.26612845356638`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.68145305, -18.434645434559798`}, {-17.68145305, \
-17.12670207451581}}], 
              LineBox[{{-17.68145305, -17.12670207451581}, {-17.68145305, \
-15.81875871447182}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-20.60559836, -20.77578380635647}, {-20.60559836, \
-18.83744469679945}}], 
              LineBox[{{-20.60559836, -18.83744469679945}, {-20.60559836, \
-16.899105587242435`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.00794796, -19.65346245900448}, {-19.00794796, \
-17.78868604330424}}], 
              LineBox[{{-19.00794796, -17.78868604330424}, {-19.00794796, \
-15.923909627603997`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-235.69025, -248.8463471275128}, {-235.69025, \
-235.93504411246462`}}], 
              LineBox[{{-235.69025, -235.93504411246462`}, {-235.69025, \
-223.02374109741646`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-26.383318370000005`, -27.75900287676331}, \
{-26.383318370000005`, -24.642128135443862`}}], 
              LineBox[{{-26.383318370000005`, -24.642128135443862`}, \
{-26.383318370000005`, -21.525253394124412`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.80124367, -16.264569014727464`}, {-14.80124367, \
-13.601619709613987`}}], 
              LineBox[{{-14.80124367, -13.601619709613987`}, {-14.80124367, \
-10.93867040450051}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-20.95241934, -19.956917043786216`}, {-20.95241934, \
-16.912750188932847`}}], 
              LineBox[{{-20.95241934, -16.912750188932847`}, {-20.95241934, \
-13.868583334079478`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-156.0998953, -160.4052343124354}, {-156.0998953, \
-147.04033008397138`}}], 
              LineBox[{{-156.0998953, -147.04033008397138`}, {-156.0998953, \
-133.67542585550737`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-126.6848415, -149.67323144740914`}, {-126.6848415, \
-137.9888621060926}}], 
              LineBox[{{-126.6848415, -137.9888621060926}, {-126.6848415, \
-126.30449276477607`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-247.64144069999998`, -250.9720271688666}, \
{-247.64144069999998`, -238.92240079341863`}}], 
              LineBox[{{-247.64144069999998`, -238.92240079341863`}, \
{-247.64144069999998`, -226.87277441797067`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.034326870000005`, -21.72792775014566}, \
{-19.034326870000005`, -19.037416706890216`}}], 
              LineBox[{{-19.034326870000005`, -19.037416706890216`}, \
{-19.034326870000005`, -16.34690566363477}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.93444314, -16.187369855309022`}, {-15.93444314, \
-14.22972030136918}}], 
              LineBox[{{-15.93444314, -14.22972030136918}, {-15.93444314, \
-12.27207074742934}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-166.1010446, -178.78346109728665`}, {-166.1010446, \
-167.8287061159853}}], 
              LineBox[{{-166.1010446, -167.8287061159853}, {-166.1010446, \
-156.87395113468398`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.9332059, -16.339954780918454`}, {-14.9332059, \
-14.513617341853895`}}], 
              LineBox[{{-14.9332059, -14.513617341853895`}, {-14.9332059, \
-12.687279902789337`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.06816885, -19.08054676457188}, {-16.06816885, \
-16.944484444906752`}}], 
              LineBox[{{-16.06816885, -16.944484444906752`}, {-16.06816885, \
-14.808422125241623`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-22.069685250000003`, -21.75022169985375}, \
{-22.069685250000003`, -18.217247792186637`}}], 
              LineBox[{{-22.069685250000003`, -18.217247792186637`}, \
{-22.069685250000003`, -14.684273884519522`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-254.9438531, -268.54801955028734`}, {-254.9438531, \
-252.99641077511973`}}], 
              LineBox[{{-254.9438531, -252.99641077511973`}, {-254.9438531, \
-237.4448019999521}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-221.3077422, -241.2804799704832}, {-221.3077422, \
-230.90637408946367`}}], 
              LineBox[{{-221.3077422, -230.90637408946367`}, {-221.3077422, \
-220.53226820844412`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-196.1206745, -209.92820581488527`}, {-196.1206745, \
-198.1678013029287}}], 
              LineBox[{{-196.1206745, -198.1678013029287}, {-196.1206745, \
-186.40739679097211`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-172.25085999999996`, -179.52956657467277`}, \
{-172.25085999999996`, -163.00498773587228`}}], 
              LineBox[{{-172.25085999999996`, -163.00498773587228`}, \
{-172.25085999999996`, -146.48040889707178`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-140.9718293, -175.33796939180775`}, {-140.9718293, \
-158.2507963353862}}], 
              LineBox[{{-140.9718293, -158.2507963353862}, {-140.9718293, \
-141.16362327896468`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-22.05424117, -23.35632377326763}, {-22.05424117, \
-21.156594699034294`}}], 
              LineBox[{{-22.05424117, -21.156594699034294`}, {-22.05424117, \
-18.956865624800958`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.3280814, -21.623277879592326`}, {-19.3280814, \
-19.240250172978985`}}], 
              LineBox[{{-19.3280814, -19.240250172978985`}, {-19.3280814, \
-16.857222466365645`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-128.9414524, -184.27170365767665`}, {-128.9414524, \
-154.93586404089606`}}], 
              LineBox[{{-128.9414524, -154.93586404089606`}, {-128.9414524, \
-125.60002442411547`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-27.16299725, -24.62074688585487}, {-27.16299725, \
-20.415468064857723`}}], 
              LineBox[{{-27.16299725, -20.415468064857723`}, {-27.16299725, \
-16.210189243860576`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-214.40795, -228.7052387675469}, {-214.40795, \
-215.11467976154694`}}], 
              LineBox[{{-214.40795, -215.11467976154694`}, {-214.40795, \
-201.524120755547}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.65439725, -21.45195416235505}, {-16.65439725, \
-18.626905266898905`}}], 
              LineBox[{{-16.65439725, -18.626905266898905`}, {-16.65439725, \
-15.801856371442758`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-193.6218514, -205.5389454601933}, {-193.6218514, \
-197.0867059281088}}], 
              LineBox[{{-193.6218514, -197.0867059281088}, {-193.6218514, \
-188.63446639602432`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.38074683, -16.91312806694552}, {-16.38074683, \
-15.37020253159287}}], 
              LineBox[{{-16.38074683, -15.37020253159287}, {-16.38074683, \
-13.827276996240219`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-25.258079340000002`, -26.512567273033024`}, \
{-25.258079340000002`, -25.28178453440207}}], 
              LineBox[{{-25.258079340000002`, -25.28178453440207}, \
{-25.258079340000002`, -24.051001795771118`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-161.344421, -217.1766432978569}, {-161.344421, \
-197.04437698635468`}}], 
              LineBox[{{-161.344421, -197.04437698635468`}, {-161.344421, \
-176.91211067485244`}}]}},
            Antialiasing->False]}}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.007333333333333334], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVmGlUDV4bxVOkKE0kFalu83TnRhKlNCpJROre252akyFSiAzhn0qUBg0k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            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.007333333333333334], AbsoluteThickness[
            1.6]}, {}}}, {{}, {}}}, {{{}, {}, 
          TagBox[
           {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
            Dashing[{0, Small}], LineBox[CompressedData["
1:eJxFxW0w03EcAPCdp0uHErKLecgaL5bpNM2E6pyVUDlP05k4EbKtk/GvzWSe
x4iu0Z3z0Io6lsRplSUP83COyrmOo7prqeXh6M7+8nCqF76/F5/7OCfwwq4a
EAiEkH/+PzMbvLbjX9G7+1gl9knqi1YHPFbZ+qAbW3dENC/0NWGHSRwVjdsR
iWoi2vryN6ZwVQaHTmO5603oRQ3r2ev1cniickOrYaNrfr6PWOkpg8uOnU3V
WqMHIhUFTllSmJLeGOA6VgrzLPv8gsnorbtD/qqiErjTkKtdmSuG2y/9qeD7
o6uPtggsFEVwwwZOyNoshFcfUqtcOeh0P4OhphcF8ETSptdJM7QgbbqNxM+H
WfHRwyMaCRzr+UbX44au0/cqhaI8uJ+lU7Kn7sDumfquHAa6v1pxhSvLhb1J
PHLwFzGscp/dxptzYNlhqYN3pAheHDcM2WsnhOtj1X38wVuww55epZUAgylp
0pZA32xY0l6js/glgFOUPEZyWyZsP1y+vSm4CZMHlkwplAy4K9uW/HXhBvxg
n6SAJufDB9R8HamDC5fcS+mMOHMdfkqbN39ZlwLP+ejzmJRkWGVWWvgDS4Rp
Nq0C85l4mEvqN2oe58AfaunexWI2HLU+rnhSGg47l5lOYrEXYCYz/37QxwCY
zq6tPIHT4cSC9u6YenTV86HPIhZ62VRPHZAfh1tehY1cZHjC9vZmBqmYB2ys
3p5n4EfghINUupiFVnNjJINyMpzt2O0YxnCBF3P50WmYE/yoSFPtg9vAHIaL
x7DcGibqxGPhDCu4LMjbmIvth7WHopdO4cZwlNCSEsMwhEfnRjkZGAFOOH27
4Ty+9nb3c0bLljnYChwne2cSj3+H2W6hk1J8Cl74vRUcmLSm3v0viQ2Giw==

             "]]},
           Annotation[#, "Charting`Private`Tag$10449016#1"]& ]}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, False}, {True, False}},
       FrameLabel->{{
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(E\\), \\(^\\)]\\)  \
[\\!\\(\\*SubscriptBox[\\(k\\), \\(B\\)]\\)T]\"", TraditionalForm], None}, {
          FormBox[
          "\"E [\\!\\(\\*SubscriptBox[\\(k\\), \\(B\\)]\\)T]\"", 
           TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{57.000000000000114`, 1.5}, {40.00000000000003, 
        5.43666777714229}},
       LabelStyle->Medium,
       Method->{
        "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
         "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& )}},
       PlotRange->{{-310, 5}, {-310, 5}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {192., -118.66252583997979}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{
        {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
         EdgeForm[{Opacity[0.5389999999999999], Thickness[Small]}], {{}, 
          {RGBColor[0.97858, 0.678934, 0.157834], Opacity[0.5], EdgeForm[{
           Opacity[0.5389999999999999], Thickness[Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.85, 0.}, {-0.8, 1}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{61.72593648140596, 
                 70.3000485966273}, {-37.97468974091121, -35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 1]& ,
              TagBoxNote->"1"],
             StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.8, 0.}, {-0.75, 1}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{69.85004859662732, 
                 78.42416071184869}, {-37.97468974091121, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 1]& ,
              TagBoxNote->"1"],
             StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.7, 0.}, {-0.65, 1}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{86.09827282707008, 
                 94.67238494229144}, {-37.97468974091121, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 1]& ,
              TagBoxNote->"1"],
             StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.65, 0.}, {-0.6, 1}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{94.22238494229143, 
                 102.7964970575128}, {-37.97468974091121, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 1]& ,
              TagBoxNote->"1"],
             StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.55, 0.}, {-0.5, 2}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{110.47060917273419`, 
                 119.04472128795555`}, {-39.911631063851395`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 2]& ,
              TagBoxNote->"2"],
             StyleBox["2", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[2, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.5, 0.}, {-0.45, 2}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{118.59472128795554`, 
                 127.1688334031769}, {-39.911631063851395`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 2]& ,
              TagBoxNote->"2"],
             StyleBox["2", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[2, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.45, 0.}, {-0.4, 2}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{126.71883340317689`, 
                 135.29294551839826`}, {-39.911631063851395`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 2]& ,
              TagBoxNote->"2"],
             StyleBox["2", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[2, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.4, 0.}, {-0.35, 1}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{134.84294551839824`, 
                 143.4170576336196}, {-37.97468974091121, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 1]& ,
              TagBoxNote->"1"],
             StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.35, 0.}, {-0.3, 1}, "RoundingRadius" -> 0]},
                ImageSizeCache->{{142.9670576336196, 
                 151.541169748841}, {-37.97468974091121, -35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 1]& ,
              TagBoxNote->"1"],
             StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.3, 0.}, {-0.25, 2}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{151.091169748841, 
                 159.66528186406237`}, {-39.911631063851395`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 2]& ,
              TagBoxNote->"2"],
             StyleBox["2", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[2, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.25, 0.}, {-0.2, 9}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{159.21528186406235`, 
                 167.78939397928372`}, {-53.470220324432674`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 9]& ,
              TagBoxNote->"9"],
             StyleBox["9", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[9, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.2, 0.}, {-0.15, 13}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{167.3393939792837, 
                 175.91350609450507`}, {-61.21798561619342, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 13]& ,
              TagBoxNote->"13"],
             StyleBox["13", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[13, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.15, 0.}, {-0.1, 32}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{175.46350609450505`, 
                 184.03761820972647`}, {-98.01987075205693, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 32]& ,
              TagBoxNote->"32"],
             StyleBox["32", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[32, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.1, 0.}, {-0.05, 44}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{183.58761820972646`, 
                 192.16173032494783`}, {-121.26316662733913`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 44]& ,
              TagBoxNote->"44"],
             StyleBox["44", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[44, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.05, 0.}, {0., 59}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{191.7117303249478, 
                 200.28584244016918`}, {-150.3172864714419, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 59]& ,
              TagBoxNote->"59"],
             StyleBox["59", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[59, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{0., 0.}, {0.05, 57}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{199.83584244016916`, 
                 208.40995455539053`}, {-146.44340382556155`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 57]& ,
              TagBoxNote->"57"],
             StyleBox["57", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[57, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{0.05, 0.}, {0.1, 48}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{207.9599545553905, 
                 216.53406667061188`}, {-129.01093191909987`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 48]& ,
              TagBoxNote->"48"],
             StyleBox["48", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[48, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{0.1, 0.}, {0.15, 24}, "RoundingRadius" -> 0]},
                ImageSizeCache->{{216.08406667061186`, 
                 224.6581787858333}, {-82.52434016853545, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 24]& ,
              TagBoxNote->"24"],
             StyleBox["24", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[24, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{0.15, 0.}, {0.2, 7}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{224.20817878583327`, 
                 232.78229090105464`}, {-49.59633767855232, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 7]& ,
              TagBoxNote->"7"],
             StyleBox["7", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[7, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{0.2, 0.}, {0.25, 3}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{232.33229090105462`, 
                 240.906403016276}, {-41.84857238679158, -35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 3]& ,
              TagBoxNote->"3"],
             StyleBox["3", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[3, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{0.25, 0.}, {0.3, 5}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{240.45640301627597`, 
                 249.03051513149734`}, {-45.722455032671945`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 5]& ,
              TagBoxNote->"5"],
             StyleBox["5", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[5, {FontSize -> Medium}], 
             "Tooltip"]& ]}, {}, {}}}, {{{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-0.873, 0.},
       DisplayFunction->Identity,
       Frame->{{True, False}, {True, False}},
       FrameLabel->{{
          FormBox["\"Count\"", TraditionalForm], None}, {
          FormBox["\"Rel. err\"", TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{57.000000000000114`, 1.5}, {40.00000000000003, 
        5.43666777714229}},
       LabelStyle->Medium,
       PlotRange->{{-0.85, 0.3}, {All, All}},
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {None, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {576., -118.66252583997979}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{{
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-10.452591430000002`, -16.08359022984658}, \
{-10.452591430000002`, -14.456563390413141`}}], 
              LineBox[{{-10.452591430000002`, -14.456563390413141`}, \
{-10.452591430000002`, -12.829536550979704`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-202.192968, -287.47163137155843`}, {-202.192968, \
-253.8013547748957}}], 
              LineBox[{{-202.192968, -253.8013547748957}, {-202.192968, \
-220.131078178233}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-252.11954999999998`, -241.70359289578872`}, \
{-252.11954999999998`, -218.9781903093363}}], 
              LineBox[{{-252.11954999999998`, -218.9781903093363}, \
{-252.11954999999998`, -196.25278772288388`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-215.5739689, -209.65284131039053`}, {-215.5739689, \
-194.5791670916178}}], 
              LineBox[{{-215.5739689, -194.5791670916178}, {-215.5739689, \
-179.50549287284505`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.69029945, -15.921988987962933`}, {-19.69029945, \
-13.102589968098473`}}], 
              LineBox[{{-19.69029945, -13.102589968098473`}, {-19.69029945, \
-10.283190948234012`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-156.9681656, -178.51551128676374`}, {-156.9681656, \
-162.60868474080857`}}], 
              LineBox[{{-156.9681656, -162.60868474080857`}, {-156.9681656, \
-146.7018581948534}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.402835910000002`, -16.68746564441654}, \
{-15.402835910000002`, -14.127207331674649`}}], 
              LineBox[{{-15.402835910000002`, -14.127207331674649`}, \
{-15.402835910000002`, -11.566949018932757`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-152.214854, -169.52591777014038`}, {-152.214854, \
-155.7308747174218}}], 
              LineBox[{{-152.214854, -155.7308747174218}, {-152.214854, \
-141.93583166470324`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-166.2670094, -206.00393758662585`}, {-166.2670094, \
-191.04244779557698`}}], 
              LineBox[{{-166.2670094, -191.04244779557698`}, {-166.2670094, \
-176.0809580045281}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-24.973489780000005`, -24.24897127131743}, \
{-24.973489780000005`, -21.083807848532572`}}], 
              LineBox[{{-24.973489780000005`, -21.083807848532572`}, \
{-24.973489780000005`, -17.918644425747715`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-273.6209767, -280.67760405679456`}, {-273.6209767, \
-267.475805640935}}], 
              LineBox[{{-273.6209767, -267.475805640935}, {-273.6209767, \
-254.2740072250754}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.51465421, -18.822412212476532`}, {-17.51465421, \
-17.08171776717295}}], 
              LineBox[{{-17.51465421, -17.08171776717295}, {-17.51465421, \
-15.34102332186937}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-228.6788813, -215.8389783598491}, {-228.6788813, \
-203.66875876494154`}}], 
              LineBox[{{-228.6788813, -203.66875876494154`}, {-228.6788813, \
-191.49853917003398`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-261.2832517, -266.61546364135995`}, {-261.2832517, \
-251.81353496776654`}}], 
              LineBox[{{-261.2832517, -251.81353496776654`}, {-261.2832517, \
-237.0116062941731}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-199.781755, -221.60072574138948`}, {-199.781755, \
-205.83020768321907`}}], 
              LineBox[{{-199.781755, -205.83020768321907`}, {-199.781755, \
-190.05968962504866`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.65401523, -23.504740119122047`}, {-18.65401523, \
-21.974098927590774`}}], 
              LineBox[{{-18.65401523, -21.974098927590774`}, {-18.65401523, \
-20.4434577360595}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-233.1004677, -238.14368185588444`}, {-233.1004677, \
-216.99659065915338`}}], 
              LineBox[{{-233.1004677, -216.99659065915338`}, {-233.1004677, \
-195.84949946242233`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-20.58593557, -21.985236958319735`}, {-20.58593557, \
-19.66163270657321}}], 
              LineBox[{{-20.58593557, -19.66163270657321}, {-20.58593557, \
-17.338028454826688`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-14.035328210000001`, -17.673192633581248`}, \
{-14.035328210000001`, -16.099547886069136`}}], 
              LineBox[{{-14.035328210000001`, -16.099547886069136`}, \
{-14.035328210000001`, -14.525903138557023`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-180.9368838, -232.56866922517304`}, {-180.9368838, \
-209.03328365540784`}}], 
              LineBox[{{-180.9368838, -209.03328365540784`}, {-180.9368838, \
-185.49789808564265`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-20.2795015, -21.010894362043754`}, {-20.2795015, \
-19.09238897278913}}], 
              LineBox[{{-20.2795015, -19.09238897278913}, {-20.2795015, \
-17.173883583534508`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.63682455, -22.700527426618358`}, {-15.63682455, \
-21.155761495425377`}}], 
              LineBox[{{-15.63682455, -21.155761495425377`}, {-15.63682455, \
-19.610995564232397`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-5.866946123, -14.017380381941702`}, {-5.866946123, \
-12.442987084365884`}}], 
              LineBox[{{-5.866946123, -12.442987084365884`}, {-5.866946123, \
-10.868593786790065`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-10.1054112, -17.880055645364664`}, {-10.1054112, \
-15.69027443801492}}], 
              LineBox[{{-10.1054112, -15.69027443801492}, {-10.1054112, \
-13.500493230665178`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-230.1019404, -257.7920281074207}, {-230.1019404, \
-235.60653761923209`}}], 
              LineBox[{{-230.1019404, -235.60653761923209`}, {-230.1019404, \
-213.42104713104348`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-291.30778, -247.53809969359176`}, {-291.30778, \
-230.44888208962217`}}], 
              LineBox[{{-291.30778, -230.44888208962217`}, {-291.30778, \
-213.3596644856526}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-12.28408675, -13.034862708386658`}, {-12.28408675, \
-10.917361208145469`}}], 
              LineBox[{{-12.28408675, -10.917361208145469`}, {-12.28408675, \
-8.799859707904279}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-24.67568185, -26.520750261030784`}, {-24.67568185, \
-25.20693008996167}}], 
              LineBox[{{-24.67568185, -25.20693008996167}, {-24.67568185, \
-23.893109918892556`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.480867, -21.918620764138815`}, {-15.480867, \
-20.188886667237874`}}], 
              LineBox[{{-15.480867, -20.188886667237874`}, {-15.480867, \
-18.459152570336933`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-283.1428106, -274.5246387899278}, {-283.1428106, \
-252.23889841880802`}}], 
              LineBox[{{-283.1428106, -252.23889841880802`}, {-283.1428106, \
-229.95315804768828`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.758344080000002`, -14.091748268665416`}, \
{-14.758344080000002`, -12.615862016219314`}}], 
              LineBox[{{-14.758344080000002`, -12.615862016219314`}, \
{-14.758344080000002`, -11.139975763773212`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-287.80513, -279.76312361661815`}, {-287.80513, \
-255.50620753009636`}}], 
              LineBox[{{-287.80513, -255.50620753009636`}, {-287.80513, \
-231.24929144357458`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.75612748, -17.869483142003155`}, {-11.75612748, \
-16.24577164485567}}], 
              LineBox[{{-11.75612748, -16.24577164485567}, {-11.75612748, \
-14.622060147708183`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.47694274, -24.459755120995446`}, {-17.47694274, \
-21.45197143263925}}], 
              LineBox[{{-17.47694274, -21.45197143263925}, {-17.47694274, \
-18.444187744283056`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.56226548, -16.86344329355961}, {-15.56226548, \
-14.673979941133252`}}], 
              LineBox[{{-15.56226548, -14.673979941133252`}, {-15.56226548, \
-12.484516588706894`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-195.6663408, -239.30592823240178`}, {-195.6663408, \
-215.4163712348732}}], 
              LineBox[{{-195.6663408, -215.4163712348732}, {-195.6663408, \
-191.5268142373446}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-161.4118904, -217.1694906539776}, {-161.4118904, \
-202.70016164915643`}}], 
              LineBox[{{-161.4118904, -202.70016164915643`}, {-161.4118904, \
-188.23083264433527`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-13.761870920000002`, -16.9499869074453}, \
{-13.761870920000002`, -15.220785784018718`}}], 
              LineBox[{{-13.761870920000002`, -15.220785784018718`}, \
{-13.761870920000002`, -13.491584660592135`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-214.39039, -225.03284379571397`}, {-214.39039, \
-209.3179401728306}}], 
              LineBox[{{-214.39039, -209.3179401728306}, {-214.39039, \
-193.6030365499472}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-266.5537267, -261.34988018019715`}, {-266.5537267, \
-232.79657120319246`}}], 
              LineBox[{{-266.5537267, -232.79657120319246`}, {-266.5537267, \
-204.24326222618777`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-232.4892347, -280.2589482715307}, {-232.4892347, \
-253.81447345683128`}}], 
              LineBox[{{-232.4892347, -253.81447345683128`}, {-232.4892347, \
-227.3699986421319}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-197.47946709999997`, -218.67419866941927`}, \
{-197.47946709999997`, -203.51461725340727`}}], 
              LineBox[{{-197.47946709999997`, -203.51461725340727`}, \
{-197.47946709999997`, -188.35503583739526`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-150.6709562, -185.1832767667546}, {-150.6709562, \
-166.35000888188628`}}], 
              LineBox[{{-150.6709562, -166.35000888188628`}, {-150.6709562, \
-147.51674099701796`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-163.2012471, -163.7764002418946}, {-163.2012471, \
-148.44076353585046`}}], 
              LineBox[{{-163.2012471, -148.44076353585046`}, {-163.2012471, \
-133.10512682980632`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-171.1272905, -163.8919704623435}, {-171.1272905, \
-149.85249361996745`}}], 
              LineBox[{{-171.1272905, -149.85249361996745`}, {-171.1272905, \
-135.8130167775914}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-13.546501870000002`, -16.014331040565324`}, \
{-13.546501870000002`, -13.411952948229056`}}], 
              LineBox[{{-13.546501870000002`, -13.411952948229056`}, \
{-13.546501870000002`, -10.809574855892789`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-252.8883428, -255.011419920914}, {-252.8883428, \
-231.9429612033868}}], 
              LineBox[{{-252.8883428, -231.9429612033868}, {-252.8883428, \
-208.8745024858596}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-167.91973299999998`, -206.68979839223505`}, \
{-167.91973299999998`, -182.67088178794288`}}], 
              LineBox[{{-167.91973299999998`, -182.67088178794288`}, \
{-167.91973299999998`, -158.6519651836507}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-193.4124013, -222.29780114582707`}, {-193.4124013, \
-205.53628934209294`}}], 
              LineBox[{{-193.4124013, -205.53628934209294`}, {-193.4124013, \
-188.77477753835882`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-28.18247172, -23.04373085369953}, {-28.18247172, \
-20.310114590044396`}}], 
              LineBox[{{-28.18247172, -20.310114590044396`}, {-28.18247172, \
-17.576498326389263`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-156.9436822, -158.09706555868388`}, {-156.9436822, \
-147.35758195627295`}}], 
              LineBox[{{-156.9436822, -147.35758195627295`}, {-156.9436822, \
-136.61809835386202`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-10.866955680000002`, -22.08944581716387}, \
{-10.866955680000002`, -19.245947373004984`}}], 
              LineBox[{{-10.866955680000002`, -19.245947373004984`}, \
{-10.866955680000002`, -16.4024489288461}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-277.922571, -288.70542224443733`}, {-277.922571, \
-275.7305147598983}}], 
              LineBox[{{-277.922571, -275.7305147598983}, {-277.922571, \
-262.7556072753593}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-4.280727263, -13.135683689522152`}, {-4.280727263, \
-9.86526859450576}}], 
              LineBox[{{-4.280727263, -9.86526859450576}, {-4.280727263, \
-6.5948534994893695`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-239.0259818, -263.1260270915496}, {-239.0259818, \
-249.37199133701688`}}], 
              LineBox[{{-239.0259818, -249.37199133701688`}, {-239.0259818, \
-235.61795558248414`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-171.486215, -181.80559313763382`}, {-171.486215, \
-162.27467623645506`}}], 
              LineBox[{{-171.486215, -162.27467623645506`}, {-171.486215, \
-142.7437593352763}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.44477691, -17.297070553756278`}, {-11.44477691, \
-15.67783842241245}}], 
              LineBox[{{-11.44477691, -15.67783842241245}, {-11.44477691, \
-14.058606291068623`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-231.4164105, -261.60650652193294`}, {-231.4164105, \
-243.40994421135252`}}], 
              LineBox[{{-231.4164105, -243.40994421135252`}, {-231.4164105, \
-225.21338190077213`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-27.08475597, -24.97222495112252}, {-27.08475597, \
-21.31957696575311}}], 
              LineBox[{{-27.08475597, -21.31957696575311}, {-27.08475597, \
-17.6669289803837}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-158.590581, -220.08382795346452`}, {-158.590581, \
-206.20538891660277`}}], 
              LineBox[{{-158.590581, -206.20538891660277`}, {-158.590581, \
-192.32694987974102`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.597435060000002`, -19.076529860519372`}, \
{-15.597435060000002`, -17.024356812453348`}}], 
              LineBox[{{-15.597435060000002`, -17.024356812453348`}, \
{-15.597435060000002`, -14.972183764387324`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-201.0474559, -176.18357186605462`}, {-201.0474559, \
-153.49365472552785`}}], 
              LineBox[{{-201.0474559, -153.49365472552785`}, {-201.0474559, \
-130.80373758500107`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.310022820000002`, -12.60818191538744}, \
{-11.310022820000002`, -10.958372740272779`}}], 
              LineBox[{{-11.310022820000002`, -10.958372740272779`}, \
{-11.310022820000002`, -9.308563565158117}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-136.6105064, -185.06583265476368`}, {-136.6105064, \
-162.5916995717822}}], 
              LineBox[{{-136.6105064, -162.5916995717822}, {-136.6105064, \
-140.1175664888007}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-26.94997182, -19.088266956660803`}, {-26.94997182, \
-16.261822766204908`}}], 
              LineBox[{{-26.94997182, -16.261822766204908`}, {-26.94997182, \
-13.435378575749015`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-25.16425491, -25.268138574293634`}, {-25.16425491, \
-23.10611829915087}}], 
              LineBox[{{-25.16425491, -23.10611829915087}, {-25.16425491, \
-20.94409802400811}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-187.4796539, -201.16184856817742`}, {-187.4796539, \
-185.1224212851796}}], 
              LineBox[{{-187.4796539, -185.1224212851796}, {-187.4796539, \
-169.08299400218178`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-10.595815280000002`, -21.838501708993228`}, \
{-10.595815280000002`, -19.878544750810622`}}], 
              LineBox[{{-10.595815280000002`, -19.878544750810622`}, \
{-10.595815280000002`, -17.918587792628017`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-127.3825838, -150.84737406093387`}, {-127.3825838, \
-135.45055385394764`}}], 
              LineBox[{{-127.3825838, -135.45055385394764`}, {-127.3825838, \
-120.05373364696142`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-9.491366085, -18.059981578611502`}, {-9.491366085, \
-14.417046782106471`}}], 
              LineBox[{{-9.491366085, -14.417046782106471`}, {-9.491366085, \
-10.77411198560144}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-7.541234718000001, -12.668891831487185`}, \
{-7.541234718000001, -10.940593928645436`}}], 
              LineBox[{{-7.541234718000001, -10.940593928645436`}, \
{-7.541234718000001, -9.212296025803687}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-12.008740730000001`, -20.42758137468445}, \
{-12.008740730000001`, -17.284578538407125`}}], 
              LineBox[{{-12.008740730000001`, -17.284578538407125`}, \
{-12.008740730000001`, -14.1415757021298}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-14.516404840000002`, -16.65621086916681}, \
{-14.516404840000002`, -13.980880874433588`}}], 
              LineBox[{{-14.516404840000002`, -13.980880874433588`}, \
{-14.516404840000002`, -11.305550879700366`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.219611940000002`, -19.968566022802854`}, \
{-11.219611940000002`, -16.60851173343404}}], 
              LineBox[{{-11.219611940000002`, -16.60851173343404}, \
{-11.219611940000002`, -13.248457444065222`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.46927914, -17.832741815820047`}, {-17.46927914, \
-15.557243394371072`}}], 
              LineBox[{{-17.46927914, -15.557243394371072`}, {-17.46927914, \
-13.281744972922098`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-23.399845550000002`, -25.927355516724347`}, \
{-23.399845550000002`, -24.41020285490692}}], 
              LineBox[{{-23.399845550000002`, -24.41020285490692}, \
{-23.399845550000002`, -22.893050193089493`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-206.6846623, -200.10633325252854`}, {-206.6846623, \
-185.94623607815325`}}], 
              LineBox[{{-206.6846623, -185.94623607815325`}, {-206.6846623, \
-171.78613890377795`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-20.711117860000005`, -22.076602933043144`}, \
{-20.711117860000005`, -20.122993686435727`}}], 
              LineBox[{{-20.711117860000005`, -20.122993686435727`}, \
{-20.711117860000005`, -18.16938443982831}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-198.3854754, -178.4405570668967}, {-198.3854754, \
-157.07356586330658`}}], 
              LineBox[{{-198.3854754, -157.07356586330658`}, {-198.3854754, \
-135.70657465971647`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-10.09458197, -14.727991955247214`}, {-10.09458197, \
-12.48012826606362}}], 
              LineBox[{{-10.09458197, -12.48012826606362}, {-10.09458197, \
-10.232264576880025`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-22.59242554, -22.672606783769517`}, {-22.59242554, \
-19.765941706379955`}}], 
              LineBox[{{-22.59242554, -19.765941706379955`}, {-22.59242554, \
-16.859276628990393`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-133.0975666, -180.6683522988493}, {-133.0975666, \
-170.72721952524324`}}], 
              LineBox[{{-133.0975666, -170.72721952524324`}, {-133.0975666, \
-160.78608675163719`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-159.7965766, -162.23767652572107`}, {-159.7965766, \
-146.97723338311818`}}], 
              LineBox[{{-159.7965766, -146.97723338311818`}, {-159.7965766, \
-131.71679024051528`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-13.55166265, -14.19459322364057}, {-13.55166265, \
-10.943156015314585`}}], 
              LineBox[{{-13.55166265, -10.943156015314585`}, {-13.55166265, \
-7.6917188069886}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.215672570000002`, -18.811385253221772`}, \
{-15.215672570000002`, -16.137845116072338`}}], 
              LineBox[{{-15.215672570000002`, -16.137845116072338`}, \
{-15.215672570000002`, -13.464304978922904`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-12.74204637, -16.32425189208509}, {-12.74204637, \
-13.498790737307939`}}], 
              LineBox[{{-12.74204637, -13.498790737307939`}, {-12.74204637, \
-10.673329582530787`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-173.7177977, -227.57411694212715`}, {-173.7177977, \
-206.27091703260874`}}], 
              LineBox[{{-173.7177977, -206.27091703260874`}, {-173.7177977, \
-184.96771712309032`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-193.11558879999998`, -206.21275361234376`}, \
{-193.11558879999998`, -196.74474372078208`}}], 
              LineBox[{{-193.11558879999998`, -196.74474372078208`}, \
{-193.11558879999998`, -187.2767338292204}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-12.00060878, -18.575950677390555`}, {-12.00060878, \
-16.6953616950895}}], 
              LineBox[{{-12.00060878, -16.6953616950895}, {-12.00060878, \
-14.814772712788445`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-13.838459270000001`, -18.389151110810772`}, \
{-13.838459270000001`, -16.454402164310896`}}], 
              LineBox[{{-13.838459270000001`, -16.454402164310896`}, \
{-13.838459270000001`, -14.519653217811017`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-20.80179863, -24.83715184309496}, {-20.80179863, \
-23.51160705403352}}], 
              LineBox[{{-20.80179863, -23.51160705403352}, {-20.80179863, \
-22.186062264972076`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-231.6668386, -255.85258985748595`}, {-231.6668386, \
-245.72345102069346`}}], 
              LineBox[{{-231.6668386, -245.72345102069346`}, {-231.6668386, \
-235.59431218390097`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.8303766, -17.854245639757405`}, {-16.8303766, \
-15.969131529630936`}}], 
              LineBox[{{-16.8303766, -15.969131529630936`}, {-16.8303766, \
-14.084017419504466`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-167.7111972, -158.33363546639399`}, {-167.7111972, \
-146.82854585923474`}}], 
              LineBox[{{-167.7111972, -146.82854585923474`}, {-167.7111972, \
-135.3234562520755}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.61514001, -17.118150960127622`}, {-16.61514001, \
-14.361757697669406`}}], 
              LineBox[{{-16.61514001, -14.361757697669406`}, {-16.61514001, \
-11.605364435211191`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-247.58565, -245.00204772020416`}, {-247.58565, \
-216.02131028900914`}}], 
              LineBox[{{-247.58565, -216.02131028900914`}, {-247.58565, \
-187.0405728578141}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-164.4031021, -178.90901222958024`}, {-164.4031021, \
-164.0568391318588}}], 
              LineBox[{{-164.4031021, -164.0568391318588}, {-164.4031021, \
-149.20466603413735`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-12.565501530000002`, -21.192764907643323`}, \
{-12.565501530000002`, -18.746977770324236`}}], 
              LineBox[{{-12.565501530000002`, -18.746977770324236`}, \
{-12.565501530000002`, -16.30119063300515}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-167.4371538, -168.64078411524736`}, {-167.4371538, \
-154.98530185011518`}}], 
              LineBox[{{-167.4371538, -154.98530185011518`}, {-167.4371538, \
-141.329819584983}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-194.8134055, -208.71682057939532`}, {-194.8134055, \
-196.70520095098783`}}], 
              LineBox[{{-194.8134055, -196.70520095098783`}, {-194.8134055, \
-184.69358132258034`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-267.8469255, -276.1723640969882}, {-267.8469255, \
-263.8264222761086}}], 
              LineBox[{{-267.8469255, -263.8264222761086}, {-267.8469255, \
-251.480480455229}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-224.942923, -215.03826060213504`}, {-224.942923, \
-202.52915662900602`}}], 
              LineBox[{{-224.942923, -202.52915662900602`}, {-224.942923, \
-190.020052655877}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.736214950000003`, -17.777884715086184`}, \
{-15.736214950000003`, -16.023990015115483`}}], 
              LineBox[{{-15.736214950000003`, -16.023990015115483`}, \
{-15.736214950000003`, -14.270095315144781`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-250.1519291, -263.7734314983962}, {-250.1519291, \
-245.53088017872372`}}], 
              LineBox[{{-250.1519291, -245.53088017872372`}, {-250.1519291, \
-227.28832885905126`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-248.88074339999997`, -249.79593463054033`}, \
{-248.88074339999997`, -235.01171908087866`}}], 
              LineBox[{{-248.88074339999997`, -235.01171908087866`}, \
{-248.88074339999997`, -220.227503531217}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-7.196171530000001, -11.580666133788794`}, \
{-7.196171530000001, -9.501516920151047}}], 
              LineBox[{{-7.196171530000001, -9.501516920151047}, \
{-7.196171530000001, -7.422367706513301}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-141.8710277, -162.50687668561523`}, {-141.8710277, \
-144.79668300444249`}}], 
              LineBox[{{-141.8710277, -144.79668300444249`}, {-141.8710277, \
-127.08648932326976`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-27.00825379, -20.896334121345646`}, {-27.00825379, \
-17.320954907481102`}}], 
              LineBox[{{-27.00825379, -17.320954907481102`}, {-27.00825379, \
-13.74557569361656}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-25.08293619, -26.38387331192365}, {-25.08293619, \
-24.286620361096855`}}], 
              LineBox[{{-25.08293619, -24.286620361096855`}, {-25.08293619, \
-22.18936741027006}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-9.076562506, -14.287848628450163`}, {-9.076562506, \
-11.692221572120205`}}], 
              LineBox[{{-9.076562506, -11.692221572120205`}, {-9.076562506, \
-9.096594515790247}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-205.153409, -225.86022668002573`}, {-205.153409, \
-212.27982992727073`}}], 
              LineBox[{{-205.153409, -212.27982992727073`}, {-205.153409, \
-198.69943317451572`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-202.1253899, -208.28181402444835`}, {-202.1253899, \
-198.25970125971241`}}], 
              LineBox[{{-202.1253899, -198.25970125971241`}, {-202.1253899, \
-188.23758849497648`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.35430533, -24.32359003247382}, {-16.35430533, \
-22.22405490150119}}], 
              LineBox[{{-16.35430533, -22.22405490150119}, {-16.35430533, \
-20.12451977052856}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.69722556, -16.65370932709684}, {-15.69722556, \
-14.266196241947691`}}], 
              LineBox[{{-15.69722556, -14.266196241947691`}, {-15.69722556, \
-11.87868315679854}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-24.34314783, -22.82563887891814}, {-24.34314783, \
-19.763221403331652`}}], 
              LineBox[{{-24.34314783, -19.763221403331652`}, {-24.34314783, \
-16.700803927745163`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-150.9222046, -171.73652515748523`}, {-150.9222046, \
-155.7436687682736}}], 
              LineBox[{{-150.9222046, -155.7436687682736}, {-150.9222046, \
-139.75081237906198`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-194.3196694, -220.41262267147158`}, {-194.3196694, \
-204.90928685851233`}}], 
              LineBox[{{-194.3196694, -204.90928685851233`}, {-194.3196694, \
-189.40595104555308`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-138.8310933, -147.81845005734124`}, {-138.8310933, \
-135.9505163853742}}], 
              LineBox[{{-138.8310933, -135.9505163853742}, {-138.8310933, \
-124.08258271340713`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-25.942436430000004`, -26.483543344975164`}, \
{-25.942436430000004`, -24.317120374550306`}}], 
              LineBox[{{-25.942436430000004`, -24.317120374550306`}, \
{-25.942436430000004`, -22.15069740412545}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-173.3533045, -222.12020612526635`}, {-173.3533045, \
-198.25756433053297`}}], 
              LineBox[{{-173.3533045, -198.25756433053297`}, {-173.3533045, \
-174.3949225357996}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-214.1880015, -207.03773197238425`}, {-214.1880015, \
-194.76616308330594`}}], 
              LineBox[{{-214.1880015, -194.76616308330594`}, {-214.1880015, \
-182.49459419422763`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-249.5946904, -256.23891947461294`}, {-249.5946904, \
-234.66398191429016`}}], 
              LineBox[{{-249.5946904, -234.66398191429016`}, {-249.5946904, \
-213.08904435396738`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-198.294944, -209.91686832582664`}, {-198.294944, \
-201.92541426207515`}}], 
              LineBox[{{-198.294944, -201.92541426207515`}, {-198.294944, \
-193.93396019832366`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.44868644, -17.061406461068312`}, {-16.44868644, \
-15.18605050263092}}], 
              LineBox[{{-16.44868644, -15.18605050263092}, {-16.44868644, \
-13.310694544193527`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-155.4720648, -150.62854629987686`}, {-155.4720648, \
-139.19077062840782`}}], 
              LineBox[{{-155.4720648, -139.19077062840782`}, {-155.4720648, \
-127.75299495693878`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.99950242, -17.4335277719934}, {-16.99950242, \
-16.039675852580697`}}], 
              LineBox[{{-16.99950242, -16.039675852580697`}, {-16.99950242, \
-14.645823933167993`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.343036990000005`, -22.127853461061683`}, \
{-18.343036990000005`, -20.432660341654028`}}], 
              LineBox[{{-18.343036990000005`, -20.432660341654028`}, \
{-18.343036990000005`, -18.737467222246373`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-231.3836841, -239.4429497597985}, {-231.3836841, \
-217.8222427856907}}], 
              LineBox[{{-231.3836841, -217.8222427856907}, {-231.3836841, \
-196.2015358115829}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.34619017, -20.562073075174958`}, {-18.34619017, \
-18.760089797254906`}}], 
              LineBox[{{-18.34619017, -18.760089797254906`}, {-18.34619017, \
-16.958106519334855`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-137.2083688, -176.54654799515234`}, {-137.2083688, \
-162.46565039243075`}}], 
              LineBox[{{-137.2083688, -162.46565039243075`}, {-137.2083688, \
-148.38475278970915`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-22.16411359, -23.214493787661134`}, {-22.16411359, \
-21.94427946670459}}], 
              LineBox[{{-22.16411359, -21.94427946670459}, {-22.16411359, \
-20.674065145748045`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-228.8679563, -247.35039480144516`}, {-228.8679563, \
-224.40366719634554`}}], 
              LineBox[{{-228.8679563, -224.40366719634554`}, {-228.8679563, \
-201.4569395912459}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           StyleBox[{{}, {
              LineBox[{{-20.21770702, -23.186999116004444`}, {-20.21770702, \
-20.668079122161583`}}], 
              LineBox[{{-20.21770702, -20.668079122161583`}, {-20.21770702, \
-18.149159128318722`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-200.34562289999997`, -209.00858625574386`}, \
{-200.34562289999997`, -190.8540927432975}}], 
              LineBox[{{-200.34562289999997`, -190.8540927432975}, \
{-200.34562289999997`, -172.69959923085116`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-16.05789764, -16.749128026768574`}, {-16.05789764, \
-15.288541994166781`}}], 
              LineBox[{{-16.05789764, -15.288541994166781`}, {-16.05789764, \
-13.827955961564989`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.57202202, -19.38775161127652}, {-11.57202202, \
-16.39595707271473}}], 
              LineBox[{{-11.57202202, -16.39595707271473}, {-11.57202202, \
-13.404162534152936`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.34208923, -15.790329697887811`}, {-11.34208923, \
-13.584724606597385`}}], 
              LineBox[{{-11.34208923, -13.584724606597385`}, {-11.34208923, \
-11.379119515306959`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.06899218, -19.7722190073433}, {-18.06899218, \
-18.11127143078656}}], 
              LineBox[{{-18.06899218, -18.11127143078656}, {-18.06899218, \
-16.45032385422982}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-20.571342020000003`, -18.887750001380272`}, \
{-20.571342020000003`, -16.800350863759448`}}], 
              LineBox[{{-20.571342020000003`, -16.800350863759448`}, \
{-20.571342020000003`, -14.712951726138622`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-192.0334666, -211.65302966828676`}, {-192.0334666, \
-200.42053030897125`}}], 
              LineBox[{{-192.0334666, -200.42053030897125`}, {-192.0334666, \
-189.18803094965574`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-22.67410847, -27.043613738724176`}, {-22.67410847, \
-25.813658598160753`}}], 
              LineBox[{{-22.67410847, -25.813658598160753`}, {-22.67410847, \
-24.58370345759733}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-136.3388297, -174.64535654071992`}, {-136.3388297, \
-159.22858330753238`}}], 
              LineBox[{{-136.3388297, -159.22858330753238`}, {-136.3388297, \
-143.81181007434483`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-193.2731135, -219.29019749582494`}, {-193.2731135, \
-202.29286943181458`}}], 
              LineBox[{{-193.2731135, -202.29286943181458`}, {-193.2731135, \
-185.29554136780422`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-18.1726578, -25.742618451387766`}, {-18.1726578, \
-22.38772081373989}}], 
              LineBox[{{-18.1726578, -22.38772081373989}, {-18.1726578, \
-19.032823176092013`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-15.17301452, -17.805285294716526`}, {-15.17301452, \
-15.99329899302641}}], 
              LineBox[{{-15.17301452, -15.99329899302641}, {-15.17301452, \
-14.181312691336293`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-173.6078787, -218.9390986589543}, {-173.6078787, \
-192.136249403327}}], 
              LineBox[{{-173.6078787, -192.136249403327}, {-173.6078787, \
-165.33340014769973`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-12.46433826, -19.067958426411824`}, {-12.46433826, \
-17.14829128677881}}], 
              LineBox[{{-12.46433826, -17.14829128677881}, {-12.46433826, \
-15.2286241471458}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-26.932678710000005`, -27.984009500152517`}, \
{-26.932678710000005`, -24.688650323576567`}}], 
              LineBox[{{-26.932678710000005`, -24.688650323576567`}, \
{-26.932678710000005`, -21.393291147000618`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-21.74484064, -23.69813554223413}, {-21.74484064, \
-20.250947953398278`}}], 
              LineBox[{{-21.74484064, -20.250947953398278`}, {-21.74484064, \
-16.803760364562425`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-180.848529, -210.9864424173616}, {-180.848529, \
-192.4045795076202}}], 
              LineBox[{{-180.848529, -192.4045795076202}, {-180.848529, \
-173.82271659787884`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-17.657632000000003`, -21.119673210137083`}, \
{-17.657632000000003`, -17.583324067825824`}}], 
              LineBox[{{-17.657632000000003`, -17.583324067825824`}, \
{-17.657632000000003`, -14.046974925514567`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-195.1780703, -214.437837091971}, {-195.1780703, \
-202.20075379147963`}}], 
              LineBox[{{-195.1780703, -202.20075379147963`}, {-195.1780703, \
-189.96367049098825`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-202.9638538, -202.76265795542264`}, {-202.9638538, \
-186.48222199515624`}}], 
              LineBox[{{-202.9638538, -186.48222199515624`}, {-202.9638538, \
-170.20178603488984`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-277.7060449, -248.4003339888794}, {-277.7060449, \
-229.92377335493552`}}], 
              LineBox[{{-277.7060449, -229.92377335493552`}, {-277.7060449, \
-211.44721272099164`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-282.7374245, -280.5539798594036}, {-282.7374245, \
-264.87238395031807`}}], 
              LineBox[{{-282.7374245, -264.87238395031807`}, {-282.7374245, \
-249.19078804123254`}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-19.16303922, -24.35877618405152}, {-19.16303922, \
-22.761569374419956`}}], 
              LineBox[{{-19.16303922, -22.761569374419956`}, {-19.16303922, \
-21.16436256478839}}]}},
            Antialiasing->False]}, 
          {RGBColor[0.368417, 0.506779, 0.709798], 
           
           StyleBox[{{}, {
              LineBox[{{-11.46032233, -13.637050365158936`}, {-11.46032233, \
-11.84399398761229}}], 
              LineBox[{{-11.46032233, -11.84399398761229}, {-11.46032233, \
-10.050937610065644`}}]}},
            Antialiasing->False]}}, {
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.009166666666666668], AbsoluteThickness[1.6], 
           PointBox[CompressedData["
1:eJwVlnk0FAobxrMkt1ISiZR9G2JWa0nZtdiyixkzmBnDmOySblpQuYWkG/pS
KUKElCz3oY58IQk33a5rqEuRtQgVn++P9zznPc8fz3ve8zvnfVUD+a5BoqtW
rcpfqf/rud/9pJ+MaICAXWXNn/RxRdOsTd+Wg+jeZ5W3a/nISjnj032Kj5vH
nrofDAhFQofE1yMzXASU8dJSXdlgkBdjHlVQMNi8rfQslYCcWzyj79eZ2DYW
6pXgxkI0TSvZ8qUBbB42u6ju1YfteJKcUIKJ3xXobsxYJojyBzzPt7Kwvzah
zncwBNvknW8YLZgg6io9PEqOBssCqzOTCgLIk+jDeY8iMFDZR8cpEtKTC6LG
ZEmoKbENqs3moW1ta1xwNAfZlpPk1MMRqNmSmCCZwMfJzo3q4gtsrFtbvTHj
CQdXJ5+fC7tLBlFm+wX/BRoaan+RNFYPg5jMVpkPyqG4WHN9YDmbCu3KnmZ6
MQVrtFef2yKjjzQp5vwxBSIGNOq/LOYHYzF8qEhalYve+79w0u2omLiFjjvy
FETIbvxHytYQ37stfwxo0+D4KKYWsfJo6limdA7poNBqOmqepoHhzQ/uhDIM
cfr0qa1WT3koar/cxI4Mw8vCx/c+U49iuXd+95GXPBC/pnZFZuiAQLPzr+jV
BMXSK3Gh1AQ506/8F6imOBspRaHOGWCYzxX6EKnwTX32xb5yZV/f928oTOGD
FN5fanN6J7irNa1dzXURXbHUOfhjxfdS+4s8xccER0lD/ZQ2BFPz70ctiPA6
4j+2NYEE/ifv4OpIGpTOvdo3qGyInLuKw5u9d6JyearYNZqNrqvPPrmOc0F4
0EI12MmCo2pIbYgHBx1ei9Obz+pBcCmrd63AAJPuepuT2rk4f+GfS/oELpqM
UqT/LopA9eEPyccVwkDMTOm8uzEM+Rm3CNJP+LC0ZLZ5lrMxQbjWGBvBQbqI
enxcbyB8b3TbUNpYsN3enB8RzMLHWNV6xd8CMf767FMZVhCGTKtu2NUFori6
V75TXg8j1sQTY68JYFIHD4bl8WFgsVCvv8RD8cnhyPCfK7x5yPXH9gYjaa0R
i7yTDYGhtb3uAw4c+qJjawx2ocMypoTpRIWOj1gheYXnG4s1ToLQQIz4cfIH
6zQxnUNhz1lQ0Lm5822zvwDqFRbECnMBxh/XfItR3oQ5Z+NE8Tp1uBa3vukR
hsHSj+4zoscHM6FZ5iI/CGKZXZov7Fm4OHG5vfa9FopiLW9J+RqiaVhpl9s4
D+TrrlY7wsLBdzTOqJQzx1hMa1unCw1HZVXWDr9m4uZ8y/nMFg6U/LeKvicZ
Qvzzr3t2SZAg47yr+bQqBxseLom3GzLR1V3gVHddC1OV0z3lo5qY/eORddpm
BrLqpiiTriykrA71IX0xQwtZsUvCioiDRYp56wmmIPvdyCBsM8bTejU3b34I
WlevE46qh8B8+4GqDSRNvO1Y7/RRSEG5xVPLxL4AeMaPTnIn6DgnHHK//F0N
+xQ+aKf06sNKVo5vStgB90rxlOxBTZz8YXYvXlwHatdy1f+yJyE/Z4txsORO
3B7/XdxoTg//mnxciIjQwrvDL3jPc4moXUoqU4sjoTYuW8RpuyGSqnTs/IKN
IZM+LCXGMUE95xM+9nLQazF0yc4iBKSDU13raqjY8e72qURlKijpJ1+5t7Oh
rNJ+x+cmE58H7daHETXQvHdvQPesDhLy91CKc4zgcz6ySfYZBa/P/LRSvkXH
nw2DDBvPIDg8pv12fIGJewXTSTYBgTjqLTwbqaiH1GsMr3+HNFF6JfsmL9wA
JQKHLgd1ImZSYn4dP6aLLZnCE4xlAvJ6BsnzNUFIDCD7lLRyIBdvP1KpzoZa
dutUTw4bpxnWbU6rdDB5wNdUrJIIHd+LqY5leuDM7KtyiyLin+6O0n0dVMgm
SN2fTzZGvcdIg8csD37WTclaj8KheOTyxaweIpSyREXJU4YwpheoNM+x0Cqb
e/SUTyD2cLpexecTsaC66ZBJrT6EeZsKG2bCcW3/aOb9VaHw30A3Gr7AwsRv
B250nWTBgn6Tm6aqiwpG8KTpH2Q4OX7T/TnOwrv+xpyUACb88+a5a3zYMKvK
Fsm4wgb9BUTSGyKgk3ZJwvR4BO5//Yunv2NlPpGhtxPOHGzUTiBMxxli2fse
TUOCiOl47rW/rfnoqgmb/1ERDv+g1vWGSnxcv/VgFZ0ehgiJFOJgqxLmhazu
llXqUCk7Fj1Qx8BJPd+wJIVAmO64PqYkag4L5U4FgisJguqAQ+ZypvC2e/gl
wMEEng3BFIq2GhTKS/q5gdogNvys/Xibg137Phz5msrF7Lcykpj1Sq8lHu/U
yoaYllRTlQ8Rz6ISin1NjWBtc/uPRZYhznyrHHBM1Yfieau0Pk8TlIx6JAQ+
pUD6rklVcn8gPN4K1NpX7peEi2udmSMbz5ch3JrPQc74gvNVHwa6yj0KuEt0
PGSnn7KaNkXjldUdBi4m+KKy2+ZQSRD0JNO/7V7J13v6eJt4CxeRtgL2aS82
+kJ0q9dQ+KALlz32uIehzzrYIOK/bJS+81/K281B6KzL9v6jRKSyp0T3BRhg
vvKW9jY+Exl7RdoUgxmw1F9iDiwTEWLrTdZZS4SDf5lNlycZGvdFeprDqXhb
LlS3+8yD+W7FV05moYDXvrH/eJFRav7QIruZDOOKdbP3tBhIfncnd/gQC9KD
mt5iBCN0Pc86UD9NQ7iv44GWXB4e9sW+GV3PQ4xoVWGdMRXruuvN15RQ8TWl
yXPjOg7eSBx6cvhdCF44GzFebyBCcepxS12WAXq/z28SamhjadxdcCSICKHb
Sxetci1oikhJMPT0kP+8Oq54ExlbaT32iUpkSNYlxFllrvCv79L2vp0Ia+kL
OjIibFj/uvg9SooDx1x2QGapEUpoUhP7X5nCXCrwwZu1DIS2TqU7jzCxufuM
V4MOG2lfawwDHDgwDaYepOiT0frzz5K9TCPoWc/4ZnsZICbodHnGD0OMSUk2
RlYFIZL3UNtPnI30uYzGhnEd6C3PcOc0SVBR2Sn5bMIMGhpmzP0VJtiRelBY
1kjD8htxFQtLKgq3OGpp5wbjnHmt88x6NnI6lDJ9ikiQtx+qPZxNwlG/RFQG
sXFih3EWb+XPErv9+f0bfw6i3F77hTuFQLmifna/rwBF59XTLzbwcOhzwfH2
EgEakwfsZ9MjkNpPm6rXpeDPZx9oc81GGJp08S8f00JSQf+icoU2/ge9QfQd

            "]]}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.009166666666666668], AbsoluteThickness[1.6]}, {}}, {
           {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
            0.009166666666666668], AbsoluteThickness[
            1.6]}, {}}}, {{}, {}}}, {{{}, {}, 
          TagBox[
           {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
            Dashing[{0, Small}], LineBox[CompressedData["
1:eJxFxW0w03EcAPCdp0uHErKLecgaL5bpNM2E6pyVUDlP05k4EbKtk/GvzWSe
x4iu0Z3z0Io6lsRplSUP83COyrmOo7prqeXh6M7+8nCqF76/F5/7OCfwwq4a
EAiEkH/+PzMbvLbjX9G7+1gl9knqi1YHPFbZ+qAbW3dENC/0NWGHSRwVjdsR
iWoi2vryN6ZwVQaHTmO5603oRQ3r2ev1cniickOrYaNrfr6PWOkpg8uOnU3V
WqMHIhUFTllSmJLeGOA6VgrzLPv8gsnorbtD/qqiErjTkKtdmSuG2y/9qeD7
o6uPtggsFEVwwwZOyNoshFcfUqtcOeh0P4OhphcF8ETSptdJM7QgbbqNxM+H
WfHRwyMaCRzr+UbX44au0/cqhaI8uJ+lU7Kn7sDumfquHAa6v1pxhSvLhb1J
PHLwFzGscp/dxptzYNlhqYN3pAheHDcM2WsnhOtj1X38wVuww55epZUAgylp
0pZA32xY0l6js/glgFOUPEZyWyZsP1y+vSm4CZMHlkwplAy4K9uW/HXhBvxg
n6SAJufDB9R8HamDC5fcS+mMOHMdfkqbN39ZlwLP+ejzmJRkWGVWWvgDS4Rp
Nq0C85l4mEvqN2oe58AfaunexWI2HLU+rnhSGg47l5lOYrEXYCYz/37QxwCY
zq6tPIHT4cSC9u6YenTV86HPIhZ62VRPHZAfh1tehY1cZHjC9vZmBqmYB2ys
3p5n4EfghINUupiFVnNjJINyMpzt2O0YxnCBF3P50WmYE/yoSFPtg9vAHIaL
x7DcGibqxGPhDCu4LMjbmIvth7WHopdO4cZwlNCSEsMwhEfnRjkZGAFOOH27
4Ty+9nb3c0bLljnYChwne2cSj3+H2W6hk1J8Cl74vRUcmLSm3v0viQ2Giw==

             "]]},
           Annotation[#, "Charting`Private`Tag$10450366#1"]& ]}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, False}, {True, False}},
       FrameLabel->{{
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(E\\), \\(^\\)]\\)  \
[\\!\\(\\*SubscriptBox[\\(k\\), \\(B\\)]\\)T]\"", TraditionalForm], None}, {
          FormBox[
          "\"E [\\!\\(\\*SubscriptBox[\\(k\\), \\(B\\)]\\)T]\"", 
           TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{57.000000000000114`, 1.5}, {40.00000000000003, 
        5.43666777714229}},
       LabelStyle->Medium,
       Method->{
        "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
         "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& )}},
       PlotRange->{{-310, 5}, {-310, 5}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {192., -355.98757751993935}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{
        {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
         EdgeForm[{Opacity[0.574], Thickness[Small]}], {{}, 
          {RGBColor[0.97858, 0.678934, 0.157834], Opacity[0.5], EdgeForm[{
           Opacity[0.574], Thickness[Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-1.4, 0.}, {-1.3, 1}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{61.72593648140596, 
                 72.55674640641095}, {-38.41857212741832, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 1]& ,
              TagBoxNote->"1"],
             StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-1.2, 0.}, {-1.1, 1}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{82.48755633141607, 
                 93.3183662564212}, {-38.41857212741832, -35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 1]& ,
              TagBoxNote->"1"],
             StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.9, 0.}, {-0.8, 1}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{113.62998610643129`, 
                 124.46079603143642`}, {-38.41857212741832, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 1]& ,
              TagBoxNote->"1"],
             StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.8, 0.}, {-0.7, 1}, "RoundingRadius" -> 0]},
                ImageSizeCache->{{124.0107960314364, 
                 134.84160595644147`}, {-38.41857212741832, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 1]& ,
              TagBoxNote->"1"],
             StyleBox["1", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[1, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.6, 0.}, {-0.5, 2}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{144.77241588144656`, 
                 155.60322580645163`}, {-40.79939583686565, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 2]& ,
              TagBoxNote->"2"],
             StyleBox["2", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[2, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.5, 0.}, {-0.4, 5}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{155.15322580645162`, 
                 165.9840357314567}, {-47.941866965207566`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 5]& ,
              TagBoxNote->"5"],
             StyleBox["5", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[5, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.4, 0.}, {-0.3, 10}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{165.53403573145667`, 
                 176.3648456564618}, {-59.845985512444116`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 10]& ,
              TagBoxNote->"10"],
             StyleBox["10", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[10, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.3, 0.}, {-0.2, 7}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{175.91484565646178`, 
                 186.74565558146685`}, {-52.70351438410219, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 7]& ,
              TagBoxNote->"7"],
             StyleBox["7", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[7, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.2, 0.}, {-0.1, 19}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{186.29565558146683`, 
                 197.12646550647196`}, {-81.27339889746992, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 19]& ,
              TagBoxNote->"19"],
             StyleBox["19", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[19, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.1, 0.}, {0., 34}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{196.67646550647194`, 
                 207.507275431477}, {-116.98575453917957`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 34]& ,
              TagBoxNote->"34"],
             StyleBox["34", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[34, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{0., 0.}, {0.1, 48}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{207.057275431477, 
                 217.88808535648207`}, {-150.31728647144192`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 48]& ,
              TagBoxNote->"48"],
             StyleBox["48", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[48, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{0.1, 0.}, {0.2, 20}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{217.43808535648205`, 
                 228.26889528148718`}, {-83.65422260691722, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 20]& ,
              TagBoxNote->"20"],
             StyleBox["20", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[20, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{0.2, 0.}, {0.3, 5}, "RoundingRadius" -> 0]},
                ImageSizeCache->{{227.81889528148716`, 
                 238.64970520649223`}, {-47.941866965207566`, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 5]& ,
              TagBoxNote->"5"],
             StyleBox["5", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[5, {FontSize -> Medium}], "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             TagBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{0.3, 0.}, {0.4, 3}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{238.1997052064922, 
                 249.03051513149734`}, {-43.18021954631295, \
-35.58774841797102}}],
               "DelayedMouseEffectStyle"],
              StatusArea[#, 3]& ,
              TagBoxNote->"3"],
             StyleBox["3", {FontSize -> Medium}, StripOnInput -> False]],
            Annotation[#, 
             Style[3, {FontSize -> Medium}], 
             "Tooltip"]& ]}, {}, {}}}, {{{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-1.436, 0.},
       DisplayFunction->Identity,
       Frame->{{True, False}, {True, False}},
       FrameLabel->{{
          FormBox["\"Count\"", TraditionalForm], None}, {
          FormBox["\"Rel. err\"", TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{57.000000000000114`, 1.5}, {40.00000000000003, 
        5.43666777714229}},
       LabelStyle->Medium,
       PlotRange->{{-1.4, 0.4}, {All, All}},
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {None, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {576., -355.98757751993935}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[445]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.8097537923816104`*^9, {3.809754018554528*^9, 3.8097540352803907`*^9}, {
   3.809754099949095*^9, 3.809754112997416*^9}, 3.809754143173547*^9, 
   3.809754195132349*^9},
 CellLabel->
  "Out[115]=",ExpressionUUID->"ba2eb4ae-8d84-45b4-ba5f-e83169740433"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.7741785461530685`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7741785461530685`", ",", "1.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8097537923816104`*^9, {3.809754018554528*^9, 3.8097540352803907`*^9}, {
   3.809754099949095*^9, 3.809754112997416*^9}, 3.809754143173547*^9, 
   3.809754195248747*^9},
 CellLabel->
  "Out[116]=",ExpressionUUID->"e736387d-2b7f-4906-91aa-5937694ba5dd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.6798954760738201`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6798954760738201`", ",", "1.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8097537923816104`*^9, {3.809754018554528*^9, 3.8097540352803907`*^9}, {
   3.809754099949095*^9, 3.809754112997416*^9}, 3.809754143173547*^9, 
   3.8097541953219566`*^9},
 CellLabel->
  "Out[117]=",ExpressionUUID->"e0b6b60b-28cb-4f2a-9ac2-d4309c14ec17"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<nm-Figure4.png\>\"", ",", "figure4Total", ",", 
   RowBox[{"ImageResolution", "\[Rule]", "600"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8097540419695373`*^9, 3.809754054501048*^9}, {
  3.809754201791458*^9, 3.8097542090463753`*^9}},
 CellLabel->
  "In[118]:=",ExpressionUUID->"36593954-9f8a-4a64-b253-997c5f5a47ce"],

Cell[BoxData["\<\"nm-Figure4.png\"\>"], "Output",
 CellChangeTimes->{
  3.8097537923816104`*^9, {3.809754018554528*^9, 3.8097540372016473`*^9}, 
   3.8097542120546117`*^9},
 CellLabel->
  "Out[118]=",ExpressionUUID->"c743c705-c956-48f3-99d8-af1f5ac1efb3"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"ensemblePredictionResultsUnscaled", " ", "/.", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], "\[RuleDelayed]", 
          RowBox[{"{", 
           RowBox[{"a", ",", " ", 
            RowBox[{"Around", "[", 
             RowBox[{"b", ",", "c"}], "]"}]}], "}"}]}]}], "  ", "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"True", ",", "False"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<E [\!\(\*SubscriptBox[\(k\), \(B\)]\)T]\>\"", ",", 
          "\"\<\!\(\*OverscriptBox[\(E\), \(^\)]\)  \
[\!\(\*SubscriptBox[\(k\), \(B\)]\)T]\>\""}], "}"}]}], ",", " ", 
       RowBox[{"LabelStyle", "\[Rule]", "Medium"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "350"}], ",", "0"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", "Dotted"}], "]"}]}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{"ensemblePredictionResultsValidationUnscaled", "  ", "/.", " ", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], "\[RuleDelayed]", 
         RowBox[{"{", 
          RowBox[{"a", ",", " ", 
           RowBox[{"Around", "[", 
            RowBox[{"b", ",", "c"}], "]"}]}], "}"}]}]}], "  ", "}"}], ",", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"True", ",", "False"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<E [\!\(\*SubscriptBox[\(k\), \(B\)]\)T]\>\"", ",", 
         "\"\<\!\(\*OverscriptBox[\(E\), \(^\)]\) [\!\(\*SubscriptBox[\(k\), \
\(B\)]\)T]\>\""}], "}"}]}], ",", " ", 
      RowBox[{"LabelStyle", "\[Rule]", "Medium"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{"x", ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "350"}], ",", "0"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", "Dotted"}], "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8045944166377087`*^9, 3.8045944266535892`*^9}},
 CellLabel->
  "In[208]:=",ExpressionUUID->"61df62c3-08fa-41f5-99f0-126a217db2be"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"testProteinNum", " ", "=", " ", "1"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"goldRealValues", "=", 
    RowBox[{"proteinPCAWithEnergy", " ", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"testProteinNum", " ", ",", 
         RowBox[{"testProteinNum", "+", "numProteins"}], ",", 
         RowBox[{"testProteinNum", " ", "+", 
          RowBox[{"2", "*", "numProteins"}]}], ",", 
         RowBox[{"testProteinNum", " ", "+", 
          RowBox[{"3", "*", "numProteins"}]}]}], "}"}], ",", ";;"}], "]"}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"tio2RealValues", "=", 
  RowBox[{"proteinPCAWithEnergy", " ", "[", 
   RowBox[{"[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"testProteinNum", " ", "+", 
        RowBox[{"numProteins", "*", "4"}]}], ",", 
       RowBox[{"testProteinNum", "+", 
        RowBox[{"numProteins", "*", "5"}]}], ",", 
       RowBox[{"testProteinNum", " ", "+", 
        RowBox[{"6", "*", "numProteins"}]}], ",", 
       RowBox[{"testProteinNum", " ", "+", 
        RowBox[{"7", "*", "numProteins"}]}]}], "}"}], ",", ";;"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"gold1ax8", " ", "=", " ", 
  RowBox[{"Table", " ", "[", "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ensemblePredictionSet", " ", "=", " ", 
      RowBox[{
       RowBox[{"ensemblePredictions", "[", " ", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"proteinPCAWithEnergy", "[", 
            RowBox[{"[", 
             RowBox[{"testProteinNum", ",", " ", 
              RowBox[{";;", 
               RowBox[{"-", "4"}]}]}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", 
             RowBox[{"Log", "[", "RNP", "]"}]}], " ", "}"}]}], "]"}], " ", 
         ",", " ", "networkEnsemble"}], "]"}], "*", "goldScaleVal"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"RNP", ",", 
       RowBox[{"Mean", "[", "ensemblePredictionSet", " ", "]"}], ",", " ", 
       RowBox[{
       "StandardDeviation", "[", "ensemblePredictionSet", " ", "]"}]}], 
      "}"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", ",", " ", 
    RowBox[{"{", 
     RowBox[{"RNP", ",", "5", ",", "200", ",", "5"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"tio21ax8", " ", "=", " ", 
  RowBox[{"Table", "[", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ensemblePredictionSet", " ", "=", " ", 
      RowBox[{
       RowBox[{"ensemblePredictions", "[", " ", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"proteinPCAWithEnergy", "[", 
            RowBox[{"[", 
             RowBox[{"testProteinNum", ",", " ", 
              RowBox[{";;", 
               RowBox[{"-", "4"}]}]}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", " ", 
             RowBox[{"Log", "[", "RNP", "]"}]}], " ", "}"}]}], "]"}], "  ", 
         ",", " ", "networkEnsemble"}], "]"}], "*", "tio2ScaleVal"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"RNP", ",", " ", 
       RowBox[{"Mean", "[", "ensemblePredictionSet", "]"}], ",", " ", 
       RowBox[{"StandardDeviation", "[", "ensemblePredictionSet", "]"}]}], 
      "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"RNP", ",", "5", ",", "200", ",", "2"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.804587331884779*^9, 3.804587358342365*^9}, {
  3.807801445689539*^9, 3.807801476644876*^9}, {3.8078015536695237`*^9, 
  3.807801556568065*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"7ed9537a-8b3e-41cd-bf96-3d651a9989ea"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.809756982698186*^9},
 CellLabel->
  "Out[119]=",ExpressionUUID->"9e0ce8dd-aa9b-4ff5-9bb6-99ea3fb0fb57"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4.937009556247947`", ",", "4.660818285635254`", ",", 
     RowBox[{"-", "2.4118111485876255`"}], ",", "1.`", ",", 
     "1.6094379124341003`", ",", 
     RowBox[{"-", "1.0617495125649359`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.937009556247947`", ",", "4.660818285635254`", ",", 
     RowBox[{"-", "2.4118111485876255`"}], ",", "1.`", ",", 
     "3.912023005428146`", ",", 
     RowBox[{"-", "1.304245851431593`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.937009556247947`", ",", "4.660818285635254`", ",", 
     RowBox[{"-", "2.4118111485876255`"}], ",", "1.`", ",", 
     "4.605170185988092`", ",", 
     RowBox[{"-", "1.339727337218227`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.937009556247947`", ",", "4.660818285635254`", ",", 
     RowBox[{"-", "2.4118111485876255`"}], ",", "1.`", ",", 
     "5.298317366548036`", ",", 
     RowBox[{"-", "1.3675884064015846`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.809756982826332*^9},
 CellLabel->
  "Out[121]=",ExpressionUUID->"093ccb71-9986-454e-838e-5cf044cee4f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"5", ",", 
     RowBox[{"-", "146.82854585923477`"}], ",", "11.505089607159256`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", 
     RowBox[{"-", "164.03232283725046`"}], ",", "17.968630052710058`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", 
     RowBox[{"-", "176.58816929685685`"}], ",", "20.858587217884214`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"20", ",", 
     RowBox[{"-", "186.63109943531424`"}], ",", "23.227223635163707`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"25", ",", 
     RowBox[{"-", "194.51992078667718`"}], ",", "25.78962416351344`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"30", ",", 
     RowBox[{"-", "200.5612436616301`"}], ",", "27.986403922359987`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"35", ",", 
     RowBox[{"-", "205.44656822688336`"}], ",", "29.44172956940736`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"40", ",", 
     RowBox[{"-", "209.7701104765043`"}], ",", "29.93748341244053`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"45", ",", 
     RowBox[{"-", "213.32042264148635`"}], ",", "29.72197763032502`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"50", ",", 
     RowBox[{"-", "216.02131028900914`"}], ",", "28.98073743119502`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"55", ",", 
     RowBox[{"-", "217.84513803084593`"}], ",", "28.092862796528724`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"60", ",", 
     RowBox[{"-", "219.21926228642718`"}], ",", "27.295966429969113`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"65", ",", 
     RowBox[{"-", "220.3112001499789`"}], ",", "26.468987336318175`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"70", ",", 
     RowBox[{"-", "221.25394995884093`"}], ",", "25.56621394812888`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"75", ",", 
     RowBox[{"-", "222.05119108148526`"}], ",", "24.92357292094827`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"80", ",", 
     RowBox[{"-", "222.79412696379848`"}], ",", "24.420021700532228`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"85", ",", 
     RowBox[{"-", "223.51131189184218`"}], ",", "23.946507907270995`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"90", ",", 
     RowBox[{"-", "224.12186712080668`"}], ",", "23.552491013024653`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"95", ",", 
     RowBox[{"-", "224.59894967203743`"}], ",", "23.179793365014746`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"100", ",", 
     RowBox[{"-", "224.98390174031826`"}], ",", "22.83018202459841`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"105", ",", 
     RowBox[{"-", "225.20083430285388`"}], ",", "22.462464221243064`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"110", ",", 
     RowBox[{"-", "225.30113811504228`"}], ",", "22.11911053762205`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"115", ",", 
     RowBox[{"-", "225.2935519549141`"}], ",", "21.880843031801593`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"120", ",", 
     RowBox[{"-", "225.15812747975414`"}], ",", "21.741199169572592`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"125", ",", 
     RowBox[{"-", "224.9881953073531`"}], ",", "21.63117115014165`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"130", ",", 
     RowBox[{"-", "224.80380049706864`"}], ",", "21.528002323101944`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"135", ",", 
     RowBox[{"-", "224.54417127383715`"}], ",", "21.46195896715528`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"140", ",", 
     RowBox[{"-", "224.23878056863887`"}], ",", "21.457157044936753`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"145", ",", 
     RowBox[{"-", "223.9065051689041`"}], ",", "21.464849489664665`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"150", ",", 
     RowBox[{"-", "223.54805656457518`"}], ",", "21.480071306004135`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"155", ",", 
     RowBox[{"-", "223.17983008088908`"}], ",", "21.54923581640741`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"160", ",", 
     RowBox[{"-", "222.79499497278954`"}], ",", "21.608796589633112`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"165", ",", 
     RowBox[{"-", "222.38734741246495`"}], ",", "21.701604705805444`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"170", ",", 
     RowBox[{"-", "221.92139313775914`"}], ",", "21.81342882466813`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"175", ",", 
     RowBox[{"-", "221.42966950219906`"}], ",", "21.93802574447317`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"180", ",", 
     RowBox[{"-", "220.93745906277485`"}], ",", "22.082309739212633`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"185", ",", 
     RowBox[{"-", "220.45755081995674`"}], ",", "22.22237337844157`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"190", ",", 
     RowBox[{"-", "219.96007322882122`"}], ",", "22.38006968107731`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"195", ",", 
     RowBox[{"-", "219.4649518175344`"}], ",", "22.556733251336752`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"200", ",", 
     RowBox[{"-", "218.97819030933636`"}], ",", "22.725402586452425`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8097569960659504`*^9},
 CellLabel->
  "Out[122]=",ExpressionUUID->"3e5a9efd-4221-43a9-805e-f81a8aad14d3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"5", ",", 
     RowBox[{"-", "10.717025025886077`"}], ",", "1.5534087893065398`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", 
     RowBox[{"-", "11.36646716609672`"}], ",", "1.5581469228370919`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     RowBox[{"-", "11.969813662872431`"}], ",", "1.6737413351185715`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11", ",", 
     RowBox[{"-", "12.503947606616846`"}], ",", "1.789823635480465`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"13", ",", 
     RowBox[{"-", "12.974220719816602`"}], ",", "1.8504473360604046`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", 
     RowBox[{"-", "13.371044919992235`"}], ",", "1.8948944856435386`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"17", ",", 
     RowBox[{"-", "13.707060854961876`"}], ",", "1.8951515512324664`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"19", ",", 
     RowBox[{"-", "13.995442994252704`"}], ",", "1.8868155435717346`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"21", ",", 
     RowBox[{"-", "14.241805397794524`"}], ",", "1.8641028053845188`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"23", ",", 
     RowBox[{"-", "14.465473718593897`"}], ",", "1.8531741043733034`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"25", ",", 
     RowBox[{"-", "14.653213425371291`"}], ",", "1.834850901673884`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"27", ",", 
     RowBox[{"-", "14.808811446758824`"}], ",", "1.8191215091835404`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"29", ",", 
     RowBox[{"-", "14.936890370765463`"}], ",", "1.805649460178622`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"31", ",", 
     RowBox[{"-", "15.043384556387739`"}], ",", "1.782916075118526`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"33", ",", 
     RowBox[{"-", "15.15643945702173`"}], ",", "1.7522982796215851`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"35", ",", 
     RowBox[{"-", "15.256806944028837`"}], ",", "1.7295104569279525`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"37", ",", 
     RowBox[{"-", "15.345536238787762`"}], ",", "1.710853007378033`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"39", ",", 
     RowBox[{"-", "15.422124889446133`"}], ",", "1.6982670813713954`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"41", ",", 
     RowBox[{"-", "15.487188947035985`"}], ",", "1.683120519616427`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"43", ",", 
     RowBox[{"-", "15.535547264456197`"}], ",", "1.665763354884637`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"45", ",", 
     RowBox[{"-", "15.577218121109707`"}], ",", "1.6491013697231962`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"47", ",", 
     RowBox[{"-", "15.618999561088774`"}], ",", "1.6354769276939929`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"49", ",", 
     RowBox[{"-", "15.658055837181887`"}], ",", "1.6229034047776731`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"51", ",", 
     RowBox[{"-", "15.699143036431755`"}], ",", "1.6192662492886816`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"53", ",", 
     RowBox[{"-", "15.740189368634676`"}], ",", "1.6223761767227833`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"55", ",", 
     RowBox[{"-", "15.776094580111147`"}], ",", "1.6280356447716282`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"57", ",", 
     RowBox[{"-", "15.812811756206882`"}], ",", "1.6351729691001702`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"59", ",", 
     RowBox[{"-", "15.848462524532446`"}], ",", "1.6433768952384125`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"61", ",", 
     RowBox[{"-", "15.882199585387024`"}], ",", "1.6473101275538091`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"63", ",", 
     RowBox[{"-", "15.91457491181086`"}], ",", "1.6539108883905491`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"65", ",", 
     RowBox[{"-", "15.9453109123069`"}], ",", "1.6584385147197214`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"67", ",", 
     RowBox[{"-", "15.97376687269274`"}], ",", "1.658789935037713`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"69", ",", 
     RowBox[{"-", "15.99989043111008`"}], ",", "1.659068961993051`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"71", ",", 
     RowBox[{"-", "16.022988458588532`"}], ",", "1.659116741403607`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"73", ",", 
     RowBox[{"-", "16.042811190888912`"}], ",", "1.6569231736799033`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"75", ",", 
     RowBox[{"-", "16.061498996652716`"}], ",", "1.654552167172314`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"77", ",", 
     RowBox[{"-", "16.077347590881132`"}], ",", "1.6508471781782348`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"79", ",", 
     RowBox[{"-", "16.092679407000272`"}], ",", "1.647963532009563`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"81", ",", 
     RowBox[{"-", "16.10675733298235`"}], ",", "1.6451142558161123`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"83", ",", 
     RowBox[{"-", "16.12083819169106`"}], ",", "1.640367703609981`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"85", ",", 
     RowBox[{"-", "16.134759072069574`"}], ",", "1.6352263778636078`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"87", ",", 
     RowBox[{"-", "16.149152818147613`"}], ",", "1.6309928502643778`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"89", ",", 
     RowBox[{"-", "16.16514106147973`"}], ",", "1.6318259557302262`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"91", ",", 
     RowBox[{"-", "16.17960890112861`"}], ",", "1.63124521123599`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"93", ",", 
     RowBox[{"-", "16.193022230238274`"}], ",", "1.6310892996727213`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"95", ",", 
     RowBox[{"-", "16.207714028281604`"}], ",", "1.628067706265273`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"97", ",", 
     RowBox[{"-", "16.223038333260835`"}], ",", "1.624062452572577`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"99", ",", 
     RowBox[{"-", "16.238420824096472`"}], ",", "1.622507484806576`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"101", ",", 
     RowBox[{"-", "16.25358029837979`"}], ",", "1.6261021496729235`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"103", ",", 
     RowBox[{"-", "16.271197207912664`"}], ",", "1.6276468209125856`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"105", ",", 
     RowBox[{"-", "16.288776457443145`"}], ",", "1.6282214595959934`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"107", ",", 
     RowBox[{"-", "16.30502690098154`"}], ",", "1.6290918273162853`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"109", ",", 
     RowBox[{"-", "16.32019323151733`"}], ",", "1.6306905340724953`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"111", ",", 
     RowBox[{"-", "16.33410267545996`"}], ",", "1.6324073465803537`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"113", ",", 
     RowBox[{"-", "16.34718587203217`"}], ",", "1.6348049039900066`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"115", ",", 
     RowBox[{"-", "16.360847248637473`"}], ",", "1.6370130270915688`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"117", ",", 
     RowBox[{"-", "16.37367421334977`"}], ",", "1.6384384466915984`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"119", ",", 
     RowBox[{"-", "16.387429735852063`"}], ",", "1.6392143023602996`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"121", ",", 
     RowBox[{"-", "16.399807640465312`"}], ",", "1.6405911107499085`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"123", ",", 
     RowBox[{"-", "16.411437599750318`"}], ",", "1.6443836262945455`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"125", ",", 
     RowBox[{"-", "16.423454534100568`"}], ",", "1.649026845077202`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"127", ",", 
     RowBox[{"-", "16.43329761095726`"}], ",", "1.6515973859475448`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"129", ",", 
     RowBox[{"-", "16.441545181779265`"}], ",", "1.6539311278294608`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"131", ",", 
     RowBox[{"-", "16.449262491599452`"}], ",", "1.6567188487855669`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"133", ",", 
     RowBox[{"-", "16.45687979132581`"}], ",", "1.6603222882835207`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"135", ",", 
     RowBox[{"-", "16.464226183124488`"}], ",", "1.664264223569589`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"137", ",", 
     RowBox[{"-", "16.47063151911188`"}], ",", "1.668074806097725`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"139", ",", 
     RowBox[{"-", "16.477728119584967`"}], ",", "1.6716294738789703`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"141", ",", 
     RowBox[{"-", "16.484737867569326`"}], ",", "1.6758768366267516`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"143", ",", 
     RowBox[{"-", "16.491864956098347`"}], ",", "1.6805971330867027`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"145", ",", 
     RowBox[{"-", "16.499349527532683`"}], ",", "1.6850082083514328`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"147", ",", 
     RowBox[{"-", "16.508374085673506`"}], ",", "1.6897546601285807`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"149", ",", 
     RowBox[{"-", "16.51776446328798`"}], ",", "1.6948936779598387`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"151", ",", 
     RowBox[{"-", "16.52705238133947`"}], ",", "1.7002065719643433`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"153", ",", 
     RowBox[{"-", "16.5360851859085`"}], ",", "1.7058685783302288`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"155", ",", 
     RowBox[{"-", "16.545160256421667`"}], ",", "1.7112441160648937`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"157", ",", 
     RowBox[{"-", "16.55428521390543`"}], ",", "1.7175003311332593`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"159", ",", 
     RowBox[{"-", "16.56278595421166`"}], ",", "1.7243370147020607`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"161", ",", 
     RowBox[{"-", "16.571148859144795`"}], ",", "1.7314281705959378`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"163", ",", 
     RowBox[{"-", "16.578854415339332`"}], ",", "1.7380236331825152`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"165", ",", 
     RowBox[{"-", "16.586138519878837`"}], ",", "1.744292787015179`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"167", ",", 
     RowBox[{"-", "16.593301359226263`"}], ",", "1.7509280263766507`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"169", ",", 
     RowBox[{"-", "16.600275197509667`"}], ",", "1.758321148508004`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"171", ",", 
     RowBox[{"-", "16.607116959971286`"}], ",", "1.766485269060371`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"173", ",", 
     RowBox[{"-", "16.614053324650108`"}], ",", "1.7743053717575226`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"175", ",", 
     RowBox[{"-", "16.620812933757072`"}], ",", "1.782094042129122`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"177", ",", 
     RowBox[{"-", "16.627438801519517`"}], ",", "1.7896202737838538`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"179", ",", 
     RowBox[{"-", "16.633902672670494`"}], ",", "1.7972210173513152`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"181", ",", 
     RowBox[{"-", "16.640178696001644`"}], ",", "1.8050365917541984`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"183", ",", 
     RowBox[{"-", "16.64666917254969`"}], ",", "1.8128466057742942`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"185", ",", 
     RowBox[{"-", "16.653068907440794`"}], ",", "1.8204982794854119`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"187", ",", 
     RowBox[{"-", "16.659027498011845`"}], ",", "1.8280667086059248`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"189", ",", 
     RowBox[{"-", "16.66525898108046`"}], ",", "1.8361735440632663`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"191", ",", 
     RowBox[{"-", "16.671237902504032`"}], ",", "1.8442216598753598`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"193", ",", 
     RowBox[{"-", "16.677054115317713`"}], ",", "1.8521706426634221`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"195", ",", 
     RowBox[{"-", "16.682293801337973`"}], ",", "1.8600405164136244`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"197", ",", 
     RowBox[{"-", "16.687399927751688`"}], ",", "1.8682469339895604`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"199", ",", 
     RowBox[{"-", "16.692670482970293`"}], ",", "1.876489796812019`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.809757031491156*^9},
 CellLabel->
  "Out[123]=",ExpressionUUID->"70dac31f-1f40-4bba-be73-a2b5b5a62b4b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"figgold1ax8", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ListLinePlot", "[", 
       RowBox[{
        RowBox[{"gold1ax8", "[", 
         RowBox[{"[", 
          RowBox[{";;", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", " ", 
        RowBox[{"Frame", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"True", ",", "False"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], " ", ",", "  ", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<R [nm]\>\"", ",", " ", 
           "\"\<E [\!\(\*SubscriptBox[\(k\), \(B\)]\)T]\>\""}], "}"}]}], " ", 
        ",", " ", 
        RowBox[{"LabelStyle", "\[Rule]", "Medium"}], ",", " ", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "270"}], ",", 
             RowBox[{"-", "150"}]}], "}"}]}], "}"}]}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"goldRealValues", "[", 
          RowBox[{"[", 
           RowBox[{";;", ",", 
            RowBox[{
             RowBox[{"-", "2"}], ";;"}]}], "]"}], "]"}], " ", "/.", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"a_", ",", "b_"}], "}"}], "\[RuleDelayed]", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Exp", "[", "a", "]"}], ",", 
            RowBox[{"72.0883", "*", "b"}]}], "}"}]}]}], ",", " ", 
        RowBox[{"Frame", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"True", ",", "False"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], " ", ",", 
        RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", " ", 
        RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", " ", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<R [nm]\>\"", ",", " ", 
           "\"\<E [\!\(\*SubscriptBox[\(k\), \(B\)]\)T]\>\""}], "}"}]}], " ", 
        ",", " ", 
        RowBox[{"LabelStyle", "\[Rule]", "Medium"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ListLinePlot", "[", "  ", 
       RowBox[{
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"gold1ax8", " ", "/.", " ", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], "\[RuleDelayed]", 
            RowBox[{"{", 
             RowBox[{"a", ",", 
              RowBox[{"b", "+", "c"}]}], "}"}]}]}], ",", 
          RowBox[{"gold1ax8", " ", "/.", " ", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], "\[RuleDelayed]", 
            RowBox[{"{", 
             RowBox[{"a", ",", 
              RowBox[{"b", "-", "c"}]}], "}"}]}]}]}], "}"}], "    ", ",", 
        RowBox[{"Filling", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"Opacity", "[", "0", "]"}]}]}], "]"}]}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"figtio21ax8", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{"tio21ax8", "[", 
        RowBox[{"[", 
         RowBox[{";;", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"True", ",", "False"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], " ", ",", "  ", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<R [nm]\>\"", ",", " ", 
          "\"\<E [\!\(\*SubscriptBox[\(k\), \(B\)]\)T]\>\""}], "}"}]}], " ", 
       ",", " ", 
       RowBox[{"LabelStyle", "\[Rule]", "Medium"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"All", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "22"}], ",", 
            RowBox[{"-", "5"}]}], "}"}]}], "}"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"tio2RealValues", "[", 
         RowBox[{"[", 
          RowBox[{";;", ",", 
           RowBox[{
            RowBox[{"-", "2"}], ";;"}]}], "]"}], "]"}], " ", "/.", " ", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"a_", ",", "b_"}], "}"}], "\[RuleDelayed]", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Exp", "[", "a", "]"}], ",", 
           RowBox[{"tio2ScaleVal", "*", "b"}]}], "}"}]}]}], ",", " ", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"True", ",", "False"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"True", ",", "False"}], "}"}]}], "}"}]}], " ", ",", 
       RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", " ", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", " ", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<R [nm]\>\"", ",", " ", 
          "\"\<E [\!\(\*SubscriptBox[\(k\), \(B\)]\)T]\>\""}], "}"}]}], ",", 
       " ", 
       RowBox[{"LabelStyle", "\[Rule]", "Medium"}]}], "]"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"ListLinePlot", "[", "  ", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{"tio21ax8", " ", "/.", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], "\[RuleDelayed]", 
           RowBox[{"{", 
            RowBox[{"a", ",", 
             RowBox[{"b", "+", "c"}]}], "}"}]}]}], ",", 
         RowBox[{"tio21ax8", " ", "/.", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"a_", ",", "b_", ",", "c_"}], "}"}], "\[RuleDelayed]", 
           RowBox[{"{", 
            RowBox[{"a", ",", 
             RowBox[{"b", "-", "c"}]}], "}"}]}]}]}], "}"}], "    ", ",", 
       RowBox[{"Filling", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Opacity", "[", "0", "]"}]}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.804587331884779*^9, 3.804587358342365*^9}, {
  3.807801445689539*^9, 3.807801476644876*^9}, {3.8078015536695237`*^9, 
  3.8078015591547294`*^9}},
 CellLabel->
  "In[124]:=",ExpressionUUID->"3ff9fe48-897f-4d83-a08a-bc9336abb07b"],

Cell[BoxData[
 GraphicsBox[{{{}, {{{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        NCache[
         Rational[7, 360], 0.019444444444444445`]], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQPbPBr/7WenEHBhA4kHQATDOoOHyWeX6SozEFytdz
iLuQ5XFJKA3KN3GISSv8bhiSDuVbOji8fGWwOCADyrdzsKl02fpVMBPCb3B0
2GRT7Om1DspncHGYfGfnviUWWVB5N4d5h34/c1gF5TN4OszyfjVpHUM2VN7b
4VbSyzhuayifwc8hb124EUs6lO8Q4JAXyhL1tROmPtAhmnFVtMIKKP9AkEP+
rKroxQdh+kMcYnw+12TehOkPdZiy4eCqmA8w/WEOgV4PQp8x50D1hztYrm6Y
oSUM5TNEOsxf0iBfIw/lO0Q5tITy2+SqQfkN0Q4fS9PeLNKE6Y9x4DsoeDwF
xmeIc5jsEpPIrwrTH+/Q++Sw93y4eQkOyW8v7t4hCeU/SHDYIvjgZqYgzPxE
B93lquJL2KF8hSQH5cMK4kx/Yf5Ncliz7PXazo9QfkKyg14Hs/bBpzD/pzhs
EvaZWQDz/4IUB9fpaWqpZ2DhkerwTLeMt2YvlP8g1UG40fHW/rWw8ElzmPdP
ddX/uVC+QrqDzP+5jkv6YPanO6z5WPt6Rx3M/gyHqwGLHj3Ig9mf6bCk+nCo
b3z2AQDux8vZ
        "]]}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], AbsoluteThickness[1.6]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        NCache[
         Rational[7, 360], 0.019444444444444445`]], AbsoluteThickness[
       1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        NCache[
         Rational[7, 360], 0.019444444444444445`]], AbsoluteThickness[
       1.6]}, {}}}, {{}, {}}}, {{}, {
     {RGBColor[1, 0, 0], PointSize[0.012833333333333334`], AbsoluteThickness[
      1.6], GeometricTransformationBox[InsetBox[
        FormBox[
         StyleBox[
          GraphicsBox[
           {EdgeForm[None], DiskBox[{0, 0}]}],
          StripOnInput->False,
          GraphicsBoxOptions->{DefaultBaseStyle->Directive[
            PointSize[0.012833333333333334`], 
            AbsoluteThickness[1.6], 
            RGBColor[1, 0, 0]]}],
         TraditionalForm], {0., 0.}, Automatic, Offset[6.272]], {{{
       4.999999999999999, -167.7112204646935}}, {{
       49.99999999999999, -247.58568434478056`}}, {{
       100.00000000000004`, -249.1770245655293}}, {{
       199.99999999999991`, -252.11958497371765`}}}]}, {
      {RGBColor[1, 0, 0], PointSize[0.012833333333333334`], AbsoluteThickness[
       1.6]}, {}}, {
      {RGBColor[1, 0, 0], PointSize[0.012833333333333334`], AbsoluteThickness[
       1.6]}, {}}}, {{}, {}}}, {{}, GraphicsComplexBox[CompressedData["
1:eJztlItPU3cUx6vOGZVERNRkPlYdvuZgOhsDiOWLIqMWi2DptTxvS28ftm4q
GxglsSkENYjOR3xGrbYxWYhVdGO+0GqmLJjgA7c5xRQxYpSXQNi6JUt2F8/5
K+SX3PzyyTnf3/fm5Jszw/x1tjRcoVB45e//+92JRtLY7qDxjRh8xzEYyC65
PXqZmTgO3dMqr60tKyZWIW9e364ul4U4AbemfHiocLJErIZtQuYkaR+xOwX1
JVbfHIWV6qmwLK147t9C7E5DTdfs0tkDXNdAiC0pyjDZqK5F6ccVvqhLxAod
TruDvup/ibEaSws19oFEO/VnIU0z0DOslDiYjcSkwKaJfmKFHoHQkdrwXWLk
ID2jORTVz3oDqlLU+vgoB+kFFD8sv+KIJVYYURM+tqIzlRi58E7RXvEKxO48
BLZtm98isT4fMX3Ca9V61hdCpRyzRWBGEQpedDW4nMwiNn9eZ2ixE7eJaIv8
YespM79vwk/DDeNGGImVZpxeNXnsTB37mbH9trP3s2XEYjGaQyMfxarY34JF
jZmGwVnEXguE7PNH+yayv4SaJfs3fjOC/SW8OHi++movz8eKQNI0c8FTYqUN
4z2/76tq5HnbEPYdKd5zgVi0I6LHpIw8zvN3oGHNl79N2sEcDcN0TczZJs6X
nL+O3OZRQStxHO55sh5pA9yvQoGvz1S2ZB1xAq7X32t6tdNJrMb4UIK+aq+L
/jcFgZHuXlf+eqqn4tbWt8f8fxLL+Tt3+L6QZ/qK6ho8c5juRHqJ5fypz2R+
9MF1ruuQ2NoTLL9PLOfvZMYN7V+PuT8LGy6Lv6ifEMv584fTUheGWK/HmMsZ
uicdrM9BW/SP357pYb0BU9d4hAODrBcwrrKytDPMeiPqVkt/R/zD+lzY97Q0
JHC/nD+Va9XZTd2sz0f4u7v+Ay9ZX4h+eyC9sZX1RWh4efSPBy3MInS1/coT
TcRy/nZERcR/EeT3TfBpB6evqCeW8+eP//ST9lr2M+PBdqerg+cn52/3gmEe
/SH2t2ChmN7auYtYzt+i1qkXHnvYX0Ky0vh9RRn7S1jufDj3Zyf7W7E7GNd/
SmR/G+aUW97ezGF/G8Rkc0n7Sva348TFdn8d2N+Bal/yrxWLmYf239D+G9p/
Q/vv/dt//wHbIDLN
     "], {{{}, {}, {}, {}, {}, {}, {}, 
       {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[{{41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 
          55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 
          72, 73, 74, 75, 76, 77, 78, 79, 80, 40, 39, 38, 37, 36, 35, 34, 33, 
          32, 31, 30, 29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 
          15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 
          1}}]]}, {}, {}}, {{}, {}, {}, 
       {Hue[0.67, 0.6, 0.6], Opacity[0], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40}]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0], 
        LineBox[{41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 
         56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 
         73, 74, 75, 76, 77, 78, 79, 80}]}}, {
       {Opacity[0]}, 
       {Opacity[0]}}, {
       {Opacity[0]}, 
       {Opacity[0]}, {}, {}, {}}, {
       {Opacity[0]}, 
       {Opacity[0]}, {}, {}, {}}}], {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.9375000000000001, -150.},
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox[
     "\"E [\\!\\(\\*SubscriptBox[\\(k\\), \\(B\\)]\\)T]\"", TraditionalForm], 
     None}, {
     FormBox["\"R [nm]\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Medium,
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0.9375000000000001, 200.}, {-270, -150}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.809757032696586*^9},
 CellLabel->
  "Out[124]=",ExpressionUUID->"5c36e638-5062-4d0c-b950-4f130be3a9de"],

Cell[BoxData[
 GraphicsBox[{{{}, {{{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        NCache[
         Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJw1ywlM03cYxnEsyqLjmOBEXRVEQWG1BRkwtR2P5ZLZ1VJauQq9Dw5ByuIm
hxA1KAGma+Y4dMIgyCyOIi4kxDCaDUOypW4sgMdYJhjCxsqmGA9Q0m3h//6S
N7988uS7VVMk1bPc3Nw0/93///JbB2H48ZnNRcH2ZbMxN9V84cubIYyDUFvV
nFf7aAfjEMS09eavYoUyDkOKftrbMU/mIutITdPCQBjjCHTYVJPueW8zjoR7
r/Ab6xI5CqGew7OOMg7jGMSuFFikf5P3AJ8cWyoW72K8D5K/es6yL5MFWBrk
b+j5nRwL87Xgquj13GVXAX0FAWMbJOT96FzcFll+iiyEMHNv4GwPOQ7Zrml7
4F1yPDxe6UaPLpATUNQcj0hfHuNEJF2JCKrZQU5C797uk3N88gH0Jd657pSQ
k9FlOO73TE9+HyvixzculpIPIknxc7yiniyCq8AxsbOV/AGiKt/szu0li2E4
77pq+558CFWPbKFxo4whwZOR/h9cDxnbJShLllg+nac9BS8Npe2PXbSnYOAX
uWVqVTizSyG61Xjt6RrGdineVTzRf+tDeyrihQIvhx/tqeCtKxzv96ddhpKh
MbPsLdplGMwvxj9baJfDofKxVAbRLseEp+ckN4T2w+AfENoSw2g/jMU82b3F
XbSnQZB4ZSY3gvY0jGi3DHKiaE/HWvbBNRv30J4OFtcavFpAewYqSo62z4L2
DCjsQdwjCbRn4obFbf9cMu2ZsG1+5731YtqzUDq0gvcihfYsiC7a7WfktCvg
ZOVwJtNpV2BycF+5SkF7NgJ6l9hXlbRn48xLRSNXS3sORBXbf8ww0J6D/oSy
hdRc2pV4Xcw7bSygXQnfyksNzkLGgSrcMj/ctLqYsUqFmIGJ31gljFtVaJ5/
7PvsQ8YPVDB/NF995xj1aui9OsVlH1OvBt91TysqpV6NkbQ/hv3LqVfDWnFp
YraCeg3aPaZyxiqp18B9013H9pPUayC/z4+uO029BsNbO2ac1dRr8Wv60wf8
Guq1eGFStZyrpV4Lmfq7tul66rW4+erUgO956nW4wRn+KdpCvQ5+r51z8D6j
Xofdt+s5Xp9Tr8OFOu+mqQbq9cib6WjraqJeD7NTubLgIvV6iJVxTbu/oF6P
tnxb49xl6g2oGxKNtrRSb8CJ5z7mpDbqDUh2Cu1T7dQb0FWoZdd1UG9EwImA
al4n9UaEBNo8+r6i3gg1uyVXbKXeiJ3+SbHjXdSbkP9nUH7q19Sb0MAqu23t
pt6E7OdvFC/YqDfBO+7Qfen1cPu/iQPieg==
        "]]}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       NCache[
        Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[1.6]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        NCache[
         Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[
       1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        NCache[
         Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[
       1.6]}, {}}}, {{}, {}}}, {{}, {
     {RGBColor[1, 0, 0], PointSize[0.012833333333333334`], AbsoluteThickness[
      1.6], GeometricTransformationBox[InsetBox[
        FormBox[
         StyleBox[
          GraphicsBox[
           {EdgeForm[None], DiskBox[{0, 0}]}],
          StripOnInput->False,
          GraphicsBoxOptions->{DefaultBaseStyle->Directive[
            PointSize[0.012833333333333334`], 
            AbsoluteThickness[1.6], 
            RGBColor[1, 0, 0]]}],
         TraditionalForm], {0., 0.}, Automatic, Offset[6.272]], {{{
       4.999999999999999, -9.316867899}}, {{
       49.99999999999999, -11.44477691}}, {{
       100.00000000000004`, -11.75612748}}, {{
       199.99999999999991`, -12.00060878}}}]}, {
      {RGBColor[1, 0, 0], PointSize[0.012833333333333334`], AbsoluteThickness[
       1.6]}, {}}, {
      {RGBColor[1, 0, 0], PointSize[0.012833333333333334`], AbsoluteThickness[
       1.6]}, {}}}, {{}, {}}}, {{}, GraphicsComplexBox[CompressedData["
1:eJztl/s/1Pkex6fW0XY5RdmyVu7kVjJYIXrJbV3G/RaDuc+EiB6iVgdbSj06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     "], {{{}, {}, {}, {}, {}, {}, {}, 
       {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[{{99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
          110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
          123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
          136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
          149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
          162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
          175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
          188, 189, 190, 191, 192, 193, 194, 195, 196, 98, 97, 96, 95, 94, 93,
           92, 91, 90, 89, 88, 87, 86, 85, 84, 83, 82, 81, 80, 79, 78, 77, 76,
           75, 74, 73, 72, 71, 70, 69, 68, 67, 66, 65, 64, 63, 62, 61, 60, 59,
           58, 57, 56, 55, 54, 53, 52, 51, 50, 49, 48, 47, 46, 45, 44, 43, 42,
           41, 40, 39, 38, 37, 36, 35, 34, 33, 32, 31, 30, 29, 28, 27, 26, 25,
           24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 
          7, 6, 5, 4, 3, 2, 1}}]]}, {}, {}}, {{}, {}, {}, 
       {Hue[0.67, 0.6, 0.6], Opacity[0], 
        LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
         18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
         35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 
         52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 
         69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 
         86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98}]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0], 
        LineBox[{99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 
         111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
          125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 
         138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151,
          152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
         165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178,
          179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 
         192, 193, 194, 195, 196}]}}, {
       {Opacity[0]}, 
       {Opacity[0]}}, {
       {Opacity[0]}, 
       {Opacity[0]}, {}, {}, {}}, {
       {Opacity[0]}, 
       {Opacity[0]}, {}, {}, {}}}], {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.9583333333333335, -5.},
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox[
     "\"E [\\!\\(\\*SubscriptBox[\\(k\\), \\(B\\)]\\)T]\"", TraditionalForm], 
     None}, {
     FormBox["\"R [nm]\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Medium,
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0.9583333333333335, 199.}, {-22, -5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8097570330188637`*^9},
 CellLabel->
  "Out[125]=",ExpressionUUID->"4661d315-a298-44e5-8d87-76ac6f478ba3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<nm-Figure5.png\>\"", ",", 
   RowBox[{"GraphicsRow", "[", 
    RowBox[{"{", 
     RowBox[{"figgold1ax8", ",", "figtio21ax8"}], "}"}], "]"}], ",", 
   RowBox[{"ImageResolution", "\[Rule]", "600"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.805183848054593*^9, 3.80518385661228*^9}, {
  3.809757062085534*^9, 3.8097570779427605`*^9}},
 CellLabel->
  "In[127]:=",ExpressionUUID->"b7ca4b57-9a06-4a78-b876-3c2248515445"],

Cell[BoxData["\<\"nm-Figure5.png\"\>"], "Output",
 CellChangeTimes->{3.809757049359167*^9, 3.809757080283844*^9},
 CellLabel->
  "Out[127]=",ExpressionUUID->"4a37a677-5b6d-4998-a48f-a3d86bf89e3f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\<ensemblePredictionResultsValidation.csv\>\"", ",", 
   "ensemblePredictionResultsValidation"}], "]"}]], "Input",
 CellChangeTimes->{{3.809753894420334*^9, 3.8097539282804136`*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"f41f0e56-b88d-4c27-a2e0-6585a3079485"],

Cell[BoxData["\<\"ensemblePredictionResultsValidation.csv\"\>"], "Output",
 CellChangeTimes->{{3.809753904506522*^9, 3.8097539291477823`*^9}},
 CellLabel->"Out[68]=",ExpressionUUID->"3b59ab2b-8529-43a3-b662-da54f3e69871"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["trainingSet"], "Input",
 CellLabel->
  "In[128]:=",ExpressionUUID->"82ddea65-269e-4126-9394-e6dd2addcdc7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7.22661819619284`"}], ",", "2.152496674228478`", ",", 
      RowBox[{"-", "3.2995241272622993`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1792090429475053`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "12.96244747926624`"}], ",", "2.038759221921331`", ",", 
      "6.728626921219389`", ",", "1.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.5150160176364371`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "13.060469205364882`"}], ",", "2.2505554067043327`", ",", 
      "2.3025629375567593`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.49861134824271`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.000487623375335`"}], ",", "0.812499798921313`", ",", 
      "2.634461233836259`", ",", "0.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "3.6504938804901603`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.89257340254789`"}], ",", 
      RowBox[{"-", "4.15002115502496`"}], ",", "6.798357109240167`", ",", 
      "0.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.7634724030768383`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.677786461994058`", ",", "5.358104820124155`", ",", 
      RowBox[{"-", "3.3008908607018745`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.683276549384816`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.173364671643092`", ",", 
      RowBox[{"-", "5.456199324879877`"}], ",", "5.644739804280257`", ",", 
      "0.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.813942007779627`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.903017638438694`", ",", "4.742565484514013`", ",", 
      "2.3459604847131366`", ",", "0.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.735815338385749`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "16.279261281924313`"}], ",", 
      RowBox[{"-", "0.49228122332192126`"}], ",", "0.8608240174150654`", ",", 
      "0.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.520279859599943`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "21.101238365522494`"}], ",", 
      RowBox[{"-", "0.6100623026867971`"}], ",", "8.529832677047214`", ",", 
      "0.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.6720561661262874`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7.22661819619284`"}], ",", "2.152496674228478`", ",", 
      RowBox[{"-", "3.2995241272622993`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.173650745896161`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.9199658186892536`"}], ",", 
      RowBox[{"-", "5.78671447426552`"}], ",", "1.0996213303519675`", ",", 
      "1.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.6168823494888613`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "17.509317972619726`"}], ",", 
      RowBox[{"-", "4.187905029120511`"}], ",", 
      RowBox[{"-", "7.444913458882694`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.963215221854322`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "21.101238365522494`"}], ",", 
      RowBox[{"-", "0.6100623026867971`"}], ",", "8.529832677047214`", ",", 
      "0.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1729315829242166`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.000487623375335`"}], ",", "0.812499798921313`", ",", 
      "2.634461233836259`", ",", "0.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "3.523297317775189`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.173364671643092`", ",", 
      RowBox[{"-", "5.456199324879877`"}], ",", "5.644739804280257`", ",", 
      "0.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.8221759428611772`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5.686556490849456`", ",", 
      RowBox[{"-", "2.6378878844623017`"}], ",", 
      RowBox[{"-", "4.6755445260498965`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.3596933372763467`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.189101413994847`", ",", "1.1164480587777574`", ",", 
      RowBox[{"-", "1.9677139011959657`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.946087580937209`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9.654463080833843`", ",", 
      RowBox[{"-", "4.444024296716794`"}], ",", "3.4225881955038027`", ",", 
      "0.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.8252364815422863`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.173364671643092`", ",", 
      RowBox[{"-", "5.456199324879877`"}], ",", "5.644739804280257`", ",", 
      "1.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.0793450244814395`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1.8198684914301597`", ",", "7.921471483348814`", ",", 
      "5.626105779912632`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.6867640887223556`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "8.472869124450304`"}], ",", "3.5978236482209143`", ",", 
      RowBox[{"-", "5.053346098672997`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.0401040579417815`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "7.062708447633639`", ",", "4.813353001058087`", ",", 
      "5.280333637534039`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.755728283085556`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.5909365816875582`", ",", 
      RowBox[{"-", "2.020853005809032`"}], ",", 
      RowBox[{"-", "6.711775236845678`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "4.318758428033179`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6.034405098172207`", ",", 
      RowBox[{"-", "1.9743317948787145`"}], ",", "3.7510600129390017`", ",", 
      "0.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.3658444415868374`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.342857453477421`", ",", "5.200288278290438`", ",", 
      RowBox[{"-", "7.987489123641171`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.643278585190466`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "3.462309329225504`", ",", "5.419251285035988`", ",", 
      "3.4111623448922996`", ",", "0.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.273624233561373`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.0761771390251065`", ",", 
      RowBox[{"-", "2.9054512418166403`"}], ",", 
      RowBox[{"-", "1.8868765186398941`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.986252610514135`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "12.96244747926624`"}], ",", "2.038759221921331`", ",", 
      "6.728626921219389`", ",", "0.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.660280407539144`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "7.062708447633639`", ",", "4.813353001058087`", ",", 
      "5.280333637534039`", ",", "0.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.916321435839302`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.669067346434376`", ",", "2.7869725551194775`", ",", 
      "0.3139405108205799`", ",", "0.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.0124220646654263`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.342857453477421`", ",", "5.200288278290438`", ",", 
      RowBox[{"-", "7.987489123641171`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.6715654720066184`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "13.060469205364882`"}], ",", "2.2505554067043327`", ",", 
      "2.3025629375567593`", ",", "1.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.5005975989784637`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.7424967599278345`", ",", 
      RowBox[{"-", "0.20872781708074226`"}], ",", 
      RowBox[{"-", "2.4189556204138123`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.613259001836464`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.189101413994847`", ",", "1.1164480587777574`", ",", 
      RowBox[{"-", "1.9677139011959657`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.627146439456394`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.9199658186892536`"}], ",", 
      RowBox[{"-", "5.78671447426552`"}], ",", "1.0996213303519675`", ",", 
      "0.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.185391254252251`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1.8198684914301597`", ",", "7.921471483348814`", ",", 
      "5.626105779912632`", ",", "0.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "3.4025682895238605`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3.57197363290299`", ",", 
      RowBox[{"-", "4.7777284361151855`"}], ",", 
      RowBox[{"-", "6.22194990393694`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.7357170797087846`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.61306622871624`", ",", "2.3961737427316545`", ",", 
      "6.222154108557685`", ",", "0.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "3.1605888820500527`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5.686556490849456`", ",", 
      RowBox[{"-", "2.6378878844623017`"}], ",", 
      RowBox[{"-", "4.6755445260498965`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "0.8967016011938442`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3.525166247038391`"}], ",", "9.160944810588841`", ",", 
      RowBox[{"-", "4.16891759840301`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.5296524689701387`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.89257340254789`"}], ",", 
      RowBox[{"-", "4.15002115502496`"}], ",", "6.798357109240167`", ",", 
      "0.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.1786172622488342`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.6036409803939666`", ",", "6.391999139353731`", ",", 
      RowBox[{"-", "2.559143060053504`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.285132624175161`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.4899130949982198`", ",", 
      RowBox[{"-", "3.107397441377313`"}], ",", "4.721410197336367`", ",", 
      "1.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.052872440673891`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.1178193739091504`", ",", 
      RowBox[{"-", "4.596281425511127`"}], ",", 
      RowBox[{"-", "3.273107514094848`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.8932088070504725`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.216659038552705`", ",", 
      RowBox[{"-", "9.155257767984248`"}], ",", 
      RowBox[{"-", "5.037840424380177`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.747995148726652`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2.245104345849121`"}], ",", 
      RowBox[{"-", "7.59940581983865`"}], ",", 
      RowBox[{"-", "5.849196524803394`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1854593041394104`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.4388879395003342`"}], ",", 
      RowBox[{"-", "2.598110592650474`"}], ",", "1.089966830516735`", ",", 
      "0.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.619205957028527`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.7424967599278345`", ",", 
      RowBox[{"-", "0.20872781708074226`"}], ",", 
      RowBox[{"-", "2.4189556204138123`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.6364423764517784`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.6738018344904457`", ",", 
      RowBox[{"-", "8.412325310002771`"}], ",", "2.341229054839705`", ",", 
      "1.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.268105494976362`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.240926738495293`", ",", "4.911838904709936`", ",", 
      RowBox[{"-", "2.2121773596200205`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.2469034206779133`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "16.279261281924313`"}], ",", 
      RowBox[{"-", "0.49228122332192126`"}], ",", "0.8608240174150654`", ",", 
      "0.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.573546270829839`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5.686556490849456`", ",", 
      RowBox[{"-", "2.6378878844623017`"}], ",", 
      RowBox[{"-", "4.6755445260498965`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.420200839831268`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.89257340254789`"}], ",", 
      RowBox[{"-", "4.15002115502496`"}], ",", "6.798357109240167`", ",", 
      "1.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.9824046146929666`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.6036409803939666`", ",", "6.391999139353731`", ",", 
      RowBox[{"-", "2.559143060053504`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.2177377930408098`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.903017638438694`", ",", "4.742565484514013`", ",", 
      "2.3459604847131366`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.525901725524116`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7.22661819619284`"}], ",", "2.152496674228478`", ",", 
      RowBox[{"-", "3.2995241272622993`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.2732135829550124`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2.0242794604536134`"}], ",", "6.511836631694567`", ",", 
      RowBox[{"-", "1.7038664141685957`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "0.7522319959567022`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.216659038552705`", ",", 
      RowBox[{"-", "9.155257767984248`"}], ",", 
      RowBox[{"-", "5.037840424380177`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.541556933865403`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2.245104345849121`"}], ",", 
      RowBox[{"-", "7.59940581983865`"}], ",", 
      RowBox[{"-", "5.849196524803394`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.3848314213029607`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "17.509317972619726`"}], ",", 
      RowBox[{"-", "4.187905029120511`"}], ",", 
      RowBox[{"-", "7.444913458882694`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.96002115893819`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "2.858864173869224`", ",", "0.24123912459719887`", ",", 
      "1.249400159230766`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.3140264854248112`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "4.988943438898219`", ",", "0.6344010287775762`", ",", 
      "4.7449910575496475`", ",", "0.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.2021013593192458`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.0904821921155445`", ",", 
      RowBox[{"-", "7.650442394352687`"}], ",", 
      RowBox[{"-", "0.2709773852783684`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.761936197260062`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.7424967599278345`", ",", 
      RowBox[{"-", "0.20872781708074226`"}], ",", 
      RowBox[{"-", "2.4189556204138123`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.781964757382926`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "4.988943438898219`", ",", "0.6344010287775762`", ",", 
      "4.7449910575496475`", ",", "1.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.360409687048968`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "13.060469205364882`"}], ",", "2.2505554067043327`", ",", 
      "2.3025629375567593`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.3739411032345816`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "16.279261281924313`"}], ",", 
      RowBox[{"-", "0.49228122332192126`"}], ",", "0.8608240174150654`", ",", 
      "1.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1661277148813993`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.2912429039761473`", ",", 
      RowBox[{"-", "1.9058632965000448`"}], ",", "1.936580480057262`", ",", 
      "1.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.560634835382048`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2.0242794604536134`"}], ",", "6.511836631694567`", ",", 
      RowBox[{"-", "1.7038664141685957`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.2454386026690554`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5.686556490849456`", ",", 
      RowBox[{"-", "2.6378878844623017`"}], ",", 
      RowBox[{"-", "4.6755445260498965`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.449383637758643`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.342857453477421`", ",", "5.200288278290438`", ",", 
      RowBox[{"-", "7.987489123641171`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.6878525222335004`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3.57197363290299`", ",", 
      RowBox[{"-", "4.7777284361151855`"}], ",", 
      RowBox[{"-", "6.22194990393694`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.9311712014167497`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2.245104345849121`"}], ",", 
      RowBox[{"-", "7.59940581983865`"}], ",", 
      RowBox[{"-", "5.849196524803394`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.9929101067063706`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.342857453477421`", ",", "5.200288278290438`", ",", 
      RowBox[{"-", "7.987489123641171`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.0466615257484952`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3.57197363290299`", ",", 
      RowBox[{"-", "4.7777284361151855`"}], ",", 
      RowBox[{"-", "6.22194990393694`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.918638329393169`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9.654463080833843`", ",", 
      RowBox[{"-", "4.444024296716794`"}], ",", "3.4225881955038027`", ",", 
      "1.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.188719338941301`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.000487623375335`"}], ",", "0.812499798921313`", ",", 
      "2.634461233836259`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.6798693324170957`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "3.462309329225504`", ",", "5.419251285035988`", ",", 
      "3.4111623448922996`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.9694279930005818`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6.199240769610545`", ",", 
      RowBox[{"-", "2.2862404532308434`"}], ",", 
      RowBox[{"-", "1.7258778043858518`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.4249411448299518`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.473519174393998`", ",", 
      RowBox[{"-", "9.684193355858039`"}], ",", "0.33074910344652403`", ",", 
      "0.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.7491024769764967`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3.57197363290299`", ",", 
      RowBox[{"-", "4.7777284361151855`"}], ",", 
      RowBox[{"-", "6.22194990393694`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.730671244941446`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.89257340254789`"}], ",", 
      RowBox[{"-", "4.15002115502496`"}], ",", "6.798357109240167`", ",", 
      "0.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.082516994091551`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1.8198684914301597`", ",", "7.921471483348814`", ",", 
      "5.626105779912632`", ",", "0.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.9480229493583494`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "8.472869124450304`"}], ",", "3.5978236482209143`", ",", 
      RowBox[{"-", "5.053346098672997`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.9978934440567908`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.757558356675843`", ",", 
      RowBox[{"-", "0.009002644883284122`"}], ",", "0.3856205604535658`", ",",
       "1.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.8824981005730477`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.9199658186892536`"}], ",", 
      RowBox[{"-", "5.78671447426552`"}], ",", "1.0996213303519675`", ",", 
      "1.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.7440363372598227`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "7.062708447633639`", ",", "4.813353001058087`", ",", 
      "5.280333637534039`", ",", "0.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.6839668370549503`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9.965673017368527`", ",", 
      RowBox[{"-", "2.5014136237752815`"}], ",", "4.287008219560214`", ",", 
      "0.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.4824047830791938`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "4.988943438898219`", ",", "0.6344010287775762`", ",", 
      "4.7449910575496475`", ",", "0.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.658610141813601`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "8.472869124450304`"}], ",", "3.5978236482209143`", ",", 
      RowBox[{"-", "5.053346098672997`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.0425445255649137`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5.978080265467851`", ",", 
      RowBox[{"-", "1.6514724013405755`"}], ",", 
      RowBox[{"-", "2.1290168518478425`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.356259062324824`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "3.462309329225504`", ",", "5.419251285035988`", ",", 
      "3.4111623448922996`", ",", "0.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.327160275268008`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6.034405098172207`", ",", 
      RowBox[{"-", "1.9743317948787145`"}], ",", "3.7510600129390017`", ",", 
      "0.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.709697050658297`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7.809087735503671`"}], ",", 
      RowBox[{"-", "3.1054225656324093`"}], ",", 
      RowBox[{"-", "1.750351386471387`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.6224079218098204`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.669067346434376`", ",", "2.7869725551194775`", ",", 
      "0.3139405108205799`", ",", "0.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.9753887101497345`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "4.988943438898219`", ",", "0.6344010287775762`", ",", 
      "4.7449910575496475`", ",", "0.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.586328195605694`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7.809087735503671`"}], ",", 
      RowBox[{"-", "3.1054225656324093`"}], ",", 
      RowBox[{"-", "1.750351386471387`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.363480310047582`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6.034405098172207`", ",", 
      RowBox[{"-", "1.9743317948787145`"}], ",", "3.7510600129390017`", ",", 
      "1.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.8229064258009817`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7.809087735503671`"}], ",", 
      RowBox[{"-", "3.1054225656324093`"}], ",", 
      RowBox[{"-", "1.750351386471387`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.3454925702912357`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "21.101238365522494`"}], ",", 
      RowBox[{"-", "0.6100623026867971`"}], ",", "8.529832677047214`", ",", 
      "0.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.6401872356800253`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.757558356675843`", ",", 
      RowBox[{"-", "0.009002644883284122`"}], ",", "0.3856205604535658`", ",",
       "1.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.016415919516947`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "8.232062222433456`", ",", "3.878152809256657`", ",", 
      "0.4213911791829493`", ",", "0.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.7704540681988712`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6.199240769610545`", ",", 
      RowBox[{"-", "2.2862404532308434`"}], ",", 
      RowBox[{"-", "1.7258778043858518`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.863516272892588`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.1178193739091504`", ",", 
      RowBox[{"-", "4.596281425511127`"}], ",", 
      RowBox[{"-", "3.273107514094848`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.856474115282801`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.173364671643092`", ",", 
      RowBox[{"-", "5.456199324879877`"}], ",", "5.644739804280257`", ",", 
      "0.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1815620553629445`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "21.101238365522494`"}], ",", 
      RowBox[{"-", "0.6100623026867971`"}], ",", "8.529832677047214`", ",", 
      "0.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.737632397716744`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.58371347981322`"}], ",", "0.21494728902017465`", ",", 
      "6.938379786136243`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.2697372505915945`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.903017638438694`", ",", "4.742565484514013`", ",", 
      "2.3459604847131366`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.488449453362758`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "4.988943438898219`", ",", "0.6344010287775762`", ",", 
      "4.7449910575496475`", ",", "1.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.8424869028713913`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "2.858864173869224`", ",", "0.24123912459719887`", ",", 
      "1.249400159230766`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.3608718081963393`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.4281067184743153`", ",", "5.165011933852659`", ",", 
      RowBox[{"-", "1.2213463494536325`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1894689410787334`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "2.858864173869224`", ",", "0.24123912459719887`", ",", 
      "1.249400159230766`", ",", "0.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.7608620706636264`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.7424967599278345`", ",", 
      RowBox[{"-", "0.20872781708074226`"}], ",", 
      RowBox[{"-", "2.4189556204138123`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.8874403679155103`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.4899130949982198`", ",", 
      RowBox[{"-", "3.107397441377313`"}], ",", "4.721410197336367`", ",", 
      "0.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.301390829217894`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6.034405098172207`", ",", 
      RowBox[{"-", "1.9743317948787145`"}], ",", "3.7510600129390017`", ",", 
      "0.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.7030520379939653`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.61306622871624`", ",", "2.3961737427316545`", ",", 
      "6.222154108557685`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.0426924604687287`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.648243222482892`", ",", "3.465491321168917`", ",", 
      "6.744954758904018`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.0128701193103373`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.473519174393998`", ",", 
      RowBox[{"-", "9.684193355858039`"}], ",", "0.33074910344652403`", ",", 
      "1.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.9994340385742935`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.000487623375335`"}], ",", "0.812499798921313`", ",", 
      "2.634461233836259`", ",", "0.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "3.6805822901333904`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.6885863352449928`"}], ",", "0.6422308404797592`", ",", 
      RowBox[{"-", "4.827256905638052`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.803027891215064`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "3.462309329225504`", ",", "5.419251285035988`", ",", 
      "3.4111623448922996`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.9169094525764343`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.1178193739091504`", ",", 
      RowBox[{"-", "4.596281425511127`"}], ",", 
      RowBox[{"-", "3.273107514094848`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.9673116239687343`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.473519174393998`", ",", 
      RowBox[{"-", "9.684193355858039`"}], ",", "0.33074910344652403`", ",", 
      "1.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.114429987868967`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "12.96244747926624`"}], ",", "2.038759221921331`", ",", 
      "6.728626921219389`", ",", "0.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "3.8164885933623895`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.240926738495293`", ",", "4.911838904709936`", ",", 
      RowBox[{"-", "2.2121773596200205`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.189142117256492`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7.22661819619284`"}], ",", "2.152496674228478`", ",", 
      RowBox[{"-", "3.2995241272622993`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.177235930650831`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6.199240769610545`", ",", 
      RowBox[{"-", "2.2862404532308434`"}], ",", 
      RowBox[{"-", "1.7258778043858518`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.7902686081192933`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.6738018344904457`", ",", 
      RowBox[{"-", "8.412325310002771`"}], ",", "2.341229054839705`", ",", 
      "0.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.780124495947955`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "12.96244747926624`"}], ",", "2.038759221921331`", ",", 
      "6.728626921219389`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.37704131673849`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.61306622871624`", ",", "2.3961737427316545`", ",", 
      "6.222154108557685`", ",", "0.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.2256876851982477`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6.034405098172207`", ",", 
      RowBox[{"-", "1.9743317948787145`"}], ",", "3.7510600129390017`", ",", 
      "1.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.2865664548721572`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.6885863352449928`"}], ",", "0.6422308404797592`", ",", 
      RowBox[{"-", "4.827256905638052`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.2207232682793134`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.34086637869685965`"}], ",", 
      RowBox[{"-", "4.729865545752679`"}], ",", "0.6430090199245856`", ",", 
      "1.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.076658731637496`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.7424967599278345`", ",", 
      RowBox[{"-", "0.20872781708074226`"}], ",", 
      RowBox[{"-", "2.4189556204138123`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.6653432216355186`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "12.96244747926624`"}], ",", "2.038759221921331`", ",", 
      "6.728626921219389`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.2717636619424586`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.342857453477421`", ",", "5.200288278290438`", ",", 
      RowBox[{"-", "7.987489123641171`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.6158587261674198`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.216659038552705`", ",", 
      RowBox[{"-", "9.155257767984248`"}], ",", 
      RowBox[{"-", "5.037840424380177`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.930420293298644`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.9199658186892536`"}], ",", 
      RowBox[{"-", "5.78671447426552`"}], ",", "1.0996213303519675`", ",", 
      "1.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.9240505651557291`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.937009556247947`", ",", "4.660818285635254`", ",", 
      RowBox[{"-", "2.4118111485876255`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.0617495125649359`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5.978080265467851`", ",", 
      RowBox[{"-", "1.6514724013405755`"}], ",", 
      RowBox[{"-", "2.1290168518478425`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.3737334343760965`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5.978080265467851`", ",", 
      RowBox[{"-", "1.6514724013405755`"}], ",", 
      RowBox[{"-", "2.1290168518478425`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.0374515770058514`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.34086637869685965`"}], ",", 
      RowBox[{"-", "4.729865545752679`"}], ",", "0.6430090199245856`", ",", 
      "1.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.0316044303058174`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.58371347981322`"}], ",", "0.21494728902017465`", ",", 
      "6.938379786136243`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.1919709459186112`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.0904821921155445`", ",", 
      RowBox[{"-", "7.650442394352687`"}], ",", 
      RowBox[{"-", "0.2709773852783684`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.814063583936894`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.4388879395003342`"}], ",", 
      RowBox[{"-", "2.598110592650474`"}], ",", "1.089966830516735`", ",", 
      "0.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.591682722672434`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.2912429039761473`", ",", 
      RowBox[{"-", "1.9058632965000448`"}], ",", "1.936580480057262`", ",", 
      "0.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.0640299998793146`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.61306622871624`", ",", "2.3961737427316545`", ",", 
      "6.222154108557685`", ",", "0.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "3.069331154893534`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.240926738495293`", ",", "4.911838904709936`", ",", 
      RowBox[{"-", "2.2121773596200205`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.4256362122058936`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3.57197363290299`", ",", 
      RowBox[{"-", "4.7777284361151855`"}], ",", 
      RowBox[{"-", "6.22194990393694`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.4505125964286294`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2.245104345849121`"}], ",", 
      RowBox[{"-", "7.59940581983865`"}], ",", 
      RowBox[{"-", "5.849196524803394`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.0014263713509326`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.5909365816875582`", ",", 
      RowBox[{"-", "2.020853005809032`"}], ",", 
      RowBox[{"-", "6.711775236845678`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.0282195152942757`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.669067346434376`", ",", "2.7869725551194775`", ",", 
      "0.3139405108205799`", ",", "1.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.4582893658871239`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7.22661819619284`"}], ",", "2.152496674228478`", ",", 
      RowBox[{"-", "3.2995241272622993`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.1820708952868766`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1.8198684914301597`", ",", "7.921471483348814`", ",", 
      "5.626105779912632`", ",", "0.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "3.3594362232756527`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.530323944083149`", ",", "3.851541438480213`", ",", 
      RowBox[{"-", "1.576416976759367`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.273198516707776`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9.654463080833843`", ",", 
      RowBox[{"-", "4.444024296716794`"}], ",", "3.4225881955038027`", ",", 
      "1.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.2023459834541594`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.473519174393998`", ",", 
      RowBox[{"-", "9.684193355858039`"}], ",", "0.33074910344652403`", ",", 
      "1.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.8799593071920673`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.4899130949982198`", ",", 
      RowBox[{"-", "3.107397441377313`"}], ",", "4.721410197336367`", ",", 
      "1.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.110221254322642`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.903017638438694`", ",", "4.742565484514013`", ",", 
      "2.3459604847131366`", ",", "1.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.1409551391080244`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.6885863352449928`"}], ",", "0.6422308404797592`", ",", 
      RowBox[{"-", "4.827256905638052`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.757314862094801`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.216659038552705`", ",", 
      RowBox[{"-", "9.155257767984248`"}], ",", 
      RowBox[{"-", "5.037840424380177`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.873256267938004`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "6.394165948129891`"}], ",", "4.024052359972618`", ",", 
      RowBox[{"-", "3.709965360301293`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.958119834719342`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.757558356675843`", ",", 
      RowBox[{"-", "0.009002644883284122`"}], ",", "0.3856205604535658`", ",",
       "0.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.011362880157096`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "2.588834498877551`", ",", "0.6639224208641121`", ",", 
      "1.1737138594297802`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.5001603587002417`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.5909365816875582`", ",", 
      RowBox[{"-", "2.020853005809032`"}], ",", 
      RowBox[{"-", "6.711775236845678`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "4.1380548574532705`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.648243222482892`", ",", "3.465491321168917`", ",", 
      "6.744954758904018`", ",", "1.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.0500562195050378`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.5909365816875582`", ",", 
      RowBox[{"-", "2.020853005809032`"}], ",", 
      RowBox[{"-", "6.711775236845678`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.9139589467304607`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.173364671643092`", ",", 
      RowBox[{"-", "5.456199324879877`"}], ",", "5.644739804280257`", ",", 
      "1.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.4118205473153038`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2.245104345849121`"}], ",", 
      RowBox[{"-", "7.59940581983865`"}], ",", 
      RowBox[{"-", "5.849196524803394`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.95440885286236`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.342857453477421`", ",", "5.200288278290438`", ",", 
      RowBox[{"-", "7.987489123641171`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.6510665052994216`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.342857453477421`", ",", "5.200288278290438`", ",", 
      RowBox[{"-", "7.987489123641171`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.8383060838072642`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "8.232062222433456`", ",", "3.878152809256657`", ",", 
      "0.4213911791829493`", ",", "0.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.2331523039317482`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.473519174393998`", ",", 
      RowBox[{"-", "9.684193355858039`"}], ",", "0.33074910344652403`", ",", 
      "0.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.7182683359530375`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.757558356675843`", ",", 
      RowBox[{"-", "0.009002644883284122`"}], ",", "0.3856205604535658`", ",",
       "0.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.2746710762594033`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "6.394165948129891`"}], ",", "4.024052359972618`", ",", 
      RowBox[{"-", "3.709965360301293`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.2733648386925838`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.4281067184743153`", ",", "5.165011933852659`", ",", 
      RowBox[{"-", "1.2213463494536325`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1626891748902994`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.6738018344904457`", ",", 
      RowBox[{"-", "8.412325310002771`"}], ",", "2.341229054839705`", ",", 
      "1.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.650537371161189`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9.965673017368527`", ",", 
      RowBox[{"-", "2.5014136237752815`"}], ",", "4.287008219560214`", ",", 
      "1.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.1365945418896721`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.530323944083149`", ",", "3.851541438480213`", ",", 
      RowBox[{"-", "1.576416976759367`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.3080582130606784`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.34086637869685965`"}], ",", 
      RowBox[{"-", "4.729865545752679`"}], ",", "0.6430090199245856`", ",", 
      "1.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.0885067501309114`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.669067346434376`", ",", "2.7869725551194775`", ",", 
      "0.3139405108205799`", ",", "0.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.0131599376264857`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "7.062708447633639`", ",", "4.813353001058087`", ",", 
      "5.280333637534039`", ",", "0.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.8348597920688643`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.4281067184743153`", ",", "5.165011933852659`", ",", 
      RowBox[{"-", "1.2213463494536325`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.544200737734242`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "14.291307998600852`"}], ",", 
      RowBox[{"-", "0.43334955500761424`"}], ",", 
      RowBox[{"-", "0.5890793305142412`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.521293293515738`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.1178193739091504`", ",", 
      RowBox[{"-", "4.596281425511127`"}], ",", 
      RowBox[{"-", "3.273107514094848`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.3241736834096076`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5.978080265467851`", ",", 
      RowBox[{"-", "1.6514724013405755`"}], ",", 
      RowBox[{"-", "2.1290168518478425`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.7340162389758447`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.189101413994847`", ",", "1.1164480587777574`", ",", 
      RowBox[{"-", "1.9677139011959657`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.8539575168817375`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.473519174393998`", ",", 
      RowBox[{"-", "9.684193355858039`"}], ",", "0.33074910344652403`", ",", 
      "0.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1048395446750088`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "17.509317972619726`"}], ",", 
      RowBox[{"-", "4.187905029120511`"}], ",", 
      RowBox[{"-", "7.444913458882694`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.952689176029899`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.2912429039761473`", ",", 
      RowBox[{"-", "1.9058632965000448`"}], ",", "1.936580480057262`", ",", 
      "1.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.5411808264715219`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.000487623375335`"}], ",", "0.812499798921313`", ",", 
      "2.634461233836259`", ",", "0.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.814221232047535`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "4.988943438898219`", ",", "0.6344010287775762`", ",", 
      "4.7449910575496475`", ",", "0.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.5285461133840186`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.648243222482892`", ",", "3.465491321168917`", ",", 
      "6.744954758904018`", ",", "0.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.1913375931097825`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.189101413994847`", ",", "1.1164480587777574`", ",", 
      RowBox[{"-", "1.9677139011959657`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.6835333866290907`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "21.101238365522494`"}], ",", 
      RowBox[{"-", "0.6100623026867971`"}], ",", "8.529832677047214`", ",", 
      "1.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1457496061260297`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.5909365816875582`", ",", 
      RowBox[{"-", "2.020853005809032`"}], ",", 
      RowBox[{"-", "6.711775236845678`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.0565671181188865`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9.965673017368527`", ",", 
      RowBox[{"-", "2.5014136237752815`"}], ",", "4.287008219560214`", ",", 
      "1.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.1077317153304014`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.677786461994058`", ",", "5.358104820124155`", ",", 
      RowBox[{"-", "3.3008908607018745`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.8443055980381835`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.4281067184743153`", ",", "5.165011933852659`", ",", 
      RowBox[{"-", "1.2213463494536325`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.4648958353707653`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.903017638438694`", ",", "4.742565484514013`", ",", 
      "2.3459604847131366`", ",", "1.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.542890841782037`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.89257340254789`"}], ",", 
      RowBox[{"-", "4.15002115502496`"}], ",", "6.798357109240167`", ",", 
      "1.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.0277404984492904`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "4.988943438898219`", ",", "0.6344010287775762`", ",", 
      "4.7449910575496475`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.295095284737405`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9.965673017368527`", ",", 
      RowBox[{"-", "2.5014136237752815`"}], ",", "4.287008219560214`", ",", 
      "0.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.4972092249656637`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.6036409803939666`", ",", "6.391999139353731`", ",", 
      RowBox[{"-", "2.559143060053504`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.0834595120350223`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.4388879395003342`"}], ",", 
      RowBox[{"-", "2.598110592650474`"}], ",", "1.089966830516735`", ",", 
      "1.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.8100517264073053`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.2912429039761473`", ",", 
      RowBox[{"-", "1.9058632965000448`"}], ",", "1.936580480057262`", ",", 
      "1.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.6772607818904013`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.81468744341777`"}], ",", "4.0530403824280565`", ",", 
      RowBox[{"-", "5.995407601384168`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.1611530901898215`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9.654463080833843`", ",", 
      RowBox[{"-", "4.444024296716794`"}], ",", "3.4225881955038027`", ",", 
      "1.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.1658466088092159`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.58371347981322`"}], ",", "0.21494728902017465`", ",", 
      "6.938379786136243`", ",", "1.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "0.6377205409905283`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.58371347981322`"}], ",", "0.21494728902017465`", ",", 
      "6.938379786136243`", ",", "0.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "3.580553238258253`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9.654463080833843`", ",", 
      RowBox[{"-", "4.444024296716794`"}], ",", "3.4225881955038027`", ",", 
      "1.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "0.9200999178918784`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "8.472869124450304`"}], ",", "3.5978236482209143`", ",", 
      RowBox[{"-", "5.053346098672997`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "4.036813052438891`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.173364671643092`", ",", 
      RowBox[{"-", "5.456199324879877`"}], ",", "5.644739804280257`", ",", 
      "0.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.753081229975076`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1.8198684914301597`", ",", "7.921471483348814`", ",", 
      "5.626105779912632`", ",", "0.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "3.246348327862958`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3.525166247038391`"}], ",", "9.160944810588841`", ",", 
      RowBox[{"-", "4.16891759840301`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.9805869302767483`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.4899130949982198`", ",", 
      RowBox[{"-", "3.107397441377313`"}], ",", "4.721410197336367`", ",", 
      "0.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.6235617865259395`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2.245104345849121`"}], ",", 
      RowBox[{"-", "7.59940581983865`"}], ",", 
      RowBox[{"-", "5.849196524803394`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.288768471273212`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.2912429039761473`", ",", 
      RowBox[{"-", "1.9058632965000448`"}], ",", "1.936580480057262`", ",", 
      "1.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.6085759944569897`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.648243222482892`", ",", "3.465491321168917`", ",", 
      "6.744954758904018`", ",", "1.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "0.5816901316977806`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "16.279261281924313`"}], ",", 
      RowBox[{"-", "0.49228122332192126`"}], ",", "0.8608240174150654`", ",", 
      "0.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1492796721908647`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.189101413994847`", ",", "1.1164480587777574`", ",", 
      RowBox[{"-", "1.9677139011959657`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.7228955699790829`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "2.858864173869224`", ",", "0.24123912459719887`", ",", 
      "1.249400159230766`", ",", "1.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "0.9535947635417147`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.5909365816875582`", ",", 
      RowBox[{"-", "2.020853005809032`"}], ",", 
      RowBox[{"-", "6.711775236845678`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "4.456279653741267`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.6738018344904457`", ",", 
      RowBox[{"-", "8.412325310002771`"}], ",", "2.341229054839705`", ",", 
      "1.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.3339358439843125`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.34086637869685965`"}], ",", 
      RowBox[{"-", "4.729865545752679`"}], ",", "0.6430090199245856`", ",", 
      "0.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.7294918467340534`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.530323944083149`", ",", "3.851541438480213`", ",", 
      RowBox[{"-", "1.576416976759367`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.1292019965777838`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "14.291307998600852`"}], ",", 
      RowBox[{"-", "0.43334955500761424`"}], ",", 
      RowBox[{"-", "0.5890793305142412`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.3037787661901432`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7.809087735503671`"}], ",", 
      RowBox[{"-", "3.1054225656324093`"}], ",", 
      RowBox[{"-", "1.750351386471387`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.7235728987357857`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.669067346434376`", ",", "2.7869725551194775`", ",", 
      "0.3139405108205799`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.9726148832794022`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.0761771390251065`", ",", 
      RowBox[{"-", "2.9054512418166403`"}], ",", 
      RowBox[{"-", "1.8868765186398941`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.942539460985966`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.937009556247947`", ",", "4.660818285635254`", ",", 
      RowBox[{"-", "2.4118111485876255`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.4565529297476747`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.648243222482892`", ",", "3.465491321168917`", ",", 
      "6.744954758904018`", ",", "0.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.401298724106231`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.81468744341777`"}], ",", "4.0530403824280565`", ",", 
      RowBox[{"-", "5.995407601384168`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.236988921501675`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3.57197363290299`", ",", 
      RowBox[{"-", "4.7777284361151855`"}], ",", 
      RowBox[{"-", "6.22194990393694`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.722152833698788`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3.525166247038391`"}], ",", "9.160944810588841`", ",", 
      RowBox[{"-", "4.16891759840301`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.5913808238504437`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "13.060469205364882`"}], ",", "2.2505554067043327`", ",", 
      "2.3025629375567593`", ",", "0.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.781842790278421`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.677786461994058`", ",", "5.358104820124155`", ",", 
      RowBox[{"-", "3.3008908607018745`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.6964798041401727`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "7.062708447633639`", ",", "4.813353001058087`", ",", 
      "5.280333637534039`", ",", "1.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.2211347274050246`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "8.232062222433456`", ",", "3.878152809256657`", ",", 
      "0.4213911791829493`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.9113824523376886`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1.8198684914301597`", ",", "7.921471483348814`", ",", 
      "5.626105779912632`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.665478071547456`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3.525166247038391`"}], ",", "9.160944810588841`", ",", 
      RowBox[{"-", "4.16891759840301`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.950197320535693`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.4281067184743153`", ",", "5.165011933852659`", ",", 
      RowBox[{"-", "1.2213463494536325`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.149064046324306`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9.654463080833843`", ",", 
      RowBox[{"-", "4.444024296716794`"}], ",", "3.4225881955038027`", ",", 
      "0.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.80130141525066`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.240926738495293`", ",", "4.911838904709936`", ",", 
      RowBox[{"-", "2.2121773596200205`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.9390361178869782`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.4899130949982198`", ",", 
      RowBox[{"-", "3.107397441377313`"}], ",", "4.721410197336367`", ",", 
      "0.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.3241077961483065`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "6.394165948129891`"}], ",", "4.024052359972618`", ",", 
      RowBox[{"-", "3.709965360301293`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.6108665485060056`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.530323944083149`", ",", "3.851541438480213`", ",", 
      RowBox[{"-", "1.576416976759367`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.2987538947032866`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.677786461994058`", ",", "5.358104820124155`", ",", 
      RowBox[{"-", "3.3008908607018745`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.626646345751855`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.757558356675843`", ",", 
      RowBox[{"-", "0.009002644883284122`"}], ",", "0.3856205604535658`", ",",
       "0.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.0514135943576965`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.677786461994058`", ",", "5.358104820124155`", ",", 
      RowBox[{"-", "3.3008908607018745`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.7014678903682787`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.9199658186892536`"}], ",", 
      RowBox[{"-", "5.78671447426552`"}], ",", "1.0996213303519675`", ",", 
      "0.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.524949497345547`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3.525166247038391`"}], ",", "9.160944810588841`", ",", 
      RowBox[{"-", "4.16891759840301`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.945753880415252`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "8.232062222433456`", ",", "3.878152809256657`", ",", 
      "0.4213911791829493`", ",", "1.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.9382787710334402`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "2.858864173869224`", ",", "0.24123912459719887`", ",", 
      "1.249400159230766`", ",", "1.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.3753427076762832`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.189101413994847`", ",", "1.1164480587777574`", ",", 
      RowBox[{"-", "1.9677139011959657`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.8081821610694333`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "4.988943438898219`", ",", "0.6344010287775762`", ",", 
      "4.7449910575496475`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.2659874142665286`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.5909365816875582`", ",", 
      RowBox[{"-", "2.020853005809032`"}], ",", 
      RowBox[{"-", "6.711775236845678`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.536805537084552`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.6885863352449928`"}], ",", "0.6422308404797592`", ",", 
      RowBox[{"-", "4.827256905638052`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.175054634094643`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "17.509317972619726`"}], ",", 
      RowBox[{"-", "4.187905029120511`"}], ",", 
      RowBox[{"-", "7.444913458882694`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.2276095507328586`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.6036409803939666`", ",", "6.391999139353731`", ",", 
      RowBox[{"-", "2.559143060053504`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.957317162420805`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.6036409803939666`", ",", "6.391999139353731`", ",", 
      RowBox[{"-", "2.559143060053504`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.1577727048318107`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.189101413994847`", ",", "1.1164480587777574`", ",", 
      RowBox[{"-", "1.9677139011959657`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.7620022450104076`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2.0242794604536134`"}], ",", "6.511836631694567`", ",", 
      RowBox[{"-", "1.7038664141685957`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.653769904931855`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.1178193739091504`", ",", 
      RowBox[{"-", "4.596281425511127`"}], ",", 
      RowBox[{"-", "3.273107514094848`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.85178634144325`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "14.291307998600852`"}], ",", 
      RowBox[{"-", "0.43334955500761424`"}], ",", 
      RowBox[{"-", "0.5890793305142412`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.5387762505249283`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.4281067184743153`", ",", "5.165011933852659`", ",", 
      RowBox[{"-", "1.2213463494536325`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.843904164266386`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5.978080265467851`", ",", 
      RowBox[{"-", "1.6514724013405755`"}], ",", 
      RowBox[{"-", "2.1290168518478425`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1183514729034654`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6.199240769610545`", ",", 
      RowBox[{"-", "2.2862404532308434`"}], ",", 
      RowBox[{"-", "1.7258778043858518`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.436144007731041`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.4899130949982198`", ",", 
      RowBox[{"-", "3.107397441377313`"}], ",", "4.721410197336367`", ",", 
      "1.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.5964012768069344`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.530323944083149`", ",", "3.851541438480213`", ",", 
      RowBox[{"-", "1.576416976759367`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.885479715221432`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.0904821921155445`", ",", 
      RowBox[{"-", "7.650442394352687`"}], ",", 
      RowBox[{"-", "0.2709773852783684`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.709713025513575`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.4388879395003342`"}], ",", 
      RowBox[{"-", "2.598110592650474`"}], ",", "1.089966830516735`", ",", 
      "0.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.5109357192409476`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5.978080265467851`", ",", 
      RowBox[{"-", "1.6514724013405755`"}], ",", 
      RowBox[{"-", "2.1290168518478425`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.098081263678752`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "2.588834498877551`", ",", "0.6639224208641121`", ",", 
      "1.1737138594297802`", ",", "1.`", ",", "1.6094379124341003`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.602267783018035`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1.8198684914301597`", ",", "7.921471483348814`", ",", 
      "5.626105779912632`", ",", "1.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.6638146270975036`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.61306622871624`", ",", "2.3961737427316545`", ",", 
      "6.222154108557685`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.0772015129318868`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.216659038552705`", ",", 
      RowBox[{"-", "9.155257767984248`"}], ",", 
      RowBox[{"-", "5.037840424380177`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.7549373955187453`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7.240926738495293`", ",", "4.911838904709936`", ",", 
      RowBox[{"-", "2.2121773596200205`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.479864682599629`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2.0242794604536134`"}], ",", "6.511836631694567`", ",", 
      RowBox[{"-", "1.7038664141685957`"}], ",", "0.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.69770557881176`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5.978080265467851`", ",", 
      RowBox[{"-", "1.6514724013405755`"}], ",", 
      RowBox[{"-", "2.1290168518478425`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.2949453146233938`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "5.61306622871624`", ",", "2.3961737427316545`", ",", 
      "6.222154108557685`", ",", "0.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "3.1989999901509663`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9.965673017368527`", ",", 
      RowBox[{"-", "2.5014136237752815`"}], ",", "4.287008219560214`", ",", 
      "0.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.46785008355726`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.4899130949982198`", ",", 
      RowBox[{"-", "3.107397441377313`"}], ",", "4.721410197336367`", ",", 
      "0.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.262772304628116`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.173364671643092`", ",", 
      RowBox[{"-", "5.456199324879877`"}], ",", "5.644739804280257`", ",", 
      "1.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.0149769601533443`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.0761771390251065`", ",", 
      RowBox[{"-", "2.9054512418166403`"}], ",", 
      RowBox[{"-", "1.8868765186398941`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.3482123232837777`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.4281067184743153`", ",", "5.165011933852659`", ",", 
      RowBox[{"-", "1.2213463494536325`"}], ",", "1.`", ",", 
      "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1661442128588955`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7.22661819619284`"}], ",", "2.152496674228478`", ",", 
      RowBox[{"-", "3.2995241272622993`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.269466511135165`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.89257340254789`"}], ",", 
      RowBox[{"-", "4.15002115502496`"}], ",", "6.798357109240167`", ",", 
      "1.`", ",", "4.605170185988092`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.006640828534197`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7.22661819619284`"}], ",", "2.152496674228478`", ",", 
      RowBox[{"-", "3.2995241272622993`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.6867485320537914`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "2.588834498877551`", ",", "0.6639224208641121`", ",", 
      "1.1737138594297802`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.3877360141264714`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "8.232062222433456`", ",", "3.878152809256657`", ",", 
      "0.4213911791829493`", ",", "0.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.165398781133524`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.7424967599278345`", ",", 
      RowBox[{"-", "0.20872781708074226`"}], ",", 
      RowBox[{"-", "2.4189556204138123`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.7573567288112952`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "16.279261281924313`"}], ",", 
      RowBox[{"-", "0.49228122332192126`"}], ",", "0.8608240174150654`", ",", 
      "0.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.4352519764305685`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.81468744341777`"}], ",", "4.0530403824280565`", ",", 
      RowBox[{"-", "5.995407601384168`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.1691503513099413`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "7.062708447633639`", ",", "4.813353001058087`", ",", 
      "5.280333637534039`", ",", "1.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.815887852043558`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.34086637869685965`"}], ",", 
      RowBox[{"-", "4.729865545752679`"}], ",", "0.6430090199245856`", ",", 
      "0.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.30413350906229`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3.57197363290299`", ",", 
      RowBox[{"-", "4.7777284361151855`"}], ",", 
      RowBox[{"-", "6.22194990393694`"}], ",", "1.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.701786937116347`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.473519174393998`", ",", 
      RowBox[{"-", "9.684193355858039`"}], ",", "0.33074910344652403`", ",", 
      "1.`", ",", "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.831127223144348`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "2.588834498877551`", ",", "0.6639224208641121`", ",", 
      "1.1737138594297802`", ",", "1.`", ",", "5.298317366548036`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "2.5150595469067576`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.58371347981322`"}], ",", "0.21494728902017465`", ",", 
      "6.938379786136243`", ",", "0.`", ",", "4.605170185988092`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "3.5365501539847872`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "14.291307998600852`"}], ",", 
      RowBox[{"-", "0.43334955500761424`"}], ",", 
      RowBox[{"-", "0.5890793305142412`"}], ",", "0.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.0699541104387413`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.34086637869685965`"}], ",", 
      RowBox[{"-", "4.729865545752679`"}], ",", "0.6430090199245856`", ",", 
      "0.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.7205621675864418`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "10.81468744341777`"}], ",", "4.0530403824280565`", ",", 
      RowBox[{"-", "5.995407601384168`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.3894430010754864`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7.22661819619284`"}], ",", "2.152496674228478`", ",", 
      RowBox[{"-", "3.2995241272622993`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.9555440876736012`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3.525166247038391`"}], ",", "9.160944810588841`", ",", 
      RowBox[{"-", "4.16891759840301`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.513299540798506`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.6885863352449928`"}], ",", "0.6422308404797592`", ",", 
      RowBox[{"-", "4.827256905638052`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.2026265938006944`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "17.509317972619726`"}], ",", 
      RowBox[{"-", "4.187905029120511`"}], ",", 
      RowBox[{"-", "7.444913458882694`"}], ",", "0.`", ",", 
      "1.6094379124341003`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.7886601610330888`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "6.394165948129891`"}], ",", "4.024052359972618`", ",", 
      RowBox[{"-", "3.709965360301293`"}], ",", "1.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "3.0954929706672867`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.7424967599278345`", ",", 
      RowBox[{"-", "0.20872781708074226`"}], ",", 
      RowBox[{"-", "2.4189556204138123`"}], ",", "0.`", ",", 
      "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.974241031379715`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3.57197363290299`", ",", 
      RowBox[{"-", "4.7777284361151855`"}], ",", 
      RowBox[{"-", "6.22194990393694`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "1.8979337642157876`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6.034405098172207`", ",", 
      RowBox[{"-", "1.9743317948787145`"}], ",", "3.7510600129390017`", ",", 
      "0.`", ",", "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.6858987971555437`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "8.232062222433456`", ",", "3.878152809256657`", ",", 
      "0.4213911791829493`", ",", "1.`", ",", "3.912023005428146`"}], "}"}], 
    "\[Rule]", 
    RowBox[{"-", "1.8667485844753542`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2.245104345849121`"}], ",", 
      RowBox[{"-", "7.59940581983865`"}], ",", 
      RowBox[{"-", "5.849196524803394`"}], ",", "1.`", ",", 
      "3.912023005428146`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.878408679643283`"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.2912429039761473`", ",", 
      RowBox[{"-", "1.9058632965000448`"}], ",", "1.936580480057262`", ",", 
      "0.`", ",", "5.298317366548036`"}], "}"}], "\[Rule]", 
    RowBox[{"-", "2.2381502044229378`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8097610289131255`*^9},
 CellLabel->
  "Out[128]=",ExpressionUUID->"36ac3045-708e-4203-b623-6c5e4ea531a9"]
}, Open  ]]
},
WindowSize->{1658, 915},
WindowMargins->{{Automatic, 104}, {6, Automatic}},
CellContext->Notebook,
Magnification:>0.9 Inherited,
FrontEndVersion->"12.1 for Microsoft Windows (64-bit) (March 14, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"88cd92b6-b017-499c-9ef1-0f3add964137"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 5887, 152, 315, "Input",ExpressionUUID->"a55fe3f7-2029-40ee-abb6-d052e0c9017a"],
Cell[6470, 176, 8760, 228, 88, "Output",ExpressionUUID->"bd6bc1e8-c6f2-42dc-9020-4047684b94db"],
Cell[15233, 406, 197, 4, 30, "Output",ExpressionUUID->"658d6a5b-21d1-46be-859f-5b2ab43482d6"],
Cell[15433, 412, 6134, 100, 229, "Output",ExpressionUUID->"797e7b4c-8bdf-4782-8fd9-df63b9e0144e"],
Cell[21570, 514, 960477, 15945, 343, "Output",ExpressionUUID->"fe39fe13-f10a-47c1-9bbb-02b7c1ffab5b"]
}, Open  ]],
Cell[982062, 16462, 461, 7, 63, "Input",ExpressionUUID->"aa6c0a0c-b477-41ce-aedc-d10d7c9bb961"],
Cell[CellGroupData[{
Cell[982548, 16473, 4852, 123, 369, "Input",ExpressionUUID->"8de9aeb2-890e-4bc2-840f-abd23110d055"],
Cell[987403, 16598, 150, 2, 30, "Output",ExpressionUUID->"6c77e2f8-a859-42e1-9316-9ee3485753eb"],
Cell[987556, 16602, 152, 2, 30, "Output",ExpressionUUID->"17bd84da-37c5-4069-9e3b-5c5fd411b564"],
Cell[987711, 16606, 90350, 1565, 1949, "Output",ExpressionUUID->"83ecb88e-e40a-4202-a8a8-391db0575edf"],
Cell[1078064, 18173, 180, 2, 30, "Output",ExpressionUUID->"b24dfb73-1a00-4667-93e1-708a5f208318"]
}, Open  ]],
Cell[1078259, 18178, 736, 13, 63, "Input",ExpressionUUID->"56f838f2-39c9-4c79-8475-a3c9fa2813ee"],
Cell[CellGroupData[{
Cell[1079020, 18195, 9065, 217, 387, "Input",ExpressionUUID->"86763866-1c74-49e0-86ec-ef492dbb4215"],
Cell[1088088, 18414, 52488, 1420, 697, "Output",ExpressionUUID->"4f5eb2d1-3181-49c2-99b6-fcf2bdc5a014"],
Cell[1140579, 19836, 198, 4, 30, "Output",ExpressionUUID->"754d18a5-5459-44a2-b5d4-e07d1fd94884"],
Cell[CellGroupData[{
Cell[1140802, 19844, 280, 8, 21, "Print",ExpressionUUID->"032ea2be-6533-4067-9072-0687e8c20082"],
Cell[1141085, 19854, 281, 8, 21, "Print",ExpressionUUID->"0c58243c-ec91-403e-90a1-966d8b68141c"],
Cell[1141369, 19864, 283, 8, 21, "Print",ExpressionUUID->"5cfa4030-fd74-427b-9fd3-083b874290e4"],
Cell[1141655, 19874, 283, 8, 21, "Print",ExpressionUUID->"a0658a94-34fb-4020-a2bc-66bc24d93990"],
Cell[1141941, 19884, 283, 8, 21, "Print",ExpressionUUID->"0d3efe86-a09f-45c3-af48-fc825e510f25"],
Cell[1142227, 19894, 283, 8, 21, "Print",ExpressionUUID->"dae92b97-9255-4ccd-ad89-f0d3532ad1e3"],
Cell[1142513, 19904, 283, 8, 21, "Print",ExpressionUUID->"da82ebd9-662a-48e8-a0da-405380684762"],
Cell[1142799, 19914, 283, 8, 21, "Print",ExpressionUUID->"ced5428a-6a10-4219-9566-e87469e094c4"],
Cell[1143085, 19924, 281, 8, 21, "Print",ExpressionUUID->"86fd0064-f196-4f1b-96ba-39f7dcc14ca8"],
Cell[1143369, 19934, 283, 8, 21, "Print",ExpressionUUID->"8be5755e-674d-4d03-ab7f-a75d8a063018"],
Cell[1143655, 19944, 283, 8, 21, "Print",ExpressionUUID->"3aca4e12-37f6-4dff-9295-767fcb435552"],
Cell[1143941, 19954, 283, 8, 21, "Print",ExpressionUUID->"3a2f1513-b9c0-42ad-9d72-7e4f41a3e86a"],
Cell[1144227, 19964, 280, 8, 21, "Print",ExpressionUUID->"3691316b-3364-46b4-aea7-e1eda8465420"],
Cell[1144510, 19974, 283, 8, 21, "Print",ExpressionUUID->"52710a37-150f-4a65-b2c1-734239f344cb"],
Cell[1144796, 19984, 283, 8, 21, "Print",ExpressionUUID->"07c65707-5635-41e8-b391-2ea1b55b6ea3"],
Cell[1145082, 19994, 280, 8, 21, "Print",ExpressionUUID->"3ae1e1e1-67d3-4419-bee5-d64eed3b9fed"],
Cell[1145365, 20004, 281, 8, 21, "Print",ExpressionUUID->"9aaffe3e-e54c-4f70-a06f-b95e9466bf0c"],
Cell[1145649, 20014, 281, 8, 21, "Print",ExpressionUUID->"ce4a7bc8-17d7-45b5-8cc9-0743a9a53dc4"],
Cell[1145933, 20024, 281, 8, 21, "Print",ExpressionUUID->"88b5cc8d-31ea-43f8-96a7-4a4d9061d8ce"],
Cell[1146217, 20034, 281, 8, 21, "Print",ExpressionUUID->"c411caa0-59a1-4736-9433-cbca50f8e75d"],
Cell[1146501, 20044, 283, 8, 21, "Print",ExpressionUUID->"d460b92f-ab71-406c-ba25-1dce08290d43"],
Cell[1146787, 20054, 283, 8, 21, "Print",ExpressionUUID->"fea3b115-074a-4a37-8175-b40aaea751fe"],
Cell[1147073, 20064, 281, 8, 21, "Print",ExpressionUUID->"ce35c671-049a-49fe-b1a0-8985bfd6bdda"],
Cell[1147357, 20074, 281, 8, 21, "Print",ExpressionUUID->"8391edcb-d326-4def-86c2-7975524e0e57"],
Cell[1147641, 20084, 283, 8, 21, "Print",ExpressionUUID->"bb0583cd-7a6f-45f5-b193-fa25e2e8e9af"],
Cell[1147927, 20094, 281, 8, 21, "Print",ExpressionUUID->"f80116f3-7484-4313-a393-9116dee79161"],
Cell[1148211, 20104, 280, 8, 21, "Print",ExpressionUUID->"8d8b947d-3f18-48a4-b7fa-41d5bf4dd889"],
Cell[1148494, 20114, 283, 8, 21, "Print",ExpressionUUID->"ec0f9b80-ee6a-4271-9824-b7d6089ced94"],
Cell[1148780, 20124, 282, 8, 21, "Print",ExpressionUUID->"aa9b9460-1037-40d2-8e13-e0e44a160617"],
Cell[1149065, 20134, 283, 8, 21, "Print",ExpressionUUID->"8f2f9b31-3409-45c5-8958-6d640ac42f23"],
Cell[1149351, 20144, 283, 8, 21, "Print",ExpressionUUID->"ea4c487e-c547-4d41-bb3e-79a316d81ed0"],
Cell[1149637, 20154, 281, 8, 21, "Print",ExpressionUUID->"5c32e5da-81ae-457d-b848-ee7cce192723"],
Cell[1149921, 20164, 281, 8, 21, "Print",ExpressionUUID->"85de8d30-a7d0-4d56-8a34-0c7de3f2fbad"],
Cell[1150205, 20174, 283, 8, 21, "Print",ExpressionUUID->"d6def51f-e39f-4236-8df1-a80ab15c9060"],
Cell[1150491, 20184, 281, 8, 21, "Print",ExpressionUUID->"8dc25c9c-b34d-47d1-aa5e-94bd2ecc9ec2"],
Cell[1150775, 20194, 281, 8, 21, "Print",ExpressionUUID->"41c6a09d-a9a9-4dd5-85b4-72a3a693b3b7"],
Cell[1151059, 20204, 281, 8, 21, "Print",ExpressionUUID->"186612aa-23d1-438e-a34d-8a042ff824f6"],
Cell[1151343, 20214, 283, 8, 21, "Print",ExpressionUUID->"0dc64aa6-d667-46c9-8dfa-b1123ff6330b"],
Cell[1151629, 20224, 283, 8, 21, "Print",ExpressionUUID->"3bfd3e34-ef32-437c-a17d-1e4d60a3a27e"],
Cell[1151915, 20234, 281, 8, 21, "Print",ExpressionUUID->"f0526cb0-4bf9-4d60-a602-d995d87affd5"],
Cell[1152199, 20244, 281, 8, 21, "Print",ExpressionUUID->"45d41984-e4aa-44e7-ba9e-b4c1252950d2"],
Cell[1152483, 20254, 283, 8, 21, "Print",ExpressionUUID->"d85d2bb7-6e6b-4a85-8299-2e9f0e18a474"],
Cell[1152769, 20264, 281, 8, 21, "Print",ExpressionUUID->"e81b1171-1be9-4bb2-8cb0-4184d4f6a934"],
Cell[1153053, 20274, 280, 8, 21, "Print",ExpressionUUID->"47bfb5bb-c830-4cc4-b794-2306e3af3f81"],
Cell[1153336, 20284, 281, 8, 21, "Print",ExpressionUUID->"357be996-5785-4d76-b24a-b35844d5f3c0"],
Cell[1153620, 20294, 283, 8, 21, "Print",ExpressionUUID->"a547f6a6-0741-4969-bf8f-3e4b77867a1f"],
Cell[1153906, 20304, 281, 8, 21, "Print",ExpressionUUID->"be256ec0-4765-4880-8601-8dd4afe96155"],
Cell[1154190, 20314, 283, 8, 21, "Print",ExpressionUUID->"ffa5179b-a23f-4c57-a509-48d883af107b"],
Cell[1154476, 20324, 283, 8, 21, "Print",ExpressionUUID->"1ffd9207-0d57-4b8f-ba64-eeca58b5193a"],
Cell[1154762, 20334, 281, 8, 21, "Print",ExpressionUUID->"2429eb20-d55f-4a8e-a9ce-b80d8bf74e1f"],
Cell[1155046, 20344, 281, 8, 21, "Print",ExpressionUUID->"03e94afe-daa3-4d49-bb65-fd9c4b35ea64"],
Cell[1155330, 20354, 281, 8, 21, "Print",ExpressionUUID->"8b261a71-50cd-4fdb-a3cd-667212c66db5"],
Cell[1155614, 20364, 281, 8, 21, "Print",ExpressionUUID->"450e02d1-2aa0-4ece-9bfa-a3135068c0c3"],
Cell[1155898, 20374, 283, 8, 21, "Print",ExpressionUUID->"d374e705-6e25-45b8-bd19-e64ec04ce590"],
Cell[1156184, 20384, 282, 8, 21, "Print",ExpressionUUID->"13148da1-3740-4de4-90a7-a6b278289922"],
Cell[1156469, 20394, 284, 8, 21, "Print",ExpressionUUID->"e0cf6d8a-5559-454d-b2bd-101de68d8d3a"],
Cell[1156756, 20404, 283, 8, 21, "Print",ExpressionUUID->"1502457f-e5cb-43c9-a3fa-8ecec8f715e6"],
Cell[1157042, 20414, 284, 8, 21, "Print",ExpressionUUID->"813e0003-480f-45eb-88b0-c1824b9ff6ad"],
Cell[1157329, 20424, 284, 8, 21, "Print",ExpressionUUID->"6c74531c-d795-4792-8eaf-a63cdff0b2fd"],
Cell[1157616, 20434, 282, 8, 21, "Print",ExpressionUUID->"49704739-e56f-43d1-b028-63b6164954fb"],
Cell[1157901, 20444, 282, 8, 21, "Print",ExpressionUUID->"e34e154b-b570-49b9-8d7c-72f54e97fd58"],
Cell[1158186, 20454, 281, 8, 21, "Print",ExpressionUUID->"c7523834-3826-4065-a14c-a324927b94c6"],
Cell[1158470, 20464, 284, 8, 21, "Print",ExpressionUUID->"66e50b8f-20d0-4b45-a6fc-72cd88ade3cc"],
Cell[1158757, 20474, 284, 8, 21, "Print",ExpressionUUID->"bfd3fce3-e584-4d14-85e0-7352d569a61b"],
Cell[1159044, 20484, 283, 8, 21, "Print",ExpressionUUID->"ff4d11bb-e02a-4561-ba41-2c2a81fa1e2e"],
Cell[1159330, 20494, 282, 8, 21, "Print",ExpressionUUID->"4fba3838-83e4-4ed6-92a1-dc310fcf22ec"],
Cell[1159615, 20504, 282, 8, 21, "Print",ExpressionUUID->"ed4247c7-2b5b-48fe-8b4b-e6da19ecd108"],
Cell[1159900, 20514, 280, 8, 21, "Print",ExpressionUUID->"1fe78090-99f8-44bb-a59f-9d5c936c7830"],
Cell[1160183, 20524, 282, 8, 21, "Print",ExpressionUUID->"724ad1f8-4cec-4303-a927-d7e77e514c33"],
Cell[1160468, 20534, 283, 8, 21, "Print",ExpressionUUID->"706e0591-24ec-465a-9b96-39eb0bb8bdea"],
Cell[1160754, 20544, 284, 8, 21, "Print",ExpressionUUID->"6416dd86-0fe1-414d-8b6a-788be7174118"],
Cell[1161041, 20554, 284, 8, 21, "Print",ExpressionUUID->"b674edc9-921f-4e88-8add-71a8c72eab69"],
Cell[1161328, 20564, 282, 8, 21, "Print",ExpressionUUID->"841dd508-2306-4571-a6ed-0b0bb061ce3d"],
Cell[1161613, 20574, 282, 8, 21, "Print",ExpressionUUID->"20c356cf-0443-4680-8208-f748020f50f6"],
Cell[1161898, 20584, 284, 8, 21, "Print",ExpressionUUID->"f7b253ce-7644-420a-9d27-f54d83d848b0"],
Cell[1162185, 20594, 282, 8, 21, "Print",ExpressionUUID->"daae1518-e889-466a-983f-fe66cb058fb2"],
Cell[1162470, 20604, 282, 8, 21, "Print",ExpressionUUID->"17cc60d0-f9c3-4985-acfe-de1e3cfa9ce0"],
Cell[1162755, 20614, 283, 8, 21, "Print",ExpressionUUID->"666efec1-83fb-42ab-8bca-2842c00a9eca"],
Cell[1163041, 20624, 282, 8, 21, "Print",ExpressionUUID->"f99989ed-9a52-46c5-b5c0-2e39d225dfd3"],
Cell[1163326, 20634, 282, 8, 21, "Print",ExpressionUUID->"61adff48-d54f-47e4-87d2-b46f4b4a500f"],
Cell[1163611, 20644, 284, 8, 21, "Print",ExpressionUUID->"98ab76ee-9ec5-4d50-8188-2d3e972aceba"],
Cell[1163898, 20654, 282, 8, 21, "Print",ExpressionUUID->"9e461a10-f7a0-4c62-980c-2761466cb08c"],
Cell[1164183, 20664, 282, 8, 21, "Print",ExpressionUUID->"020626f9-7f43-480f-95b0-8a8d12d86e7a"],
Cell[1164468, 20674, 284, 8, 21, "Print",ExpressionUUID->"97537188-2fe4-43a5-a90a-6f232fb5e1c0"],
Cell[1164755, 20684, 283, 8, 21, "Print",ExpressionUUID->"3cdb9852-d961-4fa1-af37-846e0ef19023"],
Cell[1165041, 20694, 284, 8, 21, "Print",ExpressionUUID->"0bd4bac8-96a0-4180-8caa-23de4807d8a9"],
Cell[1165328, 20704, 281, 8, 21, "Print",ExpressionUUID->"f9e7ff77-f871-436b-be87-3944127d9087"],
Cell[1165612, 20714, 284, 8, 21, "Print",ExpressionUUID->"5bbfaa82-dd02-4a97-9aba-f7f788e65da6"],
Cell[1165899, 20724, 284, 8, 21, "Print",ExpressionUUID->"e8ae779f-9f7e-4ccf-8358-a44027f5d86e"],
Cell[1166186, 20734, 283, 8, 21, "Print",ExpressionUUID->"cc0081dc-c00d-4a79-b56f-d97edf514f13"],
Cell[1166472, 20744, 282, 8, 21, "Print",ExpressionUUID->"39a0efc8-3864-446b-a49e-b43c15647e83"],
Cell[1166757, 20754, 281, 8, 21, "Print",ExpressionUUID->"70357f64-59b4-4eec-8bcb-9286b2e8545c"],
Cell[1167041, 20764, 284, 8, 21, "Print",ExpressionUUID->"9805572e-5bb7-4109-bbd5-99a8955feb56"],
Cell[1167328, 20774, 284, 8, 21, "Print",ExpressionUUID->"7a77a894-9574-44ab-8f14-bd3d2f7a5545"],
Cell[1167615, 20784, 282, 8, 21, "Print",ExpressionUUID->"e4aea358-f85e-4f24-aa82-7040c1e6b65c"],
Cell[1167900, 20794, 282, 8, 21, "Print",ExpressionUUID->"3360cfa1-7649-47ea-aec7-fb258e523854"],
Cell[1168185, 20804, 284, 8, 21, "Print",ExpressionUUID->"1493d286-c44d-4202-9d46-e493a7383f9f"],
Cell[1168472, 20814, 282, 8, 21, "Print",ExpressionUUID->"c97fe13e-cef5-42c6-a258-b51cfa25d1c8"],
Cell[1168757, 20824, 281, 8, 21, "Print",ExpressionUUID->"e1a4d5c4-4e6d-4899-98bd-22cb34813670"],
Cell[1169041, 20834, 283, 8, 21, "Print",ExpressionUUID->"3cf92f18-6c5b-4ddd-9dfb-d9cc65956359"],
Cell[1169327, 20844, 281, 8, 21, "Print",ExpressionUUID->"b56417b1-7974-4a62-a72a-73978e5ef29a"],
Cell[1169611, 20854, 284, 8, 21, "Print",ExpressionUUID->"5c25d3b6-a68b-4755-a6cc-eb0559cbbd67"],
Cell[1169898, 20864, 284, 8, 21, "Print",ExpressionUUID->"1de45725-2635-4f74-ac28-b2c49ab22238"],
Cell[1170185, 20874, 282, 8, 21, "Print",ExpressionUUID->"613a7bac-369e-403e-b34b-6b0fe19aac87"],
Cell[1170470, 20884, 284, 8, 21, "Print",ExpressionUUID->"0e1cc401-9a12-4ce4-903b-ae13674ac3ea"],
Cell[1170757, 20894, 282, 8, 21, "Print",ExpressionUUID->"ff9b3955-7592-4e88-8bbb-45b0a878cc42"],
Cell[1171042, 20904, 281, 8, 21, "Print",ExpressionUUID->"f8d28d6b-e5c5-4896-8dd2-3a07b9e4e694"],
Cell[1171326, 20914, 282, 8, 21, "Print",ExpressionUUID->"2adfb314-3984-48e1-9f9f-48edc721dfdf"],
Cell[1171611, 20924, 281, 8, 21, "Print",ExpressionUUID->"d8ca3dd9-197a-4348-b8d8-cb3a9102172d"],
Cell[1171895, 20934, 284, 8, 21, "Print",ExpressionUUID->"f7939c38-2bb9-4af8-8e2b-428cfe5201c0"],
Cell[1172182, 20944, 283, 8, 21, "Print",ExpressionUUID->"1c34511c-f9b0-4d74-8386-ff789330f65a"],
Cell[1172468, 20954, 284, 8, 21, "Print",ExpressionUUID->"74e59342-cd00-4298-9c96-8840116f6309"],
Cell[1172755, 20964, 284, 8, 21, "Print",ExpressionUUID->"16e4fb36-4bec-4411-85c8-049c4ea83364"],
Cell[1173042, 20974, 284, 8, 21, "Print",ExpressionUUID->"9e7a2112-05e9-46f5-bdfd-2f6ee3719eb6"],
Cell[1173329, 20984, 284, 8, 21, "Print",ExpressionUUID->"7f60fd2f-0c90-4b51-a117-efcebc0800ce"],
Cell[1173616, 20994, 282, 8, 21, "Print",ExpressionUUID->"8f23e978-ad32-4afc-a66d-591079cc886c"],
Cell[1173901, 21004, 284, 8, 21, "Print",ExpressionUUID->"71888764-d4eb-4322-843e-5bff628c2035"],
Cell[1174188, 21014, 281, 8, 21, "Print",ExpressionUUID->"4381ed52-c29e-44c5-addf-b67acd717f3c"],
Cell[1174472, 21024, 282, 8, 21, "Print",ExpressionUUID->"cbd2f012-7f52-41db-aa70-a5860d52d5fe"],
Cell[1174757, 21034, 284, 8, 21, "Print",ExpressionUUID->"e7f8ddd1-ec60-4bd8-bd82-77e0ba8c53b8"]
}, Open  ]],
Cell[1175056, 21045, 1393804, 24536, 2826, "Output",ExpressionUUID->"2784685e-7587-4764-a0aa-8b2d3f1de8ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2568897, 45586, 738, 19, 26, "Input",ExpressionUUID->"8994e769-a327-411c-ac51-9f0ef2487393"],
Cell[2569638, 45607, 197, 2, 30, "Output",ExpressionUUID->"0fbef0de-0968-415c-a765-f847c3a18da6"]
}, Open  ]],
Cell[2569850, 45612, 4736, 125, 131, "Input",ExpressionUUID->"ec6169ef-330d-4db8-8a72-6a0507e49759"],
Cell[2574589, 45739, 34709, 750, 276, InheritFromParent,ExpressionUUID->"8f3ceb37-4bd1-4367-800f-deecfe3f26d3"],
Cell[CellGroupData[{
Cell[2609323, 46493, 319, 5, 26, "Input",ExpressionUUID->"62eddf83-f7d0-48df-b7ad-f26e5d5747d1"],
Cell[2609645, 46500, 170, 2, 30, "Output",ExpressionUUID->"95321f43-0fa7-4b87-a33e-56d24d95d569"]
}, Open  ]],
Cell[2609830, 46505, 147, 3, 45, "Input",ExpressionUUID->"bed1b3a5-c7f5-4b70-a605-2ff5ca5038c2"],
Cell[CellGroupData[{
Cell[2610002, 46512, 7103, 182, 19665, "Input",ExpressionUUID->"eb6dff20-f013-48b4-b936-0534e08e19fc"],
Cell[2617108, 46696, 3225696, 56544, 576, "Output",ExpressionUUID->"3241282a-7e0e-4ef8-98b5-ea9c09d4c007"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5842841, 103245, 2445, 54, 261, "Input",ExpressionUUID->"56bb20da-0b82-4c74-8f13-48a420e56de6"],
Cell[5845289, 103301, 53589, 1579, 895, "Output",ExpressionUUID->"e92a8a51-aef7-45ae-a882-7f8796d19ee4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5898915, 104885, 1688, 40, 189, "Input",ExpressionUUID->"a7721b20-c2b0-44a7-91c0-0754ac37fbad"],
Cell[5900606, 104927, 3161, 44, 139, "Output",ExpressionUUID->"7d3481d5-e7d6-4dcf-9c44-354664ff18bf"],
Cell[5903770, 104973, 6159, 83, 265, "Output",ExpressionUUID->"fb3ea7ec-3715-486a-892e-6601a84e1982"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5909966, 105061, 819, 15, 63, "Input",ExpressionUUID->"3c38b259-4e51-420e-9b7e-226d4fcb8a36"],
Cell[5910788, 105078, 51530, 1579, 823, "Output",ExpressionUUID->"f08ad3e8-5d66-4e3b-aaf7-a94a66b089b6"],
Cell[5962321, 106659, 25803, 789, 427, "Output",ExpressionUUID->"c42878e0-808d-4895-8478-320494d44bf6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5988161, 107453, 6918, 181, 292, "Input",ExpressionUUID->"d27a5d98-854a-482a-991f-dd1d6dcbc610"],
Cell[5995082, 107636, 104832, 2381, 226, "Output",ExpressionUUID->"cf264f19-d4cc-4ea5-a974-94419a64d4f4"],
Cell[6099917, 110019, 53767, 1223, 226, "Output",ExpressionUUID->"3b06ac14-2001-4dbd-bf0b-30d367efe114"],
Cell[6153687, 111244, 17028, 473, 232, "Output",ExpressionUUID->"f6ee2094-594e-43de-80a1-644ac6a69625"],
Cell[6170718, 111719, 11594, 326, 237, "Output",ExpressionUUID->"002b71e1-6c12-487f-a7e0-461c4c54eb67"],
Cell[6182315, 112047, 209263, 4895, 350, "Output",ExpressionUUID->"ba2eb4ae-8d84-45b4-ba5f-e83169740433"],
Cell[6391581, 116944, 487, 12, 30, "Output",ExpressionUUID->"e736387d-2b7f-4906-91aa-5937694ba5dd"],
Cell[6392071, 116958, 489, 12, 30, "Output",ExpressionUUID->"e0b6b60b-28cb-4f2a-9ac2-d4309c14ec17"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6392597, 116975, 372, 7, 26, InheritFromParent,ExpressionUUID->"36593954-9f8a-4a64-b253-997c5f5a47ce"],
Cell[6392972, 116984, 255, 5, 30, "Output",ExpressionUUID->"c743c705-c956-48f3-99d8-af1f5ac1efb3"]
}, Open  ]],
Cell[6393242, 116992, 3116, 81, 202, "Input",ExpressionUUID->"61df62c3-08fa-41f5-99f0-126a217db2be"],
Cell[CellGroupData[{
Cell[6396383, 117077, 3768, 93, 261, "Input",ExpressionUUID->"7ed9537a-8b3e-41cd-bf96-3d651a9989ea"],
Cell[6400154, 117172, 153, 3, 30, "Output",ExpressionUUID->"9e0ce8dd-aa9b-4ff5-9bb6-99ea3fb0fb57"],
Cell[6400310, 117177, 1121, 25, 30, "Output",ExpressionUUID->"093ccb71-9986-454e-838e-5cf044cee4f0"],
Cell[6401434, 117204, 5436, 165, 103, "Output",ExpressionUUID->"3e5a9efd-4221-43a9-805e-f81a8aad14d3"],
Cell[6406873, 117371, 13062, 397, 229, "Output",ExpressionUUID->"70dac31f-1f40-4bba-be73-a2b5b5a62b4b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6419972, 117773, 6943, 182, 279, "Input",ExpressionUUID->"3ff9fe48-897f-4d83-a08a-bc9336abb07b"],
Cell[6426918, 117957, 5976, 127, 223, "Output",ExpressionUUID->"5c36e638-5062-4d0c-b950-4f130be3a9de"],
Cell[6432897, 118086, 9345, 177, 232, "Output",ExpressionUUID->"4661d315-a298-44e5-8d87-76ac6f478ba3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6442279, 118268, 468, 10, 26, "Input",ExpressionUUID->"b7ca4b57-9a06-4a78-b876-3c2248515445"],
Cell[6442750, 118280, 196, 3, 30, "Output",ExpressionUUID->"4a37a677-5b6d-4998-a48f-a3d86bf89e3f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6442983, 118288, 316, 6, 26, "Input",ExpressionUUID->"f41f0e56-b88d-4c27-a2e0-6585a3079485"],
Cell[6443302, 118296, 221, 2, 30, "Output",ExpressionUUID->"3b59ab2b-8529-43a3-b662-da54f3e69871"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6443560, 118303, 120, 2, 26, "Input",ExpressionUUID->"82ddea65-269e-4126-9394-e6dd2addcdc7"],
Cell[6443683, 118307, 84701, 2134, 1435, "Output",ExpressionUUID->"36ac3045-708e-4203-b623-6c5e4ea531a9"]
}, Open  ]]
}
]
*)

